The Lorenz attractor
====================

This notebook contains a full TDA pipeline to analyse the transitions of
the Lorenz system to a chaotic regime from the stable one and viceversa.

If you are looking at a static version of this notebook and would like
to run its contents, head over to
`GitHub <https://github.com/giotto-ai/giotto-tda/blob/master/examples/lorenz_attractor.ipynb>`__
and download the source.

See also
--------

-  `Topology of time
   series <https://giotto-ai.github.io/gtda-docs/latest/notebooks/topology_time_series.html>`__,
   in which the *Takens embedding* technique used here is explained in
   detail and illustrated via simple examples.
-  `Gravitational waves
   detection <https://giotto-ai.github.io/gtda-docs/latest/notebooks/gravitational_waves_detection.html>`__,
   where,following
   `arXiv:1910.08245 <https://arxiv.org/abs/1910.08245>`__, the Takens
   embedding technique is shown to be effective for the detection of
   gravitational waves signals buried in background noise.
-  `Topological feature extraction using VietorisRipsPersistence and
   PersistenceEntropy <https://giotto-ai.github.io/gtda-docs/latest/notebooks/vietoris_rips_quickstart.html>`__
   for a quick introduction to general topological feature extraction in
   ``giotto-tda``.

**License: AGPLv3**

Import libraries
----------------

The first step consists in importing relevant *gtda* components and
other useful libraries or modules.

.. code:: ipython3

    # Import the gtda modules
    from gtda.time_series import Resampler, SlidingWindow, takens_embedding_optimal_parameters, \
        TakensEmbedding, PermutationEntropy
    from gtda.homology import WeakAlphaPersistence, VietorisRipsPersistence
    from gtda.diagrams import Scaler, Filtering, PersistenceEntropy, BettiCurve, PairwiseDistance
    from gtda.graphs import KNeighborsGraph, GraphGeodesicDistance
    
    from gtda.pipeline import Pipeline
    
    import numpy as np
    from sklearn.metrics import pairwise_distances
    
    import plotly.express as px
    from plotly.offline import init_notebook_mode, iplot
    init_notebook_mode(connected=True)
    
    # gtda plotting functions
    from gtda.plotting import plot_heatmap
    
    # Import data from openml
    import openml



.. raw:: html

    <script type="text/javascript">
    window.PlotlyConfig = {MathJaxConfig: 'local'};
    if (window.MathJax) {MathJax.Hub.Config({SVG: {font: "STIX-Web"}});}
    if (typeof require !== 'undefined') {
    require.undef("plotly");
    requirejs.config({
        paths: {
            'plotly': ['https://cdn.plot.ly/plotly-latest.min']
        }
    });
    require(['plotly'], function(Plotly) {
        window._Plotly = Plotly;
    });
    }
    </script>



.. code:: ipython3

    # Plotting functions
    from gtda.plotting import plot_point_cloud

Setting up the Lorenz attractor simulation
------------------------------------------

In the next block we set up all the parameters of the Lorenz system and
we define also the instants at which the regime (stable VS chaotic)
changes.

.. code:: ipython3

    # Plotting the trajectories of the Lorenz system
    from openml.datasets.functions import get_dataset
    
    point_cloud = get_dataset(42182).get_data(dataset_format='array')[0]
    plot_point_cloud(point_cloud)



.. raw:: html

    <div>                            <div id="335000dc-0b91-4141-aa9c-bf18876eb164" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("335000dc-0b91-4141-aa9c-bf18876eb164")) {                    Plotly.newPlot(                        "335000dc-0b91-4141-aa9c-bf18876eb164",                        [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316, 317, 318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 374, 375, 376, 377, 378, 379, 380, 381, 382, 383, 384, 385, 386, 387, 388, 389, 390, 391, 392, 393, 394, 395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440, 441, 442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452, 453, 454, 455, 456, 457, 458, 459, 460, 461, 462, 463, 464, 465, 466, 467, 468, 469, 470, 471, 472, 473, 474, 475, 476, 477, 478, 479, 480, 481, 482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 543, 544, 545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601, 602, 603, 604, 605, 606, 607, 608, 609, 610, 611, 612, 613, 614, 615, 616, 617, 618, 619, 620, 621, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660, 661, 662, 663, 664, 665, 666, 667, 668, 669, 670, 671, 672, 673, 674, 675, 676, 677, 678, 679, 680, 681, 682, 683, 684, 685, 686, 687, 688, 689, 690, 691, 692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 741, 742, 743, 744, 745, 746, 747, 748, 749, 750, 751, 752, 753, 754, 755, 756, 757, 758, 759, 760, 761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772, 773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820, 821, 822, 823, 824, 825, 826, 827, 828, 829, 830, 831, 832, 833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 843, 844, 845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898, 899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924, 925, 926, 927, 928, 929, 930, 931, 932, 933, 934, 935, 936, 937, 938, 939, 940, 941, 942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 981, 982, 983, 984, 985, 986, 987, 988, 989, 990, 991, 992, 993, 994, 995, 996, 997, 998, 999, 1000, 1001, 1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091, 1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143, 1144, 1145, 1146, 1147, 1148, 1149, 1150, 1151, 1152, 1153, 1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 1190, 1191, 1192, 1193, 1194, 1195, 1196, 1197, 1198, 1199, 1200, 1201, 1202, 1203, 1204, 1205, 1206, 1207, 1208, 1209, 1210, 1211, 1212, 1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221, 1222, 1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243, 1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252, 1253, 1254, 1255, 1256, 1257, 1258, 1259, 1260, 1261, 1262, 1263, 1264, 1265, 1266, 1267, 1268, 1269, 1270, 1271, 1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311, 1312, 1313, 1314, 1315, 1316, 1317, 1318, 1319, 1320, 1321, 1322, 1323, 1324, 1325, 1326, 1327, 1328, 1329, 1330, 1331, 1332, 1333, 1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343, 1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375, 1376, 1377, 1378, 1379, 1380, 1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388, 1389, 1390, 1391, 1392, 1393, 1394, 1395, 1396, 1397, 1398, 1399, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437, 1438, 1439, 1440, 1441, 1442, 1443, 1444, 1445, 1446, 1447, 1448, 1449, 1450, 1451, 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461, 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1515, 1516, 1517, 1518, 1519, 1520, 1521, 1522, 1523, 1524, 1525, 1526, 1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541, 1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573, 1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 1585, 1586, 1587, 1588, 1589, 1590, 1591, 1592, 1593, 1594, 1595, 1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616, 1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626, 1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635, 1636, 1637, 1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 1649, 1650, 1651, 1652, 1653, 1654, 1655, 1656, 1657, 1658, 1659, 1660, 1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668, 1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 1680, 1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695, 1696, 1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705, 1706, 1707, 1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 1719, 1720, 1721, 1722, 1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732, 1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743, 1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762, 1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773, 1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783, 1784, 1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814, 1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835, 1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 1855, 1856, 1857, 1858, 1859, 1860, 1861, 1862, 1863, 1864, 1865, 1866, 1867, 1868, 1869, 1870, 1871, 1872, 1873, 1874, 1875, 1876, 1877, 1878, 1879, 1880, 1881, 1882, 1883, 1884, 1885, 1886, 1887, 1888, 1889, 1890, 1891, 1892, 1893, 1894, 1895, 1896, 1897, 1898, 1899, 1900, 1901, 1902, 1903, 1904, 1905, 1906, 1907, 1908, 1909, 1910, 1911, 1912, 1913, 1914, 1915, 1916, 1917, 1918, 1919, 1920, 1921, 1922, 1923, 1924, 1925, 1926, 1927, 1928, 1929, 1930, 1931, 1932, 1933, 1934, 1935, 1936, 1937, 1938, 1939, 1940, 1941, 1942, 1943, 1944, 1945, 1946, 1947, 1948, 1949, 1950, 1951, 1952, 1953, 1954, 1955, 1956, 1957, 1958, 1959, 1960, 1961, 1962, 1963, 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972, 1973, 1974, 1975, 1976, 1977, 1978, 1979, 1980, 1981, 1982, 1983, 1984, 1985, 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025, 2026, 2027, 2028, 2029, 2030, 2031, 2032, 2033, 2034, 2035, 2036, 2037, 2038, 2039, 2040, 2041, 2042, 2043, 2044, 2045, 2046, 2047, 2048, 2049, 2050, 2051, 2052, 2053, 2054, 2055, 2056, 2057, 2058, 2059, 2060, 2061, 2062, 2063, 2064, 2065, 2066, 2067, 2068, 2069, 2070, 2071, 2072, 2073, 2074, 2075, 2076, 2077, 2078, 2079, 2080, 2081, 2082, 2083, 2084, 2085, 2086, 2087, 2088, 2089, 2090, 2091, 2092, 2093, 2094, 2095, 2096, 2097, 2098, 2099, 2100, 2101, 2102, 2103, 2104, 2105, 2106, 2107, 2108, 2109, 2110, 2111, 2112, 2113, 2114, 2115, 2116, 2117, 2118, 2119, 2120, 2121, 2122, 2123, 2124, 2125, 2126, 2127, 2128, 2129, 2130, 2131, 2132, 2133, 2134, 2135, 2136, 2137, 2138, 2139, 2140, 2141, 2142, 2143, 2144, 2145, 2146, 2147, 2148, 2149, 2150, 2151, 2152, 2153, 2154, 2155, 2156, 2157, 2158, 2159, 2160, 2161, 2162, 2163, 2164, 2165, 2166, 2167, 2168, 2169, 2170, 2171, 2172, 2173, 2174, 2175, 2176, 2177, 2178, 2179, 2180, 2181, 2182, 2183, 2184, 2185, 2186, 2187, 2188, 2189, 2190, 2191, 2192, 2193, 2194, 2195, 2196, 2197, 2198, 2199, 2200, 2201, 2202, 2203, 2204, 2205, 2206, 2207, 2208, 2209, 2210, 2211, 2212, 2213, 2214, 2215, 2216, 2217, 2218, 2219, 2220, 2221, 2222, 2223, 2224, 2225, 2226, 2227, 2228, 2229, 2230, 2231, 2232, 2233, 2234, 2235, 2236, 2237, 2238, 2239, 2240, 2241, 2242, 2243, 2244, 2245, 2246, 2247, 2248, 2249, 2250, 2251, 2252, 2253, 2254, 2255, 2256, 2257, 2258, 2259, 2260, 2261, 2262, 2263, 2264, 2265, 2266, 2267, 2268, 2269, 2270, 2271, 2272, 2273, 2274, 2275, 2276, 2277, 2278, 2279, 2280, 2281, 2282, 2283, 2284, 2285, 2286, 2287, 2288, 2289, 2290, 2291, 2292, 2293, 2294, 2295, 2296, 2297, 2298, 2299, 2300, 2301, 2302, 2303, 2304, 2305, 2306, 2307, 2308, 2309, 2310, 2311, 2312, 2313, 2314, 2315, 2316, 2317, 2318, 2319, 2320, 2321, 2322, 2323, 2324, 2325, 2326, 2327, 2328, 2329, 2330, 2331, 2332, 2333, 2334, 2335, 2336, 2337, 2338, 2339, 2340, 2341, 2342, 2343, 2344, 2345, 2346, 2347, 2348, 2349, 2350, 2351, 2352, 2353, 2354, 2355, 2356, 2357, 2358, 2359, 2360, 2361, 2362, 2363, 2364, 2365, 2366, 2367, 2368, 2369, 2370, 2371, 2372, 2373, 2374, 2375, 2376, 2377, 2378, 2379, 2380, 2381, 2382, 2383, 2384, 2385, 2386, 2387, 2388, 2389, 2390, 2391, 2392, 2393, 2394, 2395, 2396, 2397, 2398, 2399, 2400, 2401, 2402, 2403, 2404, 2405, 2406, 2407, 2408, 2409, 2410, 2411, 2412, 2413, 2414, 2415, 2416, 2417, 2418, 2419, 2420, 2421, 2422, 2423, 2424, 2425, 2426, 2427, 2428, 2429, 2430, 2431, 2432, 2433, 2434, 2435, 2436, 2437, 2438, 2439, 2440, 2441, 2442, 2443, 2444, 2445, 2446, 2447, 2448, 2449, 2450, 2451, 2452, 2453, 2454, 2455, 2456, 2457, 2458, 2459, 2460, 2461, 2462, 2463, 2464, 2465, 2466, 2467, 2468, 2469, 2470, 2471, 2472, 2473, 2474, 2475, 2476, 2477, 2478, 2479, 2480, 2481, 2482, 2483, 2484, 2485, 2486, 2487, 2488, 2489, 2490, 2491, 2492, 2493, 2494, 2495, 2496, 2497, 2498, 2499, 2500, 2501, 2502, 2503, 2504, 2505, 2506, 2507, 2508, 2509, 2510, 2511, 2512, 2513, 2514, 2515, 2516, 2517, 2518, 2519, 2520, 2521, 2522, 2523, 2524, 2525, 2526, 2527, 2528, 2529, 2530, 2531, 2532, 2533, 2534, 2535, 2536, 2537, 2538, 2539, 2540, 2541, 2542, 2543, 2544, 2545, 2546, 2547, 2548, 2549, 2550, 2551, 2552, 2553, 2554, 2555, 2556, 2557, 2558, 2559, 2560, 2561, 2562, 2563, 2564, 2565, 2566, 2567, 2568, 2569, 2570, 2571, 2572, 2573, 2574, 2575, 2576, 2577, 2578, 2579, 2580, 2581, 2582, 2583, 2584, 2585, 2586, 2587, 2588, 2589, 2590, 2591, 2592, 2593, 2594, 2595, 2596, 2597, 2598, 2599, 2600, 2601, 2602, 2603, 2604, 2605, 2606, 2607, 2608, 2609, 2610, 2611, 2612, 2613, 2614, 2615, 2616, 2617, 2618, 2619, 2620, 2621, 2622, 2623, 2624, 2625, 2626, 2627, 2628, 2629, 2630, 2631, 2632, 2633, 2634, 2635, 2636, 2637, 2638, 2639, 2640, 2641, 2642, 2643, 2644, 2645, 2646, 2647, 2648, 2649, 2650, 2651, 2652, 2653, 2654, 2655, 2656, 2657, 2658, 2659, 2660, 2661, 2662, 2663, 2664, 2665, 2666, 2667, 2668, 2669, 2670, 2671, 2672, 2673, 2674, 2675, 2676, 2677, 2678, 2679, 2680, 2681, 2682, 2683, 2684, 2685, 2686, 2687, 2688, 2689, 2690, 2691, 2692, 2693, 2694, 2695, 2696, 2697, 2698, 2699, 2700, 2701, 2702, 2703, 2704, 2705, 2706, 2707, 2708, 2709, 2710, 2711, 2712, 2713, 2714, 2715, 2716, 2717, 2718, 2719, 2720, 2721, 2722, 2723, 2724, 2725, 2726, 2727, 2728, 2729, 2730, 2731, 2732, 2733, 2734, 2735, 2736, 2737, 2738, 2739, 2740, 2741, 2742, 2743, 2744, 2745, 2746, 2747, 2748, 2749, 2750, 2751, 2752, 2753, 2754, 2755, 2756, 2757, 2758, 2759, 2760, 2761, 2762, 2763, 2764, 2765, 2766, 2767, 2768, 2769, 2770, 2771, 2772, 2773, 2774, 2775, 2776, 2777, 2778, 2779, 2780, 2781, 2782, 2783, 2784, 2785, 2786, 2787, 2788, 2789, 2790, 2791, 2792, 2793, 2794, 2795, 2796, 2797, 2798, 2799, 2800, 2801, 2802, 2803, 2804, 2805, 2806, 2807, 2808, 2809, 2810, 2811, 2812, 2813, 2814, 2815, 2816, 2817, 2818, 2819, 2820, 2821, 2822, 2823, 2824, 2825, 2826, 2827, 2828, 2829, 2830, 2831, 2832, 2833, 2834, 2835, 2836, 2837, 2838, 2839, 2840, 2841, 2842, 2843, 2844, 2845, 2846, 2847, 2848, 2849, 2850, 2851, 2852, 2853, 2854, 2855, 2856, 2857, 2858, 2859, 2860, 2861, 2862, 2863, 2864, 2865, 2866, 2867, 2868, 2869, 2870, 2871, 2872, 2873, 2874, 2875, 2876, 2877, 2878, 2879, 2880, 2881, 2882, 2883, 2884, 2885, 2886, 2887, 2888, 2889, 2890, 2891, 2892, 2893, 2894, 2895, 2896, 2897, 2898, 2899, 2900, 2901, 2902, 2903, 2904, 2905, 2906, 2907, 2908, 2909, 2910, 2911, 2912, 2913, 2914, 2915, 2916, 2917, 2918, 2919, 2920, 2921, 2922, 2923, 2924, 2925, 2926, 2927, 2928, 2929, 2930, 2931, 2932, 2933, 2934, 2935, 2936, 2937, 2938, 2939, 2940, 2941, 2942, 2943, 2944, 2945, 2946, 2947, 2948, 2949, 2950, 2951, 2952, 2953, 2954, 2955, 2956, 2957, 2958, 2959, 2960, 2961, 2962, 2963, 2964, 2965, 2966, 2967, 2968, 2969, 2970, 2971, 2972, 2973, 2974, 2975, 2976, 2977, 2978, 2979, 2980, 2981, 2982, 2983, 2984, 2985, 2986, 2987, 2988, 2989, 2990, 2991, 2992, 2993, 2994, 2995, 2996, 2997, 2998, 2999, 3000, 3001, 3002, 3003, 3004, 3005, 3006, 3007, 3008, 3009, 3010, 3011, 3012, 3013, 3014, 3015, 3016, 3017, 3018, 3019, 3020, 3021, 3022, 3023, 3024, 3025, 3026, 3027, 3028, 3029, 3030, 3031, 3032, 3033, 3034, 3035, 3036, 3037, 3038, 3039, 3040, 3041, 3042, 3043, 3044, 3045, 3046, 3047, 3048, 3049, 3050, 3051, 3052, 3053, 3054, 3055, 3056, 3057, 3058, 3059, 3060, 3061, 3062, 3063, 3064, 3065, 3066, 3067, 3068, 3069, 3070, 3071, 3072, 3073, 3074, 3075, 3076, 3077, 3078, 3079, 3080, 3081, 3082, 3083, 3084, 3085, 3086, 3087, 3088, 3089, 3090, 3091, 3092, 3093, 3094, 3095, 3096, 3097, 3098, 3099, 3100, 3101, 3102, 3103, 3104, 3105, 3106, 3107, 3108, 3109, 3110, 3111, 3112, 3113, 3114, 3115, 3116, 3117, 3118, 3119, 3120, 3121, 3122, 3123, 3124, 3125, 3126, 3127, 3128, 3129, 3130, 3131, 3132, 3133, 3134, 3135, 3136, 3137, 3138, 3139, 3140, 3141, 3142, 3143, 3144, 3145, 3146, 3147, 3148, 3149, 3150, 3151, 3152, 3153, 3154, 3155, 3156, 3157, 3158, 3159, 3160, 3161, 3162, 3163, 3164, 3165, 3166, 3167, 3168, 3169, 3170, 3171, 3172, 3173, 3174, 3175, 3176, 3177, 3178, 3179, 3180, 3181, 3182, 3183, 3184, 3185, 3186, 3187, 3188, 3189, 3190, 3191, 3192, 3193, 3194, 3195, 3196, 3197, 3198, 3199, 3200, 3201, 3202, 3203, 3204, 3205, 3206, 3207, 3208, 3209, 3210, 3211, 3212, 3213, 3214, 3215, 3216, 3217, 3218, 3219, 3220, 3221, 3222, 3223, 3224, 3225, 3226, 3227, 3228, 3229, 3230, 3231, 3232, 3233, 3234, 3235, 3236, 3237, 3238, 3239, 3240, 3241, 3242, 3243, 3244, 3245, 3246, 3247, 3248, 3249, 3250, 3251, 3252, 3253, 3254, 3255, 3256, 3257, 3258, 3259, 3260, 3261, 3262, 3263, 3264, 3265, 3266, 3267, 3268, 3269, 3270, 3271, 3272, 3273, 3274, 3275, 3276, 3277, 3278, 3279, 3280, 3281, 3282, 3283, 3284, 3285, 3286, 3287, 3288, 3289, 3290, 3291, 3292, 3293, 3294, 3295, 3296, 3297, 3298, 3299, 3300, 3301, 3302, 3303, 3304, 3305, 3306, 3307, 3308, 3309, 3310, 3311, 3312, 3313, 3314, 3315, 3316, 3317, 3318, 3319, 3320, 3321, 3322, 3323, 3324, 3325, 3326, 3327, 3328, 3329, 3330, 3331, 3332, 3333, 3334, 3335, 3336, 3337, 3338, 3339, 3340, 3341, 3342, 3343, 3344, 3345, 3346, 3347, 3348, 3349, 3350, 3351, 3352, 3353, 3354, 3355, 3356, 3357, 3358, 3359, 3360, 3361, 3362, 3363, 3364, 3365, 3366, 3367, 3368, 3369, 3370, 3371, 3372, 3373, 3374, 3375, 3376, 3377, 3378, 3379, 3380, 3381, 3382, 3383, 3384, 3385, 3386, 3387, 3388, 3389, 3390, 3391, 3392, 3393, 3394, 3395, 3396, 3397, 3398, 3399, 3400, 3401, 3402, 3403, 3404, 3405, 3406, 3407, 3408, 3409, 3410, 3411, 3412, 3413, 3414, 3415, 3416, 3417, 3418, 3419, 3420, 3421, 3422, 3423, 3424, 3425, 3426, 3427, 3428, 3429, 3430, 3431, 3432, 3433, 3434, 3435, 3436, 3437, 3438, 3439, 3440, 3441, 3442, 3443, 3444, 3445, 3446, 3447, 3448, 3449, 3450, 3451, 3452, 3453, 3454, 3455, 3456, 3457, 3458, 3459, 3460, 3461, 3462, 3463, 3464, 3465, 3466, 3467, 3468, 3469, 3470, 3471, 3472, 3473, 3474, 3475, 3476, 3477, 3478, 3479, 3480, 3481, 3482, 3483, 3484, 3485, 3486, 3487, 3488, 3489, 3490, 3491, 3492, 3493, 3494, 3495, 3496, 3497, 3498, 3499, 3500, 3501, 3502, 3503, 3504, 3505, 3506, 3507, 3508, 3509, 3510, 3511, 3512, 3513, 3514, 3515, 3516, 3517, 3518, 3519, 3520, 3521, 3522, 3523, 3524, 3525, 3526, 3527, 3528, 3529, 3530, 3531, 3532, 3533, 3534, 3535, 3536, 3537, 3538, 3539, 3540, 3541, 3542, 3543, 3544, 3545, 3546, 3547, 3548, 3549, 3550, 3551, 3552, 3553, 3554, 3555, 3556, 3557, 3558, 3559, 3560, 3561, 3562, 3563, 3564, 3565, 3566, 3567, 3568, 3569, 3570, 3571, 3572, 3573, 3574, 3575, 3576, 3577, 3578, 3579, 3580, 3581, 3582, 3583, 3584, 3585, 3586, 3587, 3588, 3589, 3590, 3591, 3592, 3593, 3594, 3595, 3596, 3597, 3598, 3599, 3600, 3601, 3602, 3603, 3604, 3605, 3606, 3607, 3608, 3609, 3610, 3611, 3612, 3613, 3614, 3615, 3616, 3617, 3618, 3619, 3620, 3621, 3622, 3623, 3624, 3625, 3626, 3627, 3628, 3629, 3630, 3631, 3632, 3633, 3634, 3635, 3636, 3637, 3638, 3639, 3640, 3641, 3642, 3643, 3644, 3645, 3646, 3647, 3648, 3649, 3650, 3651, 3652, 3653, 3654, 3655, 3656, 3657, 3658, 3659, 3660, 3661, 3662, 3663, 3664, 3665, 3666, 3667, 3668, 3669, 3670, 3671, 3672, 3673, 3674, 3675, 3676, 3677, 3678, 3679, 3680, 3681, 3682, 3683, 3684, 3685, 3686, 3687, 3688, 3689, 3690, 3691, 3692, 3693, 3694, 3695, 3696, 3697, 3698, 3699, 3700, 3701, 3702, 3703, 3704, 3705, 3706, 3707, 3708, 3709, 3710, 3711, 3712, 3713, 3714, 3715, 3716, 3717, 3718, 3719, 3720, 3721, 3722, 3723, 3724, 3725, 3726, 3727, 3728, 3729, 3730, 3731, 3732, 3733, 3734, 3735, 3736, 3737, 3738, 3739, 3740, 3741, 3742, 3743, 3744, 3745, 3746, 3747, 3748, 3749, 3750, 3751, 3752, 3753, 3754, 3755, 3756, 3757, 3758, 3759, 3760, 3761, 3762, 3763, 3764, 3765, 3766, 3767, 3768, 3769, 3770, 3771, 3772, 3773, 3774, 3775, 3776, 3777, 3778, 3779, 3780, 3781, 3782, 3783, 3784, 3785, 3786, 3787, 3788, 3789, 3790, 3791, 3792, 3793, 3794, 3795, 3796, 3797, 3798, 3799, 3800, 3801, 3802, 3803, 3804, 3805, 3806, 3807, 3808, 3809, 3810, 3811, 3812, 3813, 3814, 3815, 3816, 3817, 3818, 3819, 3820, 3821, 3822, 3823, 3824, 3825, 3826, 3827, 3828, 3829, 3830, 3831, 3832, 3833, 3834, 3835, 3836, 3837, 3838, 3839, 3840, 3841, 3842, 3843, 3844, 3845, 3846, 3847, 3848, 3849, 3850, 3851, 3852, 3853, 3854, 3855, 3856, 3857, 3858, 3859, 3860, 3861, 3862, 3863, 3864, 3865, 3866, 3867, 3868, 3869, 3870, 3871, 3872, 3873, 3874, 3875, 3876, 3877, 3878, 3879, 3880, 3881, 3882, 3883, 3884, 3885, 3886, 3887, 3888, 3889, 3890, 3891, 3892, 3893, 3894, 3895, 3896, 3897, 3898, 3899, 3900, 3901, 3902, 3903, 3904, 3905, 3906, 3907, 3908, 3909, 3910, 3911, 3912, 3913, 3914, 3915, 3916, 3917, 3918, 3919, 3920, 3921, 3922, 3923, 3924, 3925, 3926, 3927, 3928, 3929, 3930, 3931, 3932, 3933, 3934, 3935, 3936, 3937, 3938, 3939, 3940, 3941, 3942, 3943, 3944, 3945, 3946, 3947, 3948, 3949, 3950, 3951, 3952, 3953, 3954, 3955, 3956, 3957, 3958, 3959, 3960, 3961, 3962, 3963, 3964, 3965, 3966, 3967, 3968, 3969, 3970, 3971, 3972, 3973, 3974, 3975, 3976, 3977, 3978, 3979, 3980, 3981, 3982, 3983, 3984, 3985, 3986, 3987, 3988, 3989, 3990, 3991, 3992, 3993, 3994, 3995, 3996, 3997, 3998, 3999, 4000, 4001, 4002, 4003, 4004, 4005, 4006, 4007, 4008, 4009, 4010, 4011, 4012, 4013, 4014, 4015, 4016, 4017, 4018, 4019, 4020, 4021, 4022, 4023, 4024, 4025, 4026, 4027, 4028, 4029, 4030, 4031, 4032, 4033, 4034, 4035, 4036, 4037, 4038, 4039, 4040, 4041, 4042, 4043, 4044, 4045, 4046, 4047, 4048, 4049, 4050, 4051, 4052, 4053, 4054, 4055, 4056, 4057, 4058, 4059, 4060, 4061, 4062, 4063, 4064, 4065, 4066, 4067, 4068, 4069, 4070, 4071, 4072, 4073, 4074, 4075, 4076, 4077, 4078, 4079, 4080, 4081, 4082, 4083, 4084, 4085, 4086, 4087, 4088, 4089, 4090, 4091, 4092, 4093, 4094, 4095, 4096, 4097, 4098, 4099, 4100, 4101, 4102, 4103, 4104, 4105, 4106, 4107, 4108, 4109, 4110, 4111, 4112, 4113, 4114, 4115, 4116, 4117, 4118, 4119, 4120, 4121, 4122, 4123, 4124, 4125, 4126, 4127, 4128, 4129, 4130, 4131, 4132, 4133, 4134, 4135, 4136, 4137, 4138, 4139, 4140, 4141, 4142, 4143, 4144, 4145, 4146, 4147, 4148, 4149, 4150, 4151, 4152, 4153, 4154, 4155, 4156, 4157, 4158, 4159, 4160, 4161, 4162, 4163, 4164, 4165, 4166, 4167, 4168, 4169, 4170, 4171, 4172, 4173, 4174, 4175, 4176, 4177, 4178, 4179, 4180, 4181, 4182, 4183, 4184, 4185, 4186, 4187, 4188, 4189, 4190, 4191, 4192, 4193, 4194, 4195, 4196, 4197, 4198, 4199, 4200, 4201, 4202, 4203, 4204, 4205, 4206, 4207, 4208, 4209, 4210, 4211, 4212, 4213, 4214, 4215, 4216, 4217, 4218, 4219, 4220, 4221, 4222, 4223, 4224, 4225, 4226, 4227, 4228, 4229, 4230, 4231, 4232, 4233, 4234, 4235, 4236, 4237, 4238, 4239, 4240, 4241, 4242, 4243, 4244, 4245, 4246, 4247, 4248, 4249, 4250, 4251, 4252, 4253, 4254, 4255, 4256, 4257, 4258, 4259, 4260, 4261, 4262, 4263, 4264, 4265, 4266, 4267, 4268, 4269, 4270, 4271, 4272, 4273, 4274, 4275, 4276, 4277, 4278, 4279, 4280, 4281, 4282, 4283, 4284, 4285, 4286, 4287, 4288, 4289, 4290, 4291, 4292, 4293, 4294, 4295, 4296, 4297, 4298, 4299, 4300, 4301, 4302, 4303, 4304, 4305, 4306, 4307, 4308, 4309, 4310, 4311, 4312, 4313, 4314, 4315, 4316, 4317, 4318, 4319, 4320, 4321, 4322, 4323, 4324, 4325, 4326, 4327, 4328, 4329, 4330, 4331, 4332, 4333, 4334, 4335, 4336, 4337, 4338, 4339, 4340, 4341, 4342, 4343, 4344, 4345, 4346, 4347, 4348, 4349, 4350, 4351, 4352, 4353, 4354, 4355, 4356, 4357, 4358, 4359, 4360, 4361, 4362, 4363, 4364, 4365, 4366, 4367, 4368, 4369, 4370, 4371, 4372, 4373, 4374, 4375, 4376, 4377, 4378, 4379, 4380, 4381, 4382, 4383, 4384, 4385, 4386, 4387, 4388, 4389, 4390, 4391, 4392, 4393, 4394, 4395, 4396, 4397, 4398, 4399, 4400, 4401, 4402, 4403, 4404, 4405, 4406, 4407, 4408, 4409, 4410, 4411, 4412, 4413, 4414, 4415, 4416, 4417, 4418, 4419, 4420, 4421, 4422, 4423, 4424, 4425, 4426, 4427, 4428, 4429, 4430, 4431, 4432, 4433, 4434, 4435, 4436, 4437, 4438, 4439, 4440, 4441, 4442, 4443, 4444, 4445, 4446, 4447, 4448, 4449, 4450, 4451, 4452, 4453, 4454, 4455, 4456, 4457, 4458, 4459, 4460, 4461, 4462, 4463, 4464, 4465, 4466, 4467, 4468, 4469, 4470, 4471, 4472, 4473, 4474, 4475, 4476, 4477, 4478, 4479, 4480, 4481, 4482, 4483, 4484, 4485, 4486, 4487, 4488, 4489, 4490, 4491, 4492, 4493, 4494, 4495, 4496, 4497, 4498, 4499, 4500, 4501, 4502, 4503, 4504, 4505, 4506, 4507, 4508, 4509, 4510, 4511, 4512, 4513, 4514, 4515, 4516, 4517, 4518, 4519, 4520, 4521, 4522, 4523, 4524, 4525, 4526, 4527, 4528, 4529, 4530, 4531, 4532, 4533, 4534, 4535, 4536, 4537, 4538, 4539, 4540, 4541, 4542, 4543, 4544, 4545, 4546, 4547, 4548, 4549, 4550, 4551, 4552, 4553, 4554, 4555, 4556, 4557, 4558, 4559, 4560, 4561, 4562, 4563, 4564, 4565, 4566, 4567, 4568, 4569, 4570, 4571, 4572, 4573, 4574, 4575, 4576, 4577, 4578, 4579, 4580, 4581, 4582, 4583, 4584, 4585, 4586, 4587, 4588, 4589, 4590, 4591, 4592, 4593, 4594, 4595, 4596, 4597, 4598, 4599, 4600, 4601, 4602, 4603, 4604, 4605, 4606, 4607, 4608, 4609, 4610, 4611, 4612, 4613, 4614, 4615, 4616, 4617, 4618, 4619, 4620, 4621, 4622, 4623, 4624, 4625, 4626, 4627, 4628, 4629, 4630, 4631, 4632, 4633, 4634, 4635, 4636, 4637, 4638, 4639, 4640, 4641, 4642, 4643, 4644, 4645, 4646, 4647, 4648, 4649, 4650, 4651, 4652, 4653, 4654, 4655, 4656, 4657, 4658, 4659, 4660, 4661, 4662, 4663, 4664, 4665, 4666, 4667, 4668, 4669, 4670, 4671, 4672, 4673, 4674, 4675, 4676, 4677, 4678, 4679, 4680, 4681, 4682, 4683, 4684, 4685, 4686, 4687, 4688, 4689, 4690, 4691, 4692, 4693, 4694, 4695, 4696, 4697, 4698, 4699, 4700, 4701, 4702, 4703, 4704, 4705, 4706, 4707, 4708, 4709, 4710, 4711, 4712, 4713, 4714, 4715, 4716, 4717, 4718, 4719, 4720, 4721, 4722, 4723, 4724, 4725, 4726, 4727, 4728, 4729, 4730, 4731, 4732, 4733, 4734, 4735, 4736, 4737, 4738, 4739, 4740, 4741, 4742, 4743, 4744, 4745, 4746, 4747, 4748, 4749, 4750, 4751, 4752, 4753, 4754, 4755, 4756, 4757, 4758, 4759, 4760, 4761, 4762, 4763, 4764, 4765, 4766, 4767, 4768, 4769, 4770, 4771, 4772, 4773, 4774, 4775, 4776, 4777, 4778, 4779, 4780, 4781, 4782, 4783, 4784, 4785, 4786, 4787, 4788, 4789, 4790, 4791, 4792, 4793, 4794, 4795, 4796, 4797, 4798, 4799, 4800, 4801, 4802, 4803, 4804, 4805, 4806, 4807, 4808, 4809, 4810, 4811, 4812, 4813, 4814, 4815, 4816, 4817, 4818, 4819, 4820, 4821, 4822, 4823, 4824, 4825, 4826, 4827, 4828, 4829, 4830, 4831, 4832, 4833, 4834, 4835, 4836, 4837, 4838, 4839, 4840, 4841, 4842, 4843, 4844, 4845, 4846, 4847, 4848, 4849, 4850, 4851, 4852, 4853, 4854, 4855, 4856, 4857, 4858, 4859, 4860, 4861, 4862, 4863, 4864, 4865, 4866, 4867, 4868, 4869, 4870, 4871, 4872, 4873, 4874, 4875, 4876, 4877, 4878, 4879, 4880, 4881, 4882, 4883, 4884, 4885, 4886, 4887, 4888, 4889, 4890, 4891, 4892, 4893, 4894, 4895, 4896, 4897, 4898, 4899, 4900, 4901, 4902, 4903, 4904, 4905, 4906, 4907, 4908, 4909, 4910, 4911, 4912, 4913, 4914, 4915, 4916, 4917, 4918, 4919, 4920, 4921, 4922, 4923, 4924, 4925, 4926, 4927, 4928, 4929, 4930, 4931, 4932, 4933, 4934, 4935, 4936, 4937, 4938, 4939, 4940, 4941], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [1.0, -0.10000000149011612, -1.0850000381469727, -1.961086630821228, -2.734959602355957, -3.4134247303009033, -4.003073215484619, -4.510103702545166, -4.940247058868408, -5.298763275146484, -5.590487003326416, -5.819896221160889, -5.991193771362305, -6.108391761779785, -6.1753830909729, -6.196005344390869, -6.1740851402282715, -6.113463878631592, -6.018008232116699, -5.891604900360107, -5.7381367683410645, -5.561453819274902, -5.365334510803223, -5.153444766998291, -4.929294586181641, -4.696200370788574, -4.457251071929932, -4.215278625488281, -3.972842216491699, -3.7322123050689697, -3.4953689575195312, -3.264003276824951, -3.039527416229248, -2.823087453842163, -2.615581750869751, -2.4176812171936035, -2.229851245880127, -2.052375078201294, -1.885377287864685, -1.7288448810577393, -1.5826497077941895, -1.446568489074707, -1.3203002214431763, -1.2034839391708374, -1.095712423324585, -0.9965459108352661, -0.9055230021476746, -0.8221703767776489, -0.7460107207298279, -0.6765697002410889, -0.6133813261985779, -0.5559921860694885, -0.5039650201797485, -0.4568811058998108, -0.41434216499328613, -0.3759714961051941, -0.3414146602153778, -0.31033968925476074, -0.28243711590766907, -0.2574193477630615, -0.23502019047737122, -0.2149941325187683, -0.19711527228355408, -0.18117642402648926, -0.1669880896806717, -0.1543772965669632, -0.14318659901618958, -0.1332729309797287, -0.12450660765171051, -0.11677029728889465, -0.1099579930305481, -0.10397415608167648, -0.09873276948928833, -0.09415653347969055, -0.09017610549926758, -0.08672935515642166, -0.08376068621873856, -0.08122044056653976, -0.07906430214643478, -0.0772528126835823, -0.07575084269046783, -0.07452717423439026, -0.07355412095785141, -0.07280714809894562, -0.07226452976465225, -0.07190709561109543, -0.07171791791915894, -0.07168209552764893, -0.0717865377664566, -0.07201974093914032, -0.07237885147333145, -0.07286151498556137, -0.07346592843532562, -0.07419081777334213, -0.07503540068864822, -0.0759994387626648, -0.07708317786455154, -0.07828737795352936, -0.07961329072713852, -0.0810626670718193, -0.08263776451349258, -0.08434130996465683, -0.0861765667796135, -0.08814728260040283, -0.09025771915912628, -0.09251268208026886, -0.09491749107837677, -0.09747803956270218, -0.10020077973604202, -0.10309276729822159, -0.10616166144609451, -0.10941577702760696, -0.11286410689353943, -0.11651633679866791, -0.12038290500640869, -0.12447503954172134, -0.12880480289459229, -0.13338513672351837, -0.13822990655899048, -0.14335396885871887, -0.14877328276634216, -0.15450486540794373, -0.16056697070598602, -0.16697914898395538, -0.1737622767686844, -0.1809387356042862, -0.18853244185447693, -0.19656899571418762, -0.20507580041885376, -0.21408215165138245, -0.22361944615840912, -0.23372125625610352, -0.24442355334758759, -0.25576481223106384, -0.26778626441955566, -0.2805320918560028, -0.29404959082603455, -0.30838942527770996, -0.3236059844493866, -0.33975744247436523, -0.35690629482269287, -0.37511950731277466, -0.39446887373924255, -0.4150314927101135, -0.4368900656700134, -0.46013328433036804, -0.4848564565181732, -0.5111618638038635, -0.5391592979431152, -0.568966805934906, -0.600710928440094, -0.6345279216766357, -0.6705639958381653, -0.708976149559021, -0.7499332427978516, -0.7936167120933533, -0.8402214646339417, -0.8899568915367126, -0.9430480003356934, -0.9997365474700928, -1.0602821111679077, -1.124963402748108, -1.1940797567367554, -1.2679523229599, -1.346925139427185, -1.4313675165176392, -1.5216747522354126, -1.6182695627212524, -1.7216041088104248, -1.8321610689163208, -1.950454831123352, -2.0770325660705566, -2.212475299835205, -2.357398271560669, -2.512451410293579, -2.6783175468444824, -2.8557121753692627, -3.0453810691833496, -3.2480947971343994, -3.4646456241607666, -3.6958377361297607, -3.942478656768799, -4.20536470413208, -4.485264301300049, -4.782896041870117, -5.09890079498291, -5.433807849884033, -5.787993907928467, -6.1616315841674805, -6.554630279541016, -6.965951442718506, -7.394130229949951, -7.837179183959961, -8.292485237121582, -8.75670337677002, -9.22566032409668, -9.694263458251953, -10.156438827514648, -10.605095863342285, -11.032155990600586, -11.428635597229004, -11.784817695617676, -12.090520858764648, -12.335466384887695, -12.509742736816406, -12.604347229003906, -12.611770629882812, -12.526573181152344, -12.345894813537598, -12.069820404052734, -11.701566696166992, -11.247432708740234, -10.716509819030762, -10.120189666748047, -9.36433219909668, -8.481619834899902, -7.506406307220459, -6.472689151763916, -5.412297248840332, -4.353507995605469, -3.3201944828033447, -2.3314952850341797, -1.4019087553024292, -0.5416853427886963, 0.24261239171028137, 0.9474887251853943, 1.571908712387085, 2.1167526245117188, 2.584351062774658, 2.978104591369629, 3.3021817207336426, 3.5612807273864746, 3.7604453563690186, 3.9049198627471924, 4.000033855438232, 4.0511088371276855, 4.063381195068359, 4.041934490203857, 3.9916489124298096, 3.917149782180786, 3.8227744102478027, 3.712541103363037, 3.5901291370391846, 3.458867311477661, 3.321727752685547, 3.181330680847168, 3.0399529933929443, 2.8995418548583984, 2.7617361545562744, 2.6278867721557617, 2.49908185005188, 2.376173734664917, 2.259803533554077, 2.1504292488098145, 2.048349618911743, 1.9537289142608643, 1.8666188716888428, 1.7869793176651, 1.7146967649459839, 1.6496009826660156, 1.5914793014526367, 1.540089726448059, 1.4951714277267456, 1.4564539194107056, 1.4236650466918945, 1.3965370655059814, 1.374812126159668, 1.358245611190796, 1.3466103076934814, 1.339698076248169, 1.3373219966888428, 1.3393173217773438, 1.3455426692962646, 1.3558801412582397, 1.3702356815338135, 1.38853919506073, 1.410744071006775, 1.436827301979065, 1.4667892456054688, 1.5006530284881592, 1.5384641885757446, 1.5802909135818481, 1.6262235641479492, 1.676374077796936, 1.7308766841888428, 1.7898868322372437, 1.8535821437835693, 1.92216157913208, 1.995846152305603, 2.074878692626953, 2.1595234870910645, 2.2500672340393066, 2.346818208694458, 2.450106143951416, 2.5602827072143555, 2.677719831466675, 2.802809476852417, 2.9359629154205322, 3.077608108520508, 3.2281877994537354, 3.388157367706299, 3.5579798221588135, 3.738121509552002, 3.9290459156036377, 4.1312055587768555, 4.345033168792725, 4.570930004119873, 4.809250354766846, 5.060286521911621, 5.32424783706665, 5.601238250732422, 5.891226768493652, 6.1940178871154785, 6.509216785430908, 6.836185932159424, 7.173355579376221, 7.518829345703125, 7.870335578918457, 8.225174903869629, 8.580181121826172, 8.931689262390137, 9.275522232055664, 9.607000350952148, 9.920970916748047, 10.211881637573242, 10.473883628845215, 10.70097541809082, 10.88719367980957, 11.026833534240723, 11.114700317382812, 11.14637565612793, 11.118478775024414, 11.028901100158691, 10.876995086669922, 10.663689613342285, 10.391521453857422, 10.064571380615234, 9.688308715820312, 9.2693510055542, 8.815169334411621, 8.33375072479248, 7.8332600593566895, 7.321717262268066, 6.806715488433838, 6.295199871063232, 5.793302536010742, 5.306247711181641, 4.838308334350586, 4.392818450927734, 3.972219228744507, 3.578134775161743, 3.2114663124084473, 2.872493267059326, 2.5609755516052246, 2.276254177093506, 2.017343282699585, 1.7830134630203247, 1.5718637704849243, 1.3823845386505127, 1.2130088806152344, 1.06215500831604, 0.928259551525116, 0.8098036050796509, 0.7053318619728088, 0.6134664416313171, 0.5329155921936035, 0.4624791443347931, 0.4010503888130188, 0.34761592745780945, 0.30125346779823303, 0.26112833619117737, 0.22648902237415314, 0.1966620832681656, 0.1710466593503952, 0.14910884201526642, 0.13037604093551636, 0.11443138867616653, 0.10090851783752441, 0.08948644250631332, 0.07988486438989639, 0.07185973972082138, 0.06519927829504013, 0.059720225632190704, 0.055264513939619064, 0.05169624462723732, 0.04889898747205734, 0.04677334427833557, 0.04523482918739319, 0.044207263737916946, 0.04362663999199867, 0.0434393510222435, 0.04360070824623108, 0.04407365247607231, 0.044827651232481, 0.04583776369690895, 0.047083839774131775, 0.048549823462963104, 0.05022319406270981, 0.05209445580840111, 0.054156720638275146, 0.056405358016490936, 0.05883768945932388, 0.06145274639129639, 0.06425105035305023, 0.06723442673683167, 0.07040586322546005, 0.07376938313245773, 0.07732994854450226, 0.08109334111213684, 0.08506613969802856, 0.08925560861825943, 0.09366967529058456, 0.09831689298152924, 0.10320639610290527, 0.10834785550832748, 0.11375150084495544, 0.11942806094884872, 0.1253887563943863, 0.1316453218460083, 0.13735726475715637, 0.14261485636234283, 0.1474994719028473, 0.15208451449871063, 0.15643616020679474, 0.1606140434741974, 0.16467203199863434, 0.1686587780714035, 0.17261841893196106, 0.17659102380275726, 0.18061323463916779, 0.18471866846084595, 0.18893833458423615, 0.19330111145973206, 0.19783411920070648, 0.20256294310092926, 0.20751211047172546, 0.21270526945590973, 0.21816547214984894, 0.22391550242900848, 0.22997796535491943, 0.236375629901886, 0.2431315779685974, 0.2502693831920624, 0.25781330466270447, 0.26578855514526367, 0.2742212414741516, 0.28313881158828735, 0.292570024728775, 0.3025452196598053, 0.31309643387794495, 0.32425758242607117, 0.3360646665096283, 0.34855592250823975, 0.3617720603942871, 0.3757564127445221, 0.39055511355400085, 0.40621742606163025, 0.4227959215641022, 0.4403466582298279, 0.4589296281337738, 0.47860878705978394, 0.4994525909423828, 0.5215341448783875, 0.5449317097663879, 0.5697288513183594, 0.5960150957107544, 0.6238861083984375, 0.653444230556488, 0.6847990155220032, 0.7180677056312561, 0.753375768661499, 0.7908573746681213, 0.8306561708450317, 0.8729259371757507, 0.9178311824798584, 0.9655478596687317, 1.0162643194198608, 1.070181965827942, 1.1275161504745483, 1.1884970664978027, 1.2533708810806274, 1.3224003314971924, 1.3958660364151, 1.474067211151123, 1.5573230981826782, 1.645973563194275, 1.7403799295425415, 1.8409265279769897, 1.9480208158493042, 2.062094211578369, 2.183603048324585, 2.313027858734131, 2.450873851776123, 2.597670555114746, 2.753969669342041, 2.920344352722168, 3.097385883331299, 3.2856993675231934, 3.4858994483947754, 3.6986029148101807, 3.924419641494751, 4.163941383361816, 4.417728424072266, 4.6862897872924805, 4.970065116882324, 5.269395351409912, 5.584493160247803, 5.915406703948975, 6.261973857879639, 6.623776435852051, 7.00007963180542, 7.389772891998291, 7.791298866271973, 8.202585220336914, 8.620967864990234, 9.043126106262207, 9.465018272399902, 9.88183879852295, 10.28799819946289, 10.677139282226562, 11.041168212890625, 11.371438026428223, 11.65894603729248, 11.89461612701416, 12.069657325744629, 12.175985336303711, 12.206686019897461, 12.156479835510254, 12.022148132324219, 11.802864074707031, 11.50039005279541, 11.119101524353027, 10.66583251953125, 10.149535179138184, 9.580803871154785, 8.971295356750488, 8.33312702178955, 7.678281784057617, 7.018101215362549, 6.36287784576416, 5.7215728759765625, 5.101658821105957, 4.509069442749023, 3.948241949081421, 3.4222261905670166, 2.932833194732666, 2.4808099269866943, 2.06601881980896, 1.6876130104064941, 1.344197154045105, 1.033972144126892, 0.754858672618866, 0.5046022534370422, 0.28085818886756897, 0.0812600702047348, -0.09652736037969589, -0.2547683119773865, -0.3956272006034851, -0.5211491584777832, -0.6332477927207947, -0.7336992621421814, -0.8241405487060547, -0.9060719609260559, -0.9808616042137146, -1.049752116203308, -1.1138688325881958, -1.1742286682128906, -1.2317488193511963, -1.2872567176818848, -1.341498851776123, -1.3951501846313477, -1.448821783065796, -1.5030697584152222, -1.55840265750885, -1.6152875423431396, -1.6741575002670288, -1.7354167699813843, -1.7994459867477417, -1.8666068315505981, -1.9372466802597046, -2.0117015838623047, -2.0902998447418213, -2.1733651161193848, -2.2612171173095703, -2.354175567626953, -2.4525604248046875, -2.556692361831665, -2.6668941974639893, -2.7834908962249756, -2.9068081378936768, -3.0371718406677246, -3.1749062538146973, -3.320331573486328, -3.4737603664398193, -3.6354939937591553, -3.805816888809204, -3.9849905967712402, -4.173245906829834, -4.370774745941162, -4.577717304229736, -4.794153213500977, -5.020084857940674, -5.255422592163086, -5.499966144561768, -5.753384590148926, -6.015196323394775, -6.28474235534668, -6.561164379119873, -6.843379020690918, -7.1300506591796875, -7.419571399688721, -7.710035800933838, -7.9992289543151855, -8.284613609313965, -8.563331604003906, -8.8322172164917, -9.08781909942627, -9.32645034790039, -9.544246673583984, -9.737249374389648, -9.901512145996094, -10.033220291137695, -10.128829002380371, -10.185205459594727, -10.19977855682373, -10.170675277709961, -10.096837043762207, -9.978116035461426, -9.815320014953613, -9.610222816467285, -9.365527153015137, -9.084773063659668, -8.772216796875, -8.432669639587402, -8.071317672729492, -7.693536281585693, -7.304707050323486, -6.910050868988037, -6.51448392868042, -6.122504234313965, -5.737456321716309, -5.362284183502197, -4.9994964599609375, -4.651150226593018, -4.318861484527588, -4.003823757171631, -3.706841468811035, -3.4283666610717773, -3.168544292449951, -2.927255630493164, -2.704162359237671, -2.498748302459717, -2.3103585243225098, -2.138232707977295, -1.98153817653656, -1.839394450187683, -1.7108969688415527, -1.5951356887817383, -1.4912099838256836, -1.3982412815093994, -1.3153817653656006, -1.2418218851089478, -1.1767951250076294, -1.119580626487732, -1.0695055723190308, -1.0259455442428589, -0.9883239269256592, -0.9561111330986023, -0.9288225769996643, -0.9060172438621521, -0.8872946500778198, -0.8722930550575256, -0.8606864809989929, -0.8521820902824402, -0.8465179204940796, -0.8434601426124573, -0.8428006768226624, -0.844355046749115, -0.8479599356651306, -0.8534714579582214, -0.8607629537582397, -0.8697236776351929, -0.8802566528320312, -0.8922774791717529, -0.9057130217552185, -0.9204999804496765, -0.936583936214447, -0.9539181590080261, -0.9724626541137695, -0.9921836256980896, -1.013052225112915, -1.0350443124771118, -1.0581393241882324, -1.0823203325271606, -1.1028110980987549, -1.120231032371521, -1.135140061378479, -1.148042917251587, -1.1593927145004272, -1.16959547996521, -1.1790138483047485, -1.1879714727401733, -1.196756362915039, -1.2056249380111694, -1.2148053646087646, -1.2245012521743774, -1.2348941564559937, -1.24614679813385, -1.2584055662155151, -1.271803379058838, -1.2864612340927124, -1.3024907112121582, -1.3199959993362427, -1.3390750885009766, -1.3598214387893677, -1.3823257684707642, -1.406677007675171, -1.4329631328582764, -1.461272954940796, -1.4916962385177612, -1.5243251323699951, -1.5592548847198486, -1.5965839624404907, -1.6364153623580933, -1.6788570880889893, -1.7240221500396729, -1.7720296382904053, -1.8230048418045044, -1.8770798444747925, -1.9343935251235962, -1.9950920343399048, -2.0593292713165283, -2.1272666454315186, -2.199073314666748, -2.2749264240264893, -2.355010509490967, -2.4395179748535156, -2.5286483764648438, -2.6226086616516113, -2.7216110229492188, -2.825873851776123, -2.935619831085205, -3.051074266433716, -3.172464370727539, -3.2847611904144287, -3.389258861541748, -3.487091064453125, -3.5792481899261475, -3.6665940284729004, -3.74988055229187, -3.8297603130340576, -3.9067983627319336, -3.9814813137054443, -4.054227828979492, -4.125394344329834, -4.195284366607666, -4.264150619506836, -4.332205772399902, -4.39962100982666, -4.46653413772583, -4.533052444458008, -4.599254131317139, -4.665191650390625, -4.730895519256592, -4.7963738441467285, -4.861616134643555, -4.9265947341918945, -4.991264820098877, -5.055566787719727, -5.119429111480713, -5.182765483856201, -5.245479583740234, -5.307465553283691, -5.368607997894287, -5.4287824630737305, -5.487859725952148, -5.545704364776611, -5.602175712585449, -5.657131195068359, -5.710426330566406, -5.761916160583496, -5.811456680297852, -5.858907222747803, -5.904130458831787, -5.946995735168457, -5.9873785972595215, -6.025164604187012, -6.060248374938965, -6.092537879943848, -6.121953010559082, -6.148428916931152, -6.171916961669922, -6.192383766174316, -6.209815979003906, -6.224216938018799, -6.235610008239746, -6.244037628173828, -6.2495622634887695, -6.252265930175781, -6.252248764038086, -6.249630451202393, -6.244548797607422, -6.237157344818115, -6.227626800537109, -6.216141223907471, -6.202898025512695, -6.188105583190918, -6.171983242034912, -6.154757022857666, -6.136659145355225, -6.117926597595215, -6.098798751831055, -6.079516410827637, -6.060317516326904, -6.041439056396484, -6.023114204406738, -6.0055694580078125, -5.989025592803955, -5.97369384765625, -5.959779262542725, -5.947474002838135, -5.936961650848389, -5.9284138679504395, -5.921990394592285, -5.917839050292969, -5.916094779968262, -5.916880130767822, -5.920304298400879, -5.9264631271362305, -5.9354400634765625, -5.947304725646973, -5.962113380432129, -5.979908466339111, -6.000720024108887, -6.024563789367676, -6.051442623138428, -6.081344127655029, -6.11424446105957, -6.150103569030762, -6.188867568969727, -6.230469226837158, -6.274825096130371, -6.321837425231934, -6.371392250061035, -6.423360347747803, -6.476959705352783, -6.5314507484436035, -6.586132526397705, -6.640336990356445, -6.693428993225098, -6.744801044464111, -6.793877124786377, -6.840108394622803, -6.882979869842529, -6.9220075607299805, -6.9567437171936035, -6.98677921295166, -7.011747360229492, -7.0313262939453125, -7.0452423095703125, -7.053273677825928, -7.0552544593811035, -7.051074504852295, -7.040681838989258, -7.024085521697998, -7.001354217529297, -6.9726152420043945, -6.938055038452148, -6.897914886474609, -6.852487564086914, -6.8021159172058105, -6.7471842765808105, -6.688116550445557, -6.625368595123291, -6.559421062469482, -6.490776538848877, -6.419949531555176, -6.347460746765137, -6.273833274841309, -6.199584484100342, -6.125221252441406, -6.051235675811768, -5.978100299835205, -5.906264305114746, -5.836151123046875, -5.768157005310059, -5.7026472091674805, -5.639955043792725, -5.580384254455566, -5.524205207824707, -5.4716572761535645, -5.422949314117432, -5.378260135650635, -5.337741374969482, -5.301516056060791, -5.26968240737915, -5.242315292358398, -5.219467639923096, -5.201170921325684, -5.187438011169434, -5.17826509475708, -5.17363166809082, -5.1735029220581055, -5.177829265594482, -5.186549663543701, -5.19959020614624, -5.216866493225098, -5.238281726837158, -5.263730049133301, -5.293093681335449, -5.32624626159668, -5.363049507141113, -5.403353691101074, -5.446999549865723, -5.493814945220947, -5.54361629486084, -5.596207618713379, -5.651378631591797, -5.7089056968688965, -5.768552303314209, -5.830065727233887, -5.893178462982178, -5.957608222961426, -6.023056983947754, -6.089211940765381, -6.155745029449463, -6.222313404083252, -6.288562297821045, -6.354124069213867, -6.4186201095581055, -6.481663227081299, -6.542860984802246, -6.601816177368164, -6.658131122589111, -6.711411952972412, -6.761270046234131, -6.807328224182129, -6.84922456741333, -6.886615753173828, -6.919183731079102, -6.9466376304626465, -6.968719959259033, -6.9852118492126465, -6.995934009552002, -7.000753402709961, -6.999583721160889, -6.99238920211792, -6.979186058044434, -6.960043907165527, -6.935083389282227, -6.904478549957275, -6.8684539794921875, -6.827280044555664, -6.781274795532227, -6.730793476104736, -6.676230430603027, -6.618008613586426, -6.556577205657959, -6.492406368255615, -6.425978660583496, -6.357785224914551, -6.288320541381836, -6.218075275421143, -6.147533893585205, -6.077166557312012, -6.0074286460876465, -5.938754081726074, -5.871555328369141, -5.806218147277832, -5.743102073669434, -5.682537078857422, -5.6248250007629395, -5.57023811340332, -5.519017219543457, -5.471376895904541, -5.4275007247924805, -5.387547492980957, -5.351647853851318, -5.319908618927002, -5.292413711547852, -5.269224166870117, -5.2503814697265625, -5.235908031463623, -5.2258076667785645, -5.220069885253906, -5.218667984008789, -5.221560478210449, -5.22869348526001, -5.240001678466797, -5.255406856536865, -5.274819374084473, -5.298140048980713, -5.325257301330566, -5.356050491333008, -5.390387535095215, -5.428125381469727, -5.469110488891602, -5.513177871704102, -5.560150146484375, -5.609838008880615, -5.6620402336120605, -5.716541767120361, -5.77311372756958, -5.831514835357666, -5.891488075256348, -5.952763080596924, -6.015055179595947, -6.078064918518066, -6.141480445861816, -6.204975605010986, -6.268212795257568, -6.330842018127441, -6.392505645751953, -6.452836513519287, -6.511462211608887, -6.568007946014404, -6.622097969055176, -6.673358917236328, -6.721424102783203, -6.765937328338623, -6.806554794311523, -6.842952251434326, -6.874826908111572, -6.901901721954346, -6.92393159866333, -6.940703868865967, -6.952045917510986, -6.95782470703125, -6.957952499389648, -6.95238733291626, -6.941135406494141, -6.924251556396484, -6.901839733123779, -6.874053478240967, -6.841091156005859, -6.80319881439209, -6.76066255569458, -6.713808059692383, -6.6629958152771, -6.608615398406982, -6.551083564758301, -6.490835189819336, -6.428320407867432, -6.363999843597412, -6.298336505889893, -6.231794357299805, -6.164831638336182, -6.09789514541626, -6.0314202308654785, -5.965822696685791, -5.901500225067139, -5.838826656341553, -5.719136714935303, -5.550455570220947, -5.340717792510986, -5.097636699676514, -4.828582763671875, -4.540469169616699, -4.239659309387207, -3.9318957328796387, -3.62225341796875, -3.3151192665100098, -3.0141942501068115, -2.7225136756896973, -2.4424853324890137, -2.1759390830993652, -1.9241819381713867, -1.6880613565444946, -1.4680252075195312, -1.2641842365264893, -1.0763691663742065, -0.9041849374771118, -0.747058629989624, -0.6042833924293518, -0.4750554859638214, -0.3585071563720703, -0.25373348593711853, -0.15981505811214447, -0.075836181640625, -0.0008993695955723524, 0.06586352735757828, 0.12528304755687714, 0.17814631760120392, 0.22519324719905853, 0.2671145498752594, 0.3045508861541748, 0.33809351921081543, 0.36828532814979553, 0.3956230580806732, 0.4205593764781952, 0.4435059726238251, 0.4648362696170807, 0.48488864302635193, 0.5039694905281067, 0.5223562717437744, 0.540300726890564, 0.558031439781189, 0.5757569074630737, 0.5936681628227234, 0.6119410395622253, 0.6307387351989746, 0.6502138376235962, 0.6705103516578674, 0.6917657256126404, 0.7141122817993164, 0.7376792430877686, 0.7625938653945923, 0.7889830470085144, 0.8169747591018677, 0.8466988801956177, 0.878288984298706, 0.9118828177452087, 0.9476239681243896, 0.985662579536438, 1.0261564254760742, 1.0692720413208008, 1.1151857376098633, 1.164084553718567, 1.2161672115325928, 1.2716450691223145, 1.330743670463562, 1.3937029838562012, 1.4607793092727661, 1.5322455167770386, 1.608392596244812, 1.689530611038208, 1.7759896516799927, 1.8681209087371826, 1.9662972688674927, 2.0709147453308105, 2.182391881942749, 2.3011720180511475, 2.4277219772338867, 2.5625321865081787, 2.7061166763305664, 2.8590121269226074, 3.0217745304107666, 3.1949779987335205, 3.379210948944092, 3.5750701427459717, 3.7831544876098633, 4.004056930541992, 4.2383527755737305, 4.486587047576904, 4.749256134033203, 5.026788711547852, 5.319519996643066, 5.627662181854248, 5.951269626617432, 6.290195465087891, 6.644048690795898, 7.012135982513428, 7.39340353012085, 7.785672187805176, 8.186270713806152, 8.591960906982422, 8.998873710632324, 9.402461051940918, 9.797464370727539, 10.083890914916992, 10.262483596801758, 10.334569931030273, 10.30257511138916, 10.170425415039062, 9.943790435791016, 9.630159378051758, 9.23873519897461, 8.780166625976562, 8.266160011291504, 7.709003448486328, 7.121068477630615, 6.51433801651001, 5.899996757507324, 5.288113594055176, 4.687429428100586, 4.1052446365356445, 3.5474002361297607, 3.018329381942749, 2.521164655685425, 2.0578770637512207, 1.6294361352920532, 1.2359706163406372, 0.8769270777702332, 0.5512152910232544, 0.2573385238647461, -0.0064927563071250916, -0.24226465821266174, -0.4520798623561859, -0.6380926370620728, -0.8024570345878601, -0.9472869038581848, -1.0746257305145264, -1.1864246129989624, -1.28452730178833, -1.3706609010696411, -1.4464309215545654, -1.5133200883865356, -1.5726900100708008, -1.6257846355438232, -1.673735499382019, -1.7175685167312622, -1.75821053981781, -1.7964972257614136, -1.8331809043884277, -1.8689379692077637, -1.9043769836425781, -1.9400454759597778, -1.9764374494552612, -2.0139999389648438, -2.0531389713287354, -2.0942256450653076, -2.137601375579834, -2.1835825443267822, -2.2324655055999756, -2.284529685974121, -2.3400421142578125, -2.3992598056793213, -2.462433338165283, -2.529808282852173, -2.601628541946411, -2.6781363487243652, -2.759575843811035, -2.8461921215057373, -2.9382331371307373, -3.035949230194092, -3.1395938396453857, -3.249422311782837, -3.3656914234161377, -3.4886579513549805, -3.6185765266418457, -3.755697011947632, -3.9002621173858643, -4.052501678466797, -4.212629795074463, -4.380837917327881, -4.55728816986084, -4.742105484008789, -4.935368061065674, -5.1370978355407715, -5.34724760055542, -5.565687656402588, -5.792190074920654, -6.026414394378662, -6.26788854598999, -6.515989780426025, -6.769926071166992, -7.028716564178467, -7.291171550750732, -7.555875778198242, -7.821173191070557, -8.085156440734863, -8.345660209655762, -8.600264549255371, -8.846306800842285, -9.080903053283691, -9.300986289978027, -9.503352165222168, -9.684728622436523, -9.841856956481934, -9.971580505371094, -10.069969177246094, -10.13349723815918, -10.159168243408203, -10.144639015197754, -10.088332176208496, -9.989527702331543, -9.848422050476074, -9.666152000427246, -9.444771766662598, -9.1871976852417, -8.897096633911133, -8.578754425048828, -8.236913681030273, -7.8765997886657715, -7.50294303894043, -7.121014595031738, -6.7356743812561035, -6.3514509201049805, -5.972442150115967, -5.602252960205078, -5.24395751953125, -4.900086879730225, -4.572640895843506, -4.2631144523620605, -3.9725399017333984, -3.7015326023101807, -3.4503467082977295, -3.2189278602600098, -3.0069665908813477, -2.8139500617980957, -2.639207124710083, -2.481950521469116, -2.3413145542144775, -2.2163846492767334, -2.1062254905700684, -2.009902238845825, -1.9264984130859375, -1.8551292419433594, -1.7949529886245728, -1.7451778650283813, -1.7050679922103882, -1.6739462614059448, -1.6511961221694946, -1.6362619400024414, -1.6286485195159912, -1.6279194355010986, -1.6336952447891235, -1.64565110206604, -1.6635140180587769, -1.6870602369308472, -1.7161126136779785, -1.7505377531051636, -1.790243148803711, -1.835174798965454, -1.8853148221969604, -1.9406791925430298, -2.0013155937194824, -2.067300796508789, -2.138740062713623, -2.215763807296753, -2.2985270023345947, -2.38720703125, -2.482001304626465, -2.5831267833709717, -2.690816879272461, -2.805319309234619, -2.9268949031829834, -3.0558130741119385, -3.1923506259918213, -3.3367860317230225, -3.489396572113037, -3.6504530906677246, -3.8202130794525146, -3.998915195465088, -4.186769485473633, -4.383948802947998, -4.590578079223633, -4.8067216873168945, -5.03236722946167, -5.2674126625061035, -5.51164436340332, -5.764720916748047, -6.026147365570068, -6.295254707336426, -6.571173667907715, -6.852809906005859, -7.138819217681885, -7.427583694458008, -7.717190742492676, -8.00541877746582, -8.289728164672852, -8.567256927490234, -8.834842681884766, -9.089038848876953, -9.326168060302734, -9.542379379272461, -9.733734130859375, -9.896310806274414, -10.026321411132812, -10.120255470275879, -10.174013137817383, -10.184151649475098, -10.148030281066895, -10.063955307006836, -9.931278228759766, -9.750465393066406, -9.523113250732422, -9.251906394958496, -8.94052505493164, -8.593502044677734, -8.216039657592773, -7.813800811767578, -7.39269495010376, -6.958660125732422, -6.517469882965088, -6.07456636428833, -5.634926795959473, -5.202969074249268, -4.782493591308594, -4.376659393310547, -3.987989902496338, -3.6183981895446777, -3.2692344188690186, -2.941340446472168, -2.6351125240325928, -2.3505661487579346, -2.087399959564209, -1.8450555801391602, -1.622773289680481, -1.4196419715881348, -1.2346431016921997, -1.0666874647140503, -0.9146477580070496, -0.7773838043212891, -0.653764009475708, -0.5426821112632751, -0.4430695176124573, -0.35390505194664, -0.2742212414741516, -0.2031087428331375, -0.13971850275993347, -0.08326255530118942, -0.03221717104315758, 0.013659760355949402, 0.0546516478061676, 0.09107071161270142, 0.12324727326631546, 0.1515207588672638, 0.1762322187423706, 0.19771826267242432, 0.21630631387233734, 0.2323109358549118, 0.24603107571601868, 0.2577483057975769, 0.26772555708885193, 0.2762066423892975, 0.28341612219810486, 0.28955960273742676, 0.2948243021965027, 0.29937994480133057, 0.30337971448898315, 0.3069612979888916, 0.31024816632270813, 0.31335076689720154, 0.31636759638786316, 0.31938663125038147, 0.3224862515926361, 0.32573652267456055, 0.32920023798942566, 0.33293378353118896, 0.3369882106781006, 0.3414100706577301, 0.34624215960502625, 0.35152435302734375, 0.3572941720485687, 0.36358752846717834, 0.37043923139572144, 0.3778834939002991, 0.38595446944236755, 0.3946867287158966, 0.40411558747291565, 0.4142775535583496, 0.42521071434020996, 0.4369550347328186, 0.4495528042316437, 0.4630488157272339, 0.4774908125400543, 0.49292975664138794, 0.5094201564788818, 0.5270203948020935, 0.5457931160926819, 0.5658055543899536, 0.5871297717094421, 0.6098433136940002, 0.6340293288230896, 0.6597772240638733, 0.6871828436851501, 0.7163492441177368, 0.7473871111869812, 0.7804150581359863, 0.8155605792999268, 0.8529605269432068, 0.8927615284919739, 0.9351210594177246, 0.9802079796791077, 1.0282032489776611, 1.0793009996414185, 1.1337090730667114, 1.191650390625, 1.2533632516860962, 1.3191031217575073, 1.3891429901123047, 1.4637749195098877, 1.543310523033142, 1.6280828714370728, 1.7184468507766724, 1.814780354499817, 1.9174853563308716, 2.0269887447357178, 2.1437430381774902, 2.2682266235351562, 2.400944232940674, 2.542426586151123, 2.6932294368743896, 2.853933095932007, 3.025139570236206, 3.2074697017669678, 3.4015586376190186, 3.60805082321167, 3.8275904655456543, 4.060814380645752, 4.30833625793457, 4.570733070373535, 4.848524570465088, 5.142149925231934, 5.451936721801758, 5.778069019317627, 6.12054443359375, 6.479125499725342, 6.8532867431640625, 7.24215030670166, 7.644418239593506, 8.058298110961914, 8.480659484863281, 8.907726287841797, 9.334999084472656, 9.7572021484375, 10.168257713317871, 10.561299324035645, 10.928735733032227, 11.26237964630127, 11.553644180297852, 11.79382038116455, 11.974424362182617, 12.087611198425293, 12.126619338989258, 12.086228370666504, 11.963177680969238, 11.756494522094727, 11.467702865600586, 11.10086441040039, 10.662442207336426, 10.16099739074707, 9.606735229492188, 9.01096248626709, 8.385497093200684, 7.742097854614258, 7.091958999633789, 6.445300579071045, 5.811081886291504, 5.196828365325928, 4.608572483062744, 4.050880432128906, 3.526947259902954, 3.0387375354766846, 2.5871505737304688, 2.172194242477417, 1.7931561470031738, 1.4487615823745728, 1.1373177766799927, 0.8566927909851074, 0.6046433448791504, 0.37888380885124207, 0.1771407425403595, -0.0028056311421096325, -0.1630905121564865, -0.3057427406311035, -0.43267038464546204, -0.5456523299217224, -0.6463345289230347, -0.7362301349639893, -0.8167219161987305, -0.8890672922134399, -0.9544045329093933, -1.013759732246399, -1.0680545568466187, -1.1181142330169678, -1.1646755933761597, -1.2083946466445923, -1.2498544454574585, -1.2895718812942505, -1.3280048370361328, -1.3655579090118408, -1.4025886058807373, -1.4394124746322632, -1.4763078689575195, -1.5135201215744019, -1.551265835762024, -1.589735746383667, -1.6290980577468872, -1.6695014238357544, -1.7110767364501953, -1.7539395093917847, -1.7981914281845093, -1.8439217805862427, -1.8912091255187988, -1.9401216506958008, -1.9907186031341553, -2.0430502891540527, -2.0971596240997314, -2.153080701828003, -2.2108407020568848, -2.270458936691284, -2.3319475650787354, -2.395310401916504, -2.460543632507324, -2.527634382247925, -2.5965616703033447, -2.667295217514038, -2.7397937774658203, -2.814007043838501, -2.8898723125457764, -2.967315435409546, -3.0462498664855957, -3.1132218837738037, -3.169840097427368, -3.2175586223602295, -3.2576892375946045, -3.2914130687713623, -3.3197929859161377, -3.3437821865081787, -3.3642356395721436, -3.38191819190979, -3.3975131511688232, -3.411630630493164, -3.424813985824585, -3.437546968460083, -3.4502596855163574, -3.46333384513855, -3.4771082401275635, -3.491882801055908, -3.5079240798950195, -3.5254669189453125, -3.544719696044922, -3.565866708755493, -3.589071035385132, -3.6144766807556152, -3.6422111988067627, -3.67238712310791, -3.705103874206543, -3.7404491901397705, -3.778500556945801, -3.8193252086639404, -3.8629822731018066, -3.90952205657959, -3.9589879512786865, -4.011415004730225, -4.066831588745117, -4.125257968902588, -4.186707019805908, -4.25118350982666, -4.3186845779418945, -4.38919734954834, -4.462698459625244, -4.53915548324585, -4.618523120880127, -4.700743675231934, -4.785745620727539, -4.873441219329834, -4.963726997375488, -5.056481838226318, -5.15156364440918, -5.248810768127441, -5.348038673400879, -5.449038982391357, -5.551578521728516, -5.655396938323975, -5.760207653045654, -5.865695476531982, -5.971517086029053, -6.07729959487915, -6.182642459869385, -6.2871174812316895, -6.390269756317139, -6.49161958694458, -6.5906662940979, -6.686890125274658, -6.779757022857666, -6.868721961975098, -6.953238010406494, -7.0327582359313965, -7.106746196746826, -7.174680709838867, -7.2360663414001465, -7.290441036224365, -7.3373823165893555, -7.376519203186035, -7.407538414001465, -7.430191993713379, -7.444304466247559, -7.4497785568237305, -7.44659948348999, -7.434838771820068, -7.414654731750488, -7.386292934417725, -7.350085258483887, -7.306443691253662, -7.255858421325684, -7.198887825012207, -7.136153697967529, -7.068329334259033, -6.996131896972656, -6.9203104972839355, -6.841636657714844, -6.76089334487915, -6.678864002227783, -6.596325397491455, -6.514036655426025, -6.432732105255127, -6.353114604949951, -6.275851249694824, -6.201565742492676, -6.1308393478393555, -6.064205169677734, -6.0021491050720215, -5.944502353668213, -5.891127586364746, -5.841913223266602, -5.796766757965088, -5.755609512329102, -5.718376159667969, -5.685006141662598, -5.6554460525512695, -5.62964391708374, -5.607548713684082, -5.589108943939209, -5.5742716789245605, -5.5629801750183105, -5.555174350738525, -5.550790309906006, -5.549757957458496, -5.552003383636475, -5.557446002960205, -5.5659990310668945, -5.577570915222168, -5.5920610427856445, -5.6093645095825195, -5.629368305206299, -5.651951789855957, -5.676987648010254, -5.704340934753418, -5.7338690757751465, -5.765420913696289, -5.798839092254639, -5.833956718444824, -5.870599269866943, -5.908585071563721, -5.947723388671875, -5.98781681060791, -6.028660774230957, -6.070043563842773, -6.111745834350586, -6.153544902801514, -6.195210933685303, -6.236510753631592, -6.27720832824707, -6.317065715789795, -6.355844020843506, -6.39330530166626, -6.429214000701904, -6.463339328765869, -6.495456695556641, -6.52534818649292, -6.552807807922363, -6.577639102935791, -6.5996623039245605, -6.618711471557617, -6.634640216827393, -6.647320747375488, -6.656647205352783, -6.662537097930908, -6.6649322509765625, -6.663798809051514, -6.659130573272705, -6.650946617126465, -6.639294147491455, -6.624246120452881, -6.605902194976807, -6.584387302398682, -6.559849739074707, -6.532461643218994, -6.502415657043457, -6.469923496246338, -6.435214042663574, -6.398529529571533, -6.360126495361328, -6.320268154144287, -6.279226779937744, -6.237277984619141, -6.194699287414551, -6.151767253875732, -6.108755588531494, -6.065934181213379, -6.023563385009766, -5.98189640045166, -5.9411749839782715, -5.901630401611328, -5.8634796142578125, -5.826925754547119, -5.792158126831055, -5.759350299835205, -5.7286601066589355, -5.700230121612549, -5.674187183380127, -5.650641918182373, -5.629690170288086, -5.611412525177002, -5.595873832702637, -5.583126068115234, -5.573205947875977, -5.566136837005615, -5.561930179595947, -5.560583591461182, -5.5620832443237305, -5.566402912139893, -5.5735063552856445, -5.583345413208008, -5.595860958099365, -5.610984802246094, -5.62863826751709, -5.648731708526611, -5.671167850494385, -5.69583797454834, -5.722625255584717, -5.751403331756592, -5.782036304473877, -5.814380645751953, -5.848282337188721, -5.883579730987549, -5.920103073120117, -5.9576735496521, -5.996105670928955, -6.035205364227295, -6.074772834777832, -6.1146016120910645, -6.154479026794434, -6.194189071655273, -6.2335100173950195, -6.272219181060791, -6.310091018676758, -6.346273422241211, -6.37997579574585, -6.410468578338623, -6.437081336975098, -6.459201335906982, -6.476277828216553, -6.487819194793701, -6.493399143218994, -6.492655277252197, -6.485292911529541, -6.4710869789123535, -6.4498820304870605, -6.421594142913818, -6.386210918426514, -6.343789577484131, -6.2944560050964355, -6.238402366638184, -6.175882339477539, -6.107208251953125, -6.03274393081665, -5.952899932861328, -5.868125915527344, -5.733067989349365, -5.555102348327637, -5.341463088989258, -5.099135875701904, -4.83475399017334, -4.554506778717041, -4.264064311981201, -3.9685235023498535, -3.672372579574585, -3.3794796466827393, -3.0930981636047363, -2.8158891201019287, -2.549956798553467, -2.296893835067749, -2.057831287384033, -1.8334940671920776, -1.6242552995681763, -1.430190086364746, -1.2511266469955444, -1.0866934061050415, -0.9363621473312378, -0.7994855642318726, -0.6753311157226562, -0.5631089806556702, -0.4619967043399811, -0.3711589276790619, -0.2897636890411377, -0.21699535846710205, -0.15206460654735565, -0.09421587735414505, -0.04273267090320587, 0.003059007693082094, 0.043788693845272064, 0.08004074543714523, 0.11235460638999939, 0.14122585952281952, 0.16710785031318665, 0.19041375815868378, 0.2115190029144287, 0.230763778090477, 0.2484557181596756, 0.26487264037132263, 0.28026530146598816, 0.294859915971756, 0.30886074900627136, 0.3224526345729828, 0.3358031213283539, 0.3490648567676544, 0.3623773455619812, 0.3758690655231476, 0.3896591067314148, 0.40385884046554565, 0.41857340931892395, 0.4339030683040619, 0.44994455575942993, 0.46679219603538513, 0.48453912138938904, 0.5032781958580017, 0.5231030583381653, 0.5441089868545532, 0.5663939118385315, 0.5900591611862183, 0.615210235118866, 0.6419578194618225, 0.6704183220863342, 0.7007150650024414, 0.7329785823822021, 0.7673479318618774, 0.8039713501930237, 0.8430069088935852, 0.8846239447593689, 0.9290035367012024, 0.9763396382331848, 1.0268402099609375, 1.08072829246521, 1.1382429599761963, 1.1996406316757202, 1.265196442604065, 1.3352049589157104, 1.4099825620651245, 1.4898674488067627, 1.5752222537994385, 1.666434645652771, 1.7639187574386597, 1.868116855621338, 1.9795002937316895, 2.0985705852508545, 2.225860357284546, 2.361934185028076, 2.507388114929199, 2.6628501415252686, 2.8289783000946045, 3.006460428237915, 3.1960091590881348, 3.3983590602874756, 3.614260673522949, 3.8444714546203613, 4.08974552154541, 4.350819110870361, 4.628394603729248, 4.923116207122803, 5.235079288482666, 5.564253330230713, 5.910429954528809, 6.2731709480285645, 6.6517438888549805, 7.045055389404297, 7.451579570770264, 7.869276523590088, 8.295515060424805, 8.726995468139648, 9.159675598144531, 9.58871841430664, 10.008459091186523, 10.41240406036377, 10.793280601501465, 11.143143653869629, 11.453550338745117, 11.715806007385254, 11.921293258666992, 12.061864852905273, 12.130285263061523, 12.120692253112793, 12.029036521911621, 11.853456497192383, 11.594537734985352, 11.25542163848877, 10.8417329788208, 10.361340522766113, 9.823949813842773, 9.240581512451172, 8.622992515563965, 7.983084201812744, 7.332367897033691, 6.681511402130127, 6.0400071144104, 5.415954113006592, 4.815959453582764, 4.245138168334961, 3.707184076309204, 3.2044990062713623, 2.738352060317993, 2.3090529441833496, 1.9161262512207031, 1.558476448059082, 1.2345378398895264, 0.9424065947532654, 0.6799533367156982, 0.44491609930992126, 0.2349766492843628, 0.04782000184059143, -0.11881958693265915, -0.2671246826648712, -0.3991706669330597, -0.5169099569320679, -0.622162938117981, -0.71661376953125, -0.7955895066261292, -0.860317587852478, -0.9120750427246094, -0.9521539211273193, -0.9818329215049744, -1.0023550987243652, -1.0149104595184326, -1.0206228494644165, -1.0205413103103638, -1.015634298324585, -1.006786584854126, -0.994799017906189, -0.9803897142410278, -0.9641967415809631, -0.9467818140983582, -0.92863529920578, -0.9101811051368713, -0.8917823433876038, -0.8737468123435974, -0.8563327193260193, -0.8397542238235474, -0.8241864442825317, -0.809770941734314, -0.7966198325157166, -0.7848206758499146, -0.7744399309158325, -0.7655269503593445, -0.7581169605255127, -0.752234160900116, -0.7478940486907959, -0.745106041431427, -0.7438750267028809, -0.7442034482955933, -0.746092677116394, -0.7495443224906921, -0.754561185836792, -0.7611485123634338, -0.769314706325531, -0.7790719270706177, -0.7904366850852966, -0.8034306764602661, -0.8180809617042542, -0.8344204425811768, -0.8524883389472961, -0.8723304271697998, -0.8939995765686035, -0.9175558686256409, -0.9430669546127319, -0.9706085920333862, -1.0002647638320923, -1.0321282148361206, -1.066300630569458, -1.1028934717178345, -1.1420278549194336, -1.183835506439209, -1.2284587621688843, -1.276051640510559, -1.3267802000045776, -1.380822777748108, -1.4383710622787476, -1.4996304512023926, -1.5648208856582642, -1.634177327156067, -1.707950472831726, -1.786407470703125, -1.8698325157165527, -1.9585272073745728, -2.05281138420105, -2.1530230045318604, -2.259519100189209, -2.3726754188537598, -2.4928860664367676, -2.620563268661499, -2.756136894226074, -2.900052309036255, -3.052769184112549, -3.2147583961486816, -3.38649845123291, -3.568471908569336, -3.761157751083374, -3.9650256633758545, -4.180525779724121, -4.408078670501709, -4.648059368133545, -4.900784492492676, -5.166488170623779, -5.445303916931152, -5.737232685089111, -6.042115211486816, -6.359595775604248, -6.689080715179443, -7.029697895050049, -7.380247116088867, -7.739151477813721, -8.10440731048584, -8.47353744506836, -8.843547821044922, -9.210894584655762, -9.571465492248535, -9.920583724975586, -10.253036499023438, -10.562150001525879, -10.840926170349121, -11.082202911376953, -11.278874397277832, -11.424150466918945, -11.51186466217041, -11.536797523498535, -11.494993209838867, -11.384053230285645, -11.203353881835938, -10.954183578491211, -10.639763832092285, -10.265146255493164, -9.83699893951416, -9.363286018371582, -8.851899147033691, -8.311421394348145, -7.750715732574463, -7.178536891937256, -6.603194713592529, -6.032287120819092, -5.472510814666748, -4.92954683303833, -4.408019065856934, -3.9115047454833984, -3.442596912384033, -3.00299072265625, -2.5935921669006348, -2.2146334648132324, -1.8657886981964111, -1.5462853908538818, -1.2550042867660522, -0.9905704259872437, -0.7514307498931885, -0.5359198451042175, -0.3423146605491638, -0.16887825727462769, -0.013894779607653618, 0.12430406361818314, 0.24731920659542084, 0.35667023062705994, 0.45378613471984863, 0.5400001406669617, 0.6165471076965332, 0.6845640540122986, 0.7450919151306152, 0.7990788817405701, 0.8473849892616272, 0.89078688621521, 0.9299832582473755, 0.9656006097793579, 0.9981987476348877, 1.0282764434814453, 1.056276798248291, 1.082592248916626, 1.107569932937622, 1.131515622138977, 1.154698371887207, 1.177354097366333, 1.1933387517929077, 1.2036423683166504, 1.209173560142517, 1.2107603549957275, 1.2091518640518188, 1.2050215005874634, 1.1989706754684448, 1.1915332078933716, 1.1831798553466797, 1.1743237972259521, 1.1653252840042114, 1.1564966440200806, 1.1481072902679443, 1.1403884887695312, 1.133538007736206, 1.1277236938476562, 1.1230883598327637, 1.1197525262832642, 1.1178183555603027, 1.1173726320266724, 1.1184892654418945, 1.121232032775879, 1.1256568431854248, 1.131813645362854, 1.1397483348846436, 1.1495040655136108, 1.1611229181289673, 1.1746472120285034, 1.1901205778121948, 1.20758855342865, 1.2271000146865845, 1.2487075328826904, 1.2724686861038208, 1.2984455823898315, 1.3267067670822144, 1.357326626777649, 1.3903864622116089, 1.4259750843048096, 1.464188575744629, 1.5051313638687134, 1.548916220664978, 1.5956650972366333, 1.6455087661743164, 1.6985877752304077, 1.7550526857376099, 1.8150640726089478, 1.8787932395935059, 1.9464223384857178, 2.018144130706787, 2.094163417816162, 2.1746950149536133, 2.2599666118621826, 2.3502156734466553, 2.4456918239593506, 2.5466549396514893, 2.653374671936035, 2.7661304473876953, 2.885209798812866, 3.01090669631958, 3.1435205936431885, 3.283353090286255, 3.4307055473327637, 3.5858755111694336, 3.749152421951294, 3.920811653137207, 4.101109981536865, 4.2902750968933105, 4.488501071929932, 4.6959333419799805, 4.912661552429199, 5.138701438903809, 5.373983860015869, 5.61833381652832, 5.871453285217285, 6.132898330688477, 6.402059555053711, 6.678133964538574, 6.960103511810303, 7.246708393096924, 7.53642463684082, 7.8274431228637695, 8.11765193939209, 8.404626846313477, 8.685628890991211, 8.957613945007324, 9.217256546020508, 9.460988998413086, 9.68506145477295, 9.885615348815918, 10.058786392211914, 10.200817108154297, 10.30819034576416, 10.37777042388916, 10.406944274902344, 10.39376163482666, 10.337054252624512, 10.236533164978027, 10.092841148376465, 9.907576560974121, 9.683258056640625, 9.42325210571289, 9.130684852600098, 8.80942440032959, 8.463906288146973, 8.098958015441895, 7.71960973739624, 7.330912113189697, 6.937774181365967, 6.544824123382568, 6.15629768371582, 5.7759599685668945, 5.407054424285889, 5.052282333374023, 4.713805198669434, 4.393266201019287, 4.091828346252441, 3.8102176189422607, 3.548779249191284, 3.3075294494628906, 3.086211919784546, 2.884348154067993, 2.7012882232666016, 2.536252498626709, 2.388371467590332, 2.2567191123962402, 2.14034104347229, 2.038278102874756, 1.9495859146118164, 1.8733487129211426, 1.808692455291748, 1.7547924518585205, 1.7108795642852783, 1.6762442588806152, 1.650238037109375, 1.632275104522705, 1.6218311786651611, 1.6184422969818115, 1.6217031478881836, 1.6312646865844727, 1.6468313932418823, 1.6681585311889648, 1.695049524307251, 1.7273527383804321, 1.7649590969085693, 1.807798981666565, 1.8558403253555298, 1.9090856313705444, 1.967570185661316, 2.031359910964966, 2.10054874420166, 2.175257921218872, 2.255633592605591, 2.3418445587158203, 2.4340813159942627, 2.5325541496276855, 2.637490749359131, 2.7491350173950195, 2.867743492126465, 2.993584156036377, 3.1269326210021973, 3.268068790435791, 3.41727352142334, 3.5748229026794434, 3.7409827709198, 3.916003465652466, 4.100110054016113, 4.293496131896973, 4.496310710906982, 4.708648681640625, 4.930534362792969, 5.161909580230713, 5.402614116668701, 5.652365684509277, 5.910740375518799, 6.177148818969727, 6.450812816619873, 6.730737686157227, 7.015689849853516, 7.304171085357666, 7.594394683837891, 7.884270191192627, 8.171388626098633, 8.453018188476562, 8.726115226745605, 8.987337112426758, 9.233086585998535, 9.45956039428711, 9.662829399108887, 9.838930130004883, 9.983981132507324, 10.094315528869629, 10.165621757507324, 10.19417953491211, 10.17701530456543, 10.112052917480469, 9.998230934143066, 9.835590362548828, 9.625308990478516, 9.369684219360352, 9.072059631347656, 8.736698150634766, 8.368613243103027, 7.973364353179932, 7.556840896606445, 7.12504243850708, 6.683874130249023, 6.238964080810547, 5.795517921447754, 5.3582072257995605, 4.931097507476807, 4.517612457275391, 4.1205291748046875, 3.7419962882995605, 3.3835763931274414, 3.046297311782837, 2.7307140827178955, 2.436974048614502, 2.164881944656372, 1.913961410522461, 1.6835142374038696, 1.4726718664169312, 1.280442237854004, 1.1057496070861816, 0.9474689960479736, 0.8044535517692566, 0.6755583882331848, 0.5596585273742676, 0.4556629955768585, 0.36252540349960327, 0.27925172448158264, 0.20490507781505585, 0.13860884308815002, 0.07954785972833633, 0.026968318969011307, -0.019823329523205757, -0.06146231293678284, -0.09852804243564606, -0.13154703378677368, -0.16099607944488525, -0.1873055249452591, -0.21086271107196808, -0.2320152372121811, -0.25107428431510925, -0.26831772923469543, -0.2839931547641754, -0.2983206510543823, -0.31149551272392273, -0.3236906826496124, -0.3350589871406555, -0.34573519229888916, -0.3558380603790283, -0.3654719293117523, -0.37472838163375854, -0.3836875557899475, -0.39241960644721985, -0.40098559856414795, -0.4094387888908386, -0.4178253710269928, -0.42618528008461, -0.4345530569553375, -0.44295835494995117, -0.4514264762401581, -0.45997902750968933, -0.4686341881752014, -0.4774071276187897, -0.4863104224205017, -0.49535423517227173, -0.5045466423034668, -0.5138937830924988, -0.523400068283081, -0.5330684781074524, -0.5429003834724426, -0.5528960227966309, -0.5621314644813538, -0.570799708366394, -0.5790740847587585, -0.5871104001998901, -0.5950484871864319, -0.6030141711235046, -0.611120879650116, -0.61947101354599, -0.6281576156616211, -0.6372655034065247, -0.6468725204467773, -0.6570507884025574, -0.6678675413131714, -0.6793862581253052, -0.691667377948761, -0.7047691941261292, -0.7187485694885254, -0.7336616516113281, -0.7495643496513367, -0.7665131092071533, -0.7845651507377625, -0.8037794232368469, -0.8242166638374329, -0.8459399342536926, -0.8690152764320374, -0.8935118317604065, -0.9195024967193604, -0.9470639824867249, -0.9762776494026184, -1.0072295665740967, -1.0400108098983765, -1.0747183561325073, -1.1114548444747925, -1.1503294706344604, -1.1914581060409546, -1.2349637746810913, -1.2809773683547974, -1.3296372890472412, -1.3810909986495972, -1.4354944229125977, -1.4930131435394287, -1.5538221597671509, -1.6181068420410156, -1.686063289642334, -1.7578984498977661, -1.8338305950164795, -1.914089560508728, -1.9989172220230103, -2.0885674953460693, -2.1833062171936035, -2.2834110260009766, -2.389172077178955, -2.500889778137207, -2.618875741958618, -2.7434511184692383, -2.8749449253082275, -3.01369309425354, -3.160034418106079, -3.314310073852539, -3.4768571853637695, -3.6480064392089844, -3.8280749320983887, -4.017360687255859, -4.216133117675781, -4.424624443054199, -4.64301872253418, -4.871436595916748, -5.109922885894775, -5.358426570892334, -5.616783618927002, -5.884692192077637, -6.161689281463623, -6.447126388549805, -6.740138053894043, -7.039614677429199, -7.344173431396484, -7.652129650115967, -7.961471080780029, -8.2698392868042, -8.574515342712402, -8.872418403625488, -9.160114288330078, -9.433850288391113, -9.689593315124512, -9.923110008239746, -10.130054473876953, -10.30609130859375, -10.447032928466797, -10.54900074005127, -10.608592987060547, -10.623050689697266, -10.590423583984375, -10.509696960449219, -10.380899429321289, -10.205147743225098, -9.98465347290039, -9.722661018371582, -9.42333984375, -9.091623306274414, -8.733019828796387, -8.353395462036133, -7.9578857421875, -7.551731586456299, -7.140089988708496, -6.727872371673584, -6.319611549377441, -5.919363021850586, -5.530643463134766, -5.156397819519043, -4.798995494842529, -4.460249900817871, -4.141452789306641, -3.8434245586395264, -3.5665676593780518, -3.3109259605407715, -3.076244592666626, -2.862025022506714, -2.66757869720459, -2.492074728012085, -2.334582805633545, -2.194108247756958, -2.069624423980713, -1.960098147392273, -1.8645099401474, -1.7818711996078491, -1.7112363576889038, -1.65171217918396, -1.6024647951126099, -1.5627230405807495, -1.5317811965942383, -1.5089994668960571, -1.4938037395477295, -1.4856836795806885, -1.4841910600662231, -1.4889367818832397, -1.4995884895324707, -1.515866994857788, -1.537543773651123, -1.5644373893737793, -1.5964106321334839, -1.633367896080017, -1.6752523183822632, -1.7220432758331299, -1.7737540006637573, -1.8304295539855957, -1.8921451568603516, -1.9590034484863281, -2.0311341285705566, -2.1086907386779785, -2.1918509006500244, -2.280813694000244, -2.375798463821411, -2.4770429134368896, -2.5848021507263184, -2.6993467807769775, -2.8209593296051025, -2.949934244155884, -3.0865728855133057, -3.2311811447143555, -3.3840651512145996, -3.5455269813537598, -3.715857982635498, -3.8953332901000977, -4.084203243255615, -4.2826828956604, -4.4909443855285645, -4.70910120010376, -4.93719482421875, -5.175178527832031, -5.42289924621582, -5.6800761222839355, -5.9462761878967285, -6.220892906188965, -6.503116607666016, -6.791909694671631, -7.085976600646973, -7.3837385177612305, -7.68330717086792, -7.982468128204346, -8.27866268157959, -8.489163398742676, -8.61737060546875, -8.66693115234375, -8.641947746276855, -8.547128677368164, -8.387869834899902, -8.17025375366211, -7.900979995727539, -7.587240695953369, -7.236544132232666, -6.856518268585205, -6.4547038078308105, -6.038356304168701, -5.614275932312012, -5.18866491317749, -4.767030715942383, -4.354124069213867, -3.9539144039154053, -3.5696017742156982, -3.2036499977111816, -2.857842206954956, -2.53334903717041, -2.2308027744293213, -1.9503754377365112, -1.6918545961380005, -1.4547157287597656, -1.238188624382019, -1.0413168668746948, -0.8630103468894958, -0.7020899057388306, -0.557325541973114, -0.4274674952030182, -0.31127169728279114, -0.2075195014476776, -0.11503328382968903, -0.03268745541572571, 0.040583495050668716, 0.10578006505966187, 0.16383503377437592, 0.21561264991760254, 0.2619093656539917, 0.3034557104110718, 0.34091898798942566, 0.3749067485332489, 0.4059704542160034, 0.43460971117019653, 0.4612763226032257, 0.48637863993644714, 0.5102857947349548, 0.533331573009491, 0.555818498134613, 0.5780215263366699, 0.6001916527748108, 0.6225588917732239, 0.6453359127044678, 0.6687203645706177, 0.6928979158401489, 0.7180445194244385, 0.7443287968635559, 0.7719141840934753, 0.8009608387947083, 0.8316274285316467, 0.8640729784965515, 0.8984584808349609, 0.9349481463432312, 0.9737113118171692, 1.014923334121704, 1.058767318725586, 1.1054353713989258, 1.1551294326782227, 1.2080632448196411, 1.2644630670547485, 1.3245692253112793, 1.3886369466781616, 1.4569381475448608, 1.5297622680664062, 1.6074175834655762, 1.690232515335083, 1.7785567045211792, 1.8727619647979736, 1.9732437133789062, 2.0804216861724854, 2.1947402954101562, 2.3166701793670654, 2.4467077255249023, 2.585374593734741, 2.7332186698913574, 2.890810966491699, 3.0587453842163086, 3.2376348972320557, 3.428107261657715, 3.630800724029541, 3.846355438232422, 4.075404644012451, 4.318562030792236, 4.5764079093933105, 4.849469184875488, 5.13819694519043, 5.442937850952148, 5.76390266418457, 6.101123809814453, 6.453835487365723, 6.820990085601807, 7.201193809509277, 7.592634201049805, 7.993009567260742, 8.399457931518555, 8.808494567871094, 9.215953826904297, 9.616957664489746, 10.005903244018555, 10.376487731933594, 10.721778869628906, 11.034342765808105, 11.306426048278809, 11.530208587646484, 11.698111534118652, 11.80316162109375, 11.839377403259277, 11.802160263061523, 11.688653945922852, 11.498022079467773, 11.2316255569458, 10.893058776855469, 10.488039016723633, 10.024152755737305, 9.510472297668457, 8.957097053527832, 8.374649047851562, 7.773774147033691, 7.164697647094727, 6.556853771209717, 5.958613395690918, 5.37711238861084, 4.81817626953125, 4.286320209503174, 3.784817934036255, 3.3158087730407715, 2.8804361820220947, 2.4789962768554688, 2.1110870838165283, 1.7757515907287598, 1.4716088771820068, 1.1969693899154663, 0.949934720993042, 0.7284802794456482, 0.5305240750312805, 0.35398054122924805, 0.19680269062519073, 0.05701373517513275, -0.06727034598588943, -0.17782564461231232, -0.27631109952926636, -0.3642641305923462, -0.4431001543998718, -0.5141147971153259, -0.5784884691238403, -0.6372923851013184, -0.6914955973625183, -0.7419728636741638, -0.7895124554634094, -0.8348244428634644, -0.8785486221313477, -0.9212623238563538, -0.9634877443313599, -1.0056989192962646, -1.048328161239624, -1.0917725563049316, -1.1363989114761353, -1.1825494766235352, -1.2305458784103394, -1.2806943655014038, -1.3332887887954712, -1.388614296913147, -1.446950912475586, -1.508575439453125, -1.5737651586532593, -1.6427987813949585, -1.7159593105316162, -1.7935354709625244, -1.8758231401443481, -1.963126540184021, -2.0557594299316406, -2.1540451049804688, -2.2583184242248535, -2.3689234256744385, -2.486215829849243, -2.6105599403381348, -2.7423295974731445, -2.8819050788879395, -3.0296709537506104, -3.18601393699646, -3.351317882537842, -3.5259597301483154, -3.7103023529052734, -3.9046883583068848, -4.109430313110352, -4.324799060821533, -4.551013469696045, -4.788222312927246, -5.0364885330200195, -5.295769214630127, -5.515526294708252, -5.698909282684326, -5.848718166351318, -5.967467308044434, -6.057446002960205, -6.120768070220947, -6.159418106079102, -6.175282955169678, -6.170185089111328, -6.145898818969727, -6.1041669845581055, -6.046709060668945, -5.975222110748291, -5.891380786895752, -5.796831130981445, -5.6931843757629395, -5.582006454467773, -5.464807987213135, -5.34303617477417, -5.218062877655029, -5.091177940368652, -4.96358060836792, -4.836376667022705, -4.7105712890625, -4.587071418762207, -4.466681957244873, -4.35011100769043, -4.237969875335693, -4.130779266357422, -4.028973579406738, -3.932907819747925, -3.842864513397217, -3.759059429168701, -3.6816494464874268, -3.6107401847839355, -3.5463919639587402, -3.4886276721954346, -3.4374380111694336, -3.3927884101867676, -3.354624032974243, -3.3228747844696045, -3.2974600791931152, -3.278292655944824, -3.265281915664673, -3.2583374977111816, -3.2573719024658203, -3.262301445007324, -3.27305006980896, -3.289548635482788, -3.3117380142211914, -3.3395681381225586, -3.372999429702759, -3.4120032787323, -3.4565608501434326, -3.5066640377044678, -3.562314033508301, -3.623521089553833, -3.6903038024902344, -3.7626867294311523, -3.84070086479187, -3.9243805408477783, -4.013761520385742, -4.108880043029785, -4.209769248962402, -4.316455841064453, -4.428959369659424, -4.547286033630371, -4.671425819396973, -4.80134916305542, -4.9370012283325195, -5.078295707702637, -5.225111484527588, -5.377285480499268, -5.534605979919434, -5.696805953979492, -5.863556385040283, -6.034458160400391, -6.209036350250244, -6.3867316246032715, -6.566893577575684, -6.748775482177734, -6.931529521942139, -7.114201545715332, -7.2957305908203125, -7.474949359893799, -7.65058708190918, -7.82127571105957, -7.985561847686768, -8.14192008972168, -8.288773536682129, -8.424513816833496, -8.54753589630127, -8.656262397766113, -8.749188423156738, -8.82491397857666, -8.882184028625488, -8.91993522644043, -8.937325477600098, -8.9337739944458, -8.908988952636719, -8.862988471984863, -8.795222282409668, -8.705572128295898, -8.594348907470703, -8.46227741241455, -8.31047248840332, -8.140400886535645, -7.953832626342773, -7.752790451049805, -7.539487361907959, -7.316263198852539, -7.085524082183838, -6.849679470062256, -6.611088752746582, -6.372011661529541, -6.1345672607421875, -5.900702476501465, -5.672170639038086, -5.450514316558838, -5.237059593200684, -5.0329179763793945, -4.838992118835449, -4.655984878540039, -4.484416961669922, -4.324641704559326, -4.176865577697754, -4.041164875030518, -3.9175069332122803, -3.8057682514190674, -3.7057509422302246, -3.6172001361846924, -3.539818048477173, -3.4732773303985596, -3.417232036590576, -3.371328353881836, -3.335211992263794, -3.3085362911224365, -3.290966033935547, -3.282184362411499, -3.281893253326416, -3.2898178100585938, -3.3057079315185547, -3.3293373584747314, -3.3605055809020996, -3.3990366458892822, -3.4447784423828125, -3.497601270675659, -3.557396650314331, -3.6240742206573486, -3.6975607872009277, -3.777796506881714, -3.864732503890991, -3.958327293395996, -4.058543682098389, -4.165344715118408, -4.278687953948975, -4.398523330688477, -4.524785995483398, -4.657392501831055, -4.7962327003479, -4.941165924072266, -5.092011451721191, -5.248544216156006, -5.410484790802002, -5.577491760253906, -5.749154567718506, -5.924984455108643, -6.104406356811523, -6.2867512702941895, -6.471247673034668, -6.657017230987549, -6.843068599700928, -7.028294563293457, -7.211470603942871, -7.39125919342041, -7.566211700439453, -7.734781742095947, -7.89533805847168, -8.046182632446289, -8.185575485229492, -8.311765670776367, -8.423022270202637, -8.517675399780273, -8.594158172607422, -8.65104866027832, -8.687116622924805, -8.701364517211914, -8.69306468963623, -8.661799430847168, -8.6074800491333, -8.530364990234375, -8.431065559387207, -8.31053638458252, -8.170063018798828, -8.011226654052734, -7.835864543914795, -7.646029472351074, -7.443929195404053, -7.231875896453857, -7.012228488922119, -6.787337779998779, -6.5594987869262695, -6.330904483795166, -6.103612422943115, -5.879511833190918, -5.660306453704834, -5.447499752044678, -5.242388725280762, -5.046065330505371, -4.85942268371582, -4.683164119720459, -4.517817974090576, -4.363752365112305, -4.221194267272949, -4.090244770050049, -3.970900774002075, -3.8630683422088623, -3.7665822505950928, -3.681220769882202, -3.606718063354492, -3.542778730392456, -3.4890878200531006, -3.4453201293945312, -3.4111485481262207, -3.386251449584961, -3.370316743850708, -3.3630475997924805, -3.3641645908355713, -3.373408794403076, -3.390542984008789, -3.4153528213500977, -3.4476468563079834, -3.487255573272705, -3.534031629562378, -3.58784818649292, -3.6485965251922607, -3.7161853313446045, -3.790537118911743, -3.871586561203003, -3.9592766761779785, -4.053556442260742, -4.1543755531311035, -4.261682987213135, -4.375420093536377, -4.495517253875732, -4.621888637542725, -4.7544264793396, -4.892995357513428, -5.037425518035889, -5.187506675720215, -5.342979907989502, -5.503531455993652, -5.668784141540527, -5.838290214538574, -6.0115227699279785, -6.187869071960449, -6.3666229248046875, -6.546978950500488, -6.728025436401367, -6.908745288848877, -7.088008403778076, -7.263887405395508, -7.434388637542725, -7.527000904083252, -7.547210216522217, -7.500783920288086, -7.3938093185424805, -7.232691764831543, -7.024099826812744, -6.774876117706299, -6.491919040679932, -6.182051658630371, -5.851886749267578, -5.507696628570557, -5.155307769775391, -4.8000102043151855, -4.446497440338135, -4.0988311767578125, -3.7604329586029053, -3.434095621109009, -3.1220126152038574, -2.8258228302001953, -2.546661376953125, -2.285219430923462, -2.0418026447296143, -1.8163909912109375, -1.6086962223052979, -1.418213129043579, -1.2442691326141357, -1.086065649986267, -0.9427158236503601, -0.8132764101028442, -0.6967743039131165, -0.5922286510467529, -0.4986685812473297, -0.4151473343372345, -0.34075286984443665, -0.2746157646179199, -0.21591460704803467, -0.16387945413589478, -0.11779355257749557, -0.07699374854564667, -0.040869832038879395, -0.008863039314746857, 0.019536053761839867, 0.04479008913040161, 0.06731779873371124, 0.08749702572822571, 0.10566788911819458, 0.12213589251041412, 0.1371750682592392, 0.15103092789649963, 0.16392339766025543, 0.17604951560497284, 0.18758602440357208, 0.19869175553321838, 0.20950990915298462, 0.2201700359582901, 0.23079006373882294, 0.24147792160511017, 0.25233322381973267, 0.26344868540763855, 0.274911493062973, 0.28680455684661865, 0.2992075979709625, 0.3121982216835022, 0.3258528411388397, 0.34024763107299805, 0.3554593026638031, 0.3715659976005554, 0.38864797353744507, 0.40678831934928894, 0.42607375979423523, 0.4465952515602112, 0.46844878792762756, 0.4917360544204712, 0.5165651440620422, 0.5430513024330139, 0.571317732334137, 0.6014963388442993, 0.633728563785553, 0.6681662797927856, 0.7049728035926819, 0.7443236708641052, 0.7864079475402832, 0.831429123878479, 0.8796064853668213, 0.9311761260032654, 0.986392617225647, 1.0455302000045776, 1.1088842153549194, 1.1767730712890625, 1.2495396137237549, 1.3275527954101562, 1.4112098217010498, 1.5009379386901855, 1.5971959829330444, 1.700476884841919, 1.8113092184066772, 1.930259108543396, 2.057931900024414, 2.194973945617676, 2.3420729637145996, 2.49996018409729, 2.6691744327545166, 2.8502910137176514, 3.043914556503296, 3.250669240951538, 3.4711904525756836, 3.706111431121826, 3.956050395965576, 4.221591949462891, 4.50326681137085, 4.801525115966797, 5.116706848144531, 5.449004173278809, 5.7984185218811035, 6.164709091186523, 6.547336101531982, 6.945394039154053, 7.357537746429443, 7.781905174255371, 8.216032981872559, 8.656773567199707, 9.100217819213867, 9.541629791259766, 9.975401878356934, 10.395041465759277, 10.793208122253418, 11.161802291870117, 11.49212646484375, 11.775129318237305, 12.001728057861328, 12.16321086883545, 12.251697540283203, 12.260629653930664, 12.18525505065918, 12.023051261901855, 11.774032592773438, 11.440908432006836, 11.029051780700684, 10.546276092529297, 10.002432823181152, 9.4088716506958, 8.777827262878418, 8.121784210205078, 7.452892303466797, 6.782467842102051, 6.120617389678955, 5.475996494293213, 4.855687141418457, 4.265187740325928, 3.708486557006836, 3.1881940364837646, 2.70571231842041, 2.2614188194274902, 1.8548537492752075, 1.4848958253860474, 1.1499227285385132, 0.8479523658752441, 0.5767620801925659, 0.3339886963367462, 0.11720863729715347, -0.07599849253892899, -0.2480015903711319, -0.4010820984840393, -0.5374089479446411, -0.6590219140052795, -0.7678220868110657, -0.8655681014060974, -0.9538761377334595, -1.0342236757278442, -1.1079555749893188, -1.1762909889221191, -1.240333080291748, -1.3010774850845337, -1.359421968460083, -1.416176438331604, -1.472071886062622, -1.5277698040008545, -1.5838701725006104, -1.6409196853637695, -1.699419379234314, -1.7598313093185425, -1.8225843906402588, -1.8880805969238281, -1.9566996097564697, -2.0288033485412598, -2.1047399044036865, -2.184847116470337, -2.2694549560546875, -2.358889102935791, -2.4534709453582764, -2.553521156311035, -2.659358501434326, -2.7713027000427246, -2.889671802520752, -3.0147833824157715, -3.1469526290893555, -3.2864902019500732, -3.433699131011963, -3.5888729095458984, -3.752289295196533, -3.9242053031921387, -4.104850769042969, -4.2944207191467285, -4.4930644035339355, -4.7008771896362305, -4.9178853034973145, -5.144032001495361, -5.3791632652282715, -5.623006820678711, -5.875155448913574, -6.078813552856445, -6.237485408782959, -6.35440731048584, -6.432617664337158, -6.475021839141846, -6.484437942504883, -6.463637351989746, -6.415366172790527, -6.3423590660095215, -6.24733829498291, -6.133009910583496, -6.00204610824585, -5.857067584991455, -5.700622081756592, -5.535159111022949, -5.363010406494141, -5.186366081237793, -5.007259845733643, -4.827555179595947, -4.648935317993164, -4.472897052764893, -4.300753116607666, -4.133632183074951, -3.972484827041626, -3.8180954456329346, -3.6710898876190186, -3.5319507122039795, -3.401028871536255, -3.278560161590576, -3.164677143096924, -3.0594260692596436, -2.962777614593506, -2.8746421337127686, -2.7948801517486572, -2.723313808441162, -2.6597368717193604, -2.6039233207702637, -2.5556344985961914, -2.514627456665039, -2.480658769607544, -2.443432331085205, -2.4039621353149414, -2.3631398677825928, -2.3217451572418213, -2.280453681945801, -2.2398459911346436, -2.2004175186157227, -2.162585735321045, -2.1267004013061523, -2.0930497646331787, -2.061868906021118, -2.03334641456604, -2.007631778717041, -1.9848397970199585, -1.965057611465454, -1.9483484029769897, -1.9347566366195679, -1.9243115186691284, -1.917030930519104, -1.9129244089126587, -1.9119958877563477, -1.9142457246780396, -1.9196735620498657, -1.9282793998718262, -1.9400657415390015, -1.9550381898880005, -1.9732071161270142, -1.9945886135101318, -2.01920485496521, -2.0470848083496094, -2.07826566696167, -2.1127912998199463, -2.1507151126861572, -2.1920979022979736, -2.2370097637176514, -2.285529136657715, -2.337743043899536, -2.3937480449676514, -2.453648090362549, -2.5175564289093018, -2.5855941772460938, -2.6578900814056396, -2.7345805168151855, -2.8158082962036133, -2.9017226696014404, -2.9924778938293457, -3.0882325172424316, -3.189147472381592, -3.29538631439209, -3.4071109294891357, -3.524482011795044, -3.6476547718048096, -3.776777505874634, -3.9119865894317627, -4.053404808044434, -4.201136112213135, -4.355258941650391, -4.515824317932129, -4.6828460693359375, -4.856295585632324, -5.036093711853027, -5.222102642059326, -5.414114475250244, -5.611843585968018, -5.814915657043457, -6.022854804992676, -6.235074520111084, -6.450864315032959, -6.669381618499756, -6.889638423919678, -7.110496520996094, -7.330658435821533, -7.548666954040527, -7.762904167175293, -7.971596717834473, -8.172830581665039, -8.36456298828125, -8.544655799865723, -8.710899353027344, -8.861061096191406, -8.992932319641113, -9.10438060760498, -9.193412780761719, -9.258240699768066, -9.297343254089355, -9.309529304504395, -9.293991088867188, -9.250356674194336, -9.178714752197266, -9.079639434814453, -8.954184532165527, -8.80387020111084, -8.630642890930176, -8.4368257522583, -8.225050926208496, -7.9981842041015625, -7.759246349334717, -7.511328220367432, -7.257513523101807, -7.000804901123047, -6.744060516357422, -6.489242076873779, -6.238203525543213, -5.992653846740723, -5.754130840301514, -5.523983478546143, -5.3033623695373535, -5.0932207107543945, -4.894317150115967, -4.7072272300720215, -4.532355308532715, -4.369953155517578, -4.220134258270264, -4.082895755767822, -3.9581329822540283, -3.845660448074341, -3.7452266216278076, -3.6565299034118652, -3.5792317390441895, -3.5129709243774414, -3.4573721885681152, -3.4120566844940186, -3.376649856567383, -3.3507866859436035, -3.334118127822876, -3.3263144493103027, -3.3270678520202637, -3.336094617843628, -3.353137493133545, -3.3779637813568115, -3.410367727279663, -3.4501683712005615, -3.497208595275879, -3.55135440826416, -3.612492322921753, -3.6805269718170166, -3.7553796768188477, -3.836984395980835, -3.9252851009368896, -4.020232677459717, -4.121780872344971, -4.229881763458252, -4.344481945037842, -4.465517997741699, -4.592910289764404, -4.726557731628418, -4.866332054138184, -5.01207160949707, -5.163572788238525, -5.320585250854492, -5.482802391052246, -5.6498541831970215, -5.821297645568848, -5.996612071990967, -6.175187587738037, -6.356320381164551, -6.539203643798828, -6.722923755645752, -6.906455993652344, -7.088662147521973, -7.268291473388672, -7.443982124328613, -7.614272117614746, -7.777608394622803, -7.932361125946045, -8.076848030090332, -8.209356307983398, -8.328177452087402, -8.43163776397705, -8.518139839172363, -8.586203575134277, -8.634509086608887, -8.66193962097168, -8.667620658874512, -8.650958061218262, -8.611662864685059, -8.549779891967773, -8.465692520141602, -8.360126495361328, -8.234139442443848, -8.08909797668457, -7.926643371582031, -7.748655796051025, -7.557201385498047, -7.354482173919678, -7.142781734466553, -6.924411296844482, -6.701657772064209, -6.476738452911377, -6.251760005950928, -6.028686046600342, -5.809310436248779, -5.595242023468018, -5.387890338897705, -5.1884660720825195, -4.997981071472168, -4.817254066467285, -4.646925449371338, -4.487468242645264, -4.33920431137085, -4.202322483062744, -4.076895713806152, -3.962898015975952, -3.860220432281494, -3.768688917160034, -3.688076972961426, -3.618119716644287, -3.558525323867798, -3.5089855194091797, -3.469184160232544, -3.438805103302002, -3.4175384044647217, -3.4050843715667725, -3.4011590480804443, -3.405496120452881, -3.417848825454712, -3.4379920959472656, -3.4657223224639893, -3.5008583068847656, -3.5432395935058594, -3.592726469039917, -3.649198293685913, -3.7125513553619385, -3.7826974391937256, -3.859560251235962, -3.9430742263793945, -4.033179759979248, -4.129821300506592, -4.2329421043396, -4.34248161315918, -4.458369255065918, -4.580522537231445, -4.708837032318115, -4.843186378479004, -4.9834113121032715, -5.129316329956055, -5.280661582946777, -5.437156677246094, -5.598451614379883, -5.764130592346191, -5.933704376220703, -6.106602668762207, -6.282166481018066, -6.4596428871154785, -6.638178825378418, -6.816816329956055, -6.994492053985596, -7.1700358390808105, -7.342172622680664, -7.509531021118164, -7.670650005340576, -7.823994159698486, -7.967970848083496, -8.100953102111816, -8.221308708190918, -8.327427864074707, -8.417760848999023, -8.490856170654297, -8.54539966583252, -8.580254554748535, -8.594500541687012, -8.587465286254883, -8.558762550354004, -8.508304595947266, -8.436326026916504, -8.343381881713867, -8.230344772338867, -8.09839153289795, -7.948969841003418, -7.783771514892578, -7.604685306549072, -7.41375207901001, -7.2131147384643555, -7.004966735839844, -6.791502952575684, -6.574875831604004, -6.357152462005615, -6.140280723571777, -5.926063537597656, -5.716134548187256, -5.511949062347412, -5.3147735595703125, -5.125686168670654, -4.945580959320068, -4.775174617767334, -4.615019798278809, -4.465517044067383, -4.326930999755859, -4.199407577514648, -4.082987308502197, -3.9776244163513184, -3.883200168609619, -3.7995381355285645, -3.72641658782959, -3.6635818481445312, -3.6107571125030518, -3.567652463912964, -3.533972978591919, -3.5094246864318848, -3.493720769882202, -3.4865853786468506, -3.4877569675445557, -3.496990919113159, -3.514061212539673, -3.538761854171753, -3.570906162261963, -3.6103272438049316, -3.656877279281616, -3.710426092147827, -3.770860195159912, -3.8380796909332275, -3.911997079849243, -3.9925343990325928, -4.079619407653809, -4.173183917999268, -4.273158550262451, -4.379469871520996, -4.492035388946533, -4.610759735107422, -4.735528945922852, -4.82009744644165, -4.868595600128174, -4.884974479675293, -4.873006820678711, -4.836282730102539, -4.778208255767822, -4.70199728012085, -4.610665798187256, -4.507026195526123, -4.393680572509766, -4.273017883300781, -4.147212982177734, -4.018224239349365, -3.8877992630004883, -3.757479190826416, -3.6286070346832275, -3.5023369789123535, -3.379645586013794, -3.261345624923706, -3.1480987071990967, -3.04042911529541, -2.938739776611328, -2.843324661254883, -2.754383087158203, -2.6720337867736816, -2.5963263511657715, -2.5272531509399414, -2.4647600650787354, -2.4087560176849365, -2.359121561050415, -2.3157167434692383, -2.278388261795044, -2.246974468231201, -2.22131085395813, -2.2012343406677246, -2.186587333679199, -2.1772196292877197, -2.17299222946167, -2.1737775802612305, -2.1794631481170654, -2.189950704574585, -2.2051584720611572, -2.2250208854675293, -2.2494900226593018, -2.278534173965454, -2.3121395111083984, -2.350309133529663, -2.3930628299713135, -2.4404373168945312, -2.492485523223877, -2.5492756366729736, -2.610891819000244, -2.6774322986602783, -2.7490100860595703, -2.8257503509521484, -2.9077913761138916, -2.995281934738159, -3.08838152885437, -3.187257766723633, -3.2920854091644287, -3.4030442237854004, -3.5203170776367188, -3.6440865993499756, -3.7745330333709717, -3.911829948425293, -4.056140899658203, -4.207614421844482, -4.366377353668213, -4.532530784606934, -4.706140518188477, -4.887231826782227, -5.075777530670166, -5.271689414978027, -5.474806308746338, -5.684882640838623, -5.90157413482666, -6.124425411224365, -6.352852821350098, -6.5861310958862305, -6.823378562927246, -7.063542366027832, -7.305384159088135, -7.5474724769592285, -7.788173675537109, -8.02564811706543, -8.257855415344238, -8.482563972473145, -8.697367668151855, -8.899715423583984, -9.08695125579834, -9.256361961364746, -9.405237197875977, -9.530943870544434, -9.631002426147461, -9.703169822692871, -9.74553108215332, -9.756575584411621, -9.73528003692627, -9.681164741516113, -9.594345092773438, -9.47554874420166, -9.325159072875977, -9.144275665283203, -8.934671401977539, -8.698725700378418, -8.4393310546875, -8.159790992736816, -7.863703727722168, -7.55483341217041, -7.236998081207275, -6.91395378112793, -6.589299201965332, -6.266392230987549, -5.948287487030029, -5.637692928314209, -5.336944580078125, -5.047994613647461, -4.772419452667236, -4.511434078216553, -4.265917778015137, -4.036445617675781, -3.823322057723999, -3.626619577407837, -3.4462130069732666, -3.2818167209625244, -3.1330158710479736, -2.999298334121704, -2.8800811767578125, -2.7747347354888916, -2.6826024055480957, -2.603019952774048, -2.535327434539795, -2.4788830280303955, -2.4330713748931885, -2.397310495376587, -2.3710575103759766, -2.3538119792938232, -2.345118522644043, -2.3445680141448975, -2.351797580718994, -2.3430449962615967, -2.320780038833618, -2.2872934341430664, -2.24468731880188, -2.194871664047241, -2.1395645141601562, -2.080296516418457, -2.0184168815612793, -1.9551023244857788, -1.8913681507110596, -1.8280789852142334, -1.76596200466156, -1.7056190967559814, -1.6475398540496826, -1.592113971710205, -1.539643406867981, -1.4903538227081299, -1.4444050788879395, -1.4019016027450562, -1.3629014492034912, -1.3274239301681519, -1.2954579591751099, -1.266968011856079, -1.2419002056121826, -1.2201870679855347, -1.2017524242401123, -1.1865147352218628, -1.1743903160095215, -1.1652965545654297, -1.1591533422470093, -1.1558855772018433, -1.1554243564605713, -1.1577084064483643, -1.1626847982406616, -1.1703100204467773, -1.1805500984191895, -1.1933817863464355, -1.2087920904159546, -1.2267792224884033, -1.2473523616790771, -1.2705318927764893, -1.2963496446609497, -1.3248491287231445, -1.3560850620269775, -1.3901242017745972, -1.4270447492599487, -1.4669373035430908, -1.509904146194458, -1.5560599565505981, -1.605531930923462, -1.6584596633911133, -1.7149957418441772, -1.775305986404419, -1.839569091796875, -1.9079777002334595, -1.9807379245758057, -2.058069944381714, -2.140207529067993, -2.2273991107940674, -2.3199069499969482, -2.418006658554077, -2.5219879150390625, -2.6321535110473633, -2.7488179206848145, -2.872307062149048, -3.0029561519622803, -3.141108989715576, -3.2871134281158447, -3.4413204193115234, -3.604078769683838, -3.7757301330566406, -3.9566047191619873, -4.147012233734131, -4.34723424911499, -4.5575151443481445, -4.778048038482666, -5.0089616775512695, -5.250305652618408, -5.502029895782471, -5.763964653015137, -6.035797595977783, -6.317046165466309, -6.607031345367432, -6.90484619140625, -7.20932674407959, -7.51901912689209, -7.832149505615234, -8.146599769592285, -8.459884643554688, -8.76913833618164, -9.071114540100098, -9.362198829650879, -9.63844108581543, -9.895606994628906, -10.129261016845703, -10.334864616394043, -10.507911682128906, -10.64407730102539, -10.739389419555664, -10.790412902832031, -10.79442310333252, -10.748497009277344, -10.650843620300293, -10.500923156738281, -10.299513816833496, -10.0487060546875, -9.751845359802246, -9.4133939743042, -9.03874397277832, -8.63398551940918, -8.205648422241211, -7.760437965393066, -7.304987907409668, -6.845637798309326, -6.388251304626465, -5.938079357147217, -5.499671459197998, -5.076832294464111, -4.672611713409424, -4.289333343505859, -3.928642749786377, -3.5915732383728027, -3.2786202430725098, -2.989820957183838, -2.7248330116271973, -2.4830098152160645, -2.2634682655334473, -2.0651519298553467, -1.8868844509124756, -1.7274162769317627, -1.5854624509811401, -1.4597347974777222, -1.3489665985107422, -1.2519325017929077, -1.1674625873565674, -1.0944530963897705, -1.0318729877471924, -0.9787680506706238, -0.9342626929283142, -0.8975595831871033, -0.867938220500946, -0.8447523713111877, -0.8274267315864563, -0.8154529929161072, -0.808385968208313, -0.8058393597602844, -0.8074814081192017, -0.8130308389663696, -0.8222531080245972, -0.8349564671516418, -0.8509886860847473, -0.8702338337898254, -0.8926094174385071, -0.918063759803772, -0.9465739727020264, -0.9781435132026672, -1.012800931930542, -1.0505980253219604, -1.0916087627410889, -1.1359283924102783, -1.1836720705032349, -1.2349750995635986, -1.2899914979934692, -1.3488942384719849, -1.4118751287460327, -1.4791438579559326, -1.5509289503097534, -1.6274770498275757, -1.7090532779693604, -1.7959411144256592, -1.8884423971176147, -1.986877202987671, -2.091583490371704, -2.2029168605804443, -2.3212502002716064, -2.446971893310547, -2.5804855823516846, -2.72220778465271, -2.872565269470215, -3.0319924354553223, -3.200927972793579, -3.379808187484741, -3.5690624713897705, -3.7691049575805664, -3.980325222015381, -4.2030768394470215, -4.437664031982422, -4.684326171875, -4.943218231201172, -5.214387893676758, -5.497751712799072, -5.793064594268799, -6.099889278411865, -6.417557239532471, -6.745131492614746, -7.081363677978516, -7.424653053283691, -7.773000717163086, -8.123973846435547, -8.4746675491333, -8.821682929992676, -9.161116600036621, -9.488570213317871, -9.79918098449707, -10.087691307067871, -10.348543167114258, -10.57601261138916, -10.764389991760254, -10.908182144165039, -11.002349853515625, -11.042557716369629, -11.025424003601074, -10.948745727539062, -10.811684608459473, -10.614887237548828, -10.360529899597168, -10.05227279663086, -9.695130348205566, -9.295256614685059, -8.85968017578125, -8.395989418029785, -7.912011623382568, -7.41550350189209, -6.913880348205566, -6.4139838218688965, -5.921921253204346, -5.442951202392578, -4.981436252593994, -4.540835857391357, -4.123744964599609, -3.7319562435150146, -3.3665454387664795, -3.0279645919799805, -2.716139078140259, -2.430565118789673, -2.170397996902466, -1.9345340728759766, -1.7216840982437134, -1.5304349660873413, -1.3593021631240845, -1.2067735195159912, -1.0713435411453247, -0.9515411853790283, -0.8459500670433044, -0.7532234191894531, -0.6720945239067078, -0.6013830304145813, -0.5399978756904602, -0.48693791031837463, -0.44129085540771484, -0.40223026275634766, -0.3690117597579956, -0.34096840023994446, -0.3174688518047333, -0.2979586720466614, -0.28195229172706604, -0.2690258324146271, -0.2588103115558624, -0.25098544359207153, -0.2452741116285324, -0.2414373904466629, -0.23926988244056702, -0.23859582841396332, -0.23926541209220886, -0.24115155637264252, -0.2441471815109253, -0.248162642121315, -0.25312352180480957, -0.2589688003063202, -0.26564905047416687, -0.27100157737731934, -0.27522799372673035, -0.27851247787475586, -0.28102222084999084, -0.28290823101997375, -0.2843061685562134, -0.2853373885154724, -0.28610995411872864, -0.2867197096347809, -0.28725144267082214, -0.28777992725372314, -0.28837087750434875, -0.2890821397304535, -0.2899644672870636, -0.29106250405311584, -0.29241564869880676, -0.2940587103366852, -0.29602277278900146, -0.2983356714248657, -0.30102279782295227, -0.3041074573993683, -0.30761152505874634, -0.31155577301979065, -0.3159602880477905, -0.32084497809410095, -0.32622969150543213, -0.33213475346565247, -0.33858102560043335, -0.34559035301208496, -0.3531857430934906, -0.36139151453971863, -0.3702336549758911, -0.3797399401664734, -0.3899401128292084, -0.40086624026298523, -0.4125526547431946, -0.4250364601612091, -0.43835747241973877, -0.45255860686302185, -0.4676860272884369, -0.4837893843650818, -0.5009220838546753, -0.5191415548324585, -0.5385094881057739, -0.5590920448303223, -0.5809604525566101, -0.60419100522995, -0.628865659236908, -0.6550723314285278, -0.6829053163528442, -0.7124655842781067, -0.7438615560531616, -0.7772092819213867, -0.8126333355903625, -0.8502669334411621, -0.890252947807312, -0.9327442646026611, -0.9779047966003418, -1.0259097814559937, -1.0769469738006592, -1.131217122077942, -1.1889348030090332, -1.250329852104187, -1.3156476020812988, -1.3851499557495117, -1.459116816520691, -1.537846565246582, -1.6216570138931274, -1.7108867168426514, -1.8058956861495972, -1.9070662260055542, -2.014803647994995, -2.1295366287231445, -2.2517178058624268, -2.381824493408203, -2.5203568935394287, -2.6678390502929688, -2.8248159885406494, -2.9918527603149414, -3.1695313453674316, -3.358445882797241, -3.5591981410980225, -3.7723891735076904, -3.9986112117767334, -4.2384352684021, -4.492397308349609, -4.760979175567627, -5.044588088989258, -5.34352970123291, -5.657975673675537, -5.9879279136657715, -6.3331756591796875, -6.693244457244873, -7.067342281341553, -7.4542951583862305, -7.852483749389648, -8.259771347045898, -8.673437118530273, -9.090105056762695, -9.505696296691895, -9.91538143157959, -10.312625885009766, -10.69017505645752, -11.040142059326172, -11.354146003723145, -11.623529434204102, -11.839654922485352, -11.994264602661133, -12.079898834228516, -12.090337753295898, -12.021042823791504, -11.868322372436523, -11.630977630615234, -11.31048583984375, -10.911012649536133, -10.439242362976074, -9.904031753540039, -9.31592082977295, -8.686549186706543, -8.028040885925293, -7.352413177490234, -6.6710591316223145, -5.9943437576293945, -5.331319808959961, -4.689567565917969, -4.07514762878418, -3.4926421642303467, -2.945258617401123, -2.434979200363159, -1.9627312421798706, -1.5285630226135254, -1.1318144798278809, -0.771274745464325, -0.4453222453594208, -0.152045339345932, 0.11065596342086792, 0.3449869453907013, 0.5531913042068481, 0.7374990582466125, 0.9000865817070007, 1.043047547340393, 1.168371558189392, 1.277931571006775, 1.373474359512329, 1.456618070602417, 1.5288511514663696, 1.5915348529815674, 1.6459076404571533, 1.6930904388427734, 1.7340933084487915, 1.7698227167129517, 1.8010880947113037, 1.8286103010177612, 1.8530279397964478, 1.8749054670333862, 1.8947389125823975, 1.9129631519317627, 1.9299577474594116, 1.9460523128509521, 1.9615319967269897, 1.97664213180542, 1.991592526435852, 2.006561517715454, 2.0216994285583496, 2.0371317863464355, 2.0438647270202637, 2.043321132659912, 2.036795139312744, 2.0254554748535156, 2.0103509426116943, 1.9924179315567017, 1.9724853038787842, 1.9512840509414673, 1.9294536113739014, 1.90755033493042, 1.8860549926757812, 1.8653801679611206, 1.8458781242370605, 1.8278470039367676, 1.811537742614746, 1.7971603870391846, 1.7848891019821167, 1.7748680114746094, 1.7672157287597656, 1.7620296478271484, 1.7593897581100464, 1.7593623399734497, 1.7620031833648682, 1.767359972000122, 1.7754749059677124, 1.7863872051239014, 1.800134539604187, 1.816754698753357, 1.8362876176834106, 1.8587756156921387, 1.884265422821045, 1.9128086566925049, 1.944462537765503, 1.9792907238006592, 2.0173637866973877, 2.0587596893310547, 2.1035642623901367, 2.1518712043762207, 2.2037832736968994, 2.2594106197357178, 2.3188726902008057, 2.3822970390319824, 2.4498205184936523, 2.521587371826172, 2.597750425338745, 2.6784701347351074, 2.7639143466949463, 2.8542568683624268, 2.9496777057647705, 3.0503616333007812, 3.15649676322937, 3.2682723999023438, 3.3858790397644043, 3.5095043182373047, 3.6393306255340576, 3.775533437728882, 3.918275833129883, 4.0677056312561035, 4.223949432373047, 4.387108325958252, 4.557249546051025, 4.734401226043701, 4.918543815612793, 5.109598636627197, 5.307421684265137, 5.511789798736572, 5.722389221191406, 5.9388041496276855, 6.160501480102539, 6.386819839477539, 6.6169538497924805, 6.849942684173584, 7.084657669067383, 7.319792747497559, 7.553857326507568, 7.785171985626221, 8.011873245239258, 8.231916427612305, 8.443097114562988, 8.64306926727295, 8.829378128051758, 8.999507904052734, 9.150927543640137, 9.281155586242676, 9.387826919555664, 9.468770980834961, 9.522086143493652, 9.54621696472168, 9.54002857208252, 9.502861976623535, 9.34872817993164, 9.087831497192383, 8.732053756713867, 8.294683456420898, 7.790002346038818, 7.2327656745910645, 6.637650966644287, 6.018735408782959, 5.389047622680664, 4.760223865509033, 4.142292022705078, 3.5435688495635986, 2.9706599712371826, 2.428544282913208, 1.9207122325897217, 1.4493404626846313, 1.0154818296432495, 0.6192562580108643, 0.2600319981575012, -0.06340905278921127, -0.35272499918937683, -0.6098881959915161, -0.837079644203186, -1.0366016626358032, -1.2108080387115479, -1.362047553062439, -1.4926221370697021, -1.6047534942626953, -1.7005600929260254, -1.782041311264038, -1.8510667085647583, -1.9093714952468872, -1.9585542678833008, -2.0000791549682617, -2.0352797508239746, -2.065363645553589, -2.0914204120635986, -2.114428758621216, -2.1352651119232178, -2.1547107696533203, -2.173462152481079, -2.1921377182006836, -2.211286783218384, -2.2313971519470215, -2.2529022693634033, -2.276188373565674, -2.301600933074951, -2.3294503688812256, -2.3600175380706787, -2.3935587406158447, -2.430309772491455, -2.4704906940460205, -2.5143086910247803, -2.5619618892669678, -2.6136412620544434, -2.6695332527160645, -2.7298221588134766, -2.794692039489746, -2.8643267154693604, -2.9389121532440186, -3.018636465072632, -3.1036903858184814, -3.194267511367798, -3.2905635833740234, -3.3927760124206543, -3.5011026859283447, -3.61574125289917, -3.7368855476379395, -3.8647241592407227, -3.9994378089904785, -4.1411943435668945, -4.290145397186279, -4.446420669555664, -4.610122203826904, -4.781317710876465, -4.960031986236572, -5.146238803863525, -5.339849948883057, -5.54070520401001, -5.748559951782227, -5.963071346282959, -6.183785915374756, -6.410123825073242, -6.64136266708374, -6.876626491546631, -7.1148681640625, -7.354857444763184, -7.5951714515686035, -7.834186553955078, -8.070075988769531, -8.300811767578125, -8.524176597595215, -8.73777961730957, -8.939087867736816, -9.125459671020508, -9.29419994354248, -9.44261360168457, -9.568082809448242, -9.66813850402832, -9.740549087524414, -9.783404350280762, -9.794222831726074, -9.771101951599121, -9.71279239654541, -9.618752479553223, -9.489188194274902, -9.325057983398438, -9.1280517578125, -8.900538444519043, -8.645485877990723, -8.366353988647461, -8.06697940826416, -7.751435279846191, -7.423907279968262, -7.088558197021484, -6.749417304992676, -6.410278797149658, -6.0746259689331055, -5.745571136474609, -5.425821304321289, -5.117660999298096, -4.822953701019287, -4.543153762817383, -4.279335021972656, -4.032222270965576, -3.8022289276123047, -3.5894997119903564, -3.393949508666992, -3.2153050899505615, -3.0531413555145264, -2.9069178104400635, -2.776007890701294, -2.6597275733947754, -2.557359218597412, -2.468170642852783, -2.391432285308838, -2.3264310359954834, -2.2724804878234863, -2.2289297580718994, -2.195168972015381, -2.170633316040039, -2.1548073291778564, -2.147224187850952, -2.1474685668945312, -2.1551737785339355, -2.1700234413146973, -2.1917479038238525, -2.220123529434204, -2.2549703121185303, -2.296149969100952, -2.3435635566711426, -2.397148370742798, -2.4568769931793213, -2.5227534770965576, -2.5948116779327393, -2.6731128692626953, -2.7577428817749023, -2.848809242248535, -2.9464399814605713, -3.05077862739563, -3.1619832515716553, -3.280221700668335, -3.4056692123413086, -3.538503646850586, -3.678900718688965, -3.8270294666290283, -3.983046770095825, -4.147089958190918, -4.319269180297852, -4.499661445617676, -4.688296318054199, -4.885150909423828, -5.090132713317871, -5.303071022033691, -5.523697853088379, -5.751636028289795, -5.986380100250244, -6.227280616760254, -6.47352409362793, -6.72411584854126, -6.97786283493042, -7.233357906341553, -7.488966941833496, -7.742819786071777, -7.9928059577941895, -8.236578941345215, -8.471569061279297, -8.6950044631958, -8.903948783874512, -9.095344543457031, -9.266080856323242, -9.413061141967773, -9.533296585083008, -9.623997688293457, -9.68267822265625, -9.707258224487305, -9.696161270141602, -9.64840316772461, -9.563654899597168, -9.442293167114258, -9.285412788391113, -9.094812393188477, -8.872947692871094, -8.622857093811035, -8.348064422607422, -8.05245304107666, -7.739312648773193, -7.412184238433838, -7.074739456176758, -6.730655670166016, -6.383510589599609, -6.036687850952148, -5.693304538726807, -5.3561577796936035, -5.027688980102539, -4.709965229034424, -4.404679775238037, -4.113160133361816, -3.8363900184631348, -3.57503604888916, -3.3294808864593506, -3.0998566150665283, -2.886082172393799, -2.687896728515625, -2.5048930644989014, -2.336548328399658, -2.1822519302368164, -2.041330099105835, -1.9130663871765137, -1.7967214584350586, -1.6915475130081177, -1.5968009233474731, -1.5117526054382324, -1.4356958866119385, -1.367952585220337, -1.3078774213790894, -1.2548606395721436, -1.2083302736282349, -1.1677526235580444, -1.1326324939727783, -1.1025127172470093, -1.076972484588623, -1.0556268692016602, -1.0381240844726562, -1.0241446495056152, -1.0133987665176392, -1.0056241750717163, -1.0005850791931152, -0.9980688095092773, -0.9978851079940796, -0.99986332654953, -1.0038514137268066, -1.0097135305404663, -1.0173290967941284, -1.0265908241271973, -1.0374035835266113, -1.0496830940246582, -1.0633549690246582, -1.0783531665802002, -1.0946192741394043, -1.1121015548706055, -1.1307543516159058, -1.1505368947982788, -1.1714128255844116, -1.1933497190475464, -1.216318130493164, -1.2402912378311157, -1.2652446031570435, -1.2911553382873535, -1.318001627922058, -1.3457629680633545, -1.37441885471344, -1.40394926071167, -1.4343341588974, -1.465552806854248, -1.4975837469100952, -1.530404806137085, -1.5639922618865967, -1.5983211994171143, -1.6333647966384888, -1.6690945625305176, -1.7054795026779175, -1.742486834526062, -1.7800809144973755, -1.8182233572006226, -1.8568733930587769, -1.8959869146347046, -1.9321743249893188, -1.9660617113113403, -1.9982104301452637, -2.029122829437256, -2.0592496395111084, -2.088994264602661, -2.118718385696411, -2.148747205734253, -2.179373025894165, -2.210860013961792, -2.2434470653533936, -2.277351140975952, -2.3127706050872803, -2.3498878479003906, -2.38887095451355, -2.4298765659332275, -2.4730513095855713, -2.51853346824646, -2.5664544105529785, -2.6169393062591553, -2.670109272003174, -2.726081132888794, -2.784968137741089, -2.846881151199341, -2.911928653717041, -2.9802162647247314, -3.051847457885742, -3.1269235610961914, -3.20554256439209, -3.287799835205078, -3.373785972595215, -3.4635872840881348, -3.557284116744995, -3.65494966506958, -3.7566487789154053, -3.8624355792999268, -3.9723525047302246, -4.086427211761475, -4.2046709060668945, -4.327075004577637, -4.453608989715576, -4.58421516418457, -4.718808174133301, -4.857268810272217, -4.9994401931762695, -5.145125389099121, -5.294081211090088, -5.446014404296875, -5.600576877593994, -5.757361888885498, -5.915900707244873, -6.075657367706299, -6.236026287078857, -6.396331310272217, -6.555822372436523, -6.713677406311035, -6.869004249572754, -7.020843029022217, -7.168171405792236, -7.309915065765381, -7.4449567794799805, -7.572149276733398, -7.690330982208252, -7.798346996307373, -7.895065784454346, -7.979405403137207, -8.050355911254883, -8.107007026672363, -8.148567199707031, -8.174394607543945, -8.184015274047852, -8.177142143249512, -8.153692245483398, -8.11379337310791, -8.057793617248535, -7.98625373840332, -7.899947166442871, -7.799841403961182, -7.6870808601379395, -7.562963962554932, -7.428915500640869, -7.28645658493042, -7.137173175811768, -6.98268461227417, -6.824613571166992, -6.664555549621582, -6.504056930541992, -6.344588279724121, -6.187529563903809, -6.034154415130615, -5.885620594024658, -5.742964744567871, -5.6070990562438965, -5.478812217712402, -5.358774185180664, -5.247541427612305, -5.145566463470459, -5.053203105926514, -4.9707207679748535, -4.898311614990234, -4.836102485656738, -4.783675193786621, -4.740631103515625, -4.706592082977295, -4.68072509765625, -4.66227388381958, -4.6505513191223145, -4.6449294090271, -4.644833564758301, -4.649734020233154, -4.659141540527344, -4.672601699829102, -4.6896891593933105, -4.7100043296813965, -4.733170509338379, -4.758827209472656, -4.7866315841674805, -4.8162522315979, -4.847370624542236, -4.879674434661865, -4.9128618240356445, -4.946634292602539, -4.980700969696045, -5.014774799346924, -5.0485734939575195, -5.081817626953125, -5.11423397064209, -5.145552635192871, -5.175509452819824, -5.203846454620361, -5.230312347412109, -5.254663944244385, -5.27666711807251, -5.296098232269287, -5.312745571136475, -5.326412200927734, -5.336913585662842, -5.3440842628479, -5.347774982452393, -5.347856044769287, -5.344217777252197, -5.336773872375488, -5.32545804977417, -5.3102288246154785, -5.291067600250244, -5.267980098724365, -5.24099588394165, -5.21016788482666, -5.175571918487549, -5.1373066902160645, -5.095491409301758, -5.050265312194824, -5.001785755157471, -4.9502272605896, -4.895777702331543, -4.838638782501221, -4.779021739959717, -4.7171478271484375, -4.653242111206055, -4.5875349044799805, -4.52025842666626, -4.451644420623779, -4.381922245025635, -4.311317443847656, -4.240049839019775, -4.168331623077393, -4.096367359161377, -4.024351119995117, -3.9524664878845215, -3.8808863162994385, -3.8097708225250244, -3.7392680644989014, -3.66951322555542, -3.5894112586975098, -3.501248836517334, -3.407094717025757, -3.308803081512451, -3.208021640777588, -3.1061978340148926, -3.0045909881591797, -2.904282808303833, -2.8061904907226562, -2.7110793590545654, -2.619576930999756, -2.53218674659729, -2.4493014812469482, -2.3712158203125, -2.298140525817871, -2.2302122116088867, -2.167505979537964, -2.1100456714630127, -2.057811737060547, -2.010751485824585, -1.9687854051589966, -1.9318140745162964, -1.8997247219085693, -1.872395396232605, -1.84969961643219, -1.8315106630325317, -1.8177039623260498, -1.8081601858139038, -1.8027671575546265, -1.8014219999313354, -1.8040320873260498, -1.8105162382125854, -1.8208057880401611, -1.8348451852798462, -1.8525922298431396, -1.8740184307098389, -1.8991092443466187, -1.9278641939163208, -1.9602971076965332, -1.996435284614563, -2.036320209503174, -2.080007314682007, -2.1275649070739746, -2.1790754795074463, -2.2346339225769043, -2.29434871673584, -2.358340263366699, -2.426741361618042, -2.499696731567383, -2.577362537384033, -2.659904956817627, -2.7475013732910156, -2.840337038040161, -2.9386067390441895, -3.042511463165283, -3.1522576808929443, -3.268056631088257, -3.390120029449463, -3.518660068511963, -3.6538848876953125, -3.795994997024536, -3.9451804161071777, -4.101614952087402, -4.265451431274414, -4.436813831329346, -4.6157917976379395, -4.802431106567383, -4.996725082397461, -5.198602676391602, -5.4079179763793945, -5.624436378479004, -5.847821235656738, -6.0776190757751465, -6.313241958618164, -6.553954124450684, -6.798852920532227, -7.046855449676514, -7.296683311462402, -7.546850681304932, -7.795655250549316, -8.041177749633789, -8.281278610229492, -8.5136137008667, -8.735651016235352, -8.94469928741455, -9.137953758239746, -9.312541961669922, -9.465597152709961, -9.594329833984375, -9.696114540100098, -9.768582344055176, -9.809711456298828, -9.817923545837402, -9.792157173156738, -9.73194408416748, -9.637447357177734, -9.50949478149414, -9.349567413330078, -9.159770011901855, -8.942774772644043, -8.701733589172363, -8.439288139343262, -8.158493041992188, -7.86269998550415, -7.555436611175537, -7.24029016494751, -6.92080020904541, -6.600362777709961, -6.282150745391846, -5.96905517578125, -5.663640022277832, -5.368119716644287, -5.084346771240234, -4.813817501068115, -4.5576863288879395, -4.3167901039123535, -4.0916748046875, -3.882631301879883, -3.6897265911102295, -3.51284122467041, -3.3517005443573, -3.2059075832366943, -3.0749709606170654, -2.958331346511841, -2.855384349822998, -2.7654993534088135, -2.688037872314453, -2.6223654747009277, -2.5678651332855225, -2.52394437789917, -2.4900429248809814, -2.4656388759613037, -2.4502499103546143, -2.4434382915496826, -2.444809913635254, -2.4540159702301025, -2.470752000808716, -2.4947574138641357, -2.525813102722168, -2.563741445541382, -2.608402729034424, -2.659693956375122, -2.7175464630126953, -2.7819228172302246, -2.8528151512145996, -2.9302420616149902, -3.0142459869384766, -3.1048905849456787, -3.2022571563720703, -3.3064422607421875, -3.417553186416626, -3.535705327987671, -3.6610169410705566, -3.7936055660247803, -3.9335825443267822, -4.081047534942627, -4.236082553863525, -4.39874267578125, -4.569052696228027, -4.7469940185546875, -4.932497024536133, -5.125430583953857, -5.325588703155518, -5.532680511474609, -5.746314525604248, -5.96598482131958, -6.191057205200195, -6.420753479003906, -6.6541361808776855, -6.890097141265869], "y": [-10.0, -9.949999809265137, -9.845866203308105, -9.69981575012207, -9.519610404968262, -9.309910774230957, -9.07337760925293, -8.811534881591797, -8.525410652160645, -8.216001510620117, -7.884577751159668, -7.53287410736084, -7.163171768188477, -6.778306007385254, -6.381607532501221, -5.976800918579102, -5.567870616912842, -5.158911228179932, -4.753973960876465, -4.356922149658203, -3.971306800842285, -3.6002626419067383, -3.24643611907959, -2.911942958831787, -2.598353624343872, -2.30670428276062, -2.0375301837921143, -1.790913701057434, -1.5665431022644043, -1.3637775182724, -1.1817127466201782, -1.0192444324493408, -0.8751280903816223, -0.748030424118042, -0.6365754008293152, -0.5393813252449036, -0.45509129762649536, -0.3823964297771454, -0.3200529217720032, -0.2668938934803009, -0.221836656332016, -0.18388639390468597, -0.15213686227798462, -0.12576894462108612, -0.10404747724533081, -0.08631695061922073, -0.07199640572071075, -0.060573894530534744, -0.05160076916217804, -0.04468589276075363, -0.03949003294110298, -0.03572046756744385, -0.03312588483095169, -0.03149164095520973, -0.030635390430688858, -0.030403053387999535, -0.030665213242173195, -0.031313829123973846, -0.032259318977594376, -0.03342795372009277, -0.034759558737277985, -0.036205489188432693, -0.03772686794400215, -0.03929302841424942, -0.04088017717003822, -0.04247025400400162, -0.044049929827451706, -0.04560976102948189, -0.04714346304535866, -0.04864730313420296, -0.05011959746479988, -0.051560256630182266, -0.05297044292092323, -0.054352276027202606, -0.055708568543195724, -0.05704265460371971, -0.05835820734500885, -0.059659119695425034, -0.06094939261674881, -0.06223307177424431, -0.06351418048143387, -0.06479666382074356, -0.0660843625664711, -0.06738100945949554, -0.06869018077850342, -0.0700153186917305, -0.07135970145463943, -0.07272646576166153, -0.07411862164735794, -0.07561080157756805, -0.07720550149679184, -0.07890567183494568, -0.08071476966142654, -0.08263667672872543, -0.08467575907707214, -0.08683683723211288, -0.08912517130374908, -0.09154652059078217, -0.09410709142684937, -0.09681359678506851, -0.09967327117919922, -0.10269387066364288, -0.10588370263576508, -0.10925167798995972, -0.11280731111764908, -0.11656078696250916, -0.12052296102046967, -0.12470544874668121, -0.1291206330060959, -0.13378173112869263, -0.138702854514122, -0.14389903843402863, -0.14938639104366302, -0.15518203377723694, -0.1613042801618576, -0.16777268052101135, -0.17460808157920837, -0.18183280527591705, -0.18947063386440277, -0.19754700362682343, -0.2060891091823578, -0.21512599289417267, -0.22468870878219604, -0.2348104864358902, -0.24552683532238007, -0.25687578320503235, -0.26889798045158386, -0.2816369831562042, -0.2951393723487854, -0.30945509672164917, -0.32463759183883667, -0.34074413776397705, -0.35783615708351135, -0.3759794235229492, -0.39524444937705994, -0.41570696234703064, -0.43744808435440063, -0.4605548679828644, -0.4851207435131073, -0.5112460255622864, -0.5390383005142212, -0.5686132907867432, -0.6000950932502747, -0.6336169838905334, -0.6693223118782043, -0.7073650360107422, -0.7479104399681091, -0.7911364436149597, -0.8372340202331543, -0.8864085674285889, -0.9388808608055115, -0.994888186454773, -1.0546855926513672, -1.1185473203659058, -1.1867679357528687, -1.2596640586853027, -1.3375756740570068, -1.4208680391311646, -1.509933352470398, -1.6051920652389526, -1.7070955038070679, -1.816127061843872, -1.9328044652938843, -2.0576813220977783, -2.1913490295410156, -2.3344390392303467, -2.4876229763031006, -2.651615619659424, -2.8271734714508057, -3.0150978565216064, -3.2162318229675293, -3.431459903717041, -3.6617062091827393, -3.907928466796875, -4.171113014221191, -4.45226526260376, -4.752399444580078, -5.072519302368164, -5.413601875305176, -5.776567459106445, -6.162246227264404, -6.571339130401611, -7.004361152648926, -7.461581707000732, -7.942943572998047, -8.447972297668457, -8.975666999816895, -9.524369239807129, -10.091622352600098, -10.667840957641602, -11.2477388381958, -11.824620246887207, -12.390235900878906, -12.93466854095459, -13.446272850036621, -13.911694526672363, -14.316010475158691, -14.643013954162598, -14.875699043273926, -14.996949195861816, -14.990456581115723, -14.841851234436035, -14.539977073669434, -14.078228950500488, -13.455784797668457, -12.678579330444336, -11.75980281829834, -10.719783782958984, -9.585150718688965, -8.387287139892578, -7.16022253036499, -5.938210964202881, -4.753305435180664, -2.561614751815796, -0.537211537361145, 1.2705183029174805, 2.8307666778564453, 4.131227493286133, 5.175596237182617, 5.97962760925293, 6.566797733306885, 6.964369773864746, 7.200325012207031, 7.3012919425964355, 7.291376113891602, 7.1916890144348145, 7.020347595214844, 6.792736530303955, 6.52188777923584, 6.218875885009766, 5.893171310424805, 5.552926063537598, 5.2051897048950195, 4.856060028076172, 4.510785102844238, 4.173829555511475, 3.8489184379577637, 3.5390756130218506, 3.2466578483581543, 2.973395824432373, 2.7204413414001465, 2.4884233474731445, 2.2775094509124756, 2.0874722003936768, 1.9177578687667847, 1.7675518989562988, 1.6358436346054077, 1.5214848518371582, 1.4232412576675415, 1.3398385047912598, 1.2699987888336182, 1.2124723196029663, 1.166060447692871, 1.1296334266662598, 1.1021426916122437, 1.0826283693313599, 1.0702232122421265, 1.0641539096832275, 1.0637385845184326, 1.0683846473693848, 1.07758367061615, 1.0909062623977661, 1.1079963445663452, 1.1285651922225952, 1.1523858308792114, 1.1792868375778198, 1.2091474533081055, 1.241892695426941, 1.2774882316589355, 1.3159370422363281, 1.3572754859924316, 1.4015706777572632, 1.448917269706726, 1.4994356632232666, 1.5532703399658203, 1.6105879545211792, 1.6715770959854126, 1.736446738243103, 1.8054262399673462, 1.8787648677825928, 1.9567320346832275, 2.039616823196411, 2.1277291774749756, 2.2213993072509766, 2.3209784030914307, 2.426839590072632, 2.539376974105835, 2.6590075492858887, 2.786170482635498, 2.9213271141052246, 3.0649609565734863, 3.217576503753662, 3.3796987533569336, 3.5518712997436523, 3.7346534729003906, 3.928617477416992, 4.134343147277832, 4.352413654327393, 4.5834059715271, 4.827883243560791, 5.086381435394287, 5.359396457672119, 5.647365093231201, 5.950643539428711, 6.26948356628418, 6.603999137878418, 6.954132556915283, 7.3196120262146, 7.699902057647705, 8.094149589538574, 8.501123428344727, 8.91914176940918, 9.346003532409668, 9.778910636901855, 10.207879066467285, 10.628095626831055, 11.033891677856445, 11.418729782104492, 11.775236129760742, 12.095261573791504, 12.370023727416992, 12.59029769897461, 12.74670696258545, 12.830079078674316, 12.831896781921387, 12.744803428649902, 12.563158988952637, 12.283591270446777, 11.905501365661621, 11.431452751159668, 10.867403984069824, 10.222702980041504, 9.509842872619629, 8.743943214416504, 7.942009925842285, 7.1220221519470215, 6.301939010620117, 5.49873161315918, 4.727532386779785, 4.000986099243164, 3.3288464546203613, 2.7178289890289307, 2.1717007160186768, 1.6915574073791504, 1.2762295007705688, 0.9227533936500549, 0.6268563270568848, 0.383409321308136, 0.18682359158992767, 0.031374603509902954, -0.08854874968528748, -0.1782652884721756, -0.24268417060375214, -0.2862377464771271, -0.31285369396209717, -0.3259555995464325, -0.3284837603569031, -0.32292863726615906, -0.311371773481369, -0.29552990198135376, -0.2767995595932007, -0.2563000023365021, -0.23491357266902924, -0.21332252025604248, -0.19204193353652954, -0.1714489758014679, -0.15180835127830505, -0.13329416513442993, -0.11600864678621292, -0.09999784082174301, -0.08526479452848434, -0.07178038358688354, -0.05949214845895767, -0.04833148047327995, -0.03821928799152374, -0.029070457443594933, -0.02079731412231922, -0.013312197290360928, -0.006529370788484812, -0.000366363616194576, 0.005255135707557201, 0.010408739559352398, 0.015163096599280834, 0.019581833854317665, 0.0237236600369215, 0.02764257602393627, 0.03138817101716995, 0.03495919331908226, 0.03840102255344391, 0.04175375774502754, 0.04505293071269989, 0.048330143094062805, 0.05161363631486893, 0.05492877960205078, 0.0582985021173954, 0.06174369528889656, 0.06528354436159134, 0.0689358040690422, 0.0727170929312706, 0.07664307951927185, 0.0807286873459816, 0.08498827368021011, 0.08943576365709305, 0.09408479183912277, 0.09894879162311554, 0.10404109209775925, 0.1093750074505806, 0.11496392637491226, 0.12082131206989288, 0.12696081399917603, 0.13339629769325256, 0.14014185965061188, 0.14721187949180603, 0.15462101995944977, 0.1623843014240265, 0.17051708698272705, 0.17903506755828857, 0.18795432150363922, 0.18876487016677856, 0.18993309140205383, 0.1914610117673874, 0.1933499425649643, 0.19560092687606812, 0.1982150673866272, 0.2011938840150833, 0.20453955233097076, 0.2082550972700119, 0.21234454214572906, 0.21681316196918488, 0.22166745364665985, 0.22691532969474792, 0.2325662225484848, 0.23863105475902557, 0.24512241780757904, 0.2520546019077301, 0.25944364070892334, 0.2673074007034302, 0.27566567063331604, 0.2845401465892792, 0.29395464062690735, 0.30393508076667786, 0.31450963020324707, 0.32570880651474, 0.3375655710697174, 0.35011550784111023, 0.36339691281318665, 0.37745097279548645, 0.39232194423675537, 0.4080572724342346, 0.42470791935920715, 0.44232845306396484, 0.46097737550735474, 0.48071733117103577, 0.5016154050827026, 0.5237434506416321, 0.547178328037262, 0.5720022916793823, 0.598303496837616, 0.6261761784553528, 0.6557212471961975, 0.6870467662811279, 0.7202683091163635, 0.7555096745491028, 0.7929033637046814, 0.83259117603302, 0.8747249841690063, 0.9194673299789429, 0.9669922590255737, 1.0174859762191772, 1.0711480379104614, 1.1281917095184326, 1.1888456344604492, 1.2533539533615112, 1.321978211402893, 1.3949980735778809, 1.4727123975753784, 1.5554405450820923, 1.6435235738754272, 1.737325668334961, 1.8372349739074707, 1.9436653852462769, 2.0570571422576904, 2.1778783798217773, 2.306626081466675, 2.443826913833618, 2.5900375843048096, 2.7458457946777344, 2.9118690490722656, 3.0887556076049805, 3.27718186378479, 3.477850914001465, 3.69148850440979, 3.918839931488037, 4.1606621742248535, 4.417716979980469, 4.690758228302002, 4.980520725250244, 5.287700653076172, 5.61293363571167, 5.9567694664001465, 6.319638252258301, 6.701809406280518, 7.103344917297363, 7.524042129516602, 7.963366985321045, 8.420374870300293, 8.89362621307373, 9.381081581115723, 9.879997253417969, 10.386809349060059, 10.89700984954834, 11.405035972595215, 11.904160499572754, 12.386415481567383, 12.842549324035645, 13.262044906616211, 13.633221626281738, 13.943434715270996, 14.179410934448242, 14.31743049621582, 14.343863487243652, 14.246517181396484, 14.015649795532227, 13.64503002166748, 13.132938385009766, 12.482990264892578, 11.704626083374023, 10.813163757324219, 9.829307556152344, 8.778120040893555, 7.687508583068848, 6.586410045623779, 5.502860069274902, 4.462215423583984, 3.4857263565063477, 2.589609384536743, 1.784675121307373, 1.0764762163162231, 0.4658662676811218, -0.05017060413956642, -0.4775691032409668, -0.8242366313934326, -1.0992026329040527, -1.311915397644043, -1.4717036485671997, -1.587399959564209, -1.6671006679534912, -1.7180399894714355, -1.746545433998108, -1.7580534219741821, -1.7571622133255005, -1.7477055788040161, -1.7328383922576904, -1.7151230573654175, -1.6966142654418945, -1.6789368391036987, -1.6633572578430176, -1.6508466005325317, -1.6421356201171875, -1.637762188911438, -1.6381125450134277, -1.643454670906067, -1.653968095779419, -1.6697667837142944, -1.6909197568893433, -1.7174664735794067, -1.7494300603866577, -1.786827802658081, -1.8296787738800049, -1.8780112266540527, -1.9318662881851196, -1.991302490234375, -2.0563979148864746, -2.1272521018981934, -2.2039875984191895, -2.286749839782715, -2.3757081031799316, -2.471054792404175, -2.573005199432373, -2.681796073913574, -2.797685384750366, -2.920950412750244, -3.0518860816955566, -3.1908023357391357, -3.3380227088928223, -3.493879795074463, -3.658712387084961, -3.8328611850738525, -4.016663074493408, -4.210444927215576, -4.414515495300293, -4.6291584968566895, -4.854619979858398, -5.091096878051758, -5.338723659515381, -5.5975542068481445, -5.867544651031494, -6.14853048324585, -6.440201759338379, -6.742076873779297, -7.053470611572266, -7.373461723327637, -7.700857162475586, -8.034153938293457, -8.371499061584473, -8.71065616607666, -9.04896354675293, -9.383308410644531, -9.710098266601562, -10.02525520324707, -10.324217796325684, -10.60196590423584, -10.85307502746582, -11.071796417236328, -11.25218391418457, -11.3882417678833, -11.474132537841797, -11.50440788269043, -11.474272727966309, -11.379878044128418, -11.218597412109375, -10.989304542541504, -10.692594528198242, -10.330937385559082, -9.908740997314453, -9.432300567626953, -8.909626007080078, -8.350152969360352, -7.764352321624756, -7.163261890411377, -6.55798864364624, -5.959212779998779, -5.376742839813232, -4.81914758682251, -4.293503284454346, -3.8052456378936768, -3.3581466674804688, -2.9543821811676025, -2.5946831703186035, -2.2720251083374023, -1.985738754272461, -1.7344026565551758, -1.5160340070724487, -1.3282630443572998, -1.1684867143630981, -1.033998966217041, -0.9220932126045227, -0.8301427960395813, -0.7556577324867249, -0.6963233947753906, -0.6500231623649597, -0.6148488521575928, -0.5891017913818359, -0.571286678314209, -0.5601006746292114, -0.5544200539588928, -0.5532840490341187, -0.5558791160583496, -0.5615224242210388, -0.5696462392807007, -0.5797834396362305, -0.5915533900260925, -0.6046500205993652, -0.6188305020332336, -0.633905291557312, -0.6497295498847961, -0.6661955118179321, -0.6832260489463806, -0.700768768787384, -0.7187917232513428, -0.7372788190841675, -0.7562269568443298, -0.7756426930427551, -0.795540452003479, -0.8159401416778564, -0.8368657231330872, -0.8583440780639648, -0.8804039359092712, -0.9030748605728149, -0.9263869524002075, -0.9503699541091919, -0.9750531911849976, -1.0004650354385376, -1.0266329050064087, -1.0535829067230225, -1.0813394784927368, -1.1099258661270142, -1.1393635272979736, -1.1696721315383911, -1.2008697986602783, -1.2329726219177246, -1.265994906425476, -1.299948811531067, -1.2872282266616821, -1.277010202407837, -1.2693215608596802, -1.2641681432724, -1.2615410089492798, -1.2614203691482544, -1.263779878616333, -1.2685898542404175, -1.2758201360702515, -1.2854418754577637, -1.2974300384521484, -1.311764121055603, -1.328429937362671, -1.3474202156066895, -1.3687350749969482, -1.3923832178115845, -1.4183818101882935, -1.4467568397521973, -1.4775434732437134, -1.5107861757278442, -1.5465389490127563, -1.5848650932312012, -1.6258374452590942, -1.6695386171340942, -1.7160608768463135, -1.7655060291290283, -1.8179858922958374, -1.873621940612793, -1.9325456619262695, -1.9948985576629639, -2.0608320236206055, -2.130507469177246, -2.204097032546997, -2.2817819118499756, -2.3637545108795166, -2.45021653175354, -2.541379451751709, -2.637464761734009, -2.7387030124664307, -2.8453333377838135, -2.9576032161712646, -3.0757670402526855, -3.200085401535034, -3.3308236598968506, -3.468249797821045, -3.6126327514648438, -3.76423978805542, -3.923332691192627, -4.090164661407471, -4.264975070953369, -4.295431613922119, -4.329739093780518, -4.367580890655518, -4.408661842346191, -4.452706813812256, -4.499459266662598, -4.548678398132324, -4.600139617919922, -4.653629302978516, -4.7089457511901855, -4.765894889831543, -4.8242902755737305, -4.883950710296631, -4.944698333740234, -5.0063581466674805, -5.068755626678467, -5.131717205047607, -5.195067405700684, -5.258630752563477, -5.32222843170166, -5.385679244995117, -5.448798656463623, -5.5114006996154785, -5.573294162750244, -5.6342878341674805, -5.694186210632324, -5.7527923583984375, -5.809909343719482, -5.865339756011963, -5.918886661529541, -5.97035551071167, -6.019556522369385, -6.066303730010986, -6.110418319702148, -6.151731014251709, -6.19008207321167, -6.22532320022583, -6.257321834564209, -6.285960674285889, -6.311140537261963, -6.332781791687012, -6.350825786590576, -6.365237236022949, -6.376004695892334, -6.383142471313477, -6.38668966293335, -6.38671350479126, -6.38330602645874, -6.376587390899658, -6.366703510284424, -6.353825092315674, -6.3381476402282715, -6.319888114929199, -6.299285411834717, -6.276596546173096, -6.252094745635986, -6.226067543029785, -6.198812484741211, -6.170636177062988, -6.141850471496582, -6.112769603729248, -6.0837082862854, -6.054976940155029, -6.026881217956543, -5.999719142913818, -5.97377872467041, -5.949335098266602, -5.926650047302246, -5.905971050262451, -5.887528419494629, -5.8715362548828125, -5.858189582824707, -5.847667217254639, -5.840127468109131, -5.83571195602417, -5.834543704986572, -5.836727619171143, -5.842350482940674, -5.851483345031738, -5.864179611206055, -5.880476951599121, -5.900397300720215, -5.923947811126709, -5.9511213302612305, -5.9818949699401855, -6.016232967376709, -6.054085731506348, -6.095388889312744, -6.140065670013428, -6.188024044036865, -6.239158630371094, -6.293349266052246, -6.350461483001709, -6.410345077514648, -6.47283411026001, -6.537746429443359, -6.604883193969727, -6.674028396606445, -6.744946479797363, -6.817386150360107, -6.891075611114502, -6.959353446960449, -7.0218706130981445, -7.078266620635986, -7.128179550170898, -7.1712541580200195, -7.207151889801025, -7.235558032989502, -7.2561936378479, -7.2688212394714355, -7.273255348205566, -7.269369125366211, -7.257101058959961, -7.2364606857299805, -7.207534313201904, -7.170485973358154, -7.1255598068237305, -7.073081016540527, -7.01345157623291, -6.94714879989624, -6.874719142913818, -6.796771049499512, -6.7139668464660645, -6.627013206481934, -6.536651134490967, -6.443644046783447, -6.348768711090088, -6.252800941467285, -6.15650749206543, -6.060634136199951, -5.965897083282471, -5.872975826263428, -5.782503128051758, -5.695064067840576, -5.611186981201172, -5.531345367431641, -5.4559526443481445, -5.385364532470703, -5.319879531860352, -5.259739875793457, -5.205136775970459, -5.156209945678711, -5.113056182861328, -5.075728893280029, -5.044245719909668, -5.018592357635498, -4.998725414276123, -4.984577655792236, -4.976060390472412, -4.97307014465332, -4.975486755371094, -4.983180999755859, -4.996013164520264, -5.01383638381958, -5.0364990234375, -5.063843727111816, -5.095709800720215, -5.131931781768799, -5.172342300415039, -5.216768264770508, -5.26503324508667, -5.316956043243408, -5.372349739074707, -5.431019306182861, -5.492763519287109, -5.557370662689209, -5.624619007110596, -5.694275379180908, -5.7660932540893555, -5.8398118019104, -5.915154933929443, -5.991829872131348, -6.069526195526123, -6.147916793823242, -6.226653575897217, -6.305371284484863, -6.38368558883667, -6.461194038391113, -6.537476062774658, -6.612096786499023, -6.684605121612549, -6.75454044342041, -6.821431636810303, -6.884803295135498, -6.944178104400635, -6.999083518981934, -7.049054145812988, -7.093640327453613, -7.132412433624268, -7.1649675369262695, -7.190937042236328, -7.2099928855896, -7.221853256225586, -7.226291179656982, -7.223138332366943, -7.212292671203613, -7.193721294403076, -7.167464256286621, -7.13363790512085, -7.092435359954834, -7.044126510620117, -6.989055633544922, -6.927639007568359, -6.860360145568848, -6.787761211395264, -6.710439682006836, -6.629036903381348, -6.544229030609131, -6.456718921661377, -6.367223262786865, -6.276464939117432, -6.185160160064697, -6.0940117835998535, -6.003697872161865, -5.914866924285889, -5.828127384185791, -5.744045257568359, -5.663137435913086, -5.58587121963501, -5.512659549713135, -5.443861961364746, -5.379785537719727, -5.320684909820557, -5.266765117645264, -5.218183517456055, -5.175055503845215, -5.137454509735107, -5.1054182052612305, -5.078951835632324, -5.058032512664795, -5.042611122131348, -5.032618045806885, -5.027966022491455, -5.02855110168457, -5.034256935119629, -5.044958114624023, -5.060518741607666, -5.08079719543457, -5.105645179748535, -5.134908676147461, -5.168430328369141, -5.206047058105469, -5.247592449188232, -5.29289436340332, -5.341774940490723, -5.394051551818848, -5.449533939361572, -5.508023738861084, -5.569314479827881, -5.6331892013549805, -5.699419975280762, -5.767766952514648, -5.837977409362793, -5.909782409667969, -5.982900142669678, -6.057031154632568, -6.13185977935791, -6.207054138183594, -6.28226375579834, -6.357122421264648, -6.431246757507324, -6.504238128662109, -6.575683116912842, -6.645155906677246, -6.712220191955566, -6.776432514190674, -6.837344646453857, -6.89450740814209, -6.947475910186768, -6.995813369750977, -7.039095878601074, -7.076920032501221, -7.1089067459106445, -7.134707450866699, -7.154012680053711, -7.166553974151611, -7.17211389541626, -7.170529365539551, -7.161696910858154, -7.1455769538879395, -7.12219762802124, -7.091656684875488, -7.0541229248046875, -7.009835243225098, -6.959102630615234, -6.9023003578186035, -6.839867115020752, -6.772296905517578, -6.700136184692383, -6.623973846435547, -6.54443359375, -6.462165355682373, -6.377835750579834, -6.292117595672607, -6.205684185028076, -6.119195938110352, -6.033295154571533, -5.948598861694336, -5.865689277648926, -5.785111904144287, -5.707368850708008, -5.632916450500488, -5.562163352966309, -5.495469093322754, -5.433143138885498, -5.375447750091553, -5.322597980499268, -5.274764060974121, -4.641924858093262, -4.032327175140381, -3.4530770778656006, -2.9099090099334717, -2.4070966243743896, -1.9474467039108276, -1.532371163368225, -1.162022352218628, -0.8354721069335938, -0.5509132742881775, -0.3058682084083557, -0.09738785773515701, 0.07776853442192078, 0.22297868132591248, 0.3416307866573334, 0.4370248317718506, 0.5122999548912048, 0.570384681224823, 0.6139658093452454, 0.6454735398292542, 0.6670778393745422, 0.6806941628456116, 0.687995433807373, 0.6904277801513672, 0.6892295479774475, 0.6854508519172668, 0.6799737215042114, 0.6735319495201111, 0.6667295694351196, 0.6600587368011475, 0.6539157032966614, 0.6486157178878784, 0.6444060802459717, 0.6414780616760254, 0.6399770379066467, 0.6400118470191956, 0.6416623592376709, 0.6449863910675049, 0.6500252485275269, 0.6568089723587036, 0.6653600335121155, 0.6756970882415771, 0.6878376603126526, 0.701800525188446, 0.7176077961921692, 0.7352863550186157, 0.7548693418502808, 0.7763970494270325, 0.799917995929718, 0.8254896998405457, 0.8531791567802429, 0.883063793182373, 0.9152315258979797, 0.9497816562652588, 0.9868253469467163, 1.0264860391616821, 1.0688997507095337, 1.1142164468765259, 1.1625995635986328, 1.214227557182312, 1.2692943811416626, 1.328009843826294, 1.3906010389328003, 1.4573129415512085, 1.5284092426300049, 1.6041735410690308, 1.6849104166030884, 1.7709463834762573, 1.8626307249069214, 1.960337519645691, 2.0644657611846924, 2.175441026687622, 2.2937161922454834, 2.4197728633880615, 2.554121494293213, 2.6973021030426025, 2.8498849868774414, 3.0124704837799072, 3.18568754196167, 3.3701930046081543, 3.5666701793670654, 3.7758243083953857, 3.9983789920806885, 4.235069751739502, 4.486635684967041, 4.753810405731201, 5.037307262420654, 5.337801933288574, 5.655914306640625, 5.9921793937683105, 6.34701681137085, 6.720694065093994, 7.113277912139893, 7.5245819091796875, 7.954102039337158, 8.4009428024292, 8.863733291625977, 9.340532302856445, 9.828726768493652, 10.324918746948242, 10.824812889099121, 11.316093444824219, 11.791656494140625, 12.243170738220215, 12.661094665527344, 13.034747123718262, 13.352486610412598, 12.661734580993652, 11.869820594787598, 10.983341217041016, 10.014622688293457, 8.98107624053955, 7.904078006744385, 6.80748176574707, 5.71591329574585, 4.653054237365723, 3.6401026248931885, 2.6945912837982178, 1.8296523094177246, 1.0537636280059814, 0.3709245026111603, -0.2188340276479721, -0.7187291383743286, -1.1344174146652222, -1.4731991291046143, -1.743307113647461, -1.9533191919326782, -2.1117100715637207, -2.2265331745147705, -2.3052191734313965, -2.354464530944824, -2.3801910877227783, -2.387552261352539, -2.380974054336548, -2.3642117977142334, -2.340416669845581, -2.3122074604034424, -2.2817366123199463, -2.250756025314331, -2.220675230026245, -2.1926143169403076, -2.1674513816833496, -2.1458630561828613, -2.1283609867095947, -2.1153228282928467, -2.1070191860198975, -2.103635787963867, -2.1052937507629395, -2.112065315246582, -2.123988628387451, -2.141077756881714, -2.1633338928222656, -2.1907520294189453, -2.22332763671875, -2.261061906814575, -2.3039655685424805, -2.3520619869232178, -2.4053902626037598, -2.464005708694458, -2.527982711791992, -2.5974137783050537, -2.6724116802215576, -2.753107786178589, -2.839653968811035, -2.932219982147217, -3.030994415283203, -3.136183500289917, -3.248008966445923, -3.3667080402374268, -3.4925310611724854, -3.6257388591766357, -3.7666015625, -3.9153943061828613, -4.072394847869873, -4.237878322601318, -4.412113666534424, -4.595356464385986, -4.787843704223633, -4.989782810211182, -5.201346397399902, -5.422658920288086, -5.653783321380615, -5.894710540771484, -6.145339488983154, -6.405459880828857, -6.6747331619262695, -6.952667713165283, -7.238595485687256, -7.53164529800415, -7.830713272094727, -8.134434700012207, -8.441155433654785, -8.7489013671875, -9.055354118347168, -9.357830047607422, -9.653265953063965, -9.938214302062988, -10.208850860595703, -10.461003303527832, -10.690193176269531, -10.891705513000488, -11.060688018798828, -11.192272186279297, -11.281728744506836, -11.3246431350708, -11.317123413085938, -11.256009101867676, -11.139089584350586, -10.95546817779541, -10.705249786376953, -10.390206336975098, -10.013875961303711, -9.581573486328125, -9.100289344787598, -8.578472137451172, -8.025714874267578, -7.452357292175293, -6.869027614593506, -6.286184310913086, -5.713674068450928, -5.160348892211914, -4.6337738037109375, -4.140035152435303, -3.683656930923462, -3.2676148414611816, -2.8934361934661865, -2.5613629817962646, -2.270552158355713, -2.0192980766296387, -1.8052512407302856, -1.625625491142273, -1.4773787260055542, -1.3573672771453857, -1.2624684572219849, -1.1896741390228271, -1.1361571550369263, -1.0993163585662842, -1.0768005847930908, -1.0665196180343628, -1.0666426420211792, -1.0755894184112549, -1.0920153856277466, -1.114793300628662, -1.1429935693740845, -1.17586350440979, -1.212807297706604, -1.2533663511276245, -1.297202229499817, -1.3440792560577393, -1.3938504457473755, -1.4464446306228638, -1.5018545389175415, -1.5601277351379395, -1.621357798576355, -1.6856776475906372, -1.7532533407211304, -1.8242799043655396, -1.8989766836166382, -1.9775846004486084, -2.06036376953125, -2.1475913524627686, -2.2395596504211426, -2.336575508117676, -2.4389588832855225, -2.547041893005371, -2.6611685752868652, -2.7816925048828125, -2.908977746963501, -3.043396234512329, -3.185326099395752, -3.335150957107544, -3.493256092071533, -3.6600265502929688, -3.8358423709869385, -4.021074295043945, -4.216078281402588, -4.421186923980713, -4.636704444885254, -4.8628926277160645, -5.099961280822754, -5.3480544090271, -5.607233047485352, -5.877457141876221, -6.15856409072876, -6.4502434730529785, -6.752011775970459, -7.063179016113281, -7.382819652557373, -7.709733009338379, -8.042407989501953, -8.378986358642578, -8.7172212600708, -9.054444313049316, -9.38753604888916, -9.712902069091797, -10.026461601257324, -10.32365608215332, -10.599474906921387, -10.848505020141602, -11.065023422241211, -11.243109703063965, -11.376809120178223, -11.46033000946045, -11.488280296325684, -11.455928802490234, -11.35949420928955, -11.196422576904297, -10.965659141540527, -10.657835960388184, -10.275391578674316, -9.822943687438965, -9.30727767944336, -8.737183570861816, -8.123152732849121, -7.476943016052246, -6.811044216156006, -6.138094902038574, -5.470294952392578, -4.818874359130859, -4.193655490875244, -3.6027414798736572, -3.0523459911346436, -2.5467593669891357, -2.0884346961975098, -1.6781697273254395, -1.3153477907180786, -0.9982138276100159, -0.7241545915603638, -0.4899631440639496, -0.29207390546798706, -0.1267605423927307, 0.009706167504191399, 0.12093908339738846, 0.2103501260280609, 0.28109538555145264, 0.3360443711280823, 0.37776777148246765, 0.408539354801178, 0.43034741282463074, 0.4449126124382019, 0.4537099301815033, 0.4579921066761017, 0.4588138461112976, 0.45705512166023254, 0.45344361662864685, 0.4485752284526825, 0.44293296337127686, 0.43690380454063416, 0.43079373240470886, 0.4248409569263458, 0.42719128727912903, 0.4265521466732025, 0.4235786199569702, 0.41884228587150574, 0.41283637285232544, 0.4059821367263794, 0.39863529801368713, 0.3910926878452301, 0.38359880447387695, 0.3763524293899536, 0.3695123493671417, 0.3632032871246338, 0.3575208783149719, 0.35253649950027466, 0.348301500082016, 0.3448508679866791, 0.3422066867351532, 0.34038078784942627, 0.3393774926662445, 0.33919557929039, 0.33983010053634644, 0.3412739932537079, 0.3435191810131073, 0.3465577960014343, 0.35038286447525024, 0.3549891412258148, 0.36037352681159973, 0.36653566360473633, 0.37347808480262756, 0.381206750869751, 0.3897310197353363, 0.39906400442123413, 0.40922263264656067, 0.4202277958393097, 0.4321044683456421, 0.4448818564414978, 0.45859336853027344, 0.4732770025730133, 0.4889752268791199, 0.5057352185249329, 0.5236091017723083, 0.5426540970802307, 0.5629327297210693, 0.5845129489898682, 0.6074687838554382, 0.6318801641464233, 0.6578336358070374, 0.6854225993156433, 0.7147476673126221, 0.7459172606468201, 0.7790480256080627, 0.8142651915550232, 0.8517036437988281, 0.8915079236030579, 0.9338334798812866, 0.9788470268249512, 1.0267274379730225, 1.0776666402816772, 1.1318705081939697, 1.1895596981048584, 1.2509706020355225, 1.316356897354126, 1.3859901428222656, 1.4601608514785767, 1.5391805171966553, 1.6233820915222168, 1.7131215333938599, 1.8087794780731201, 1.910761833190918, 2.0195019245147705, 2.1354615688323975, 2.259131669998169, 2.3910341262817383, 2.531722068786621, 2.681781530380249, 2.8418307304382324, 3.0125198364257812, 3.1945319175720215, 3.3885791301727295, 3.595402479171753, 3.8157665729522705, 4.0504560470581055, 4.300266265869141, 4.565998077392578, 4.848440647125244, 5.148360252380371, 5.46647834777832, 5.8034491539001465, 6.15982723236084, 6.536032676696777, 6.932304859161377, 7.348649501800537, 7.784775733947754, 8.240019798278809, 8.713261604309082, 9.202821731567383, 9.7063570022583, 10.22073745727539, 10.741922378540039, 11.264829635620117, 11.78321361541748, 12.281915664672852, 12.751326560974121, 13.180452346801758, 13.557029724121094, 13.867759704589844, 14.098674774169922, 14.235665321350098, 14.26517105102539, 14.175023078918457, 13.955405235290527, 13.59986686706543, 13.106290817260742, 12.477689743041992, 11.722712516784668, 10.855717658996582, 9.896347999572754, 8.86858081817627, 7.799317836761475, 6.716645240783691, 5.647989273071289, 4.618375301361084, 3.64900541305542, 2.756308078765869, 1.9515084028244019, 1.240708589553833, 0.6253762245178223, 0.1031109020113945, -0.3314526379108429, -0.685729444026947, -0.9683486223220825, -1.188452124595642, -1.3551501035690308, -1.4771316051483154, -1.5624111890792847, -1.6181880235671997, -1.6507896184921265, -1.6656757593154907, -1.6689320802688599, -1.6638020277023315, -1.652951955795288, -1.6385468244552612, -1.622322916984558, -1.6056544780731201, -1.5896128416061401, -1.5750192403793335, -1.5624897480010986, -1.5524744987487793, -1.545290231704712, -1.5411478281021118, -1.5401760339736938, -1.5424398183822632, -1.5479564666748047, -1.5567079782485962, -1.568651556968689, -1.5837275981903076, -1.601866364479065, -1.6229923963546753, -1.647029161453247, -1.673900842666626, -1.7035354375839233, -1.7358651161193848, -1.7708275318145752, -1.808366298675537, -1.8484309911727905, -1.8909767866134644, -1.9359644651412964, -1.9833595752716064, -2.0331318378448486, -2.085254669189453, -2.1397042274475098, -2.196458101272583, -2.255495309829712, -2.3167948722839355, -2.3803346157073975, -2.4460909366607666, -2.5140368938446045, -2.584141731262207, -2.6563704013824463, -2.7306807041168213, -2.8070247173309326, -2.885344982147217, -2.965575933456421, -3.0476410388946533, -3.1314520835876465, -3.2169082164764404, -3.3038952350616455, -3.392282724380493, -3.4819254875183105, -3.572659730911255, -3.664304256439209, -3.7566583156585693, -3.715970993041992, -3.6794049739837646, -3.6470248699188232, -3.618863344192505, -3.5949289798736572, -3.5752112865448, -3.5596859455108643, -3.548316717147827, -3.54106068611145, -3.5378682613372803, -3.5386874675750732, -3.543464183807373, -3.5521440505981445, -3.564673662185669, -3.581001043319702, -3.601077079772949, -3.6248557567596436, -3.6522939205169678, -3.68335223197937, -3.7179951667785645, -3.756190538406372, -3.79790997505188, -3.843127727508545, -3.8918213844299316, -3.943969964981079, -3.9995548725128174, -4.058557987213135, -4.120961666107178, -4.1867475509643555, -4.255895137786865, -4.328381538391113, -4.40418004989624, -4.4832587242126465, -4.565579414367676, -4.651094436645508, -4.739748954772949, -4.831475257873535, -4.926193714141846, -5.023809432983398, -5.124210834503174, -5.227268695831299, -5.332832336425781, -5.440728664398193, -5.550759792327881, -5.6627020835876465, -5.77630090713501, -5.891273021697998, -6.0073018074035645, -6.1240363121032715, -6.241090297698975, -6.358042240142822, -6.474431991577148, -6.589763641357422, -6.70350456237793, -6.815086841583252, -6.923910140991211, -7.029343128204346, -7.130729675292969, -7.227392196655273, -7.318638801574707, -7.403769493103027, -7.482087135314941, -7.5529046058654785, -7.615555763244629, -7.669410228729248, -7.71388053894043, -7.748440742492676, -7.772634983062744, -7.786092758178711, -7.788539409637451, -7.779809474945068, -7.759854316711426, -7.728752136230469, -7.686711311340332, -7.6340742111206055, -7.571316719055176, -7.499044895172119, -7.417988300323486, -7.328991413116455, -7.232997894287109, -7.131039142608643, -7.024214267730713, -6.913671016693115, -6.800588607788086, -6.686154365539551, -6.571545600891113, -6.457911491394043, -6.346355438232422, -6.237918853759766, -6.133571624755859, -6.034200668334961, -5.940601825714111, -5.853477954864502, -5.773436546325684, -5.700990200042725, -5.63655948638916, -5.580478191375732, -5.532999038696289, -5.4943013191223145, -5.464498043060303, -5.4436445236206055, -5.425681114196777, -5.4107561111450195, -5.398983478546143, -5.390445709228516, -5.38519811630249, -5.383272647857666, -5.384677886962891, -5.389404296875, -5.397423267364502, -5.408692359924316, -5.423152923583984, -5.440735340118408, -5.461356163024902, -5.484922885894775, -5.511331558227539, -5.540468692779541, -5.572211265563965, -5.606428623199463, -5.642979145050049, -5.681714057922363, -5.722475528717041, -5.7650957107543945, -5.8094000816345215, -5.855202674865723, -5.902310371398926, -5.9505205154418945, -5.999621391296387, -6.049391269683838, -6.099601745605469, -6.150014400482178, -6.200383186340332, -6.250454902648926, -6.29996919631958, -6.348659992218018, -6.396256923675537, -6.442485332489014, -6.487070083618164, -6.5297346115112305, -6.570204734802246, -6.608210563659668, -6.643487930297852, -6.67578125, -6.7048468589782715, -6.73045539855957, -6.75239372253418, -6.7704691886901855, -6.784511089324951, -6.794373989105225, -6.799940586090088, -6.801124095916748, -6.7978692054748535, -6.790155410766602, -6.777997016906738, -6.761445045471191, -6.740586757659912, -6.71554708480835, -6.686485767364502, -6.653598785400391, -6.617115020751953, -6.577293395996094, -6.534422397613525, -6.4888153076171875, -6.440806865692139, -6.390750408172607, -6.339012145996094, -6.285968780517578, -6.232001781463623, -6.177494525909424, -6.122827053070068, -6.068373203277588, -6.014495849609375, -5.961544990539551, -5.909854412078857, -5.859737873077393, -5.811489105224609, -5.765378952026367, -5.721653938293457, -5.680537223815918, -5.642226219177246, -5.606893062591553, -5.574686050415039, -5.54572868347168, -5.5201215744018555, -5.4979424476623535, -5.479249477386475, -5.464078426361084, -5.452448844909668, -5.444360733032227, -5.439799785614014, -5.4387359619140625, -5.44112491607666, -5.446911811828613, -5.456027507781982, -5.468394756317139, -5.48392391204834, -5.5025177001953125, -5.524069309234619, -5.548464298248291, -5.575578689575195, -5.605282306671143, -5.637436389923096, -5.671894550323486, -5.708503246307373, -5.747100353240967, -5.7875165939331055, -5.829575061798096, -5.8730902671813965, -5.917869567871094, -5.963710784912109, -6.01040506362915, -6.057735919952393, -6.105477333068848, -6.153397560119629, -6.201257705688477, -6.248812198638916, -6.295809268951416, -6.34199333190918, -6.387104511260986, -6.430880546569824, -6.473059177398682, -6.513377666473389, -6.551576614379883, -6.587400436401367, -6.620600700378418, -6.650938510894775, -6.671913146972656, -6.683298110961914, -6.684905052185059, -6.676593780517578, -6.6582841873168945, -6.629963397979736, -6.591693878173828, -6.543617248535156, -6.485959529876709, -6.419032573699951, -6.343232154846191, -6.259037494659424, -6.167004585266113, -6.067760944366455, -5.961996555328369, -5.850454330444336, -5.733919143676758, -5.613204479217529, -5.489141464233398, -5.362565040588379, -5.234302997589111, -5.105162143707275, -4.517545223236084, -3.953409194946289, -3.4187111854553223, -2.9181926250457764, -2.455317497253418, -2.032280683517456, -1.6500829458236694, -1.3086546659469604, -1.007014513015747, -0.7434437870979309, -0.5156643390655518, -0.32100772857666016, -0.1565667688846588, -0.01932607777416706, 0.09373129159212112, 0.1855405867099762, 0.25889378786087036, 0.316397100687027, 0.36044472455978394, 0.3932053744792938, 0.4166194200515747, 0.43240320682525635, 0.44205933809280396, 0.44689011573791504, 0.44801366329193115, 0.4463810324668884, 0.44279345870018005, 0.4379196763038635, 0.4323121905326843, 0.426422655582428, 0.42061617970466614, 0.4151841104030609, 0.41035589575767517, 0.40630921721458435, 0.4031793475151062, 0.4010671079158783, 0.4000457525253296, 0.4001670181751251, 0.4014662206172943, 0.40396666526794434, 0.4076831340789795, 0.41262510418891907, 0.41879919171333313, 0.42621129751205444, 0.43486830592155457, 0.44477951526641846, 0.4559577405452728, 0.46842026710510254, 0.48218971490859985, 0.49729451537132263, 0.5137695670127869, 0.5316565036773682, 0.5510044693946838, 0.5718700289726257, 0.5943179130554199, 0.6184211373329163, 0.6442614793777466, 0.6719297766685486, 0.7015266418457031, 0.7331624627113342, 0.7669582962989807, 0.8030461668968201, 0.8415699601173401, 0.8826858997344971, 0.9265632629394531, 0.9733853936195374, 1.023350477218628, 1.0766723155975342, 1.1335816383361816, 1.1943273544311523, 1.2591772079467773, 1.3284196853637695, 1.402364730834961, 1.481345772743225, 1.565721035003662, 1.6558748483657837, 1.752219796180725, 1.8551979064941406, 1.9652825593948364, 2.082980155944824, 2.208832025527954, 2.3434154987335205, 2.4873454570770264, 2.641275644302368, 2.8058996200561523, 2.9819512367248535, 3.170203685760498, 3.371469497680664, 3.5865983963012695, 3.8164734840393066, 4.062006950378418, 4.324133396148682, 4.603797912597656, 4.901947498321533, 5.219509601593018, 5.557375431060791, 5.916367530822754, 6.297210216522217, 6.700484275817871, 7.126574516296387, 7.575607776641846, 8.042747497558594, 8.52681827545166, 9.026022911071777, 9.53783893585205, 10.05889892578125, 10.584861755371094, 11.110294342041016, 11.628547668457031, 12.13166332244873, 12.610315322875977, 13.053797721862793, 13.450109481811523, 13.786123275756836, 14.047904968261719, 14.221170425415039, 14.291914939880371, 14.24720573425293, 14.076105117797852, 13.770681381225586, 13.32701301574707, 12.74606990814209, 12.034351348876953, 11.204132080078125, 10.273236274719238, 9.264272689819336, 8.20337200164795, 7.118540287017822, 6.037812232971191, 4.987429618835449, 3.990267276763916, 3.064687490463257, 2.223911762237549, 1.4759199619293213, 0.8238064050674438, 0.26646688580513, -0.20052529871463776, -0.5839887261390686, -0.8922539949417114, -1.134403944015503, -1.319667100906372, -1.4569705724716187, -1.5546387434005737, -1.6202137470245361, -1.6603721380233765, -1.6809096336364746, -1.6867740154266357, -1.6821264028549194, -1.6704189777374268, -1.6544784307479858, -1.636589765548706, -1.6185758113861084, -1.6018705368041992, -1.5875846147537231, -1.5765637159347534, -1.5694392919540405, -1.5666717290878296, -1.5063707828521729, -1.4428702592849731, -1.377892255783081, -1.3128637075424194, -1.2489440441131592, -1.1870548725128174, -1.1279083490371704, -1.072034478187561, -1.0198076963424683, -0.9714707732200623, -0.9271572232246399, -0.8869112730026245, -0.8507061004638672, -0.8184595108032227, -0.7900475263595581, -0.7653166651725769, -0.7440935969352722, -0.7261934280395508, -0.7114270329475403, -0.6996060013771057, -0.6905473470687866, -0.684076726436615, -0.6800311207771301, -0.6782602071762085, -0.6786280870437622, -0.6810133457183838, -0.6853100657463074, -0.6914271712303162, -0.6992887258529663, -0.7088333368301392, -0.7200136780738831, -0.7327959537506104, -0.7471594214439392, -0.7630957961082458, -0.7806087136268616, -0.7997130751609802, -0.8204348087310791, -0.8428103923797607, -0.8668864965438843, -0.8927197456359863, -0.9203766584396362, -0.9499334096908569, -0.9814757704734802, -1.0150994062423706, -1.0509096384048462, -1.089021921157837, -1.129562258720398, -1.1726667881011963, -1.2184832096099854, -1.2671701908111572, -1.3188990354537964, -1.3738529682159424, -1.432228922843933, -1.4942374229431152, -1.5601036548614502, -1.6300684213638306, -1.70438814163208, -1.783336877822876, -1.8672058582305908, -1.9563053846359253, -2.0509650707244873, -2.1515347957611084, -2.258385181427002, -2.3719091415405273, -2.492520809173584, -2.6206576824188232, -2.756779432296753, -2.9013681411743164, -3.0549280643463135, -3.217984437942505, -3.3910815715789795, -3.5747814178466797, -3.7696588039398193, -3.976299285888672, -4.195291042327881, -4.427220821380615, -4.672660827636719, -4.9321608543396, -5.206232070922852, -5.495330810546875, -5.7998366355896, -6.120028018951416, -6.456052303314209, -6.807888507843018, -7.175307750701904, -7.557825088500977, -7.9546427726745605, -8.364591598510742, -8.786059379577637, -9.216917991638184, -9.654448509216309, -10.095253944396973, -10.535188674926758, -10.969287872314453, -11.39171028137207, -11.795710563659668, -12.1736421585083, -12.517013549804688, -12.81660270690918, -13.062644958496094, -13.245115280151367, -13.3441743850708, -13.349907875061035, -13.25369644165039, -13.048912048339844, -12.731635093688965, -12.30129623413086, -11.761190414428711, -11.118759155273438, -10.385588645935059, -9.577056884765625, -8.711653709411621, -7.809985637664795, -6.893592834472656, -5.983672618865967, -5.099867820739746, -4.24941349029541, -3.4471211433410645, -2.70436692237854, -2.0289292335510254, -1.425115942955017, -0.8941196799278259, -0.4345225691795349, -0.04287262633442879, 0.2857348620891571, 0.5571224689483643, 0.7775731086730957, 0.9534643292427063, 1.090994954109192, 1.1959960460662842, 1.2738131284713745, 1.3292450904846191, 1.366525650024414, 1.389333963394165, 1.4008264541625977, 1.4036781787872314, 1.400132179260254, 1.3920493125915527, 1.3809565305709839, 1.368093729019165, 1.3544554710388184, 1.3408293724060059, 1.3278294801712036, 1.3159258365631104, 1.3054699897766113, 1.296716570854187, 1.2898424863815308, 1.2849619388580322, 1.2821401357650757, 1.2814037799835205, 1.2827507257461548, 1.2861567735671997, 1.2915819883346558, 1.2989755868911743, 1.3082796335220337, 1.319432020187378, 1.332369089126587, 1.3470268249511719, 1.3633426427841187, 1.381256103515625, 1.3372008800506592, 1.2963746786117554, 1.2589542865753174, 1.225041389465332, 1.1946756839752197, 1.1678484678268433, 1.1445132493972778, 1.1245954036712646, 1.1080001592636108, 1.0946195125579834, 1.0843383073806763, 1.0770384073257446, 1.0726031064987183, 1.0709199905395508, 1.071883201599121, 1.0753955841064453, 1.0813698768615723, 1.089729905128479, 1.100411057472229, 1.1133607625961304, 1.128538727760315, 1.1459171772003174, 1.1654804944992065, 1.1872252225875854, 1.2111600637435913, 1.2373052835464478, 1.2656928300857544, 1.2963663339614868, 1.3293801546096802, 1.364800214767456, 1.402703046798706, 1.44317626953125, 1.4863183498382568, 1.532238483428955, 1.5810569524765015, 1.632905125617981, 1.6879255771636963, 1.7462719678878784, 1.8081098794937134, 1.873616337776184, 1.9429807662963867, 2.016404390335083, 2.094101667404175, 2.1762990951538086, 2.2632365226745605, 2.3551669120788574, 2.4523561000823975, 2.5550835132598877, 2.6636416912078857, 2.7783350944519043, 2.8994812965393066, 3.027409553527832, 3.162458658218384, 3.3049774169921875, 3.455321788787842, 3.6138525009155273, 3.780932664871216, 3.956923246383667, 4.1421799659729, 4.337045192718506, 4.541845321655273, 4.756877422332764, 4.982405662536621, 5.218643665313721, 5.4657464027404785, 5.72379207611084, 5.992764472961426, 6.272531986236572, 6.562826156616211, 6.863212585449219, 7.1730637550354, 7.491525173187256, 7.817483425140381, 8.149526596069336, 8.485907554626465, 8.824508666992188, 9.162803649902344, 9.497827529907227, 9.826151847839355, 10.143872261047363, 10.446609497070312, 10.729531288146973, 10.98740005493164, 11.214645385742188, 11.405479431152344, 11.554040908813477, 11.654585838317871, 11.701708793640137, 11.690601348876953, 11.617323875427246, 11.479095458984375, 11.274553298950195, 11.003987312316895, 10.669507026672363, 10.275116920471191, 9.826693534851074, 9.331838607788086, 8.799617767333984, 8.240195274353027, 7.66439151763916, 7.083194255828857, 6.497585296630859, 5.918073654174805, 5.354244232177734, 4.814428329467773, 4.305474281311035, 3.8326313495635986, 3.3995320796966553, 3.008272647857666, 2.659562110900879, 2.3529207706451416, 2.086904287338257, 1.8593331575393677, 1.6675100326538086, 1.5084174871444702, 1.3788844347000122, 1.2757229804992676, 1.195833683013916, 1.1362823247909546, 1.0943522453308105, 1.0675756931304932, 1.0537478923797607, 1.0509302616119385, 1.0574421882629395, 1.071847915649414, 1.092938780784607, 1.1197129487991333, 1.1513547897338867, 1.1872142553329468, 1.2267862558364868, 1.2696925401687622, 1.3156639337539673, 1.3645256757736206, 1.4161827564239502, 1.4706089496612549, 1.5278352499008179, 1.5879420042037964, 1.6510508060455322, 1.7173184156417847, 1.7869317531585693, 1.8601034879684448, 1.9370685815811157, 2.0180819034576416, 2.1034157276153564, 2.1933581829071045, 2.2882120609283447, 2.388293504714966, 2.493931531906128, 2.60546612739563, 2.7232491970062256, 2.8476414680480957, 2.979013681411743, 3.1177430152893066, 3.2642126083374023, 3.418809413909912, 3.581921100616455, 3.753931999206543, 3.9352197647094727, 4.126150131225586, 4.32706880569458, 4.538296222686768, 4.760116100311279, 4.9927659034729, 5.236422538757324, 5.4911885261535645, 5.757072448730469, 6.033970355987549, 6.321642875671387, 6.619686603546143, 6.927507400512695, 7.244288444519043, 7.568952560424805, 7.9001288414001465, 8.236112594604492, 8.574827194213867, 8.913786888122559, 9.250062942504883, 9.58026123046875, 9.90049934387207, 10.20640754699707, 10.493147850036621, 10.755452156066895, 10.987690925598145, 11.18398380279541, 11.338336944580078, 11.444828033447266, 11.49782657623291, 11.49224853515625, 11.423835754394531, 11.289444923400879, 11.087325096130371, 10.807378768920898, 10.451196670532227, 10.022541046142578, 9.527390480041504, 8.973835945129395, 8.371825218200684, 7.7327752113342285, 7.069060802459717, 6.393438816070557, 5.718448638916016, 5.055846691131592, 4.416121959686279, 3.8081281185150146, 3.238858222961426, 2.7133591175079346, 2.234776020050049, 1.8045027256011963, 1.422408938407898, 1.0871094465255737, 0.7962489724159241, 0.5467776656150818, 0.33520159125328064, 0.15779702365398407, 0.010784933343529701, -0.10953468829393387, -0.20668524503707886, -0.28394800424575806, -0.34432297945022583, -0.3905107080936432, -0.4249095618724823, -0.4496244788169861, -0.4664832353591919, -0.4770573079586029, -0.482685387134552, -0.4844977557659149, -0.48344019055366516, -0.4802970588207245, -0.4757128059864044, -0.4702115058898926, -0.4642146825790405, -0.4580571949481964, -0.45200100541114807, -0.44624757766723633, -0.44094815850257874, -0.4362131655216217, -0.4321196377277374, -0.4287179708480835, -0.42603743076324463, -0.42409056425094604, -0.42287734150886536, -0.422387957572937, -0.4226056933403015, -0.4235087037086487, -0.42507192492485046, -0.42726820707321167, -0.4300694167613983, -0.4334472119808197, -0.437373548746109, -0.4418211579322815, -0.44676390290260315, -0.4521768093109131, -0.458036333322525, -0.46432027220726013, -0.4710078537464142, -0.4780796468257904, -0.4855175018310547, -0.49330443143844604, -0.5014246106147766, -0.5098630785942078, -0.5186058878898621, -0.5276397466659546, -0.536952018737793, -0.546530544757843, -0.5563637018203735, -0.5664400458335876, -0.5767485499382019, -0.5872781872749329, -0.5980179309844971, -0.6089568138122559, -0.6200838685035706, -0.6313877105712891, -0.6428568959236145, -0.6452504396438599, -0.6488137245178223, -0.6535436511039734, -0.6594370007514954, -0.6664912700653076, -0.6747055053710938, -0.6840810775756836, -0.6946223974227905, -0.706337034702301, -0.7192363739013672, -0.7333358526229858, -0.7486550807952881, -0.7652183175086975, -0.783054530620575, -0.8021973967552185, -0.8226856589317322, -0.8445632457733154, -0.8678793907165527, -0.8926887512207031, -0.9190515875816345, -0.9470338821411133, -0.9767078161239624, -1.0081514120101929, -1.0414495468139648, -1.0766932964324951, -1.113981008529663, -1.1534181833267212, -1.195117712020874, -1.2392007112503052, -1.2857964038848877, -1.3350424766540527, -1.3870859146118164, -1.4420833587646484, -1.5002009868621826, -1.5616157054901123, -1.6265153884887695, -1.695098876953125, -1.7675774097442627, -1.8441742658615112, -1.9251255989074707, -2.010680913925171, -2.1011030673980713, -2.196669578552246, -2.297671318054199, -2.404414653778076, -2.5172195434570312, -2.636420726776123, -2.762366533279419, -2.8954195976257324, -3.035953998565674, -3.1843557357788086, -3.341019868850708, -3.5063493251800537, -3.6807501316070557, -3.8646295070648193, -4.058390140533447, -4.262424468994141, -4.477108001708984, -4.702789306640625, -4.93978214263916, -5.188349723815918, -5.448692798614502, -5.720931529998779, -6.00508451461792, -6.301047325134277, -6.608564376831055, -6.92719841003418, -7.256298542022705, -7.5949625968933105, -7.941995620727539, -8.295866966247559, -8.654666900634766, -9.016059875488281, -9.377243041992188, -9.734905242919922, -10.085203170776367, -10.423733711242676, -10.745545387268066, -11.04515266418457, -11.316598892211914, -11.55354118347168, -11.749385833740234, -11.897469520568848, -11.99128532409668, -12.024759292602539, -11.99255657196045, -11.890419960021973, -11.715508460998535, -11.466712951660156, -11.144917488098145, -10.753175735473633, -10.296775817871094, -9.783163070678711, -9.221714973449707, -8.623383522033691, -8.000202178955078, -7.364730358123779, -6.729447364807129, -6.1061787605285645, -5.505587577819824, -4.936777591705322, -4.398298740386963, -3.8963420391082764, -3.435316562652588, -3.0179147720336914, -2.645261764526367, -2.317126750946045, -2.032167911529541, -1.7881871461868286, -1.5823760032653809, -1.411538004875183, -1.2722803354263306, -1.1611698865890503, -1.0748544931411743, -1.0101523399353027, -0.9641117453575134, -0.934048056602478, -0.9175615906715393, -0.91254061460495, -0.9171541333198547, -0.9298370480537415, -0.9492707252502441, -0.9743612408638, -1.0042163133621216, -1.038122296333313, -1.0755223035812378, -1.1159954071044922, -1.1592381000518799, -1.2050471305847168, -1.2533046007156372, -1.3039644956588745, -1.3570420742034912, -1.4126031398773193, -1.4707568883895874, -1.5316483974456787, -1.5954535007476807, -1.6623742580413818, -1.7326349020004272, -1.8064796924591064, -1.8841700553894043, -1.965983510017395, -2.0522119998931885, -2.1431612968444824, -2.2391505241394043, -2.340510368347168, -2.447584867477417, -2.5607287883758545, -2.6803085803985596, -2.806701183319092, -2.940293073654175, -3.0814785957336426, -3.2306599617004395, -3.3882431983947754, -3.5546364784240723, -3.7302467823028564, -3.9154741764068604, -4.110708236694336, -4.316320419311523, -4.532655239105225, -4.760022163391113, -4.998682975769043, -5.248838424682617, -5.510611534118652, -5.784029483795166, -6.069002628326416, -6.365297317504883, -6.672510623931885, -6.990036964416504, -7.317034721374512, -7.6523871421813965, -7.994663715362549, -8.342077255249023, -8.692442893981934, -9.043132781982422, -9.391047477722168, -9.73257827758789, -10.063592910766602, -10.37942886352539, -10.67491626739502, -10.944416999816895, -10.383661270141602, -9.771240234375, -9.112977027893066, -8.417091369628906, -7.693760395050049, -6.954543590545654, -6.211706638336182, -5.477518081665039, -4.763584136962891, -4.08027458190918, -3.436286687850952, -2.8383724689483643, -2.2912309169769287, -1.7975492477416992, -1.358167052268982, -0.9723249673843384, -0.6379621624946594, -0.3520289659500122, -0.11078764498233795, 0.08991694450378418, 0.25442755222320557, 0.3870900571346283, 0.49211350083351135, 0.5734705924987793, 0.6348327398300171, 0.6795337796211243, 0.7105553150177002, 0.7305287718772888, 0.7417487502098083, 0.746194064617157, 0.7455536723136902, 0.7412546873092651, 0.734490692615509, 0.7262501120567322, 0.7173427939414978, 0.708424985408783, 0.7000220417976379, 0.6925492286682129, 0.68632972240448, 0.681611180305481, 0.6785798072814941, 0.6773728132247925, 0.6780886054039001, 0.6807965040206909, 0.6855438351631165, 0.6923628449440002, 0.7012758255004883, 0.7122997045516968, 0.7254499793052673, 0.7407434582710266, 0.7582008242607117, 0.777849018573761, 0.79972243309021, 0.8238645195960999, 0.8503289818763733, 0.8791804909706116, 0.9104956984519958, 0.9443638324737549, 0.9808873534202576, 1.0201826095581055, 1.0623805522918701, 1.1076267957687378, 1.1560832262039185, 1.2079277038574219, 1.2633554935455322, 1.3225795030593872, 1.3858317136764526, 1.4533635377883911, 1.525447130203247, 1.6023762226104736, 1.6844675540924072, 1.7720615863800049, 1.8655239343643188, 1.965246558189392, 2.0716490745544434, 2.1851792335510254, 2.3063156604766846, 2.4355669021606445, 2.5734739303588867, 2.720609426498413, 2.8775794506073, 3.045022487640381, 3.22360897064209, 3.4140396118164062, 3.617044448852539, 3.8333778381347656, 4.063814640045166, 4.309142589569092, 4.570155620574951, 4.847639560699463, 5.142359733581543, 5.455041885375977, 5.786346912384033, 6.136845588684082, 6.506979465484619, 6.897021293640137, 7.307020664215088, 7.736745834350586, 8.185608863830566, 8.65258502960205, 9.136115074157715, 9.6282377243042, 10.125383377075195, 10.623027801513672, 11.11559772491455, 11.596385955810547, 12.0574951171875, 12.489819526672363, 12.883089065551758, 13.225995063781738, 13.506412506103516, 13.711745262145996, 13.8294038772583, 13.847418785095215, 13.755175590515137, 13.544246673583984, 13.209239959716797, 12.748610496520996, 12.165316581726074, 11.467212677001953, 10.667097091674805, 9.78233528137207, 8.834053993225098, 7.845956802368164, 6.842865943908691, 5.8491716384887695, 4.88734769821167, 3.976722240447998, 3.1326138973236084, 2.365900993347168, 1.6830101013183594, 1.0862581729888916, 0.5744486451148987, 0.14360657334327698, -0.21224986016750336, -0.500382661819458, -0.7287047505378723, -0.9052739143371582, -1.0379154682159424, -1.1339625120162964, -1.200096607208252, -1.2422682046890259, -1.2656757831573486, -1.2747853994369507, -1.2733776569366455, -1.2646092176437378, -1.2510817050933838, -1.234911561012268, -1.2177979946136475, -1.2010867595672607, -1.1858271360397339, -1.1728233098983765, -1.1626801490783691, -1.155841588973999, -1.152624249458313, -1.153246521949768, -1.1578514575958252, -1.166527509689331, -1.179324746131897, -1.1962682008743286, -1.217368721961975, -1.2426323890686035, -1.2720664739608765, -1.3056857585906982, -1.3435163497924805, -1.3855990171432495, -1.4319919347763062, -1.4827719926834106, -1.5380364656448364, -1.5979037284851074, -1.662514328956604, -1.7320307493209839, -1.8066381216049194, -1.8865443468093872, -1.9719797372817993, -2.063197135925293, -2.1604719161987305, -2.264101266860962, -2.3744044303894043, -2.4917211532592773, -2.6164121627807617, -2.748857259750366, -2.8894543647766113, -3.0386178493499756, -3.1967761516571045, -3.3643696308135986, -3.54184627532959, -3.729658603668213, -3.9282567501068115, -4.138083457946777, -4.359564304351807, -4.593100547790527, -4.839053630828857, -5.0977349281311035, -5.369386672973633, -5.654162883758545, -5.95210599899292, -6.263120651245117, -6.586941719055176, -6.92310094833374, -7.270884990692139, -7.629293441772461, -7.493341445922852, -7.349358081817627, -7.196996212005615, -7.036209583282471, -6.867253303527832, -6.690670013427734, -6.507264614105225, -6.318068981170654, -6.124301910400391, -5.927321910858154, -5.728583335876465, -5.529587745666504, -5.3318400382995605, -5.136807918548584, -4.945885181427002, -4.76036262512207, -4.58140230178833, -4.4100236892700195, -4.247089862823486, -4.09330415725708, -3.9492123126983643, -3.815207004547119, -3.691538095474243, -3.578324794769287, -3.4755709171295166, -3.3831799030303955, -3.300971746444702, -3.228698968887329, -3.1660614013671875, -3.1127219200134277, -3.0683181285858154, -3.0324745178222656, -3.004812717437744, -2.9849600791931152, -2.9725561141967773, -2.9672586917877197, -2.9687485694885254, -2.976731777191162, -2.9909424781799316, -3.0111448764801025, -3.0371317863464355, -3.068727493286133, -3.1057848930358887, -3.1481854915618896, -3.1958389282226562, -3.2486798763275146, -3.306668281555176, -3.369786262512207, -3.4380369186401367, -3.511441707611084, -3.5900392532348633, -3.6738827228546143, -3.76303768157959, -3.8575797080993652, -3.957592248916626, -4.063163757324219, -4.174385070800781, -4.291346549987793, -4.414134502410889, -4.542828559875488, -4.677496910095215, -4.818192005157471, -4.96494722366333, -5.117770195007324, -5.276637554168701, -5.441490173339844, -5.612224578857422, -5.7886857986450195, -5.970660209655762, -6.157866477966309, -6.349946022033691, -6.546455383300781, -6.746852397918701, -6.950490474700928, -7.1566057205200195, -7.364309310913086, -7.57257604598999, -7.780240058898926, -7.985987186431885, -8.188350677490234, -8.385714530944824, -8.576314926147461, -8.758249282836914, -8.929492950439453, -9.087918281555176, -9.231324195861816, -9.357474327087402, -9.46413803100586, -9.54914665222168, -9.610448837280273, -9.646180152893066, -9.654728889465332, -9.634807586669922, -9.58552360534668, -9.506438255310059, -9.397621154785156, -9.259690284729004, -9.09383487701416, -8.901811599731445, -8.685925483703613, -8.44898509979248, -8.185325622558594, -7.898719787597656, -7.593338489532471, -7.2736382484436035, -6.9442315101623535, -6.609752178192139, -6.27471923828125, -5.943411827087402, -5.619757652282715, -5.307248115539551, -5.008871555328369, -4.727078914642334, -4.463772296905518, -4.220315456390381, -3.997565984725952, -3.7959232330322266, -3.6153836250305176, -3.4556045532226562, -3.3159680366516113, -3.195645570755005, -3.093656301498413, -3.0089199542999268, -2.94030499458313, -2.8866665363311768, -2.8468782901763916, -2.8198585510253906, -2.804586887359619, -2.800119400024414, -2.805595636367798, -2.8202433586120605, -2.8433797359466553, -2.8744099140167236, -2.9128246307373047, -2.9581944942474365, -3.0101656913757324, -3.068453550338745, -3.132835865020752, -3.2031474113464355, -3.2792727947235107, -3.361140727996826, -3.4487175941467285, -3.5420022010803223, -3.641019821166992, -3.745816469192505, -3.856454849243164, -3.9730076789855957, -4.095553874969482, -4.224173069000244, -4.3589396476745605, -4.499917507171631, -4.647156238555908, -4.8006815910339355, -4.960492134094238, -5.126550674438477, -5.2987775802612305, -5.477041244506836, -5.66115140914917, -5.850849151611328, -6.045795440673828, -6.24556303024292, -6.449624061584473, -6.657339572906494, -6.867948055267334, -7.080554962158203, -7.294120788574219, -7.5074543952941895, -7.719203948974609, -7.927852630615234, -8.131715774536133, -8.328944206237793, -8.517531394958496, -8.695327758789062, -8.860057830810547, -9.009352684020996, -9.14078426361084, -9.251914024353027, -9.340343475341797, -9.40378189086914, -9.440113067626953, -9.447473526000977, -9.424330711364746, -9.369556427001953, -9.282504081726074, -9.163066864013672, -9.011728286743164, -8.829587936401367, -8.618372917175293, -8.380414009094238, -8.11860466003418, -7.836328029632568, -7.537364959716797, -7.225780963897705, -6.905803680419922, -6.581692218780518, -6.257611274719238, -5.937511444091797, -5.625027656555176, -5.323397636413574, -5.035400390625, -4.763322353363037, -4.508945941925049, -4.273558616638184, -4.057981491088867, -3.862607955932617, -3.6874592304229736, -3.532238245010376, -3.3963892459869385, -3.2791566848754883, -3.1796388626098633, -3.0968375205993652, -3.0297014713287354, -2.977163076400757, -2.93816876411438, -2.9117019176483154, -2.8968019485473633, -2.8925764560699463, -2.8982093334198, -2.912966012954712, -2.93619441986084, -2.9673256874084473, -3.005868911743164, -3.05141019821167, -3.1036057472229004, -3.162177085876465, -3.226905107498169, -3.297624349594116, -3.3742170333862305, -3.456606388092041, -3.5447514057159424, -3.6386420726776123, -3.7382917404174805, -3.8437342643737793, -3.955016851425171, -4.072196006774902, -4.195332050323486, -4.324483871459961, -4.4597039222717285, -4.60103178024292, -4.748488903045654, -4.902072906494141, -5.061750411987305, -5.227449417114258, -5.399053573608398, -5.576391696929932, -5.759231090545654, -5.947267055511475, -6.140114784240723, -6.337296962738037, -6.538235187530518, -6.742238998413086, -6.948495388031006, -7.156059741973877, -7.363844871520996, -7.570616722106934, -7.774986267089844, -7.97540807723999, -8.17017936706543, -8.357447624206543, -8.535221099853516, -8.701379776000977, -8.84679889678955, -8.968899726867676, -8.360508918762207, -7.729096412658691, -7.082942962646484, -6.431039333343506, -5.78263521194458, -5.146773338317871, -4.531860828399658, -3.945305824279785, -3.393247604370117, -2.8803982734680176, -2.4099884033203125, -1.9838093519210815, -1.6023321151733398, -1.2648802995681763, -0.9698351621627808, -0.7148499488830566, -0.49705877900123596, -0.31326642632484436, -0.16011305153369904, -0.03420914709568024, 0.06775858998298645, 0.14894899725914001, 0.2123125195503235, 0.2605576515197754, 0.2961338460445404, 0.3212272822856903, 0.3377661406993866, 0.34743237495422363, 0.3516780734062195, 0.35174453258514404, 0.34868234395980835, 0.34337201714515686, 0.33654388785362244, 0.32879728078842163, 0.320618212223053, 0.31239578127861023, 0.30443692207336426, 0.2969795763492584, 0.2902044951915741, 0.28424543142318726, 0.2791981101036072, 0.2751278877258301, 0.27207642793655396, 0.27006715536117554, 0.2691100835800171, 0.26920562982559204, 0.2703479528427124, 0.2725276052951813, 0.27573370933532715, 0.2799556255340576, 0.2851845920085907, 0.2914145588874817, 0.2986433804035187, 0.3068732023239136, 0.316111296415329, 0.3263702690601349, 0.33766862750053406, 0.3500308394432068, 0.36348778009414673, 0.37807685136795044, 0.3938421905040741, 0.41083502769470215, 0.4291137754917145, 0.44874438643455505, 0.4698006510734558, 0.49236446619033813, 0.5165263414382935, 0.5423856377601624, 0.5700514316558838, 0.5996425747871399, 0.6312887072563171, 0.6651306748390198, 0.7013214826583862, 0.7400269508361816, 0.7814269065856934, 0.8257156610488892, 0.8731037378311157, 0.9238185286521912, 0.9781058430671692, 1.036231279373169, 1.0984816551208496, 1.1651663780212402, 1.2366198301315308, 1.3132025003433228, 1.3953031301498413, 1.483341097831726, 1.577768087387085, 1.6790708303451538, 1.7877730131149292, 1.9044381380081177, 2.0296716690063477, 2.164123296737671, 2.30849027633667, 2.4635183811187744, 2.6300048828125, 2.808799982070923, 3.000808000564575, 3.2069873809814453, 3.428351402282715, 3.6659655570983887, 3.9209437370300293, 4.192102432250977, 4.480341911315918, 4.786525726318359, 5.111462116241455, 5.4558796882629395, 5.820400238037109, 6.205500602722168, 6.611466884613037, 7.038340091705322, 7.485851287841797, 7.953343391418457, 8.439680099487305, 8.943144798278809, 9.461324691772461, 9.99098014831543, 10.527914047241211, 11.06683349609375, 11.601212501525879, 12.123181343078613, 12.62343692779541, 13.091217041015625, 13.514338493347168, 13.87934684753418, 14.171802520751953, 14.37671184539795, 14.479146957397461, 14.465043067932129, 14.322154998779297, 14.041119575500488, 13.616558074951172, 13.048072814941406, 12.341017723083496, 11.506889343261719, 10.563215255737305, 9.532861709594727, 8.442788124084473, 7.32234525680542, 6.201298713684082, 5.107839584350586, 4.0668206214904785, 3.0984253883361816, 2.217400550842285, 1.432866096496582, 0.7486440539360046, 0.16396604478359222, -0.32559117674827576, -0.7270973324775696, -1.049306869506836, -1.3018245697021484, -1.49443781375885, -1.6366245746612549, -1.7372223138809204, -1.8042317628860474, -1.8447258472442627, -1.8648345470428467, -1.869781255722046, -1.863950490951538, -1.8509719371795654, -1.8338117599487305, -1.8148627281188965, -1.7960293292999268, -1.7788068056106567, -1.7643505334854126, -1.7535383701324463, -1.7470238208770752, -1.7452819347381592, -1.7486484050750732, -1.7573519945144653, -1.771541953086853, -1.7913106679916382, -1.8167120218276978, -1.8477762937545776, -1.8845221996307373, -1.926966667175293, -1.9751317501068115, -2.029050827026367, -2.088773012161255, -2.1543655395507812, -2.225917100906372, -2.3035380840301514, -2.387362241744995, -2.477546215057373, -2.574270248413086, -2.677736520767212, -2.7881691455841064, -2.9058117866516113, -3.0309274196624756, -3.163795232772827, -3.304708242416382, -3.4539713859558105, -3.611896514892578, -3.778799295425415, -3.9549942016601562, -4.140788555145264, -4.336475849151611, -4.5423264503479, -4.758581161499023, -4.985436916351318, -5.22303581237793, -5.47144889831543, -5.730660438537598, -6.000548362731934, -6.280860900878906, -6.571192741394043, -6.8709564208984375, -7.179354190826416, -7.49534273147583, -7.817601203918457, -8.144493103027344, -7.911733150482178, -7.665533065795898, -7.406703948974609, -7.136514186859131, -6.856656074523926, -6.569183826446533, -6.276432037353516, -5.980926990509033, -5.6852922439575195, -5.392153739929199, -5.104053020477295, -4.823370456695557, -4.552262783050537, -4.292611598968506, -4.045995235443115, -3.8136696815490723, -3.596566915512085, -3.39530611038208, -3.210214138031006, -3.041353225708008, -2.8885552883148193, -2.751457691192627, -2.629540205001831, -2.522160768508911, -2.4285900592803955, -2.348040819168091, -2.2796967029571533, -2.222733736038208, -2.176340341567993, -2.1397321224212646, -2.1121649742126465, -2.092942476272583, -2.081422805786133, -2.0770223140716553, -2.0792174339294434, -2.0875446796417236, -2.10159969329834, -2.1210365295410156, -2.1455636024475098, -2.174941301345825, -2.1083946228027344, -2.0487284660339355, -1.9957399368286133, -1.9491931200027466, -1.9088294506072998, -1.8743776082992554, -1.8455603122711182, -1.8221017122268677, -1.8037322759628296, -1.7901932001113892, -1.7812402248382568, -1.7766451835632324, -1.776199221611023, -1.7797129154205322, -1.7870177030563354, -1.7979656457901, -1.8124302625656128, -1.830305576324463, -1.8515061140060425, -1.8759658336639404, -1.9036381244659424, -1.9344944953918457, -1.9685239791870117, -2.005732536315918, -2.046142101287842, -2.089790105819702, -2.136728048324585, -2.1870217323303223, -2.240750551223755, -2.2980058193206787, -2.358891725540161, -2.4235239028930664, -2.4920287132263184, -2.5645434856414795, -2.6412160396575928, -2.722202777862549, -2.8076696395874023, -2.8977911472320557, -2.992748975753784, -3.0927317142486572, -3.1979334354400635, -3.308553695678711, -3.4247941970825195, -3.5468592643737793, -3.674952507019043, -3.809274911880493, -3.9500226974487305, -4.097383499145508, -4.2515339851379395, -4.412633419036865, -4.580821514129639, -4.756210803985596, -4.938880443572998, -5.128870010375977, -5.326169967651367, -5.53071403503418, -5.742366313934326, -5.960911273956299, -6.186041355133057, -6.417342185974121, -6.6542792320251465, -6.896180152893066, -7.142220973968506, -7.3914079666137695, -7.642563343048096, -7.894308090209961, -8.145051002502441, -8.392974853515625, -8.636034965515137, -8.871950149536133, -9.098217964172363, -9.312117576599121, -9.510743141174316, -9.69103717803955, -9.849833488464355, -9.983930587768555, -10.090160369873047, -10.165483474731445, -10.20709228515625, -10.212522506713867, -10.179770469665527, -10.10741138458252, -9.994706153869629, -9.841694831848145, -9.649266242980957, -9.419198036193848, -9.154153823852539, -8.85764217376709, -8.533939361572266, -8.187957763671875, -7.8250932693481445, -7.451042175292969, -7.071600437164307, -6.692471027374268, -6.319073677062988, -5.956384658813477, -5.608804702758789, -5.280066967010498, -4.973182201385498, -4.690426826477051, -4.4333600997924805, -4.195876121520996, -3.9788565635681152, -3.782707929611206, -3.607424020767212, -3.4526541233062744, -3.31777286529541, -3.2019448280334473, -3.1041858196258545, -3.0234169960021973, -2.9585111141204834, -2.908332347869873, -2.8717665672302246, -2.8477466106414795, -2.8352692127227783, -2.8334083557128906, -2.841322183609009, -2.858257532119751, -2.8835501670837402, -2.9166228771209717, -2.9569835662841797, -3.004218101501465, -3.0579872131347656, -3.118018627166748, -3.1841018199920654, -3.256080389022827, -3.3338472843170166, -3.417337417602539, -3.506521463394165, -3.6014013290405273, -3.7020034790039062, -3.80837345123291, -3.9205715656280518, -4.03866720199585, -4.1627326011657715, -4.292839527130127, -4.42905330657959, -4.571425914764404, -4.719992160797119, -4.874761581420898, -5.0357136726379395, -5.202789783477783, -5.375885486602783, -5.554841995239258, -5.739439487457275, -5.929384231567383, -6.124301910400391, -6.323725700378418, -6.527085781097412, -6.733698844909668, -6.942756652832031, -7.153316497802734, -7.364291667938232, -7.574441432952881, -7.7823686599731445, -7.986512660980225, -8.185152053833008, -8.376405715942383, -8.558247566223145, -8.72851848602295, -8.8849515914917, -9.025199890136719, -9.146883964538574, -9.247631072998047, -9.325136184692383, -9.377227783203125, -9.401935577392578, -9.397566795349121, -9.36277961730957, -9.296658515930176, -9.19877815246582, -9.06926155090332, -8.908814430236816, -8.718750953674316, -8.500986099243164, -8.25800895690918, -7.992830276489258, -7.708905220031738, -7.410036087036133, -7.1002583503723145, -6.783720016479492, -6.464555740356445, -6.146766662597656, -5.834110260009766, -5.530009746551514, -5.237479209899902, -4.959076404571533, -4.696876049041748, -4.452463626861572, -4.226953983306885, -4.021018981933594, -3.834932804107666, -3.668623447418213, -3.5217278003692627, -3.393649101257324, -3.283612012863159, -3.1907131671905518, -3.1139681339263916, -3.052351236343384, -3.004829168319702, -2.9703879356384277, -2.9480555057525635, -2.9369163513183594, -2.9361236095428467, -2.9449055194854736, -2.9625697135925293, -2.98850417137146, -3.0221755504608154, -3.063126564025879, -3.1109721660614014, -3.1653943061828613, -3.2261366844177246, -3.292999029159546, -3.3658316135406494, -3.444528818130493, -3.5290231704711914, -3.619281053543091, -3.7152953147888184, -3.8170814514160156, -3.9246714115142822, -4.038109302520752, -4.157444477081299, -4.282729148864746, -4.414010524749756, -4.551326274871826, -4.694698810577393, -4.844130039215088, -4.999593734741211, -5.161029815673828, -5.328336238861084, -5.501361846923828, -5.679898262023926, -5.863670825958252, -6.052328586578369, -6.24543571472168, -6.442461967468262, -6.642770767211914, -6.84561014175415, -7.050104141235352, -7.255241394042969, -7.459869384765625, -7.662687301635742, -7.862242698669434, -8.056931495666504, -8.245000839233398, -8.424554824829102, -8.593573570251465, -8.749926567077637, -8.891406059265137, -9.015756607055664, -9.120720863342285, -9.204090118408203, -9.263760566711426, -9.297798156738281, -9.304506301879883, -9.282496452331543, -9.230756759643555, -9.148715019226074, -9.036293029785156, -8.893950462341309, -8.722708702087402, -8.52415657043457, -8.300433158874512, -8.054186820983887, -7.788515567779541, -7.506882667541504, -7.213017463684082, -6.910806179046631, -6.6041765213012695, -6.296985149383545, -5.992908954620361, -5.695354461669922, -5.407378196716309, -5.1316328048706055, -4.870331287384033, -4.6252312660217285, -4.397640705108643, -4.188437461853027, -3.998105764389038, -3.8267767429351807, -3.6742796897888184, -3.540194034576416, -3.423900842666626, -3.324632406234741, -3.2415177822113037, -3.1736245155334473, -3.1199915409088135, -3.0796597003936768, -3.0516951084136963, -3.0352060794830322, -3.029358148574829, -3.033381700515747, -3.0465786457061768, -3.068324327468872, -3.0980687141418457, -3.13533353805542, -3.179710626602173, -3.2308571338653564, -3.2884910106658936, -3.352386236190796, -3.4223666191101074, -3.498300552368164, -3.580096483230591, -3.6676952838897705, -3.7610669136047363, -3.860203981399536, -3.965116500854492, -4.075827598571777, -4.192366600036621, -4.3147664070129395, -4.443055629730225, -4.577254295349121, -4.717369079589844, -4.8633856773376465, -5.015263557434082, -5.172929763793945, -5.336270332336426, -5.505125999450684, -5.679279327392578, -5.8584513664245605, -5.581213474273682, -5.305078029632568, -5.03238582611084, -4.765296459197998, -4.505768775939941, -4.2555389404296875, -4.016097545623779, -3.788682222366333, -3.5742673873901367, -3.3735697269439697, -3.1870574951171875, -3.014967203140259, -2.857325315475464, -2.7139742374420166, -2.584599494934082, -2.4687578678131104, -2.365905523300171, -2.2754242420196533, -2.196646213531494, -2.1288750171661377, -2.071404457092285, -2.0235352516174316, -1.9845870733261108, -1.9539097547531128, -1.9308903217315674, -1.91495943069458, -1.9055943489074707, -1.9023219347000122, -1.9047187566757202, -1.9124114513397217, -1.9250750541687012, -1.9424320459365845, -1.9642497301101685, -1.99033784866333, -2.0205466747283936, -2.0547635555267334, -2.0929110050201416, -2.134943962097168, -2.180846691131592, -2.2306323051452637, -2.28433895111084, -2.3420283794403076, -2.4037842750549316, -2.4697113037109375, -2.5399322509765625, -2.6145880222320557, -2.693835496902466, -2.777846574783325, -2.866807699203491, -2.9609174728393555, -3.060386896133423, -3.1654369831085205, -3.2762985229492188, -3.393209218978882, -3.516413450241089, -3.6461596488952637, -3.782697916030884, -3.9262776374816895, -4.077143669128418, -4.235534191131592, -4.401673793792725, -4.575771808624268, -4.758012294769287, -4.948550701141357, -5.147503852844238, -5.354940891265869, -5.570873737335205, -5.795243740081787, -6.027909755706787, -6.268631458282471, -6.517053604125977, -6.772688388824463, -7.0348944664001465, -7.302857875823975, -7.575569152832031, -7.851799964904785, -8.130084991455078, -8.408699035644531, -8.685637474060059, -8.958606719970703, -9.22501277923584, -9.481961250305176, -9.726268768310547, -9.954482078552246, -10.162919998168945, -10.347725868225098, -10.504940032958984, -10.630599975585938, -10.720848083496094, -10.772072792053223, -10.781051635742188, -10.745116233825684, -10.662304878234863, -10.531525611877441, -10.352682113647461, -10.126778602600098, -9.855979919433594, -9.54361629486084, -9.194130897521973, -8.812963485717773, -8.406379699707031, -7.971652030944824, -7.516327381134033, -7.048236846923828, -6.575207710266113, -6.104778289794922, -5.6439385414123535, -5.19891357421875, -4.7750020027160645, -4.376479148864746, -4.006556987762451, -3.6674070358276367, -3.360227108001709, -3.0853450298309326, -2.8423454761505127, -2.6302077770233154, -2.447446584701538, -2.292243003845215, -2.162565231323242, -2.0562708377838135, -1.9711936712265015, -1.9052112102508545, -1.8562965393066406, -1.8225551843643188, -1.8022487163543701, -1.7938084602355957, -1.795841097831726, -1.8071272373199463, -1.8266154527664185, -1.8534133434295654, -1.8867764472961426, -1.9260954856872559, -1.9708842039108276, -2.020766019821167, -2.0754618644714355, -2.134779691696167, -2.1986021995544434, -2.266878366470337, -2.339613914489746, -2.4168639183044434, -2.2642698287963867, -2.1203958988189697, -1.9859144687652588, -1.8612322807312012, -1.7465300559997559, -1.6418009996414185, -1.5468846559524536, -1.4614996910095215, -1.3852720260620117, -1.3177599906921387, -1.2584768533706665, -1.2069091796875, -1.162532925605774, -1.1248265504837036, -1.0932811498641968, -1.0674083232879639, -1.0467469692230225, -1.0308666229248047, -1.0193709135055542, -1.0118992328643799, -1.0081267356872559, -1.007764458656311, -1.0105587244033813, -1.016289472579956, -1.0247690677642822, -1.035840392112732, -1.049375057220459, -1.065271258354187, -1.0834522247314453, -1.1038644313812256, -1.1264756917953491, -1.1512737274169922, -1.178264856338501, -1.2074724435806274, -1.238936424255371, -1.2727112770080566, -1.3088665008544922, -1.3474851846694946, -1.3886632919311523, -1.432510256767273, -1.4791477918624878, -1.528710126876831, -1.5813440084457397, -1.6372087001800537, -1.6964759826660156, -1.7593305110931396, -1.8259700536727905, -1.8966057300567627, -1.9714624881744385, -2.050779104232788, -2.1348092555999756, -2.223820924758911, -2.3180975914001465, -2.4179375171661377, -2.5236551761627197, -2.635580062866211, -2.7540571689605713, -2.8794467449188232, -3.0121235847473145, -3.1524760723114014, -3.3009045124053955, -3.457820415496826, -3.623642921447754, -3.798797130584717, -3.983708620071411, -4.178800106048584, -4.384483337402344, -4.601154804229736, -4.829183578491211, -5.068902492523193, -5.32059383392334, -5.584474563598633, -5.8606791496276855, -6.149235248565674, -6.450042247772217, -6.762841701507568, -7.087186336517334, -7.422400951385498, -7.767547607421875, -8.121378898620605, -8.482292175292969, -8.848282814025879, -9.216897010803223, -9.585183143615723, -9.949651718139648, -10.30624771118164, -10.650323867797852, -10.976653099060059, -11.279446601867676, -11.552422523498535, -11.788901329040527, -11.98195743560791, -12.124616622924805, -12.210103034973145, -12.232144355773926, -12.185300827026367, -12.06533432006836, -11.8695650100708, -11.59720516204834, -11.24962329864502, -10.83051586151123, -10.33515739440918, -9.771961212158203, -9.151644706726074, -8.486823081970215, -7.791440486907959, -7.080098628997803, -6.367331504821777, -5.666897296905518, -4.991160869598389, -4.35060977935791, -3.7535431385040283, -3.2059385776519775, -2.7114880084991455, -2.271771192550659, -1.886530876159668, -1.5540040731430054, -1.2712767124176025, -1.0346256494522095, -0.8398289084434509, -0.6824293732643127, -0.5579473972320557, -0.4620424211025238, -0.39062726497650146, -0.3399428427219391, -0.3065996468067169, -0.28759393095970154, -0.28030481934547424, -0.28247833251953125, -0.29220256209373474, -0.3078780472278595, -0.32818537950515747, -0.3520530164241791, -0.37862542271614075, -0.4072335362434387, -0.43736743927001953, -0.46865177154541016, -0.5008238554000854, -0.5337144732475281, -0.5672316551208496, -0.6013461351394653, -0.6360798478126526, -0.6714956164360046, -0.7076893448829651, -0.7447830438613892, -0.7829198837280273, -0.8222596645355225, -0.8629759550094604, -0.905253529548645, -0.9492867588996887, -0.9952786564826965, -1.0434401035308838, -1.0939894914627075, -1.1471531391143799, -1.2031655311584473, -1.2622696161270142, -1.32471764087677, -1.3907718658447266, -1.4607057571411133, -1.534804344177246, -1.6133657693862915, -1.6967018842697144, -1.7851390838623047, -1.8790196180343628, -1.978702187538147, -2.0845625400543213, -2.1969945430755615, -2.3164100646972656, -2.443239688873291, -2.577932119369507, -2.720953941345215, -2.8727900981903076, -3.033939838409424, -3.2049179077148438, -3.386249542236328, -3.578467845916748, -3.782109260559082, -3.997706413269043, -4.2257819175720215, -4.466838836669922, -4.721346378326416, -4.989730358123779, -5.272351264953613, -5.56948709487915, -5.881306171417236, -6.207840919494629, -6.548950672149658, -6.904286861419678, -7.273244857788086, -7.654914379119873, -8.048025131225586, -8.450883865356445, -8.861310005187988, -9.276567459106445, -9.693297386169434, -10.107455253601074, -10.51425552368164, -10.908133506774902, -11.282730102539062, -11.630908966064453, -11.944822311401367, -12.216021537780762, -12.435647964477539, -12.594682693481445, -12.684286117553711, -12.69620418548584, -12.623244285583496, -12.459787368774414, -12.202309608459473, -11.84985637664795, -11.404428482055664, -10.871219635009766, -10.258642196655273, -9.578134536743164, -8.84371280670166, -8.071313858032227, -7.277959823608398, -6.480842113494873, -5.696398735046387, -4.93949556350708, -4.222771167755127, -3.5562069416046143, -2.946934700012207, -2.3992676734924316, -1.914919376373291, -1.4933557510375977, -1.1322228908538818, -0.827799916267395, -0.5754336714744568, -0.36992600560188293, -0.20585863292217255, -0.07784824818372726, 0.01926499418914318, 0.09028881043195724, 0.13960038125514984, 0.1711076945066452, 0.1882409006357193, 0.1939651072025299, 0.19080746173858643, 0.1808929592370987, 0.16598476469516754, 0.147525817155838, 0.12667988240718842, 0.10437042266130447, 0.08131644874811172, 0.05806506425142288, 0.03502039611339569, 0.012468947097659111, -0.009398382157087326, -0.03046746924519539, -0.05068499967455864, -0.0700450912117958, -0.08857820183038712, -0.105973020195961, -0.12236690521240234, -0.13789492845535278, -0.15268780291080475, -0.16687053442001343, -0.18056155741214752, -0.19387224316596985, -0.20690681040287018, -0.2197623997926712, -0.23252935707569122, -0.2452915608882904, -0.2581269145011902, -0.27110782265663147, -0.2843016982078552, -0.29777151346206665, -0.311576247215271, -0.3257714509963989, -0.319174200296402, -0.31326571106910706, -0.3080727756023407, -0.3036099374294281, -0.29988235235214233, -0.29688769578933716, -0.2946183979511261, -0.2930629551410675, -0.2922075688838959, -0.29203709959983826, -0.29253607988357544, -0.2936895191669464, -0.29548344016075134, -0.29790541529655457, -0.3009450137615204, -0.30459389090538025, -0.3088463246822357, -0.3136990964412689, -0.3191518187522888, -0.32520684599876404, -0.33186954259872437, -0.3391481339931488, -0.3470539152622223, -0.35560110211372375, -0.3648070693016052, -0.37469223141670227, -0.38528013229370117, -0.3965975046157837, -0.4086743891239166, -0.4215441346168518, -0.43524351716041565, -0.44981294870376587, -0.4652964174747467, -0.48174184560775757, -0.4992011785507202, -0.5177305936813354, -0.5373906493186951, -0.5582466125488281, -0.5803688168525696, -0.6038328409194946, -0.628719687461853, -0.6551164984703064, -0.6831167340278625, -0.7128204703330994, -0.7443352341651917, -0.7777760028839111, -0.8132661581039429, -0.8509377837181091, -0.8909324407577515, -0.9334017634391785, -0.9785080552101135, -1.0264251232147217, -1.0773391723632812, -1.1314494609832764, -1.188969373703003, -1.2501269578933716, -1.3151665925979614, -1.3843494653701782, -1.4579548835754395, -1.5362814664840698, -1.6196478605270386, -1.7083947658538818, -1.8028854131698608, -1.903506875038147, -2.010671615600586, -2.1248185634613037, -2.246413469314575, -2.375951051712036, -2.5139544010162354, -2.6609768867492676, -2.817601203918457, -2.9844393730163574, -3.162132978439331, -3.3513503074645996, -3.5527842044830322, -3.7671494483947754, -3.9951770305633545, -4.237607955932617, -4.495184421539307, -4.7686381340026855, -5.0586771965026855, -5.365967273712158, -5.691108226776123, -6.034609317779541, -6.396852970123291, -6.778054714202881, -7.17821741104126, -7.597069263458252, -8.034001350402832, -8.487988471984863, -8.957499504089355, -9.440404891967773, -9.933865547180176, -10.434219360351562, -10.936871528625488, -11.43618106842041, -11.925363540649414, -12.396422386169434, -12.840121269226074, -13.246013641357422, -13.602555274963379, -13.887818336486816, -14.08812141418457, -14.18984603881836, -14.18017578125, -14.047981262207031, -13.784784317016602, -13.38575267791748, -12.850604057312012, -12.184296607971191, -11.397383689880371, -10.49383544921875, -9.494876861572266, -8.426061630249023, -7.315754413604736, -6.1933088302612305, -5.0871357917785645, -4.022921085357666, -3.0222065448760986, -2.101468324661255, -1.2717607021331787, -0.5388741493225098, 0.09609301388263702, 0.6358986496925354, 1.0862038135528564, 1.4546284675598145, 1.7499072551727295, 1.9811943769454956, 2.1575355529785156, 2.2875003814697266, 2.378951072692871, 2.43892240524292, 2.4735827445983887, 2.488250255584717, 2.4874465465545654, 2.4749677181243896, 2.453965663909912, 2.4270308017730713, 2.396268844604492, 2.3633744716644287, 2.329695463180542, 2.2962887287139893, 2.2639708518981934, 2.2333600521087646, 2.204911470413208, 2.1789486408233643, 2.1556882858276367, 2.1352624893188477, 2.1177356243133545, 2.1031198501586914, 2.091386556625366, 2.08247709274292, 2.0763096809387207, 2.0727875232696533, 2.0718023777008057, 2.073239803314209, 2.076981782913208, 2.082908868789673, 2.0909035205841064, 2.100849151611328, 2.112632989883423, 2.126145839691162, 2.141282081604004, 2.15794038772583, 2.176023483276367, 2.104461193084717, 2.0384297370910645, 1.9780608415603638, 1.9233976602554321, 1.874411940574646, 1.8310192823410034, 1.7930924892425537, 1.7604726552963257, 1.7329797744750977, 1.7104207277297974, 1.692596197128296, 1.679307222366333, 1.6703593730926514, 1.6655666828155518, 1.6647549867630005, 1.6677637100219727, 1.6744476556777954, 1.684678554534912, 1.6983453035354614, 1.715354561805725, 1.735630750656128, 1.7591161727905273, 1.7857705354690552, 1.815570592880249, 1.8485097885131836, 1.884597897529602, 1.9238601922988892, 1.9663368463516235, 2.012083053588867, 2.0611679553985596, 2.1136741638183594, 2.1696977615356445, 2.2293472290039062, 2.2927439212799072, 2.360020875930786, 2.4313228130340576, 2.506805419921875, 2.5866353511810303, 2.670990228652954, 2.760056495666504, 2.8540308475494385, 2.953118085861206, 3.0575308799743652, 3.1674892902374268, 3.2832183837890625, 3.4049479961395264, 3.5329108238220215, 3.66733980178833, 3.8084664344787598, 3.956517219543457, 4.111711025238037, 4.27425479888916, 4.444338798522949, 4.622129917144775, 4.807768821716309, 5.001358509063721, 5.202957630157471, 5.412572860717773, 5.630144119262695, 5.855535984039307, 6.088521480560303, 6.328768730163574, 6.57582426071167, 6.829094886779785, 7.087830543518066, 7.351102352142334, 7.61778450012207, 7.88653564453125, 8.155777931213379, 8.423684120178223, 8.68816089630127, 8.946843147277832, 9.197093963623047, 9.43600845336914, 9.660435676574707, 9.867005348205566, 10.052179336547852, 10.212310791015625, 10.343722343444824, 10.4428129196167, 10.50616455078125, 10.53067684173584, 10.513704299926758, 10.453203201293945, 10.347870826721191, 10.197266578674316, 10.001921653747559, 9.763400077819824, 9.48432731628418, 9.168364524841309, 7.961520671844482, 6.739767074584961, 5.530052185058594, 4.358353614807129, 3.2478723526000977, 2.2176318168640137, 1.2816184759140015, 0.4484989047050476, -0.27814576029777527, -0.8991896510124207, -1.4190927743911743, -1.8449410200119019, -2.185518980026245, -2.4504969120025635, -2.6497769355773926, -2.79300594329834, -2.8892455101013184, -2.9467735290527344, -2.9729864597320557, -2.9743785858154297, -2.956568479537964, -2.9243569374084473, -2.8818023204803467, -2.8323001861572266, -2.7786645889282227, -2.7232041358947754, -2.6677932739257812, -2.6139354705810547, -2.5628199577331543, -2.515371799468994, -2.4722957611083984, -2.4341139793395996, -2.4011993408203125, -2.3738040924072266, -2.352083444595337, -2.336118221282959, -2.3259317874908447, -2.321505546569824, -2.32279109954834, -2.3297226428985596, -2.342224359512329, -2.360217571258545, -2.3836281299591064, -2.4123897552490234, -2.44644832611084, -2.4857640266418457, -2.5303146839141846, -2.5800955295562744, -2.6351218223571777, -2.6954281330108643, -2.7610690593719482, -2.8321192264556885, -2.9086720943450928, -2.990840196609497, -3.078754186630249, -3.172560930252075, -3.2724239826202393, -3.3785197734832764, -3.4910387992858887, -3.6101808547973633, -3.7361550331115723, -3.869176149368286, -4.009461402893066, -4.157227516174316, -4.312687873840332, -4.476044654846191, -4.647487163543701, -4.827183246612549, -5.015273094177246, -5.211859703063965, -5.417003154754639, -5.630704402923584, -5.852898120880127, -6.083437442779541, -6.32207727432251, -6.568460464477539, -6.822098255157471, -7.0823493003845215, -7.348402500152588, -7.6192522048950195, -7.8936767578125, -8.170218467712402, -8.447161674499512, -8.722515106201172, -8.994001388549805, -9.259040832519531, -9.51476001739502, -9.757996559143066, -9.985321998596191, -10.193078994750977, -10.377434730529785, -10.534459114074707, -10.660211563110352, -10.750859260559082, -10.802809715270996, -10.812856674194336, -10.778339385986328, -10.697300910949707, -10.56864070892334, -10.392247200012207, -10.169099807739258, -9.891590118408203, -9.563017845153809, -9.188002586364746, -8.772396087646484, -8.323111534118652, -7.84788703918457, -7.3549957275390625, -6.852917671203613, -6.350006580352783, -5.8541717529296875, -5.3726019859313965, -4.911544322967529, -4.476153373718262, -4.070417404174805, -3.6971476078033447, -3.358034610748291, -3.053748846054077, -2.784076690673828, -2.5480730533599854, -2.3442206382751465, -2.1705853939056396, -2.0249555110931396, -1.9049670696258545, -1.8082058429718018, -1.732290506362915, -1.674936056137085, -1.6339980363845825, -1.6075037717819214, -1.593668818473816, -1.590904712677002, -1.5978184938430786, -1.6132062673568726, -1.6360435485839844, -1.6654722690582275, -1.7007869482040405, -1.7414199113845825, -1.7869271039962769, -1.8369734287261963, -1.8913204669952393, -1.949813723564148, -2.0123720169067383, -2.078977346420288, -2.1496663093566895, -2.224522590637207, -2.3036701679229736, -2.387267827987671, -2.47550368309021, -2.568591833114624, -2.666767120361328, -2.7702841758728027, -2.8794124126434326, -2.994433879852295, -3.1156418323516846, -3.2433364391326904, -3.377823829650879, -3.519412040710449, -3.668408155441284, -3.8251149654388428, -3.9898266792297363, -4.1628241539001465, -4.344368934631348, -4.534697532653809, -4.734012126922607, -4.942473411560059, -5.160189151763916, -5.387202262878418, -5.623477458953857, -5.8688859939575195, -6.123188018798828, -6.386013507843018, -6.6568403244018555, -6.934971809387207, -7.219511985778809, -7.509339332580566, -7.803079128265381, -8.099080085754395, -8.3953857421875, -8.689713478088379, -8.979440689086914, -9.261585235595703, -9.532814979553223, -9.789449691772461, -10.027494430541992, -10.242680549621582, -10.430537223815918, -10.586479187011719, -10.705925941467285, -10.784442901611328, -10.817911148071289, -10.802703857421875, -10.73588752746582, -10.6154146194458, -10.44030475616455, -10.210801124572754, -9.928478240966797, -9.596294403076172, -9.218576431274414, -8.800924301147461, -8.3500394821167, -7.873487949371338, -7.379403591156006, -6.876163482666016, -6.372048854827881, -5.874924182891846, -5.3919572830200195, -4.921044826507568, -4.4680304527282715, -4.0377349853515625, -3.6339032649993896, -3.2592031955718994, -2.915281295776367, -2.602855920791626, -2.321837902069092, -2.071467161178589, -1.8504531383514404, -1.657110571861267, -1.4894843101501465, -1.345458984375, -1.2228509187698364, -1.1194825172424316, -1.033239483833313, -0.9621127247810364, -0.9042273759841919, -0.85785973072052, -0.8214462995529175, -0.793584942817688, -0.7730317115783691, -0.7586933374404907, -0.7496175169944763, -0.7449817657470703, -0.744081437587738, -0.7463177442550659, -0.7511857748031616, -0.758263349533081, -0.7672004103660583, -0.7777094841003418, -0.7895566821098328, -0.8025539517402649, -0.8165519833564758, -0.8314341306686401, -0.84711092710495, -0.8635155558586121, -0.8805996179580688, -0.8983297944068909, -0.9166850447654724, -0.9356538653373718, -0.9552324414253235, -0.9754228591918945, -0.9962313771247864, -1.0176677703857422, -1.0397437810897827, -1.0624728202819824, -1.0858688354492188, -1.1099460124969482, -1.134718418121338, -1.160199522972107, -1.1864017248153687, -1.21333646774292, -1.2410138845443726, -1.2694425582885742, -1.2986294031143188, -1.3285796642303467, -1.3592965602874756, -1.3907815217971802, -1.423033595085144, -1.456049919128418, -1.4898251295089722, -1.5243514776229858, -1.5596188306808472, -1.5956141948699951, -1.6323219537734985, -1.6697237491607666, -1.7077980041503906, -1.7465202808380127, -1.7858625650405884, -1.825793981552124, -1.8662797212600708, -1.907281517982483, -1.948757529258728, -1.990661859512329, -2.032944679260254, -2.075552463531494, -2.118427038192749, -2.161506175994873, -2.204723596572876, -2.2480080127716064, -2.2578611373901367, -2.2710487842559814, -2.287548065185547, -2.30733585357666, -2.330390453338623, -2.3566946983337402, -2.3862357139587402, -2.419006586074829, -2.4550065994262695, -2.4942429065704346, -2.536729574203491, -2.5824875831604004, -2.6315464973449707, -2.6839425563812256, -2.7397193908691406, -2.7989275455474854, -2.861624240875244, -2.927872657775879, -2.997741460800171, -3.0713043212890625, -3.148638963699341, -3.2298269271850586, -3.3149518966674805, -3.404099464416504, -3.4973552227020264, -3.594804286956787, -3.696528911590576, -3.802608013153076, -3.913114547729492, -4.028113842010498, -4.147661209106445, -4.271799087524414, -4.400555610656738, -4.533940315246582, -4.671939849853516, -4.814517498016357, -4.961604595184326, -5.113100528717041, -5.268864631652832, -5.428712844848633, -5.592411518096924, -5.759672164916992, -5.930144786834717, -6.103412628173828, -6.278985500335693, -6.456294059753418, -6.634683609008789, -6.813411235809326, -6.991638660430908, -7.168429374694824, -7.34274959564209, -7.513465404510498, -7.679347515106201, -7.83907413482666, -7.991241931915283, -8.13437557220459, -8.266945838928223, -8.387388229370117, -8.494128227233887, -8.585610389709473, -8.660331726074219, -8.716879844665527, -8.753969192504883, -8.770487785339355, -8.765534400939941, -8.738462448120117, -8.688915252685547, -8.616859436035156, -8.52260971069336, -8.406843185424805, -8.270601272583008, -8.115286827087402, -7.942640781402588, -7.754706382751465, -7.553788661956787, -7.342398166656494, -7.123188018798828, -6.898887634277344, -6.67223596572876, -6.445913314819336, -6.222480773925781, -6.004326820373535, -5.7936224937438965, -5.592287540435791, -5.401970863342285, -5.22403621673584, -5.059566497802734, -4.909370422363281, -4.774001121520996, -4.653778553009033, -4.548819065093994, -4.459062576293945, -4.384305000305176, -4.3242292404174805, -4.278431415557861, -4.246449947357178, -4.227787971496582, -4.221933841705322, -4.2283782958984375, -4.246629238128662, -4.276222229003906, -4.311829090118408, -4.353235721588135, -4.400242328643799, -4.447921276092529, -4.496213912963867, -4.545047283172607, -4.594333171844482, -4.6439690589904785, -4.693838119506836, -4.743810176849365, -4.7937421798706055, -4.843476295471191, -4.892843246459961, -4.941661834716797, -4.989738464355469, -5.036870002746582, -5.082841873168945, -5.127432823181152, -5.170412063598633, -5.211544513702393, -5.250588893890381, -5.287302017211914, -5.321439743041992, -5.352757930755615, -5.381016254425049, -5.405979633331299, -5.427420616149902, -5.445122241973877, -5.458880424499512, -5.468505859375, -5.473827362060547, -5.47469425201416, -5.470978260040283, -5.4625749588012695, -5.449408531188965, -5.431429386138916, -5.408619403839111, -5.3809895515441895, -5.348584175109863, -5.3114776611328125, -5.269775867462158, -5.223616123199463, -5.1731648445129395, -5.118617057800293, -5.060193061828613, -4.998137474060059, -4.932714939117432, -4.8642096519470215, -4.792919635772705, -4.719153881072998, -4.643230438232422, -4.5654706954956055, -4.4861979484558105, -4.405731678009033, -4.324388027191162, -4.242472171783447, -4.160279273986816, -4.078090667724609, -3.9961719512939453, -3.914771556854248, -3.834118604660034, -3.754422903060913, -3.6758735179901123, -3.598639488220215, -3.5228683948516846, -3.4486873149871826, -3.376204252243042, -3.305506944656372, -3.2366652488708496, -3.169731855392456, -3.104743003845215, -3.041719913482666, -2.868492364883423, -2.707786798477173, -2.559706926345825, -2.424180507659912, -2.3009870052337646, -2.1897835731506348, -2.0901291370391846, -2.001509666442871, -1.9233591556549072, -1.8550792932510376, -1.7960561513900757, -1.7456752061843872, -1.703332781791687, -1.6684463024139404, -1.6404613256454468, -1.6188572645187378, -1.603151559829712, -1.5929017066955566, -1.5877071619033813, -1.5872089862823486, -1.5910899639129639, -1.5990731716156006, -1.6109204292297363, -1.6264307498931885, -1.6454381942749023, -1.6678098440170288, -1.6934435367584229, -1.7222659587860107, -1.7542306184768677, -1.7893155813217163, -1.8275223970413208, -1.8688737154006958, -1.91341233253479, -1.9611998796463013, -2.012315273284912, -2.0668537616729736, -2.1249265670776367, -2.186659574508667, -2.252192497253418, -2.32167911529541, -2.395285129547119, -2.4731898307800293, -2.555584192276001, -2.642670154571533, -2.734661102294922, -2.8317811489105225, -2.9342637062072754, -3.042351722717285, -3.1562957763671875, -3.276353359222412, -3.4027884006500244, -3.53586745262146, -3.6758596897125244, -3.823033332824707, -3.9776527881622314, -4.139975070953369, -4.310245513916016, -4.488692283630371, -4.675520896911621, -4.870906352996826, -5.074986457824707, -5.287849426269531, -5.509527206420898, -5.739977836608887, -5.979075908660889, -6.226593971252441, -6.482186794281006, -6.7453694343566895, -7.015500068664551, -7.291753768920898, -7.573101997375488, -7.858286380767822, -8.145797729492188, -8.433849334716797, -8.720362663269043, -9.00294303894043, -9.278879165649414, -9.545133590698242, -9.798355102539062, -10.034900665283203, -10.250874519348145, -10.442187309265137, -10.604631423950195, -10.733985900878906, -10.826139450073242, -10.877236366271973, -10.883837699890137, -10.843093872070312, -10.752923011779785, -10.612177848815918, -10.42078971862793, -10.17988109588623, -9.891828536987305, -9.560264587402344, -9.190018653869629, -8.786982536315918, -8.357921600341797, -7.910218238830566, -7.451596736907959, -6.989813804626465, -6.53236722946167, -6.077280521392822, -5.6313371658325195, -5.200559616088867, -4.790063858032227, -4.403973579406738, -4.0453925132751465, -3.7164244651794434, -3.418243885040283, -3.151193380355835, -2.9149057865142822, -2.70843505859375, -2.530388832092285, -2.3790535926818848, -2.2525084018707275, -2.1487228870391846, -2.0656394958496094, -2.001237630844116, -1.953585147857666, -1.9208719730377197, -1.9014348983764648, -1.893770456314087, -1.8965413570404053, -1.908575177192688, -1.928860068321228, -1.9565356969833374, -1.990883708000183, -2.031315565109253, -2.0773613452911377, -2.1286563873291016, -2.184931516647339, -2.2460005283355713, -2.311750650405884, -2.3821332454681396, -2.4571549892425537, -2.5368707180023193, -2.6213767528533936, -2.7108044624328613, -2.8053152561187744, -2.9050960540771484, -3.010354518890381, -3.1213157176971436, -3.238218069076538, -3.36130952835083, -3.4908456802368164, -3.6270840167999268, -3.770282030105591, -3.920691967010498, -4.07855749130249, -4.244107723236084, -4.4175519943237305, -4.59907341003418, -4.788821220397949, -4.986903667449951, -5.193376541137695, -5.408233642578125, -5.631393909454346, -5.862687587738037, -6.101842403411865, -6.348465442657471, -6.602024555206299, -6.861830234527588, -7.12701416015625, -7.396507263183594, -7.6690192222595215, -7.943017959594727, -8.216708183288574, -8.488018035888672, -8.754583358764648, -9.013744354248047, -9.262547492980957], "z": [10.0, 9.633333206176758, 9.386394500732422, 9.242918014526367, 9.186662673950195, 9.202041625976562, 9.27444076538086, 9.390336990356445, 9.537337303161621, 9.704184532165527, 9.880752563476562, 10.058052062988281, 10.228242874145508, 10.384649276733398, 10.521770477294922, 10.635278701782227, 10.721994400024414, 10.779839515686035, 10.807765007019043, 10.805652618408203, 10.774194717407227, 10.714761734008789, 10.62926197052002, 10.519996643066406, 10.38952922821045, 10.240555763244629, 10.075801849365234, 9.897931098937988, 9.709478378295898, 9.512795448303223, 9.310019493103027, 9.103057861328125, 8.893577575683594, 8.683015823364258, 8.472585678100586, 8.263300895690918, 8.055986404418945, 7.8513078689575195, 7.649787902832031, 7.4518280029296875, 7.257726669311523, 7.067698001861572, 6.881886005401611, 6.700377941131592, 6.523214817047119, 6.350402355194092, 6.181918621063232, 6.017719268798828, 5.8577446937561035, 5.701923370361328, 5.550174236297607, 5.402411937713623, 5.258546352386475, 5.118484973907471, 4.982136249542236, 4.8494062423706055, 4.720202922821045, 4.594435691833496, 4.472014427185059, 4.352851867675781, 4.236861705780029, 4.123960494995117, 4.014066219329834, 3.9070987701416016, 3.802980661392212, 3.7016360759735107, 3.6029913425445557, 3.506974697113037, 3.413516044616699, 3.322547674179077, 3.2340033054351807, 3.1478183269500732, 3.063930034637451, 2.9822776317596436, 2.902801275253296, 2.8254435062408447, 2.750147819519043, 2.6768593788146973, 2.605525016784668, 2.536092519760132, 2.4685113430023193, 2.4027326107025146, 2.33870792388916, 2.27639102935791, 2.2157363891601562, 2.1566996574401855, 2.0992379188537598, 2.043309450149536, 1.9888733625411987, 1.9358899593353271, 1.8843207359313965, 1.8341280221939087, 1.7852754592895508, 1.737727403640747, 1.6914492845535278, 1.6464074850082397, 1.602569341659546, 1.5599029064178467, 1.5183770656585693, 1.4779620170593262, 1.4386281967163086, 1.400347113609314, 1.3630911111831665, 1.3268332481384277, 1.2915472984313965, 1.2572078704833984, 1.223790168762207, 1.1912702322006226, 1.1596245765686035, 1.1288305521011353, 1.09886634349823, 1.0697104930877686, 1.0413423776626587, 1.0137418508529663, 0.9868895411491394, 0.9607666730880737, 0.9353550672531128, 0.9106371402740479, 0.8865960240364075, 0.8632153868675232, 0.8404794931411743, 0.8183733224868774, 0.7968823909759521, 0.7759929895401001, 0.7556918859481812, 0.7359667420387268, 0.7168057560920715, 0.6981979012489319, 0.6801329255104065, 0.6626012921333313, 0.6455944180488586, 0.629104495048523, 0.6131247878074646, 0.5976493954658508, 0.5826737284660339, 0.5681941509246826, 0.554208517074585, 0.5407159328460693, 0.5277171730995178, 0.5152145624160767, 0.5032125115394592, 0.4917173683643341, 0.4807378947734833, 0.47028541564941406, 0.4603741765022278, 0.4510217308998108, 0.4422492980957031, 0.4340822696685791, 0.4265507459640503, 0.4196900725364685, 0.413541704416275, 0.4081538915634155, 0.4035826325416565, 0.39989277720451355, 0.3971591889858246, 0.39546826481819153, 0.39491933584213257, 0.3956267535686493, 0.3977218270301819, 0.4013552963733673, 0.4067001938819885, 0.41395488381385803, 0.4233468472957611, 0.4351368248462677, 0.44962358474731445, 0.4671494662761688, 0.48810654878616333, 0.5129439234733582, 0.5421757102012634, 0.5763903856277466, 0.6162614226341248, 0.6625589728355408, 0.7161632776260376, 0.7780799269676208, 0.8494565486907959, 0.9316015839576721, 1.026004672050476, 1.134359359741211, 1.25858736038208, 1.4008638858795166, 1.5636451244354248, 1.749694585800171, 1.9621096849441528, 2.204345703125, 2.4802348613739014, 2.7939980030059814, 3.150244951248169, 3.5539591312408447, 4.010456562042236, 4.525319576263428, 5.103882312774658, 5.751290798187256, 6.472250938415527, 7.270702362060547, 8.149422645568848, 9.109554290771484, 10.150078773498535, 11.267242431640625, 12.453990936279297, 13.699466705322266, 14.98863410949707, 16.302143096923828, 17.61650276184082, 18.90468978881836, 20.137178421020508, 21.283472061157227, 22.31396484375, 23.202045440673828, 23.926145553588867, 24.471487045288086, 24.83124542236328, 25.00693702697754, 25.007980346679688, 24.85049057006836, 24.447050094604492, 23.845436096191406, 23.101797103881836, 22.27326011657715, 21.41190528869629, 20.560802459716797, 19.75218963623047, 19.007434844970703, 18.33819580078125, 17.74823570251465, 17.23539924621582, 16.79347801208496, 16.413793563842773, 16.086444854736328, 15.80125904083252, 15.548439979553223, 15.319019317626953, 15.10511589050293, 14.900068283081055, 14.698471069335938, 14.496137619018555, 14.290006637573242, 14.078025817871094, 13.859007835388184, 13.632481575012207, 13.398544311523438, 13.157721519470215, 12.910845756530762, 12.658940315246582, 12.4031343460083, 12.144586563110352, 11.88443374633789, 11.623746871948242, 11.363509178161621, 11.104598999023438, 10.847782135009766, 10.593717575073242, 10.34295654296875, 10.095954895019531, 9.853079795837402, 9.614623069763184, 9.38080883026123, 9.151805877685547, 8.927734375, 8.708678245544434, 8.494686126708984, 8.285785675048828, 8.08198070526123, 7.8832621574401855, 7.689608097076416, 7.500988960266113, 7.317368984222412, 7.138708114624023, 6.964966297149658, 6.7961015701293945, 6.63207483291626, 6.472849369049072, 6.3183913230896, 6.16867208480835, 6.023670196533203, 5.883369445800781, 5.747763156890869, 5.616852760314941, 5.490652084350586, 5.369184494018555, 5.252487659454346, 5.140614986419678, 5.03363561630249, 4.931637287139893, 4.834728717803955, 4.743041515350342, 4.656733512878418, 4.575991630554199, 4.501034736633301, 4.432117462158203, 4.369535446166992, 4.313628673553467, 4.264787197113037, 4.223456859588623, 4.1901469230651855, 4.16543436050415, 4.1499738693237305, 4.144505023956299, 4.149862766265869, 4.166985034942627, 4.196924686431885, 4.2408599853515625, 4.30010461807251, 4.376121520996094, 4.4705305099487305, 4.585119724273682, 4.721855163574219, 4.882884979248047, 5.07054328918457, 5.287347316741943, 5.5359883308410645, 5.819314479827881, 6.14030122756958, 6.502006530761719, 6.907512664794922, 7.359842777252197, 7.861410140991211, 8.414163589477539, 9.019405364990234, 9.677579879760742, 10.388045310974121, 11.148825645446777, 11.956376075744629, 12.805355072021484, 13.688455581665039, 14.596298217773438, 15.517441749572754, 16.438518524169922, 17.344539642333984, 18.219356536865234, 19.046306610107422, 19.808977127075195, 20.4920597076416, 21.082212448120117, 21.568851470947266, 21.944761276245117, 22.206478118896484, 22.354393005371094, 22.39253807067871, 22.32813835144043, 22.17093276977539, 21.932401657104492, 21.624954223632812, 21.261184692382812, 20.853225708007812, 20.41227912902832, 19.948291778564453, 19.46979522705078, 18.983863830566406, 18.496177673339844, 18.011154174804688, 17.532102584838867, 17.061410903930664, 16.60071563720703, 16.151058197021484, 15.713032722473145, 15.286897659301758, 14.872671127319336, 14.470210075378418, 14.079261779785156, 13.69951057434082, 13.330605506896973, 12.972182273864746, 12.623878479003906, 12.28533935546875, 11.956225395202637, 11.636214256286621, 11.32500171661377, 11.022299766540527, 10.727837562561035, 10.44135856628418, 10.162620544433594, 9.89139461517334, 9.627461433410645, 9.370612144470215, 9.120646476745605, 8.877372741699219, 8.640604972839355, 8.410164833068848, 8.185880661010742, 7.967584609985352, 7.755115032196045, 7.54831600189209, 7.347034454345703, 7.151122570037842, 6.960436820983887, 6.774837017059326, 6.594188213348389, 6.418358325958252, 6.247217655181885, 6.080642223358154, 5.9185099601745605, 5.760702610015869, 5.607104778289795, 5.457604885101318, 5.312093257904053, 5.170464038848877, 5.032614231109619, 4.89844274520874, 4.767852306365967, 4.640747547149658, 4.517035961151123, 4.396626949310303, 4.279433727264404, 4.165370464324951, 4.054354190826416, 3.9463047981262207, 3.8411431312561035, 3.73879337310791, 3.639181137084961, 3.542234182357788, 3.447882652282715, 3.356058120727539, 3.2666945457458496, 3.179727554321289, 3.0950944423675537, 3.0127344131469727, 2.932588815689087, 2.854600191116333, 2.7787132263183594, 2.7048628330230713, 2.6329939365386963, 2.563053846359253, 2.494990825653076, 2.428755283355713, 2.3642985820770264, 2.3015737533569336, 2.240535259246826, 2.1811389923095703, 2.1233417987823486, 2.0671021938323975, 2.0123798847198486, 1.9591355323791504, 1.9073313474655151, 1.8569303750991821, 1.8078972101211548, 1.7601971626281738, 1.7137969732284546, 1.6686643362045288, 1.6247680187225342, 1.582077980041504, 1.5405652523040771, 1.500201940536499, 1.4609612226486206, 1.422817349433899, 1.385745882987976, 1.349723219871521, 1.3147271871566772, 1.2807364463806152, 1.247731328010559, 1.2156929969787598, 1.184604287147522, 1.1544491052627563, 1.1252130270004272, 1.096882939338684, 1.06944739818573, 1.0428967475891113, 1.0172232389450073, 0.9924208521842957, 0.9684858918190002, 0.9454169273376465, 0.9232151508331299, 0.9018843173980713, 0.8814314603805542, 0.8618668913841248, 0.8432045578956604, 0.8254625797271729, 0.8086637854576111, 0.7928358316421509, 0.7780122756958008, 0.7642330527305603, 0.7515450716018677, 0.7400033473968506, 0.7296720147132874, 0.7206251621246338, 0.7129483819007874, 0.706740140914917, 0.7021135091781616, 0.6991978287696838, 0.6981412768363953, 0.6991127729415894, 0.702305257320404, 0.7079384922981262, 0.7162626385688782, 0.7275625467300415, 0.7421621084213257, 0.7604293823242188, 0.7827826142311096, 0.8096965551376343, 0.8417100310325623, 0.8794340491294861, 0.9235610365867615, 0.9748752117156982, 1.0342637300491333, 1.102729082107544, 1.1814032793045044, 1.271561861038208, 1.3746397495269775, 1.4922486543655396, 1.6261932849884033, 1.778489351272583, 1.9513802528381348, 2.147352695465088, 2.3691492080688477, 2.6197783946990967, 2.9025161266326904, 3.220900058746338, 3.5787124633789062, 3.9799439907073975, 4.428741455078125, 4.929324150085449, 5.485874652862549, 6.102384090423584, 6.7824602127075195, 7.529083251953125, 8.344313621520996, 9.228950500488281, 10.182148933410645, 11.201011657714844, 12.28018569946289, 13.411492347717285, 14.582544326782227, 15.777406692504883, 16.976709365844727, 18.15807342529297, 19.29688262939453, 20.367401123046875, 21.344196319580078, 22.203765869140625, 22.926164627075195, 23.49649429321289, 23.905990600585938, 24.152591705322266, 24.24087142944336, 24.181373596191406, 23.989431381225586, 23.683673858642578, 23.28443145751953, 22.812232971191406, 22.28656005859375, 21.724946975708008, 21.142423629760742, 20.551300048828125, 19.96121597290039, 19.379352569580078, 18.810773849487305, 18.258787155151367, 17.725330352783203, 17.2112979888916, 16.716835021972656, 16.2415771484375, 15.784836769104004, 15.345739364624023, 14.923327445983887, 14.516627311706543, 14.124700546264648, 13.746663093566895, 13.381706237792969, 13.029098510742188, 12.688186645507812, 12.358393669128418, 12.039207458496094, 11.730180740356445, 11.430919647216797, 11.141081809997559, 10.860363960266113, 10.588504791259766, 10.325275421142578, 10.070476531982422, 9.82394027709961, 9.58552074432373, 9.355100631713867, 9.132583618164062, 8.917898178100586, 8.710996627807617, 8.511855125427246, 8.320472717285156, 8.136877059936523, 7.961122512817383, 7.793291091918945, 7.633497714996338, 7.48189115524292, 7.3386549949646, 7.204014301300049, 7.078235626220703, 6.961633682250977, 6.8545732498168945, 6.757473945617676, 6.670816421508789, 6.595146656036377, 6.531079292297363, 6.479306697845459, 6.440601825714111, 6.415823936462402, 6.4059247970581055, 6.411952495574951, 6.435056209564209, 6.476487159729004, 6.537601947784424, 6.619859218597412, 6.72481632232666, 6.854121208190918, 7.009498596191406, 7.192732810974121, 7.405639171600342, 7.650031089782715, 7.927675247192383, 8.240233421325684, 8.589198112487793, 8.975807189941406, 9.40095043182373, 9.86506462097168, 10.368008613586426, 10.908944129943848, 11.486201286315918, 12.097158432006836, 12.738128662109375, 13.404279708862305, 14.089580535888672, 14.786811828613281, 15.487629890441895, 16.18271255493164, 16.861984252929688, 17.51491355895996, 18.130884170532227, 18.699621200561523, 19.211633682250977, 19.65865135192871, 20.034011840820312, 20.33296012878418, 20.55284309387207, 20.693172454833984, 20.755544662475586, 20.743444442749023, 20.661945343017578, 20.517343521118164, 20.316757202148438, 20.067733764648438, 19.777896881103516, 19.454635620117188, 19.104875564575195, 18.73451805114746, 18.348861694335938, 17.95256233215332, 17.54962158203125, 17.143409729003906, 16.736719131469727, 16.331806182861328, 15.930471420288086, 15.53411865234375, 15.143818855285645, 14.760367393493652, 14.384334564208984, 14.01611614227295, 13.655963897705078, 13.304019927978516, 12.960344314575195, 12.624933242797852, 12.297734260559082, 11.978662490844727, 11.667604446411133, 11.364433288574219, 11.069007873535156, 10.781180381774902, 10.500798225402832, 10.227705001831055, 9.961746215820312, 9.702765464782715, 9.45060920715332, 9.205124855041504, 8.966163635253906, 8.7335786819458, 8.507225036621094, 8.286962509155273, 8.072652816772461, 7.864161014556885, 7.661357402801514, 7.464113235473633, 7.272304058074951, 7.085809707641602, 6.904512882232666, 6.728298664093018, 6.557057857513428, 6.390683174133301, 6.229071617126465, 6.0721235275268555, 5.919742584228516, 5.771836757659912, 5.628316402435303, 5.489096641540527, 5.354095458984375, 5.223234176635742, 5.096438407897949, 4.973637104034424, 4.854762077331543, 4.73923397064209, 4.626937389373779, 4.5177717208862305, 4.411647796630859, 4.3084869384765625, 4.208218574523926, 4.110780715942383, 4.016116619110107, 3.9241764545440674, 3.8349153995513916, 3.748293161392212, 3.664273977279663, 3.582826852798462, 3.5039238929748535, 3.4275424480438232, 3.3536629676818848, 3.282271146774292, 3.213355779647827, 3.146911144256592, 3.0829358100891113, 3.0214335918426514, 2.9624133110046387, 2.9058899879455566, 2.851884603500366, 2.800424814224243, 2.7515456676483154, 2.7052900791168213, 2.6617090702056885, 2.620863437652588, 2.5828239917755127, 2.5476725101470947, 2.515502691268921, 2.486421823501587, 2.4605510234832764, 2.4380276203155518, 2.419006109237671, 2.4036595821380615, 2.392181873321533, 2.384789228439331, 2.3817226886749268, 2.3832499980926514, 2.3896679878234863, 2.401305913925171, 2.418527126312256, 2.441732883453369, 2.471365213394165, 2.5079102516174316, 2.55190110206604, 2.603921890258789, 2.664611577987671, 2.7298264503479004, 2.799252510070801, 2.8726344108581543, 2.9497649669647217, 3.030478000640869, 3.1146421432495117, 3.202155113220215, 3.292938470840454, 3.386934757232666, 3.484102249145508, 3.5844130516052246, 3.687849760055542, 3.794402837753296, 3.9040679931640625, 4.016845226287842, 4.132735729217529, 4.251739025115967, 4.373854637145996, 4.4990763664245605, 4.6273932456970215, 4.758786678314209, 4.893230438232422, 5.03068733215332, 5.171109676361084, 5.3144354820251465, 5.460590362548828, 5.609485149383545, 5.761012554168701, 5.915050983428955, 6.07145881652832, 6.230078220367432, 6.3907318115234375, 6.553222179412842, 6.7173357009887695, 6.882837295532227, 7.049476146697998, 7.216982364654541, 7.385071277618408, 7.553442001342773, 7.721780776977539, 7.8897624015808105, 8.057051658630371, 8.223307609558105, 8.388184547424316, 8.551334381103516, 8.712409973144531, 8.871070861816406, 9.026981353759766, 9.17982006072998, 9.329275131225586, 9.475055694580078, 9.616887092590332, 9.754520416259766, 9.88772964477539, 10.016317367553711, 10.14011287689209, 10.258978843688965, 10.372809410095215, 10.481529235839844, 10.585098266601562, 10.683509826660156, 10.776787757873535, 10.864991188049316, 10.94820785522461, 11.026556968688965, 11.100187301635742, 11.169272422790527, 11.234013557434082, 11.294632911682129, 11.3513765335083, 11.40450668334961, 11.454305648803711, 11.501069068908691, 11.545106887817383, 11.586739540100098, 11.626296997070312, 11.664118766784668, 11.70054817199707, 11.735933303833008, 11.770627975463867, 11.804986000061035, 11.839362144470215, 11.874112129211426, 11.909590721130371, 11.946147918701172, 11.98413372039795, 12.023893356323242, 12.065767288208008, 12.110091209411621, 12.157194137573242, 12.207396507263184, 12.261012077331543, 12.318346977233887, 12.379693031311035, 12.445332527160645, 12.515535354614258, 12.590555191040039, 12.67063045501709, 12.755980491638184, 12.84680461883545, 12.943281173706055, 13.045150756835938, 13.152084350585938, 13.263675689697266, 13.379448890686035, 13.498858451843262, 13.621294975280762, 13.746084213256836, 13.872498512268066, 13.999760627746582, 14.127050399780273, 14.253515243530273, 14.378279685974121, 14.50045394897461, 14.619150161743164, 14.73348617553711, 14.842605590820312, 14.945687294006348, 15.041952133178711, 15.130681991577148, 15.211224555969238, 15.283002853393555, 15.345524787902832, 15.39838695526123, 15.441279411315918, 15.473989486694336, 15.496397972106934, 15.50848388671875, 15.51031494140625, 15.50204849243164, 15.48392391204834, 15.456252098083496, 15.419414520263672, 15.37385082244873, 15.320049285888672, 15.25854206085205, 15.18989372253418, 15.11469554901123, 15.033555030822754, 14.94709300994873, 14.85593318939209, 14.760699272155762, 14.662009239196777, 14.560473442077637, 14.456686973571777, 14.351232528686523, 14.244672775268555, 14.137554168701172, 14.030401229858398, 13.923722267150879, 13.818001747131348, 13.713706016540527, 13.611281394958496, 13.511154174804688, 13.413735389709473, 13.319415092468262, 13.228567123413086, 13.14155101776123, 13.058707237243652, 12.980364799499512, 12.90683650970459, 12.838420867919922, 12.775403022766113, 12.71805477142334, 12.666632652282715, 12.621380805969238, 12.582527160644531, 12.550284385681152, 12.524847984313965, 12.50639820098877, 12.495092391967773, 12.491069793701172, 12.49444580078125, 12.505311012268066, 12.523727416992188, 12.549729347229004, 12.5833158493042, 12.624452590942383, 12.673066139221191, 12.729040145874023, 12.792217254638672, 12.86238956451416, 12.939302444458008, 13.022647857666016, 13.112066268920898, 13.207141876220703, 13.307403564453125, 13.412324905395508, 13.521327018737793, 13.633776664733887, 13.748991012573242, 13.866243362426758, 13.984766006469727, 14.103755950927734, 14.22238540649414, 14.339804649353027, 14.455156326293945, 14.567583084106445, 14.676238059997559, 14.780293464660645, 14.87895393371582, 14.971468925476074, 15.057135581970215, 15.13531494140625, 15.205436706542969, 15.267007827758789, 15.31961727142334, 15.36293888092041, 15.396737098693848, 15.420866012573242, 15.435267448425293, 15.439970016479492, 15.435088157653809, 15.42081069946289, 15.397401809692383, 15.365190505981445, 15.324563026428223, 15.275958061218262, 15.219857215881348, 15.15677547454834, 15.087258338928223, 15.011869430541992, 14.93118953704834, 14.845804214477539, 14.756304740905762, 14.663278579711914, 14.567307472229004, 14.468962669372559, 14.368805885314941, 14.267382621765137, 14.165221214294434, 14.062835693359375, 13.960719108581543, 13.859349250793457, 13.75918197631836, 13.66065788269043, 13.564197540283203, 13.47020435333252, 13.379064559936523, 13.29114818572998, 13.206809997558594, 13.126387596130371, 13.05020523071289, 12.978570938110352, 12.911781311035156, 12.850115776062012, 12.793840408325195, 12.743209838867188, 12.698461532592773, 12.659817695617676, 12.627486228942871, 12.60165786743164, 12.58250617980957, 12.570185661315918, 12.564828872680664, 12.566546440124512, 12.57542610168457, 12.591526985168457, 12.61488151550293, 12.645488739013672, 12.683314323425293, 12.728289604187012, 12.780303001403809, 12.839204788208008, 12.904799461364746, 12.976844787597656, 13.05505084991455, 13.139078140258789, 13.228536605834961, 13.322983741760254, 13.42192554473877, 13.524818420410156, 13.631070137023926, 13.740041732788086, 13.851054191589355, 13.963386535644531, 14.07629108428955, 14.18898868560791, 14.300687789916992, 14.410581588745117, 14.517867088317871, 14.621745109558105, 14.721437454223633, 14.816192626953125, 14.905296325683594, 14.988080978393555, 15.063932418823242, 15.132302284240723, 15.192708015441895, 15.244745254516602, 15.288086891174316, 15.322486877441406, 15.347784042358398, 15.363899230957031, 15.370832443237305, 15.36866569519043, 15.357551574707031, 15.337715148925781, 15.309441566467285, 15.273075103759766, 15.229009628295898, 15.177682876586914, 15.11956787109375, 15.05516529083252, 14.985001564025879, 14.90961742401123, 14.829564094543457, 14.745399475097656, 14.623223304748535, 14.463884353637695, 14.269842147827148, 14.044723510742188, 13.792901992797852, 13.519125938415527, 13.228192329406738, 12.92470645904541, 12.612897872924805, 12.2965087890625, 11.978742599487305, 11.66224479675293, 11.34913444519043, 11.041044235229492, 10.739182472229004, 10.444395065307617, 10.157230377197266, 9.877997398376465, 9.60682201385498, 9.343692779541016, 9.088496208190918, 8.84105110168457, 8.6011323928833, 8.368488311767578, 8.142858505249023, 7.923975944519043, 7.711583137512207, 7.505430221557617, 7.30527925491333, 7.110906600952148, 6.922101974487305, 6.738667964935303, 6.560421466827393, 6.387190341949463, 6.218814373016357, 6.055142879486084, 5.896035671234131, 5.741359710693359, 5.5909905433654785, 5.444810390472412, 5.302708148956299, 5.164579391479492, 5.030323505401611, 4.899847507476807, 4.773062229156494, 4.64988374710083, 4.530232906341553, 4.414035797119141, 4.301223278045654, 4.191730499267578, 4.085498809814453, 3.982473134994507, 3.8826050758361816, 3.78585147857666, 3.6921751499176025, 3.6015448570251465, 3.51393723487854, 3.429335117340088, 3.3477299213409424, 3.2691214084625244, 3.193519353866577, 3.120943307876587, 3.051424980163574, 2.9850077629089355, 2.921750545501709, 2.861726760864258, 2.805027723312378, 2.7517647743225098, 2.7020702362060547, 2.656102180480957, 2.6140453815460205, 2.576115846633911, 2.542564868927002, 2.5136826038360596, 2.4898035526275635, 2.4713127613067627, 2.4586503505706787, 2.4523203372955322, 2.4528980255126953, 2.46103835105896, 2.4774858951568604, 2.5030860900878906, 2.538796901702881, 2.5857014656066895, 2.6450228691101074, 2.7181384563446045, 2.80659556388855, 2.9121286869049072, 3.036674737930298, 3.1823902130126953, 3.3516645431518555, 3.547133684158325, 3.7716867923736572, 4.028470039367676, 4.32088041305542, 4.652546405792236, 5.027299404144287, 5.449118614196777, 5.922054767608643, 6.4501261711120605, 7.037173271179199, 7.686159610748291, 8.39925479888916, 9.177534103393555, 10.020636558532715, 10.926399230957031, 11.890491485595703, 12.813940048217773, 13.669175148010254, 14.431827545166016, 15.081947326660156, 15.605043411254883, 15.99278736114502, 16.243234634399414, 16.360532760620117, 16.354135513305664, 16.237632751464844, 16.027368545532227, 15.741020202636719, 15.3962984085083, 15.009894371032715, 14.596718788146973, 14.169466018676758, 13.738438606262207, 13.311601638793945, 12.894783973693848, 12.491965293884277, 12.105606079101562, 11.736970901489258, 11.386423110961914, 11.05368423461914, 10.738046646118164, 10.438538551330566, 10.15404987335205, 9.883429527282715, 9.625540733337402, 9.379312515258789, 9.143757820129395, 8.917984962463379, 8.701208114624023, 8.492738723754883, 8.291980743408203, 8.09842586517334, 7.911640167236328, 7.731259822845459, 7.556978702545166, 7.388543128967285, 7.225742816925049, 7.068406581878662, 6.916396617889404, 6.769604206085205, 6.627945899963379, 6.491361141204834, 6.3598103523254395, 6.233274936676025, 6.111752033233643, 5.9952592849731445, 5.8838300704956055, 5.777517318725586, 5.676392078399658, 5.5805439949035645, 5.490083694458008, 5.405143737792969, 5.325879096984863, 5.252470970153809, 5.185126304626465, 5.124083042144775, 5.06960916519165, 5.022008895874023, 4.98162317276001, 4.9488348960876465, 4.924070835113525, 4.907805442810059, 4.900566577911377, 4.902936935424805, 4.915560245513916, 4.939144134521484, 4.9744648933410645, 5.022371768951416, 5.083788871765137, 5.159718990325928, 5.251245975494385, 5.359535217285156, 5.4858317375183105, 5.631457805633545, 5.797808647155762, 5.986340045928955, 6.198558330535889, 6.435998916625977, 6.700205326080322, 6.992695331573486, 7.314922332763672, 7.668229103088379, 8.053789138793945, 8.472539901733398, 8.925106048583984, 9.411715507507324, 9.932104110717773, 10.485421180725098, 11.070128440856934, 11.683910369873047, 12.323587417602539, 12.985061645507812, 13.663275718688965, 14.352225303649902, 15.045005798339844, 15.733919143676758, 16.410640716552734, 17.065458297729492, 17.68839454650879, 18.269594192504883, 18.799732208251953, 19.270421981811523, 19.674612045288086, 20.00690460205078, 20.263792037963867, 20.44378089904785, 20.547378540039062, 20.57697105407715, 20.536603927612305, 20.43165397644043, 20.268489837646484, 20.05409049987793, 19.795698165893555, 19.500499725341797, 19.175378799438477, 18.826719284057617, 18.460281372070312, 18.081132888793945, 17.693635940551758, 17.301462173461914, 16.90764617919922, 16.51464080810547, 16.12440299987793, 15.738454818725586, 15.357964515686035, 14.983804702758789, 14.616615295410156, 14.256850242614746, 13.904818534851074, 13.56071949005127, 13.2246675491333, 12.89671802520752, 12.576879501342773, 12.265130043029785, 11.961423873901367, 11.665704727172852, 11.37790298461914, 11.097949028015137, 10.825769424438477, 10.561295509338379, 10.304459571838379, 10.055201530456543, 9.813468933105469, 9.579217910766602, 9.352415084838867, 9.133038520812988, 8.921080589294434, 8.716547966003418, 8.519465446472168, 8.329874038696289, 8.14783763885498, 7.973442077636719, 7.806798934936523, 7.64804744720459, 7.4973578453063965, 7.354934215545654, 7.221018314361572, 7.095892429351807, 6.979884147644043, 6.87337064743042, 6.776783466339111, 6.690612316131592, 6.615411758422852, 6.551804542541504, 6.500489711761475, 6.462246894836426, 6.4379401206970215, 6.428525924682617, 6.435056686401367, 6.458683013916016, 6.500659942626953, 6.562343597412109, 6.645192623138428, 6.750762939453125, 6.8806986808776855, 7.0367207527160645, 7.220605373382568, 7.434159278869629, 7.6791839599609375, 7.957431316375732, 8.270545959472656, 8.61999797821045, 9.007002830505371, 9.432422637939453, 9.896662712097168, 10.39954948425293, 10.940210342407227, 11.516939163208008, 12.127080917358398, 12.766918182373047, 13.431591033935547, 14.1150484085083, 14.810063362121582, 15.508296966552734, 16.2004451751709, 16.876466751098633, 17.52587890625, 18.137123107910156, 18.698884963989258, 19.200632095336914, 19.633121490478516, 19.988876342773438, 20.2625732421875, 20.451274871826172, 20.55453109741211, 20.57430076599121, 20.514726638793945, 20.381776809692383, 20.182815551757812, 19.926116943359375, 19.620405197143555, 19.2744140625, 18.896543502807617, 18.494577407836914, 18.07550811767578, 17.645429611206055, 17.209518432617188, 16.77204132080078, 16.336435317993164, 15.905384063720703, 15.48092269897461, 15.06454086303711, 14.65727710723877, 14.259808540344238, 13.872532844543457, 13.495628356933594, 13.129115104675293, 12.772895812988281, 12.426793098449707, 12.090571403503418, 11.763967514038086, 11.446695327758789, 11.13846206665039, 10.838974952697754, 10.547948837280273, 10.26510238647461, 9.990168571472168, 9.722888946533203, 9.463018417358398, 9.210315704345703, 8.964569091796875, 8.725571632385254, 8.493119239807129, 8.267011642456055, 8.047059059143066, 7.833074569702148, 7.624881744384766, 7.422309875488281, 7.22519588470459, 7.033382415771484, 6.846718788146973, 6.6650614738464355, 6.488270282745361, 6.316211700439453, 6.148756504058838, 5.985780715942383, 5.8271636962890625, 5.672788619995117, 5.522542953491211, 5.376318454742432, 5.2340087890625, 5.095511436462402, 4.960727691650391, 4.82956075668335, 4.7019171714782715, 4.577706813812256, 4.456840991973877, 4.339235305786133, 4.224807262420654, 4.113476276397705, 4.005165100097656, 3.899799346923828, 3.7973060607910156, 3.697615623474121, 3.600660562515259, 3.506376028060913, 3.4146993160247803, 3.325570583343506, 3.2389323711395264, 3.1547300815582275, 3.072911262512207, 2.99342679977417, 2.916229724884033, 2.8412766456604004, 2.768526315689087, 2.697941541671753, 2.629488229751587, 2.5631353855133057, 2.49885630607605, 2.4366281032562256, 2.376431941986084, 2.3182544708251953, 2.262086868286133, 2.207925796508789, 2.1557741165161133, 2.1056418418884277, 2.0575456619262695, 2.0115110874176025, 1.9675724506378174, 1.925774097442627, 1.8861720561981201, 1.8488348722457886, 1.813845157623291, 1.7813018560409546, 1.7513216733932495, 1.7240415811538696, 1.6996214389801025, 1.6782469749450684, 1.6601331233978271, 1.6455274820327759, 1.6347153186798096, 1.6280239820480347, 1.6258286237716675, 1.6285581588745117, 1.6367028951644897, 1.6508221626281738, 1.6715530157089233, 1.6996207237243652, 1.735849380493164, 1.7811744213104248, 1.8366563320159912, 1.9034948348999023, 1.9830455780029297, 2.076836347579956, 2.1865861415863037, 2.314222812652588, 2.4619014263153076, 2.632023811340332, 2.8272526264190674, 3.0505261421203613, 3.3050661087036133, 3.5943777561187744, 3.922241687774658, 4.292690277099609, 4.709963798522949, 5.1784467697143555, 5.702569007873535, 6.286675453186035, 6.934846878051758, 7.6506757736206055, 8.436370849609375, 9.292798042297363, 10.21906852722168, 11.212108612060547, 12.266223907470703, 13.37271499633789, 14.519579887390137, 15.691393852233887, 16.869401931762695, 18.03190803527832, 19.15500259399414, 20.213603973388672, 21.182830810546875, 22.03952407836914, 22.76384925842285, 23.340730667114258, 23.76094627380371, 24.0217227935791, 24.12674903869629, 24.085582733154297, 23.912574768066406, 23.625455856323242, 23.243812561035156, 22.787622451782227, 22.27600860595703, 21.726333618164062, 21.153610229492188, 20.570253372192383, 19.98607635498047, 19.40848731994629, 18.842784881591797, 18.29251480102539, 17.759828567504883, 17.245811462402344, 16.75077247619629, 16.274484634399414, 15.816367149353027, 15.375616073608398, 14.951345443725586, 14.542648315429688, 14.148636817932129, 13.768465995788574, 13.401351928710938, 13.046574592590332, 12.703481674194336, 12.371482849121094, 12.050047874450684, 11.738700866699219, 11.437015533447266, 11.144606590270996, 10.861130714416504, 10.586274147033691, 10.319754600524902, 10.061315536499023, 9.810721397399902, 9.56775951385498, 9.332230567932129, 9.103957176208496, 8.882770538330078, 8.668519973754883, 8.461063385009766, 8.260272979736328, 8.066028594970703, 7.878222942352295, 7.6967573165893555, 7.521542549133301, 7.352498531341553, 7.189553260803223, 7.032645225524902, 6.881720066070557, 6.736732006072998, 6.597643852233887, 6.4644269943237305, 6.337059020996094, 6.2155280113220215, 6.099828243255615, 5.98996114730835, 5.885937213897705, 5.7877726554870605, 5.695490837097168, 5.609121799468994, 5.528700828552246, 5.4542694091796875, 5.385872840881348, 5.323561191558838, 5.267387390136719, 5.217405796051025, 5.173672676086426, 5.136242866516113, 5.105170249938965, 5.080504417419434, 5.058221817016602, 5.037883758544922, 5.0191450119018555, 5.001740455627441, 4.985472202301025, 4.97020149230957, 4.955836772918701, 4.942329406738281, 4.929663181304932, 4.917853355407715, 4.906938076019287, 4.896976470947266, 4.888044834136963, 4.880234241485596, 4.873648166656494, 4.868401527404785, 4.864617824554443, 4.862428665161133, 4.861972808837891, 4.863397121429443, 4.866852760314941, 4.872498512268066, 4.880497932434082, 4.89102029800415, 4.904240608215332, 4.920340061187744, 4.939504623413086, 4.9619269371032715, 4.987805366516113, 5.017343521118164, 5.050752639770508, 5.088248252868652, 5.1300530433654785, 5.176395893096924, 5.227510929107666, 5.283637523651123, 5.345020294189453, 5.411908149719238, 5.48455286026001, 5.5632100105285645, 5.648134708404541, 5.739583492279053, 5.837809085845947, 5.943061351776123, 6.055582046508789, 6.175604820251465, 6.303348541259766, 6.439017295837402, 6.582793712615967, 6.734835624694824, 6.895270824432373, 7.0641913414001465, 7.2416486740112305, 7.427647590637207, 7.622140407562256, 7.825018882751465, 8.036109924316406, 8.255169868469238, 8.4818754196167, 8.71582317352295, 8.956522941589355, 9.203390121459961, 9.455753326416016, 9.712843894958496, 9.97380256652832, 10.237679481506348, 10.50344181060791, 10.769980430603027, 11.03611946105957, 11.300625801086426, 11.562227249145508, 11.819628715515137, 12.071527481079102, 12.316631317138672, 12.553685188293457, 12.78148365020752, 12.998895645141602, 13.20488166809082, 13.398512840270996, 13.578980445861816, 13.74561595916748, 13.897895812988281, 14.035446166992188, 14.158048629760742, 14.26563835144043, 14.358299255371094, 14.436258316040039, 14.499872207641602, 14.549622535705566, 14.586094856262207, 14.609970092773438, 14.622008323669434, 14.623034477233887, 14.613921165466309, 14.5955810546875, 14.568950653076172, 14.534979820251465, 14.494623184204102, 14.448832511901855, 14.398550033569336, 14.344701766967773, 14.287834167480469, 14.22846794128418, 14.167102813720703, 14.104218482971191, 14.040273666381836, 13.975706100463867, 13.910937309265137, 13.846366882324219, 13.782378196716309, 13.719338417053223, 13.65759563446045, 13.597481727600098, 13.539313316345215, 13.483389854431152, 13.429996490478516, 13.379403114318848, 13.331863403320312, 13.287616729736328, 13.246885299682617, 13.209878921508789, 13.176791191101074, 13.147797584533691, 13.12306022644043, 13.10272216796875, 13.086912155151367, 13.075737953186035, 13.069291114807129, 13.06764030456543, 13.07083797454834, 13.078911781311035, 13.09186840057373, 13.10969066619873, 13.132338523864746, 13.159743309020996, 13.191813468933105, 13.228426933288574, 13.269436836242676, 13.314665794372559, 13.363908767700195, 13.416930198669434, 13.473467826843262, 13.533227920532227, 13.595890998840332, 13.661111831665039, 13.728516578674316, 13.797710418701172, 13.868277549743652, 13.93978214263916, 14.011775016784668, 14.083791732788086, 14.155363082885742, 14.226014137268066, 14.295269966125488, 14.36266040802002, 14.427724838256836, 14.490015983581543, 14.549104690551758, 14.604586601257324, 14.656082153320312, 14.703243255615234, 14.745758056640625, 14.78334903717041, 14.815781593322754, 14.84286117553711, 14.864436149597168, 14.880401611328125, 14.890693664550781, 14.895295143127441, 14.894229888916016, 14.88756275177002, 14.87540054321289, 14.857885360717773, 14.835193634033203, 14.807534217834473, 14.775145530700684, 14.738289833068848, 14.697251319885254, 14.652335166931152, 14.603859901428223, 14.55215835571289, 14.497572898864746, 14.440451622009277, 14.381150245666504, 14.320023536682129, 14.257428169250488, 14.193717956542969, 14.129244804382324, 14.064353942871094, 13.999385833740234, 13.934672355651855, 13.870539665222168, 13.807303428649902, 13.745268821716309, 13.684732437133789, 13.625980377197266, 13.569287300109863, 13.514917373657227, 13.46312141418457, 13.414139747619629, 13.368199348449707, 13.325516700744629, 13.286293029785156, 13.250717163085938, 13.218964576721191, 13.191195487976074, 13.167555809020996, 13.148176193237305, 13.133170127868652, 13.122635841369629, 13.11665153503418, 13.115279197692871, 13.118559837341309, 13.126513481140137, 13.139140129089355, 13.156416893005371, 13.17829704284668, 13.204710960388184, 13.235563278198242, 13.270731925964355, 13.31006908416748, 13.353401184082031, 13.40052604675293, 13.451214790344238, 13.505210876464844, 13.562233924865723, 13.621578216552734, 13.682476043701172, 13.744105339050293, 13.805597305297852, 13.866046905517578, 13.924528121948242, 13.980104446411133, 14.031839370727539, 14.078816413879395, 14.120146751403809, 14.154986381530762, 14.182548522949219, 14.20211124420166, 14.213035583496094, 14.214766502380371, 14.206847190856934, 14.188916206359863, 14.160719871520996, 14.122103691101074, 14.073017120361328, 14.013508796691895, 13.943719863891602, 13.836982727050781, 13.694648742675781, 13.519371032714844, 13.314728736877441, 13.084869384765625, 12.834195137023926, 12.567102432250977, 12.287781715393066, 12.00007152557373, 11.707371711730957, 11.412601470947266, 11.118194580078125, 10.826118469238281, 10.537914276123047, 10.25475025177002, 9.977472305297852, 9.706659317016602, 9.442676544189453, 9.18571662902832, 8.935844421386719, 8.693028450012207, 8.457164764404297, 8.228106498718262, 8.005672454833984, 7.789665222167969, 7.579878330230713, 7.376104831695557, 7.178139686584473, 6.985784530639648, 6.798848628997803, 6.617149829864502, 6.440515041351318, 6.26878023147583, 6.101790904998779, 5.939399242401123, 5.781466007232666, 5.6278581619262695, 5.478450775146484, 5.333123207092285, 5.191761016845703, 5.05425500869751, 4.920499801635742, 4.790395736694336, 4.663846492767334, 4.540759563446045, 4.421046257019043, 4.304622173309326, 4.191405296325684, 4.08131742477417, 3.9742844104766846, 3.870234489440918, 3.7690999507904053, 3.670815944671631, 3.5753211975097656, 3.482558012008667, 3.392472505569458, 3.30501389503479, 3.2201359272003174, 3.13779616355896, 3.0579569339752197, 2.9805843830108643, 2.9056506156921387, 2.833132266998291, 2.763012409210205, 2.6952803134918213, 2.629931926727295, 2.5669713020324707, 2.5064103603363037, 2.4482712745666504, 2.3925862312316895, 2.3393988609313965, 2.288766384124756, 2.240760564804077, 2.195469856262207, 2.153001546859741, 2.1134836673736572, 2.077068567276001, 2.043935775756836, 2.0142955780029297, 1.9883930683135986, 1.9665133953094482, 1.9489867687225342, 1.9361950159072876, 1.92857825756073, 1.9266433715820312, 1.9309725761413574, 1.9422341585159302, 1.9611939191818237, 1.9887280464172363, 2.0258378982543945, 2.0736658573150635, 2.1335132122039795, 2.206860065460205, 2.2953855991363525, 2.400991201400757, 2.5258243083953857, 2.672302007675171, 2.843135118484497, 3.041350841522217, 3.270312547683716, 3.533733367919922, 3.835454225540161, 4.179561138153076, 4.570336818695068, 5.01218843460083, 5.509541988372803, 6.066699028015137, 6.687646865844727, 7.375819683074951, 8.133805274963379, 8.962994575500488, 9.86318588256836, 10.8321533203125, 11.865208625793457, 12.954782485961914, 14.090086936950684, 15.256917953491211, 16.437652587890625, 17.611530303955078, 18.75523567199707, 19.843847274780273, 20.852092742919922, 21.75583839416504, 22.533700942993164, 23.1685733795166, 23.648880004882812, 23.96938705444336, 24.131425857543945, 24.14252471923828, 24.015487670898438, 23.76707649230957, 23.41648292541504, 22.983810424804688, 22.488733291625977, 21.949438095092773, 21.38192367553711, 20.79962730407715, 20.213342666625977, 19.631349563598633, 19.059690475463867, 18.50250816345215, 17.962419509887695, 17.44085121154785, 16.9383487701416, 16.454845428466797, 15.989852905273438, 15.542633056640625, 15.112310409545898, 14.697957038879395, 14.298650741577148, 13.913507461547852, 13.541707038879395, 13.18249797821045, 12.835206031799316, 12.499226570129395, 12.174026489257812, 11.859132766723633, 11.55368423461914, 11.257065773010254, 10.968730926513672, 10.68820571899414, 10.415079116821289, 10.148998260498047, 9.889664649963379, 9.636819839477539, 9.390246391296387, 9.149754524230957, 8.915177345275879, 8.686368942260742, 8.463194847106934, 8.24553394317627, 8.033270835876465, 7.826295852661133, 7.624504566192627, 7.427793979644775, 7.2360639572143555, 7.049214839935303, 6.867149353027344, 6.689769744873047, 6.5169806480407715, 6.348687171936035, 6.184794902801514, 6.025211811065674, 5.869846820831299, 5.7186102867126465, 5.571415424346924, 5.428176403045654, 5.2888102531433105, 5.15323543548584, 5.021373748779297, 4.893149375915527, 4.768489360809326, 4.647324085235596, 4.529585838317871, 4.415212154388428, 4.304141998291016, 4.196320056915283, 4.091692924499512, 3.990213394165039, 3.8918368816375732, 3.7965247631073, 3.7042429447174072, 3.6149630546569824, 3.5286624431610107, 3.445324659347534, 3.3649404048919678, 3.2875077724456787, 3.213033437728882, 3.1415324211120605, 3.0730302333831787, 3.0075626373291016, 2.9451777935028076, 2.885936975479126, 2.82991623878479, 2.777208089828491, 2.7279229164123535, 2.6821916103363037, 2.640166997909546, 2.602027416229248, 2.5679798126220703, 2.538261651992798, 2.513145685195923, 2.4929440021514893, 2.4780125617980957, 2.4687564373016357, 2.465634822845459, 2.4691684246063232, 2.4799461364746094, 2.4986321926116943, 2.525975227355957, 2.562817335128784, 2.6101036071777344, 2.6688926219940186, 2.7403676509857178, 2.82584810256958, 2.9268012046813965, 3.0448524951934814, 3.181797504425049, 3.3396100997924805, 3.5204508304595947, 3.7266693115234375, 3.960803985595703, 4.225574970245361, 4.523869037628174, 4.858709812164307, 5.233221054077148, 5.650565147399902, 6.113867282867432, 6.626110553741455, 7.190006256103516, 7.807833194732666, 8.481245994567871, 9.211051940917969, 9.99696159362793, 10.837324142456055, 11.728853225708008, 12.666370391845703, 13.642593383789062, 14.646973609924316, 15.666424751281738, 16.685476303100586, 17.68663787841797, 18.65097999572754, 19.55893898010254, 20.391298294067383, 21.130279541015625, 21.76062774658203, 22.27060317993164, 22.65271759033203, 22.904165267944336, 23.0268497467041, 23.02703285217285, 22.91465187072754, 22.701478958129883, 22.401243209838867, 22.02864646911621, 21.598472595214844, 21.12481689453125, 20.620529174804688, 20.096858978271484, 19.563289642333984, 19.027515411376953, 18.49555778503418, 17.971927642822266, 17.45985221862793, 16.96149444580078, 16.478168487548828, 16.010540008544922, 15.558791160583496, 15.122759819030762, 14.70205020904541, 14.296119689941406, 13.904341697692871, 13.526055335998535, 13.160595893859863, 12.8073148727417, 12.465596199035645, 12.13486385345459, 11.814583778381348, 11.504263877868652, 11.203454971313477, 10.91174602508545, 10.62876033782959, 10.354156494140625, 10.08761978149414, 9.828862190246582, 9.577617645263672, 9.333641052246094, 9.096705436706543, 8.866598129272461, 8.643121719360352, 8.426091194152832, 8.21533203125, 8.01068115234375, 7.811981678009033, 7.619088649749756, 7.4318623542785645, 7.249423027038574, 7.071575164794922, 6.898153305053711, 6.729015350341797, 6.564039707183838, 6.4031195640563965, 6.246161460876465, 6.093080520629883, 5.943800449371338, 5.798250675201416, 5.656364440917969, 5.518078804016113, 5.383334636688232, 5.252074241638184, 5.124242782592773, 4.999786376953125, 4.878653526306152, 4.760794639587402, 4.646162033081055, 4.534709930419922, 4.426393985748291, 4.321174144744873, 4.219010353088379, 4.119867324829102, 4.023712635040283, 3.9305155277252197, 3.8402509689331055, 3.752896785736084, 3.6684350967407227, 3.586852788925171, 3.5081424713134766, 3.4323010444641113, 3.359332799911499, 3.289247989654541, 3.2220637798309326, 3.157805919647217, 3.096508502960205, 3.038214921951294, 2.9829790592193604, 2.930866241455078, 2.8819541931152344, 2.836334466934204, 2.7941136360168457, 2.755415201187134, 2.7203805446624756, 2.689171314239502, 2.6619720458984375, 2.638990879058838, 2.6204633712768555, 2.6066553592681885, 2.5978643894195557, 2.5944249629974365, 2.596710681915283, 2.6051392555236816, 2.620175361633301, 2.642336368560791, 2.672196388244629, 2.7103915214538574, 2.757624864578247, 2.8146727085113525, 2.8823885917663574, 2.961709976196289, 3.0536627769470215, 3.159365653991699, 3.2800352573394775, 3.4169867038726807, 3.571636915206909, 3.74550199508667, 3.940194606781006, 4.157414436340332, 4.3989386558532715, 4.666600704193115, 4.962268352508545, 5.287808895111084, 5.645046710968018, 6.035710334777832, 6.461366176605225, 6.923340797424316, 7.422628402709961, 7.959788799285889, 8.534828186035156, 9.14708137512207, 9.795077323913574, 10.476424217224121, 11.187690734863281, 11.924318313598633, 12.680569648742676, 13.449519157409668, 14.223106384277344, 14.992267608642578, 15.74713134765625, 16.477304458618164, 17.172222137451172, 17.821552276611328, 18.415637969970703, 18.9459171295166, 19.40532875061035, 19.78862953186035, 20.09260368347168, 20.3161563873291, 20.460275650024414, 20.526952743530273, 20.519927978515625, 20.444406509399414, 20.306711196899414, 20.1138973236084, 19.87339210510254, 19.5926513671875, 19.278886795043945, 18.9388484954834, 18.578664779663086, 18.203771591186523, 17.81887435913086, 17.42795181274414, 17.03430938720703, 16.64063835144043, 16.249088287353516, 15.861344337463379, 15.47869873046875, 15.102129936218262, 14.732354164123535, 14.369884490966797, 14.015076637268066, 13.668160438537598, 13.329276084899902, 12.998493194580078, 12.675832748413086, 12.361278533935547, 12.054789543151855, 11.75631046295166, 11.465773582458496, 11.183107376098633, 10.908236503601074, 10.641088485717773, 10.38159465789795, 10.129691123962402, 9.885319709777832, 9.648431777954102, 9.418990135192871, 9.196967124938965, 8.98234748840332, 8.775131225585938, 8.575335502624512, 8.382993698120117, 8.198158264160156, 8.020907402038574, 7.851339340209961, 7.689581394195557, 7.53579044342041, 7.390154838562012, 7.252900123596191, 7.124290943145752, 7.004634857177734, 6.894287109375, 6.793656349182129, 6.7032060623168945, 6.6234636306762695, 6.555022239685059, 6.498548984527588, 6.454789161682129, 6.424570560455322, 6.408812522888184, 6.408527374267578, 6.424826145172119, 6.458921909332275, 6.512131214141846, 6.585873603820801, 6.681670188903809, 6.801133632659912, 6.945962429046631, 7.117918491363525, 7.318809986114502, 7.550455093383789, 7.814644813537598, 8.113090515136719, 8.447359085083008, 8.81879997253418, 9.22845458984375, 9.676950454711914, 10.164392471313477, 10.69023323059082, 11.253149032592773, 11.850912094116211, 12.480271339416504, 13.136860847473145, 13.815129280090332, 14.508330345153809, 15.208558082580566, 15.906862258911133, 16.59343910217285, 17.257904052734375, 17.88862419128418, 18.474023818969727, 19.00309944152832, 19.465953826904297, 19.854299545288086, 20.16188621520996, 20.38479995727539, 20.521625518798828, 20.573427200317383, 20.543582916259766, 20.437467575073242, 20.26203727722168, 20.025352478027344, 19.73609733581543, 19.40312957763672, 19.035083770751953, 18.64006233215332, 18.225431442260742, 17.79766845703125, 17.362327575683594, 16.924034118652344, 16.48653793334961, 16.05280303955078, 15.625092506408691, 15.205086708068848, 14.793973922729492, 14.392547607421875, 14.00129222869873, 13.620450019836426, 13.25008487701416, 12.890128135681152, 12.540417671203613, 12.200732231140137, 11.870805740356445, 11.550353050231934, 11.2390775680542, 10.936680793762207, 10.642868995666504, 10.357354164123535, 10.079861640930176, 9.810127258300781, 9.547897338867188, 9.29293155670166, 9.045001029968262, 8.803887367248535, 8.569382667541504, 8.341288566589355, 8.119414329528809, 7.903579235076904, 7.693609237670898, 7.489336967468262, 7.29060173034668, 7.0972490310668945, 6.909129619598389, 6.726099491119385, 6.548019886016846, 6.374756336212158, 6.206178665161133, 6.042160987854004, 5.8825812339782715, 5.727321147918701, 5.576266765594482, 5.429306507110596, 5.286332130432129, 5.1472392082214355, 5.011926174163818, 4.8802947998046875, 4.752248764038086, 4.627695083618164, 4.506543159484863, 4.388706207275391, 4.274097919464111, 4.162635803222656, 4.054239749908447, 3.9488308429718018, 3.8463332653045654, 3.746673583984375, 3.6497795581817627, 3.555581569671631, 3.4640114307403564, 3.3750035762786865, 3.2884936332702637, 3.2043678760528564, 3.122565269470215, 3.043027400970459, 2.965698719024658, 2.890526294708252, 2.817460536956787, 2.746453285217285, 2.677459478378296, 2.610436201095581, 2.545342445373535, 2.482140064239502, 2.4207923412323, 2.3612658977508545, 2.3035285472869873, 2.247551202774048, 2.1933066844940186, 2.140770673751831, 2.089921236038208, 2.0407395362854004, 1.9932085275650024, 1.9473154544830322, 1.9030499458312988, 1.8604053258895874, 1.8193782567977905, 1.7799696922302246, 1.7421845197677612, 1.706032156944275, 1.6715271472930908, 1.6386891603469849, 1.607543706893921, 1.5781227350234985, 1.5504653453826904, 1.5246179103851318, 1.5006355047225952, 1.4785822629928589, 1.458532691001892, 1.4405723810195923, 1.4247993230819702, 1.4113255739212036, 1.4002779722213745, 1.3918004035949707, 1.3860554695129395, 1.3832262754440308, 1.3835190534591675, 1.3871651887893677, 1.394424319267273, 1.405587077140808, 1.4209789037704468, 1.4409632682800293, 1.4659454822540283, 1.4963778257369995, 1.5327636003494263, 1.575662612915039, 1.6256965398788452, 1.6835544109344482, 1.7499996423721313, 1.8258752822875977, 1.9121116399765015, 2.0097317695617676, 2.119858503341675, 2.243720531463623, 2.3826565742492676, 2.538120746612549, 2.7116832733154297, 2.9050323963165283, 3.119968891143799, 3.358400821685791, 3.6223294734954834, 3.9138307571411133, 4.23502779006958, 4.588054656982422, 4.975007057189941, 5.397881984710693, 5.858500957489014, 6.358420372009277, 6.898821830749512, 7.480390548706055, 8.10317611694336, 8.766448020935059, 9.468541145324707, 10.206707000732422, 10.976983070373535, 11.77408504486084, 12.591349601745605, 13.420730590820312, 14.25287914276123, 15.07730770111084, 15.882657051086426, 16.65705108642578, 17.388540267944336, 18.06560707092285, 18.677688598632812, 19.215696334838867, 19.67245101928711, 20.04303741455078, 20.324989318847656, 20.51833152770996, 20.625457763671875, 20.65085220336914, 20.600709915161133, 20.482486724853516, 20.303693771362305, 20.072328567504883, 19.796493530273438, 19.484067916870117, 19.14246368408203, 18.778430938720703, 18.397964477539062, 18.006250381469727, 17.607677459716797, 17.20587921142578, 16.803802490234375, 16.403789520263672, 16.007667541503906, 15.616823196411133, 15.232295989990234, 14.85483455657959, 14.484966278076172, 14.12304401397705, 13.769285202026367, 13.423811912536621, 13.086671829223633, 12.757859230041504, 12.437334060668945, 12.125027656555176, 11.820858001708984, 11.524731636047363, 11.236553192138672, 10.956222534179688, 10.683642387390137, 10.418718338012695, 10.16136360168457, 9.91149616241455, 9.669039726257324, 9.433931350708008, 9.20611572265625, 8.98554801940918, 8.772197723388672, 8.566047668457031, 8.367096900939941, 8.175358772277832, 7.990869522094727, 7.813683032989502, 7.6438775062561035, 7.481555461883545, 7.32684850692749, 7.1799187660217285, 7.040961742401123, 6.910210609436035, 6.78794002532959, 6.674469470977783, 6.570168972015381, 6.475462436676025, 6.390833377838135, 6.316830635070801, 6.2540740966796875, 6.2032599449157715, 6.165168285369873, 6.14066743850708, 6.130721569061279, 6.136394023895264, 6.15885591506958, 6.199386119842529, 6.259376525878906, 6.340330123901367, 6.4438605308532715, 6.571682929992676, 6.7256059646606445, 6.907512664794922, 7.11933708190918, 7.363030433654785, 7.640519618988037, 7.953649044036865, 8.304115295410156, 8.69338321685791, 9.122587203979492, 9.592422485351562, 10.10301399230957, 10.653786659240723, 11.24332046508789, 11.80312728881836, 12.317873001098633, 12.77469539642334, 13.163540840148926, 13.47740364074707, 13.712420463562012, 13.867785453796387, 13.945505142211914, 13.949995040893555, 13.887575149536133, 13.765908241271973, 13.593430519104004, 13.37883186340332, 13.13060474395752, 12.856706619262695, 12.564311981201172, 12.259675979614258, 11.948079109191895, 11.633843421936035, 11.320398330688477, 11.010370254516602, 10.705698013305664, 10.407745361328125, 10.117412567138672, 9.835233688354492, 9.561463356018066, 9.296154975891113, 9.039212226867676, 8.79044246673584, 8.549591064453125, 8.316367149353027, 8.090466499328613, 7.871580600738525, 7.659411430358887, 7.453671932220459, 7.254092216491699, 7.060420989990234, 6.872424125671387, 6.68988561630249, 6.5126051902771, 6.340398788452148, 6.173095703125, 6.010537624359131, 5.8525776863098145, 5.6990790367126465, 5.549914360046387, 5.404964447021484, 5.26411771774292, 5.127269744873047, 4.994322299957275, 4.865184307098389, 4.739769458770752, 4.617998123168945, 4.499796390533447, 4.385095596313477, 4.273833274841309, 4.165953159332275, 4.061404228210449, 3.960143566131592, 3.862133264541626, 3.767343521118164, 3.675752878189087, 3.5873470306396484, 3.502121686935425, 3.4200825691223145, 3.3412458896636963, 3.2656400203704834, 3.1933066844940186, 3.124302864074707, 3.058701276779175, 2.996593713760376, 2.9380922317504883, 2.8833320140838623, 2.8324742317199707, 2.7857091426849365, 2.743260383605957, 2.705387830734253, 2.672393798828125, 2.644627809524536, 2.6224918365478516, 2.6064491271972656, 2.597029447555542, 2.5948400497436523, 2.6005735397338867, 2.6150197982788086, 2.639077663421631, 2.67376708984375, 2.720244884490967, 2.7798194885253906, 2.8539679050445557, 2.9443531036376953, 3.0528416633605957, 3.181523323059082, 3.3327274322509766, 3.509040594100952, 3.713318109512329, 3.948695421218872, 4.218587875366211, 4.5266852378845215, 4.876928329467773, 5.273473739624023, 5.720278263092041, 6.221213340759277, 6.779910087585449, 7.3995680809021, 8.082716941833496, 8.830934524536133, 9.64452075958252, 10.522139549255371, 11.460450172424316, 12.453744888305664, 13.49362850189209, 14.568804740905762, 15.664993286132812, 16.765052795410156, 17.849355697631836, 18.896425247192383, 19.883867263793945, 20.789522171020508, 21.592782974243164, 22.275922775268555, 22.825321197509766, 23.23238754272461, 23.49408531188965, 23.612974166870117, 23.596757888793945, 23.457426071166992, 23.210100173950195, 22.871755599975586, 22.459978103637695, 21.991878509521484, 21.48325538635254, 20.948034286499023, 20.397977828979492, 19.842618942260742, 19.28937339782715, 18.743755340576172, 18.209657669067383, 17.689651489257812, 17.185264587402344, 16.697240829467773, 16.22575569152832, 15.770593643188477, 15.331284523010254, 14.907208442687988, 14.49767017364502, 14.101951599121094, 13.719347953796387, 13.349187850952148, 12.990845680236816, 12.643747329711914, 12.307369232177734, 11.981240272521973, 11.664934158325195, 11.358068466186523, 11.060296058654785, 10.771307945251465, 10.49082088470459, 10.218582153320312, 9.954358100891113, 9.697941780090332, 9.449140548706055, 9.207782745361328, 8.973712921142578, 8.746790885925293, 8.526893615722656, 8.313911437988281, 8.10775089263916, 7.908336639404297, 7.715606212615967, 7.529516696929932, 7.350042819976807, 7.177179336547852, 7.010941028594971, 6.851365566253662, 6.698515892028809, 6.552481174468994, 6.413380146026611, 6.281363487243652, 6.156617164611816, 6.039367198944092, 5.9298810958862305, 5.828474521636963, 5.735515117645264, 5.65142822265625, 5.576701641082764, 5.511893272399902, 5.457636833190918, 5.41464900970459, 5.3837385177612305, 5.365810394287109, 5.361877918243408, 5.373067378997803, 5.400627136230469, 5.445932865142822, 5.510494232177734, 5.595959186553955, 5.7041120529174805, 5.836874485015869, 5.996295928955078, 6.184540748596191, 6.403868198394775, 6.629928112030029, 6.858486175537109, 7.085743427276611, 7.308318138122559, 7.523231029510498, 7.727895259857178, 7.920112609863281, 8.098065376281738, 8.260310173034668, 8.40576171875, 8.533681869506836, 8.643651962280273, 8.735555648803711, 8.809542655944824, 8.866003036499023, 8.905526161193848, 8.928873062133789, 8.93693733215332, 8.93071460723877, 8.911269187927246, 8.879707336425781, 8.837154388427734, 8.78472900390625, 8.723530769348145, 8.654623031616211, 8.579021453857422, 8.497692108154297, 8.411539077758789, 8.321407318115234, 8.228083610534668, 8.132288932800293, 8.034692764282227, 7.9359049797058105, 7.836487293243408, 7.7369537353515625, 7.63777494430542, 7.539384365081787, 7.44218111038208, 7.346534729003906, 7.25278902053833, 7.1612653732299805, 7.072268486022949, 6.986086368560791, 6.9029974937438965, 6.823270797729492, 6.7471699714660645, 6.67495584487915, 6.606889724731445, 6.543234825134277, 6.484259128570557, 6.430238246917725, 6.3814568519592285, 6.338212013244629, 6.300813674926758, 6.269588470458984, 6.2448811531066895, 6.227055549621582, 6.216498851776123, 6.213620185852051, 6.218856334686279, 6.232668876647949, 6.255548477172852, 6.288014888763428, 6.330617427825928, 6.383935451507568, 6.4485764503479, 6.525177955627441, 6.614400863647461, 6.7169318199157715, 6.833474636077881, 6.96474552154541, 7.111467361450195, 7.274358749389648, 7.454123497009277, 7.651436805725098, 7.866929054260254, 8.101166725158691, 8.354630470275879, 8.627693176269531, 8.920589447021484, 9.23338794708252, 9.565960884094238, 9.917948722839355, 10.288732528686523, 10.677396774291992, 11.08270263671875, 11.503066062927246, 11.93653392791748, 12.380779266357422, 12.833100318908691, 13.290433883666992, 13.74938678741455, 14.20627498626709, 14.65718936920166, 15.098067283630371, 15.524784088134766, 15.933252334594727, 16.319530487060547, 16.6799259185791, 17.0111083984375, 17.310197830200195, 17.574058532714844, 17.800125122070312, 17.986499786376953, 18.131980895996094, 18.236101150512695, 18.299108505249023, 18.321918487548828, 18.306062698364258, 18.253589630126953, 18.166967391967773, 18.04897689819336, 17.90260887145996, 17.730958938598633, 17.53714370727539, 17.32421112060547, 17.095096588134766, 16.85256004333496, 16.599164962768555, 16.33725929260254, 16.06895637512207, 15.796152114868164, 15.520523071289062, 15.243542671203613, 14.966498374938965, 14.690508842468262, 14.416543006896973, 14.145440101623535, 13.877923011779785, 13.614620208740234, 13.356074333190918, 13.102763175964355, 12.85510540008545, 12.613472938537598, 12.378201484680176, 12.149599075317383, 11.927948951721191, 11.713521957397461, 11.506575584411621, 11.307365417480469, 11.116144180297852, 10.933170318603516, 10.758708000183105, 10.59303092956543, 10.43642807006836, 10.289205551147461, 10.151688575744629, 10.024222373962402, 9.907180786132812, 9.800960540771484, 9.705988883972168, 9.622722625732422, 9.551650047302246, 9.493291854858398, 9.448200225830078, 9.416960716247559, 9.400187492370605, 9.398523330688477, 9.412633895874023, 9.443206787109375, 9.49094009399414, 9.556534767150879, 9.64068603515625, 9.744068145751953, 9.867319107055664, 10.011019706726074, 10.175674438476562, 10.361684799194336, 10.569321632385254, 10.798693656921387, 11.049715042114258, 11.32206916809082, 11.615174293518066, 11.928147315979004, 12.259770393371582, 12.6084623336792, 12.97225570678711, 13.348784446716309, 13.73527717590332, 14.128572463989258, 14.525139808654785, 14.921131134033203, 15.312434196472168, 15.694756507873535, 16.063718795776367, 16.414960861206055, 16.744264602661133, 17.04766845703125, 17.321578979492188, 17.56288719177246, 17.769052505493164, 17.93817710876465, 18.06903648376465, 18.161104202270508, 18.214536666870117, 18.230127334594727, 18.209245681762695, 18.153757095336914, 18.06592559814453, 17.948322296142578, 17.803714752197266, 17.634986877441406, 17.445045471191406, 17.23674964904785, 17.012863159179688, 16.775991439819336, 16.528566360473633, 16.272823333740234, 16.010787963867188, 15.744279861450195, 15.474920272827148, 15.204141616821289, 14.93320083618164, 14.663196563720703, 14.395086288452148, 14.129704475402832, 13.867773056030273, 13.609926223754883, 13.35671329498291, 13.108622550964355, 12.866082191467285, 12.629478454589844, 12.399158477783203, 12.175443649291992, 11.95863151550293, 11.749005317687988, 11.546838760375977, 11.352399826049805, 11.165955543518066, 10.987775802612305, 10.818138122558594, 10.657329559326172, 10.50565242767334, 10.363423347473145, 10.230978012084961, 10.108674049377441, 9.996892929077148, 9.896039962768555, 9.806549072265625, 9.728882789611816, 9.663533210754395, 9.611019134521484, 9.571893692016602, 9.546733856201172, 9.536144256591797, 9.540754318237305, 9.561210632324219, 9.598172187805176, 9.652304649353027, 9.724268913269043, 9.814708709716797, 9.924240112304688, 10.05342960357666, 10.202778816223145, 10.372698783874512, 10.563488960266113, 10.775303840637207, 11.008126258850098, 11.261736869812012, 11.535676002502441, 11.829214096069336, 12.140830039978027, 12.468564987182617, 12.757622718811035, 12.999189376831055, 13.187108993530273, 13.317831039428711, 13.39024543762207, 13.40542221069336, 13.366267204284668, 13.277122497558594, 13.143353462219238, 12.970931053161621, 12.766069412231445, 12.534903526306152, 12.283244132995605, 12.016406059265137, 11.739091873168945, 11.455349922180176, 11.16856575012207, 10.881494522094727, 10.596320152282715, 10.314718246459961, 10.037934303283691, 9.766851425170898, 9.502067565917969, 9.243946075439453, 8.992676734924316, 8.748316764831543, 8.510825157165527, 8.280097007751465, 8.055978775024414, 7.838292121887207, 7.6268415451049805, 7.4214253425598145, 7.2218427658081055, 7.027894973754883, 6.839392185211182, 6.6561503410339355, 6.477995872497559, 6.304762363433838, 6.136293888092041, 5.972440242767334, 5.813061237335205, 5.658021926879883, 5.507194519042969, 5.360456943511963, 5.2176923751831055, 5.078789710998535, 4.94364070892334, 4.812143325805664, 4.684197902679443, 4.559708595275879, 4.438583850860596, 4.32073450088501, 4.206075191497803, 4.094522953033447, 3.9859979152679443, 3.8804233074188232, 3.777724504470825, 3.677830457687378, 3.580672264099121, 3.4861836433410645, 3.394301414489746, 3.304965019226074, 3.2181167602539062, 3.1337010860443115, 3.051666736602783, 2.971964120864868, 2.894547700881958, 2.8193752765655518, 2.7464072704315186, 2.6756091117858887, 2.6069493293762207, 2.540400981903076, 2.475942373275757, 2.4135560989379883, 2.353231191635132, 2.2949624061584473, 2.2387516498565674, 2.1846084594726562, 2.1325507164001465, 2.082606554031372, 2.0348143577575684, 1.989225149154663, 1.945904016494751, 1.904931664466858, 1.8664065599441528, 1.8304482698440552, 1.7971993684768677, 1.766829252243042, 1.7395380735397339, 1.7155612707138062, 1.6951745748519897, 1.6786998510360718, 1.666512131690979, 1.6590477228164673, 1.6568127870559692, 1.6603940725326538, 1.6704708337783813, 1.6878280639648438, 1.7133724689483643, 1.7481495141983032, 1.7933635711669922, 1.8503414392471313, 1.9205870628356934, 2.0058014392852783, 2.1079018115997314, 2.22904372215271, 2.3716397285461426, 2.5383787155151367, 2.732241630554199, 2.956511974334717, 3.2147793769836426, 3.5109336376190186, 3.849142551422119, 4.233810901641846, 4.669516563415527, 5.1609110832214355, 5.712584495544434, 6.328884124755859, 7.013677597045898, 7.7700605392456055, 8.600005149841309, 9.503948211669922, 10.48034381866455, 11.52518367767334, 12.631540298461914, 13.789163589477539, 14.984217643737793, 16.19919776916504, 17.41313934326172, 18.602149963378906, 19.740314483642578, 20.80097007751465, 21.758262634277344, 22.58885955810547, 23.273643493652344, 23.79915428161621, 24.158567428588867, 24.352081298828125, 24.38663673400879, 24.275012969970703, 24.034460067749023, 23.685068130493164, 23.248106002807617, 22.744531631469727, 22.193805694580078, 21.61309242248535, 21.016815185546875, 20.416549682617188, 19.821157455444336, 19.23706817626953, 18.668659210205078, 18.118648529052734, 17.588481903076172, 17.07865333557129, 16.589006423950195, 16.118942260742188, 15.6676025390625, 15.233994483947754, 14.817078590393066, 14.415831565856934, 14.029282569885254, 13.656533241271973, 13.296770095825195, 12.94926643371582, 12.61337661743164, 12.288533210754395, 11.974239349365234, 11.670062065124512, 11.37562370300293, 11.090595245361328, 10.814692497253418, 10.547670364379883, 10.289318084716797, 10.03945541381836, 9.797932624816895, 9.56462574005127, 9.339437484741211, 9.122297286987305, 8.913158416748047, 8.711999893188477, 8.518826484680176, 8.333671569824219, 8.156596183776855, 7.9876909255981445, 7.827081203460693, 7.674925327301025, 7.5314202308654785, 7.396803855895996, 7.271356582641602, 7.155407905578613, 7.049339294433594, 6.953587532043457, 6.868650436401367, 6.795091152191162, 6.733543872833252, 6.684718132019043, 6.649404048919678, 6.628476619720459, 6.6229023933410645, 6.633739471435547, 6.662144660949707, 6.709370136260986, 6.776767253875732, 6.865779876708984, 6.977940559387207, 7.114857196807861, 7.278200149536133, 7.469677448272705, 7.691007614135742, 7.9438796043396, 8.196869850158691, 8.444259643554688, 8.681071281433105, 8.903059959411621, 9.106707572937012, 9.289217948913574, 9.44849681854248, 9.583122253417969, 9.692304611206055, 9.775833129882812, 9.83401107788086, 9.867588996887207, 9.877681732177734, 9.865697860717773, 9.833259582519531, 9.782132148742676, 9.714159965515137, 9.631208419799805, 9.535120010375977, 9.42767333984375, 9.310555458068848, 9.185343742370605, 9.053491592407227, 8.916321754455566, 8.775029182434082, 8.630678176879883, 8.484216690063477, 8.33647632598877, 8.188188552856445, 8.039989471435547, 7.892432689666748, 7.745999813079834, 7.601108074188232, 7.458118915557861, 7.317347049713135, 7.179068088531494, 7.04352331161499, 6.910926342010498, 6.781467914581299, 6.655320167541504, 6.530147075653076, 6.406069278717041, 6.283217430114746, 6.161727428436279, 6.0417327880859375, 5.923364162445068, 5.806745529174805, 5.69199275970459, 5.579213619232178, 5.468506336212158, 5.359961986541748, 5.253661632537842, 5.149680137634277, 5.048085689544678, 4.948939323425293, 4.852298736572266, 4.758216381072998, 4.66674280166626, 4.577925205230713, 4.491809844970703, 4.408443450927734, 4.327872276306152, 4.250144958496094, 4.175311088562012, 4.103425025939941, 4.034543514251709, 3.9687294960021973, 3.9060511589050293, 3.846583604812622, 3.790409564971924, 3.7376203536987305, 3.6883177757263184, 3.6426141262054443, 3.6006336212158203, 3.5625147819519043, 3.5284104347229004, 3.4984896183013916, 3.4729394912719727, 3.4519665241241455, 3.4357988834381104, 3.424687385559082, 3.41890811920166, 3.418764591217041, 3.424589157104492, 3.43674635887146, 3.455634355545044, 3.4816877841949463, 3.5153794288635254, 3.5572237968444824, 3.6077778339385986, 3.6676440238952637, 3.73747181892395, 3.8179593086242676, 3.909852981567383, 4.013949394226074, 4.1310930252075195, 4.2621750831604, 4.408130168914795, 4.5699310302734375, 4.748580455780029, 4.945102691650391, 5.160531520843506, 5.3958916664123535, 5.652180194854736, 5.930344104766846, 6.2312493324279785, 6.555646896362305, 6.904138088226318, 7.277126789093018, 7.674774169921875, 8.09694766998291, 8.543167114257812, 9.01254940032959, 9.503758430480957, 10.014958381652832, 10.543771743774414, 11.087255477905273, 11.641894340515137, 12.203604698181152, 12.767777442932129, 13.329339027404785, 13.882843017578125, 14.422589302062988, 14.942774772644043, 15.437653541564941, 15.901718139648438, 16.329879760742188, 16.7176456451416, 17.061262130737305, 17.35784339904785, 17.605457305908203, 17.803159713745117, 17.95098304748535, 18.04989242553711, 18.10169219970703, 18.108896255493164, 18.074594497680664, 18.00229835510254, 17.895790100097656, 17.758975982666016, 17.595775604248047, 17.409526824951172, 17.20347023010254, 16.980684280395508, 16.744047164916992, 16.49620819091797, 16.239582061767578, 15.976338386535645, 15.708405494689941, 15.437490463256836, 15.165087699890137, 14.892501831054688, 14.62086296081543, 14.351151466369629, 14.08421516418457, 13.820786476135254, 13.56149959564209, 13.30690860748291, 13.0574951171875, 12.813688278198242, 12.575867652893066, 12.344378471374512, 12.119534492492676, 11.901632308959961, 11.690947532653809, 11.487750053405762, 11.292304992675781, 11.104873657226562, 10.925724983215332, 10.755131721496582, 10.59338092803955, 10.440770149230957, 10.297616004943848, 10.164253234863281, 10.041040420532227, 9.928357124328613, 9.826613426208496, 9.736245155334473, 9.65771770477295, 9.591526985168457, 9.538199424743652, 9.498295783996582, 9.47240161895752, 9.461133003234863, 9.465131759643555, 9.48505973815918, 9.52159309387207, 9.575417518615723, 9.647214889526367, 9.737655639648438, 9.847380638122559, 9.976985931396484, 10.127004623413086, 10.297882080078125, 10.489950180053711, 10.703400611877441, 10.938250541687012, 11.194314002990723, 11.471163749694824, 11.768096923828125, 12.084105491638184, 12.417840957641602, 12.767590522766113, 13.131260871887207, 13.506366729736328, 13.890032768249512, 14.279011726379395, 14.669717788696289, 15.058274269104004, 15.440581321716309, 15.812397003173828, 16.169437408447266, 16.50748634338379, 16.822498321533203, 17.110733032226562, 17.36884307861328, 17.593990325927734, 17.783910751342773, 17.93698501586914, 18.052255630493164, 18.12944221496582, 18.168914794921875, 18.171642303466797, 18.139131546020508, 18.073335647583008, 17.9765682220459, 17.851409912109375, 17.700603485107422, 17.526975631713867, 17.333358764648438, 17.122520446777344, 16.89711570739746, 16.65964698791504, 16.412439346313477, 16.15761947631836, 15.897119522094727, 15.632667541503906, 15.365804672241211, 15.09788990020752, 14.830120086669922, 14.563541412353516, 14.299067497253418, 14.037493705749512, 13.779516220092773, 13.525742530822754, 13.276705741882324, 13.032878875732422, 12.794681549072266, 12.562492370605469, 12.336655616760254, 12.117491722106934, 11.905299186706543, 11.700364112854004, 11.50296401977539, 11.313371658325195, 11.13186264038086, 10.958714485168457, 10.79421329498291, 10.638657569885254, 10.49235725402832, 10.355640411376953, 10.228856086730957, 10.112371444702148, 10.00658130645752, 9.911901473999023, 9.828779220581055, 9.757685661315918, 9.69912338256836, 9.653621673583984, 9.621737480163574, 9.604053497314453, 9.601176261901855, 9.613731384277344, 9.642359733581543, 9.687707901000977, 9.750423431396484, 9.831140518188477, 9.93047046661377, 10.048983573913574, 10.187191009521484, 10.345529556274414, 10.524330139160156, 10.723796844482422, 10.943979263305664, 11.184737205505371, 11.445714950561523, 11.726304054260254, 12.025615692138672, 12.342449188232422, 12.67526912689209, 13.022185325622559, 13.380941390991211, 13.74891185760498, 14.123120307922363, 14.50025749206543, 14.876726150512695, 15.248698234558105, 15.612183570861816, 15.963116645812988, 16.297456741333008, 16.611289978027344, 16.900930404663086, 17.163036346435547, 17.39469337463379, 17.593505859375, 17.75765037536621, 17.885923385620117, 17.977746963500977, 18.033172607421875, 18.052833557128906, 18.037899017333984, 17.99000358581543, 17.91115951538086, 17.803678512573242, 17.67007827758789, 17.51300048828125, 17.335124969482422, 17.13912010192871, 16.92757225036621, 16.70294761657715, 16.46756362915039, 16.223562240600586, 15.972906112670898, 15.717371940612793, 15.458553314208984, 15.197872161865234, 14.936583518981934, 14.675797462463379, 14.416487693786621, 14.15950870513916, 13.905610084533691, 13.655449867248535, 13.4096097946167, 13.168601989746094, 12.932886123657227, 12.702875137329102, 12.47894287109375, 12.26143741607666, 12.050680160522461, 11.846978187561035, 11.650626182556152, 11.4619140625, 11.2811279296875, 11.108556747436523, 10.94449520111084, 10.78924560546875, 10.643122673034668, 10.50645637512207, 10.379594802856445, 10.262901306152344, 10.15676498413086, 10.061596870422363, 9.97783088684082, 9.905927658081055, 9.846373558044434, 9.79967975616455, 9.766382217407227, 9.747040748596191, 9.742234230041504, 9.75256061553955, 9.756792068481445, 9.752321243286133, 9.737265586853027, 9.710389137268066, 9.671011924743652, 9.618927955627441, 9.554320335388184, 9.477682113647461, 9.389741897583008, 9.291396141052246, 9.18365478515625, 9.067587852478027, 8.944284439086914, 8.814824104309082, 8.680246353149414, 8.541535377502441, 8.39961051940918, 8.255313873291016, 8.109411239624023, 7.962590217590332, 7.815464496612549, 7.668576240539551, 7.522402763366699, 7.377361297607422, 7.233815670013428, 7.092082500457764, 6.9524359703063965, 6.8151140213012695, 6.680324554443359, 6.548247814178467, 6.419042587280273, 6.292849540710449, 6.169793128967285, 6.04998779296875, 5.933537483215332, 5.820539951324463, 5.71108865737915, 5.605275630950928, 5.503190994262695, 5.404928207397461, 5.310583114624023, 5.220256805419922, 5.134057521820068, 5.052100658416748, 4.974513530731201, 4.901434421539307, 4.833014488220215, 4.7694220542907715, 4.710842132568359, 4.6574788093566895, 4.609559059143066, 4.567333221435547, 4.531078338623047, 4.501100540161133, 4.477737903594971, 4.461362838745117, 4.452385902404785, 4.451258659362793, 4.458476543426514, 4.474581241607666, 4.500165939331055, 4.535876750946045, 4.5824174880981445, 4.640549182891846, 4.711095333099365, 4.794942378997803, 4.893039703369141, 5.006400108337402, 5.136097431182861, 5.283262252807617, 5.449077129364014, 5.634765148162842, 5.841580390930176, 6.070788860321045, 6.323648929595947, 6.601384162902832, 6.905149936676025, 7.235997200012207, 7.594822883605957, 7.9823198318481445, 8.39891529083252, 8.844707489013672, 9.319389343261719, 9.822184562683105, 10.351764678955078, 10.906189918518066, 11.482841491699219, 12.07837963104248, 12.688720703125, 13.309039115905762, 13.93380069732666, 14.556838989257812, 15.17147159576416, 15.770652770996094, 16.347169876098633, 16.893863677978516, 17.40387725830078, 17.87090492248535, 18.28942108154297, 18.6549015045166, 18.963973999023438, 19.213626861572266, 19.402172088623047, 19.5292911529541, 19.595983505249023, 19.604461669921875, 19.557987213134766, 19.460660934448242, 19.317201614379883, 19.13271141052246, 18.912460327148438, 18.661691665649414, 18.385461807250977, 18.08852195739746, 17.775232315063477, 17.44951057434082, 17.114809036254883, 16.774126052856445, 16.430023193359375, 16.08465576171875, 15.739821434020996, 15.396995544433594, 15.057380676269531, 14.72194766998291, 14.391471862792969, 14.066569328308105, 13.747724533081055, 13.435319900512695, 13.12965202331543, 12.830955505371094, 12.539411544799805, 12.25516414642334, 11.978327751159668, 11.708998680114746, 11.447256088256836, 11.193172454833984, 10.946818351745605, 10.708261489868164, 10.477574348449707, 10.254837036132812, 10.034626007080078, 9.816718101501465, 9.601027488708496, 9.387572288513184, 9.176441192626953, 8.967771530151367, 8.761727333068848, 8.55848503112793, 8.358219146728516, 8.161096572875977, 7.9672698974609375, 7.776872634887695, 7.590019226074219, 7.406804084777832, 7.227301597595215, 7.051567554473877, 6.879642009735107, 6.711548328399658, 6.547297954559326, 6.3868889808654785, 6.230311870574951, 6.077547550201416, 5.928570747375488, 5.783351421356201, 5.641855716705322, 5.504045486450195, 5.369881629943848, 5.239324569702148, 5.112332820892334, 4.988867282867432, 4.8688883781433105, 4.752358913421631, 4.639243125915527, 4.5295090675354, 4.423127174377441, 4.320071697235107, 4.2203216552734375, 4.1238603591918945, 4.03067684173584, 3.940765857696533, 3.8541290760040283, 3.770775079727173, 3.690720796585083, 3.6139919757843018, 3.5406246185302734, 3.4706647396087646, 3.4041712284088135, 3.3412153720855713, 3.281883478164673, 3.2262778282165527, 3.1745188236236572, 3.12674617767334, 3.0831215381622314, 3.0438308715820312, 3.0090863704681396, 2.979130268096924, 2.954237461090088, 2.9347188472747803, 2.9209253787994385, 2.913252353668213, 2.9121434688568115, 2.9180965423583984, 2.931668519973755, 2.9534809589385986, 2.9842262268066406, 3.024674892425537, 3.07568097114563, 3.1381900310516357, 3.2132458686828613, 3.3019964694976807, 3.4057016372680664, 3.5257375240325928, 3.663601875305176, 3.8209152221679688, 3.999422550201416, 4.20098876953125, 4.427591800689697, 4.681307792663574, 4.964293003082275, 5.278752326965332, 5.626902103424072, 6.010915756225586, 6.432860374450684, 6.894613265991211, 7.397765159606934, 7.943502426147461, 8.532475471496582, 9.164650917053223, 9.839151382446289, 10.554096221923828, 11.306438446044922, 12.091830253601074, 12.904512405395508, 13.737255096435547, 14.58137321472168, 15.426817893981934, 16.262372970581055, 17.075952529907227, 17.855009078979492, 18.587017059326172, 19.260019302368164, 19.86203956604004, 20.38272476196289, 20.813913345336914, 21.150070190429688, 21.388547897338867, 21.529645919799805, 21.576454162597656, 21.534528732299805, 21.411413192749023, 21.216073989868164, 20.95831298828125, 20.64822006225586, 20.29567527770996, 19.909975051879883, 19.499557495117188, 19.071847915649414, 18.633180618286133, 18.18882179260254, 17.74302864074707, 17.299152374267578, 16.85976219177246, 16.4267635345459, 16.001523971557617, 15.584980010986328, 15.177734375, 14.780136108398438, 14.392343521118164, 14.014381408691406, 13.646178245544434, 13.287598609924316, 12.93846607208252, 12.598579406738281, 12.26772403717041, 11.945683479309082, 11.632238388061523, 11.327174186706543, 11.03028392791748, 10.74136734008789, 10.460229873657227, 10.186687469482422, 9.920563697814941, 9.661687850952148, 9.40989875793457, 9.165040969848633, 8.926968574523926, 8.695542335510254, 8.470629692077637, 8.252106666564941, 8.03985595703125, 7.833769798278809, 7.633748531341553, 7.43970251083374, 7.25154972076416, 7.069221019744873, 6.8926568031311035, 6.721810340881348, 6.556647777557373, 6.397150039672852, 6.243313312530518, 6.095151901245117, 5.95269775390625, 5.816005229949951, 5.685150623321533, 5.560237407684326, 5.4413957595825195, 5.328788757324219, 5.222613334655762, 5.123106956481934, 5.030549049377441, 4.945267677307129, 4.867644786834717, 4.798121929168701, 4.737205505371094, 4.685476303100586, 4.643595218658447, 4.612313270568848, 4.592478275299072, 4.585046768188477, 4.591092109680176, 4.611813545227051, 4.648549556732178, 4.702783584594727, 4.776154518127441, 4.870462894439697, 4.98767614364624, 5.129929065704346, 5.299520015716553, 5.498901844024658, 5.730663776397705, 5.997501373291016, 6.302176475524902, 6.647459983825684, 7.036054611206055, 7.470499515533447, 7.953047275543213, 8.485518455505371, 9.06912899017334, 9.704292297363281, 10.390403747558594, 11.1256103515625, 11.906585693359375, 12.728321075439453, 13.583953857421875, 14.464672088623047, 15.359701156616211, 16.256431579589844, 17.140674591064453, 17.997095108032227, 18.809776306152344, 19.562936782836914, 20.241718292236328, 20.832998275756836, 21.32613754272461, 21.713594436645508, 21.9913272857666, 22.158926010131836, 22.219493865966797, 22.17924690246582, 22.046939849853516, 21.833145141601562, 21.54950714111328, 21.20801544189453, 20.820384979248047, 20.39756965637207, 19.949419021606445, 19.48448371887207, 19.00995445251465, 18.531686782836914, 18.054306030273438, 17.58134651184082, 17.11541748046875, 16.658357620239258, 16.211400985717773, 15.775304794311523, 15.350470542907715, 14.937039375305176, 14.534966468811035, 14.144082069396973, 13.764138221740723, 13.394838333129883, 13.03586196899414, 12.686882019042969, 12.34757137298584, 12.01761531829834, 11.696708679199219, 11.384560585021973, 11.080897331237793, 10.785457611083984, 10.497993469238281, 10.218271255493164, 9.946064949035645, 9.681163787841797, 9.423360824584961, 9.172459602355957, 8.928271293640137, 8.690614700317383, 8.459314346313477, 8.234199523925781, 8.015107154846191, 7.801878929138184, 7.594359397888184, 7.392399311065674, 7.195854187011719, 7.004582405090332, 6.818447113037109, 6.6373162269592285, 6.461060047149658, 6.289553642272949, 6.122675895690918, 5.960252285003662, 5.80216121673584, 5.648284912109375, 5.498509407043457, 5.352725505828857, 5.2108259201049805, 5.0727081298828125, 4.938271999359131, 4.80742073059082, 4.680060386657715, 4.556098937988281, 4.435448169708252, 4.318021774291992, 4.203735828399658, 4.092508792877197, 3.9842617511749268, 3.878917932510376, 3.776402473449707, 3.676643133163452, 3.5795695781707764, 3.4851133823394775, 3.3932085037231445, 3.303790330886841, 3.216797351837158, 3.1321685314178467, 3.0498464107513428, 2.969774007797241, 2.891897201538086, 2.8161637783050537, 2.742522716522217, 2.670926094055176, 2.6013269424438477, 2.5336809158325195, 2.4679455757141113, 2.4040801525115967, 2.3420467376708984, 2.2818093299865723, 2.2233338356018066, 2.1665890216827393, 2.1115458011627197, 2.058178424835205, 2.006463050842285, 1.9563792943954468, 1.9079097509384155, 1.861040472984314, 1.8157612085342407, 1.7720656394958496, 1.7299518585205078, 1.689422607421875, 1.6504857540130615, 1.6131551265716553, 1.5774505138397217, 1.5433990955352783, 1.5110355615615845, 1.480403184890747, 1.4515552520751953, 1.4245554208755493, 1.399479627609253, 1.376417636871338, 1.3554739952087402, 1.33677077293396, 1.3204492330551147, 1.3066723346710205, 1.2956279516220093, 1.2875311374664307, 1.2826288938522339, 1.281203269958496, 1.2835763692855835, 1.2901153564453125, 1.3012385368347168, 1.317421793937683, 1.3392058610916138, 1.3672044277191162, 1.402113914489746, 1.4447228908538818, 1.4959237575531006, 1.556725263595581, 1.628265142440796, 1.7118253707885742, 1.8088473081588745, 1.920947790145874, 2.0499355792999268, 2.197828531265259, 2.366868734359741, 2.559537410736084, 2.778566598892212, 3.0269455909729004, 3.307921886444092, 3.624992847442627, 3.981884479522705, 4.382513999938965, 4.830931663513184, 5.331235885620117, 5.887457370758057, 6.50340461730957, 7.182467460632324, 7.927371978759766, 8.73989200592041, 9.62050724029541, 10.568037033081055, 11.579240798950195, 12.647491455078125, 13.763079643249512, 14.912983894348145, 16.0808162689209, 17.24702262878418, 18.389379501342773, 19.483823776245117, 20.505590438842773, 21.430625915527344, 22.237123489379883, 22.905603408813477, 23.421669006347656, 23.777124404907227, 23.97051429748535, 24.00705337524414, 23.897924423217773, 23.65907859802246, 23.309715270996094, 22.870668411254883, 22.36288070678711, 21.8061580657959, 21.218250274658203, 20.61431121826172, 20.00668716430664, 19.40496063232422, 18.81618309020996, 18.245222091674805, 17.695138931274414, 17.16756820678711, 16.663074493408203, 16.18144416809082, 15.721942901611328, 15.283499717712402, 14.864862442016602, 14.464703559875488, 14.081693649291992, 13.714554786682129, 13.362089157104492, 13.02319622039795, 12.696880340576172, 12.382248878479004, 12.078506469726562, 11.784954071044922, 11.500972747802734, 11.226018905639648, 10.959615707397461, 10.701342582702637, 10.45082950592041, 10.207748413085938, 9.971808433532715, 9.742749214172363, 9.520339012145996, 9.304367065429688, 9.09464168548584, 8.890989303588867, 8.693248748779297, 8.501274108886719, 8.314927101135254, 8.134079933166504, 7.958611011505127, 7.788407325744629, 7.623362064361572, 7.463373184204102, 7.308342456817627, 7.1563239097595215, 7.007151126861572, 6.860712051391602, 6.716935634613037, 6.575782299041748, 6.4372382164001465, 6.301304340362549, 6.167994499206543, 6.037330150604248, 5.909336566925049, 5.784041404724121, 5.661472797393799, 5.541658878326416, 5.424625396728516, 5.310398101806641, 5.198999404907227, 5.090452194213867, 4.984776496887207, 4.881992340087891, 4.7821197509765625, 4.685179233551025, 4.591190814971924, 4.500176906585693, 4.412162780761719, 4.327175140380859, 4.245244026184082, 4.166405200958252, 4.090697765350342, 4.018167018890381, 3.9488649368286133, 3.882850408554077, 3.820190668106079, 3.7609620094299316, 3.7052512168884277, 3.653156280517578, 3.6047873497009277, 3.5602688789367676, 3.519739866256714, 3.483356237411499, 3.4512925148010254, 3.4237422943115234, 3.400921583175659, 3.3830697536468506, 3.370452404022217, 3.3633627891540527, 3.3621251583099365, 3.3670966625213623, 3.378669500350952, 3.397274971008301, 3.4233856201171875, 3.457517385482788, 3.5002336502075195, 3.552147150039673, 3.6139228343963623, 3.6862804889678955, 3.76999568939209, 3.8659017086029053, 3.97489070892334, 4.097911357879639, 4.235968589782715, 4.390119552612305, 4.561467170715332, 4.751153945922852, 4.960348606109619, 5.190232276916504, 5.441980361938477, 5.716736793518066, 6.015588760375977, 6.339529037475586, 6.68941593170166, 7.065928936004639, 7.469512462615967, 7.900321006774902, 8.358155250549316, 8.842394828796387, 9.351937294006348, 9.8851318359375, 10.439724922180176, 11.012819290161133, 11.60084056854248, 12.199540138244629, 12.804012298583984, 13.408753395080566, 14.007752418518066, 14.594614028930664, 15.162726402282715, 15.705445289611816, 16.216312408447266, 16.689271926879883, 17.11888885498047, 17.41895866394043, 17.584535598754883, 17.618175506591797, 17.528932571411133, 17.330894470214844, 17.04149055480957, 16.679746627807617, 16.264724731445312, 15.814257621765137, 15.344085693359375, 14.867358207702637, 14.3944730758667, 13.933175086975098, 13.4888277053833, 13.064774513244629, 12.662734985351562, 12.283186912536621, 11.925711631774902, 11.589282035827637, 11.272500038146973, 10.973774909973145, 10.691455841064453, 10.42392635345459, 10.169663429260254, 9.927275657653809, 9.695521354675293, 9.473310470581055, 9.259705543518066, 9.053906440734863, 8.855244636535645, 8.663162231445312, 8.477201461791992, 8.296990394592285, 8.12222957611084, 7.952680587768555, 7.788155555725098, 7.628510475158691, 7.473635673522949, 7.323452472686768, 7.177906513214111, 7.03696346282959, 6.900609970092773, 6.768846035003662, 6.641688346862793, 6.519166469573975, 6.4013237953186035, 6.288216590881348, 6.179914474487305, 6.076500415802002, 5.9780731201171875, 5.8847455978393555, 5.7966485023498535, 5.713929653167725, 5.636756896972656, 5.565320014953613, 5.499830722808838, 5.440526962280273, 5.387673854827881, 5.341566562652588, 5.302532196044922, 5.270933628082275, 5.247171878814697, 5.231688499450684, 5.224969387054443, 5.227548599243164, 5.240009784698486, 5.262989521026611, 5.297181606292725, 5.343338489532471, 5.402273178100586, 5.474862098693848, 5.562044620513916, 5.664821147918701, 5.784254550933838, 5.9214630126953125, 6.077616214752197, 6.25392484664917, 6.4516282081604, 6.67197847366333, 6.916219234466553, 7.185559272766113, 7.481140613555908, 7.803997993469238, 8.155014991760254, 8.534872055053711, 8.943984985351562, 9.382441520690918, 9.849929809570312, 10.345667839050293, 10.868328094482422, 11.415972709655762, 11.985992431640625, 12.575060844421387, 13.179112434387207, 13.793342590332031, 14.412242889404297, 15.02967643737793, 15.63899040222168, 16.233165740966797, 16.80501937866211, 17.347412109375, 17.852548599243164, 18.31310272216797, 18.722522735595703, 19.075300216674805, 19.367204666137695, 19.595447540283203, 19.758758544921875, 19.857397079467773, 19.893051147460938, 19.86869239807129, 19.78835105895996, 19.65687370300293, 19.479658126831055, 19.26238441467285, 19.01079559326172, 18.730487823486328, 18.426761627197266, 18.104503631591797, 17.768117904663086, 17.42149543762207, 17.068004608154297, 16.710521697998047, 16.35145378112793, 15.992793083190918, 15.636168479919434, 15.282889366149902, 14.933998107910156, 14.590315818786621, 14.252481460571289, 13.920988082885742, 13.596209526062012, 13.278426170349121, 12.967849731445312, 12.664631843566895, 12.368886947631836, 12.080695152282715, 11.800114631652832, 11.527189254760742, 11.261954307556152, 11.004437446594238, 10.754666328430176, 10.512673377990723, 10.278493881225586, 10.05217170715332, 9.833761215209961, 9.623332023620605, 9.420967102050781, 9.226766586303711, 9.040854454040527, 8.863374710083008, 8.694499015808105, 8.53442668914795, 8.383389472961426, 8.241654396057129, 8.109524726867676, 7.987348556518555, 7.875517845153809, 7.774474620819092, 7.684712886810303, 7.606785774230957, 7.541306495666504, 7.488953113555908, 7.450472354888916, 7.426682949066162, 7.418476104736328, 7.426819801330566, 7.452756881713867, 7.497405052185059, 7.561951160430908, 7.647647857666016, 7.755803108215332, 7.887765407562256, 8.044907569885254, 8.228602409362793, 8.440191268920898, 8.680949211120605, 8.95203685760498, 9.254448890686035, 9.588950157165527, 9.95600414276123, 10.355697631835938, 10.787652015686035, 11.250936508178711, 11.74398422241211, 12.264503479003906, 12.80941390991211, 13.374789237976074, 13.955836296081543, 14.54690170288086, 15.141528129577637, 15.732549667358398, 16.3122501373291, 16.872562408447266, 17.405315399169922, 17.902515411376953, 18.356651306152344, 18.760990142822266, 19.109844207763672, 19.398818969726562, 19.624954223632812, 19.78683090209961, 19.88455581665039, 19.919689178466797, 19.895084381103516, 19.814672470092773, 19.682546615600586, 19.50347328186035, 19.282665252685547, 19.025548934936523, 18.737567901611328, 18.423995971679688, 18.089815139770508, 17.73961067199707, 17.377504348754883, 17.007139205932617, 16.63166618347168, 16.253761291503906, 15.8756685256958, 15.49923038482666, 15.12593936920166, 14.756982803344727, 14.393287658691406, 14.035563468933105, 13.68433952331543, 13.34000015258789, 13.002809524536133, 12.672937393188477, 12.350480079650879, 12.03547477722168, 11.727913856506348, 11.427756309509277, 11.134932518005371, 10.849357604980469, 10.570927619934082, 10.299530982971191, 10.035048484802246, 9.777355194091797, 9.526323318481445, 9.28182315826416, 9.04372501373291, 8.811898231506348, 8.586214065551758, 8.366544723510742, 8.152762413024902, 7.944743633270264, 7.74236536026001, 7.54550838470459, 7.354054927825928, 7.1678900718688965, 6.98690128326416, 6.810979843139648, 6.640019416809082, 6.473916530609131, 6.312570571899414, 6.155884265899658, 6.003763198852539, 5.85611629486084, 5.712855339050293, 5.57389497756958, 5.43915319442749, 5.30855131149292, 5.182013034820557, 5.059464931488037, 4.940837860107422, 4.826064109802246, 4.715079307556152, 4.607821941375732, 4.504233360290527, 4.404257774353027, 4.307840824127197, 4.214932441711426, 4.12548303604126, 4.039446830749512, 3.9567792415618896, 3.8774378299713135, 3.801382303237915, 3.728573799133301, 3.6589748859405518, 3.5925495624542236, 3.5292630195617676, 3.469081163406372, 3.411970376968384, 3.357897996902466, 3.306830406188965, 3.258735179901123, 3.213578224182129, 3.17069149017334, 3.1300203800201416, 3.0915277004241943, 3.055192470550537, 3.0210070610046387, 2.9889771938323975, 2.9591195583343506, 2.9314615726470947, 2.906041145324707, 2.8829054832458496, 2.8621115684509277, 2.8437254428863525, 2.827822208404541, 2.8144869804382324, 2.80381441116333, 2.7959089279174805, 2.7908852100372314, 2.7888693809509277, 2.789998769760132, 2.7944223880767822, 2.802302360534668, 2.813814163208008, 2.8291473388671875, 2.8485066890716553, 2.8721120357513428, 2.900200366973877, 2.9330263137817383, 2.9708621501922607, 3.0139992237091064, 3.062748908996582, 3.1174423694610596, 3.178431749343872, 3.2460906505584717, 3.3208134174346924, 3.403015613555908, 3.4931328296661377, 3.5916213989257812, 3.6989552974700928, 3.815624713897705, 3.942134380340576, 4.078998565673828, 4.226738452911377, 4.385876178741455, 4.556927680969238, 4.740396976470947, 4.936764717102051, 5.146480560302734, 5.369948863983154, 5.607515811920166, 5.859455108642578, 6.125951766967773, 6.4070820808410645, 6.7027974128723145, 7.012903213500977, 7.337038516998291, 7.674659252166748, 8.025017738342285, 8.387147903442383, 8.759849548339844, 9.141684532165527, 9.530969619750977, 9.92577838897705, 10.323954582214355, 10.723128318786621, 11.120745658874512, 11.51409912109375, 11.90038013458252, 12.276724815368652, 12.640274047851562, 12.988237380981445, 13.31795597076416, 13.626967430114746, 13.91306209564209, 14.174342155456543, 14.409258842468262, 14.616646766662598, 14.795745849609375, 14.946200370788574, 15.068058967590332, 15.161746978759766, 15.22803783416748, 15.268013000488281, 15.283016204833984, 15.2746000289917, 15.24448013305664, 15.194480895996094, 15.126492500305176, 15.042427062988281, 14.944186210632324, 14.83362865447998, 14.71254825592041, 14.582656860351562, 14.445575714111328, 14.302824020385742, 14.15582275390625, 14.005891799926758, 13.854255676269531, 13.702051162719727, 13.550332069396973, 13.400077819824219, 13.252204895019531, 13.107337951660156, 12.966053009033203, 12.828890800476074, 12.69613265991211, 12.568024635314941, 12.444780349731445, 12.326581001281738, 12.213581085205078, 12.10590648651123, 12.003657341003418, 11.906907081604004, 11.815705299377441, 11.730079650878906, 11.650029182434082, 11.57553482055664, 11.506549835205078, 11.443005561828613, 11.384808540344238, 11.331843376159668, 11.283967018127441, 11.241015434265137, 11.202798843383789, 11.16910171508789, 11.139688491821289, 11.114294052124023, 11.092635154724121, 11.074402809143066, 11.059267044067383, 11.04687786102295, 11.036867141723633, 11.028848648071289, 11.022422790527344, 11.017176628112793, 11.012688636779785, 11.008530616760254, 11.00426959991455, 10.999476432800293, 10.993721008300781, 10.98658561706543, 10.977660179138184, 10.966550827026367, 10.952881813049316, 10.936300277709961, 10.916475296020508, 10.893108367919922, 10.865925788879395, 10.834691047668457, 10.799200057983398, 10.759282112121582, 10.714805603027344, 10.665672302246094, 10.611823081970215, 10.553231239318848, 10.48990535736084, 10.421886444091797, 10.349247932434082, 10.272088050842285, 10.190535545349121, 10.10473918914795, 10.014871597290039, 9.921120643615723, 9.823690414428711, 9.722799301147461, 9.618673324584961, 9.511547088623047, 9.401658058166504, 9.289249420166016, 9.174561500549316, 9.05783462524414, 8.939305305480957, 8.819208145141602, 8.69776725769043, 8.571085929870605, 8.439717292785645, 8.304280281066895, 8.165427207946777, 8.02381706237793, 7.880097389221191, 7.734885215759277, 7.588758945465088, 7.442251682281494, 7.295848846435547, 7.149985313415527, 7.0050482749938965, 6.8613786697387695, 6.719273567199707, 6.578991889953613, 6.440755844116211, 6.304756164550781, 6.1711554527282715, 6.040092468261719, 5.911684989929199, 5.7860331535339355, 5.66322135925293, 5.5433220863342285, 5.426397800445557, 5.312502861022949, 5.201685905456543, 5.093989849090576, 4.989455699920654, 4.88812255859375, 4.790030002593994, 4.695217132568359, 4.603726387023926, 4.515603065490723, 4.430896759033203, 4.3496623039245605, 4.271961688995361, 4.197864055633545, 4.127448081970215, 4.060801982879639, 3.998025894165039, 3.939232349395752, 3.8845481872558594, 3.8341164588928223, 3.788097858428955, 3.7466723918914795, 3.710041046142578, 3.678428888320923, 3.6520862579345703, 3.6312925815582275, 3.61635684967041, 3.6076228618621826, 3.6054704189300537, 3.610318899154663, 3.6226305961608887, 3.6429147720336914, 3.671729564666748, 3.709686756134033, 3.7574548721313477, 3.8157618045806885, 3.8853988647460938, 3.9672224521636963, 4.0621562004089355, 4.1711931228637695, 4.295392990112305, 4.435883522033691, 4.593855857849121, 4.770557403564453, 4.967284202575684, 5.185368537902832, 5.426161289215088, 5.69101095199585, 5.981234550476074, 6.298086643218994, 6.642714977264404, 7.016113758087158, 7.419065952301025, 7.852081775665283, 8.315324783325195, 8.808537483215332, 9.330962181091309, 9.881258964538574, 10.457433700561523, 11.056767463684082, 11.67577075958252, 12.310151100158691, 12.954815864562988, 13.603914260864258, 14.250910758972168, 14.888714790344238, 15.509849548339844, 16.106666564941406, 16.671585083007812, 17.197368621826172, 17.677391052246094, 18.10589599609375, 18.47821617126465, 18.79095458984375, 19.042083740234375, 19.230987548828125, 19.35841178894043, 19.426361083984375, 19.43715476989746, 19.394075393676758, 19.30118751525879, 19.163116455078125, 18.984840393066406, 18.77147674560547, 18.528108596801758, 18.2596435546875, 17.97068214416504, 17.665456771850586, 17.3477725982666, 17.020999908447266, 16.688066482543945, 16.351482391357422, 16.013376235961914, 15.675520896911621, 15.339391708374023, 15.00619125366211, 14.676901817321777, 14.352312088012695, 14.03305721282959, 13.719643592834473, 13.412474632263184, 13.111870765686035, 12.818087577819824, 12.531329154968262, 12.251763343811035, 11.979525566101074, 11.71473217010498, 11.457486152648926, 11.207880020141602, 10.966002464294434, 10.73194408416748, 10.505797386169434, 10.287664413452148, 10.077655792236328, 9.875895500183105, 9.682524681091309, 9.497700691223145, 9.321606636047363, 9.154446601867676, 8.996455192565918, 8.847894668579102, 8.709063529968262, 8.58029556274414, 8.461966514587402, 8.354493141174316, 8.258341789245605, 8.174026489257812, 8.102115631103516, 8.043235778808594, 7.998067855834961, 7.967357158660889, 7.951910495758057, 7.952597141265869, 7.970347881317139, 8.006153106689453, 8.061059951782227, 8.136163711547852, 8.232596397399902, 8.351520538330078, 8.49410343170166, 8.66150188446045, 8.854830741882324, 9.075132369995117, 9.323336601257324, 9.600212097167969, 9.906316757202148, 10.241935729980469]}],                        {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('335000dc-0b91-4141-aa9c-bf18876eb164');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


.. code:: ipython3

    # Selecting the z-axis and the label rho
    X = point_cloud[:, 2]
    y = point_cloud[:, 3]

.. code:: ipython3

    fig = px.line(title='Trajectory of the Lorenz solution, projected along the z-axis')
    fig.add_scatter(y=X, name='X')
    fig.add_scatter(y=y, name='y')
    fig.show()



.. raw:: html

    <div>                            <div id="4b11ae47-19d3-4899-8e01-08ded158e132" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("4b11ae47-19d3-4899-8e01-08ded158e132")) {                    Plotly.newPlot(                        "4b11ae47-19d3-4899-8e01-08ded158e132",                        [{"name": "X", "type": "scatter", "y": [10.0, 9.633333206176758, 9.386394500732422, 9.242918014526367, 9.186662673950195, 9.202041625976562, 9.27444076538086, 9.390336990356445, 9.537337303161621, 9.704184532165527, 9.880752563476562, 10.058052062988281, 10.228242874145508, 10.384649276733398, 10.521770477294922, 10.635278701782227, 10.721994400024414, 10.779839515686035, 10.807765007019043, 10.805652618408203, 10.774194717407227, 10.714761734008789, 10.62926197052002, 10.519996643066406, 10.38952922821045, 10.240555763244629, 10.075801849365234, 9.897931098937988, 9.709478378295898, 9.512795448303223, 9.310019493103027, 9.103057861328125, 8.893577575683594, 8.683015823364258, 8.472585678100586, 8.263300895690918, 8.055986404418945, 7.8513078689575195, 7.649787902832031, 7.4518280029296875, 7.257726669311523, 7.067698001861572, 6.881886005401611, 6.700377941131592, 6.523214817047119, 6.350402355194092, 6.181918621063232, 6.017719268798828, 5.8577446937561035, 5.701923370361328, 5.550174236297607, 5.402411937713623, 5.258546352386475, 5.118484973907471, 4.982136249542236, 4.8494062423706055, 4.720202922821045, 4.594435691833496, 4.472014427185059, 4.352851867675781, 4.236861705780029, 4.123960494995117, 4.014066219329834, 3.9070987701416016, 3.802980661392212, 3.7016360759735107, 3.6029913425445557, 3.506974697113037, 3.413516044616699, 3.322547674179077, 3.2340033054351807, 3.1478183269500732, 3.063930034637451, 2.9822776317596436, 2.902801275253296, 2.8254435062408447, 2.750147819519043, 2.6768593788146973, 2.605525016784668, 2.536092519760132, 2.4685113430023193, 2.4027326107025146, 2.33870792388916, 2.27639102935791, 2.2157363891601562, 2.1566996574401855, 2.0992379188537598, 2.043309450149536, 1.9888733625411987, 1.9358899593353271, 1.8843207359313965, 1.8341280221939087, 1.7852754592895508, 1.737727403640747, 1.6914492845535278, 1.6464074850082397, 1.602569341659546, 1.5599029064178467, 1.5183770656585693, 1.4779620170593262, 1.4386281967163086, 1.400347113609314, 1.3630911111831665, 1.3268332481384277, 1.2915472984313965, 1.2572078704833984, 1.223790168762207, 1.1912702322006226, 1.1596245765686035, 1.1288305521011353, 1.09886634349823, 1.0697104930877686, 1.0413423776626587, 1.0137418508529663, 0.9868895411491394, 0.9607666730880737, 0.9353550672531128, 0.9106371402740479, 0.8865960240364075, 0.8632153868675232, 0.8404794931411743, 0.8183733224868774, 0.7968823909759521, 0.7759929895401001, 0.7556918859481812, 0.7359667420387268, 0.7168057560920715, 0.6981979012489319, 0.6801329255104065, 0.6626012921333313, 0.6455944180488586, 0.629104495048523, 0.6131247878074646, 0.5976493954658508, 0.5826737284660339, 0.5681941509246826, 0.554208517074585, 0.5407159328460693, 0.5277171730995178, 0.5152145624160767, 0.5032125115394592, 0.4917173683643341, 0.4807378947734833, 0.47028541564941406, 0.4603741765022278, 0.4510217308998108, 0.4422492980957031, 0.4340822696685791, 0.4265507459640503, 0.4196900725364685, 0.413541704416275, 0.4081538915634155, 0.4035826325416565, 0.39989277720451355, 0.3971591889858246, 0.39546826481819153, 0.39491933584213257, 0.3956267535686493, 0.3977218270301819, 0.4013552963733673, 0.4067001938819885, 0.41395488381385803, 0.4233468472957611, 0.4351368248462677, 0.44962358474731445, 0.4671494662761688, 0.48810654878616333, 0.5129439234733582, 0.5421757102012634, 0.5763903856277466, 0.6162614226341248, 0.6625589728355408, 0.7161632776260376, 0.7780799269676208, 0.8494565486907959, 0.9316015839576721, 1.026004672050476, 1.134359359741211, 1.25858736038208, 1.4008638858795166, 1.5636451244354248, 1.749694585800171, 1.9621096849441528, 2.204345703125, 2.4802348613739014, 2.7939980030059814, 3.150244951248169, 3.5539591312408447, 4.010456562042236, 4.525319576263428, 5.103882312774658, 5.751290798187256, 6.472250938415527, 7.270702362060547, 8.149422645568848, 9.109554290771484, 10.150078773498535, 11.267242431640625, 12.453990936279297, 13.699466705322266, 14.98863410949707, 16.302143096923828, 17.61650276184082, 18.90468978881836, 20.137178421020508, 21.283472061157227, 22.31396484375, 23.202045440673828, 23.926145553588867, 24.471487045288086, 24.83124542236328, 25.00693702697754, 25.007980346679688, 24.85049057006836, 24.447050094604492, 23.845436096191406, 23.101797103881836, 22.27326011657715, 21.41190528869629, 20.560802459716797, 19.75218963623047, 19.007434844970703, 18.33819580078125, 17.74823570251465, 17.23539924621582, 16.79347801208496, 16.413793563842773, 16.086444854736328, 15.80125904083252, 15.548439979553223, 15.319019317626953, 15.10511589050293, 14.900068283081055, 14.698471069335938, 14.496137619018555, 14.290006637573242, 14.078025817871094, 13.859007835388184, 13.632481575012207, 13.398544311523438, 13.157721519470215, 12.910845756530762, 12.658940315246582, 12.4031343460083, 12.144586563110352, 11.88443374633789, 11.623746871948242, 11.363509178161621, 11.104598999023438, 10.847782135009766, 10.593717575073242, 10.34295654296875, 10.095954895019531, 9.853079795837402, 9.614623069763184, 9.38080883026123, 9.151805877685547, 8.927734375, 8.708678245544434, 8.494686126708984, 8.285785675048828, 8.08198070526123, 7.8832621574401855, 7.689608097076416, 7.500988960266113, 7.317368984222412, 7.138708114624023, 6.964966297149658, 6.7961015701293945, 6.63207483291626, 6.472849369049072, 6.3183913230896, 6.16867208480835, 6.023670196533203, 5.883369445800781, 5.747763156890869, 5.616852760314941, 5.490652084350586, 5.369184494018555, 5.252487659454346, 5.140614986419678, 5.03363561630249, 4.931637287139893, 4.834728717803955, 4.743041515350342, 4.656733512878418, 4.575991630554199, 4.501034736633301, 4.432117462158203, 4.369535446166992, 4.313628673553467, 4.264787197113037, 4.223456859588623, 4.1901469230651855, 4.16543436050415, 4.1499738693237305, 4.144505023956299, 4.149862766265869, 4.166985034942627, 4.196924686431885, 4.2408599853515625, 4.30010461807251, 4.376121520996094, 4.4705305099487305, 4.585119724273682, 4.721855163574219, 4.882884979248047, 5.07054328918457, 5.287347316741943, 5.5359883308410645, 5.819314479827881, 6.14030122756958, 6.502006530761719, 6.907512664794922, 7.359842777252197, 7.861410140991211, 8.414163589477539, 9.019405364990234, 9.677579879760742, 10.388045310974121, 11.148825645446777, 11.956376075744629, 12.805355072021484, 13.688455581665039, 14.596298217773438, 15.517441749572754, 16.438518524169922, 17.344539642333984, 18.219356536865234, 19.046306610107422, 19.808977127075195, 20.4920597076416, 21.082212448120117, 21.568851470947266, 21.944761276245117, 22.206478118896484, 22.354393005371094, 22.39253807067871, 22.32813835144043, 22.17093276977539, 21.932401657104492, 21.624954223632812, 21.261184692382812, 20.853225708007812, 20.41227912902832, 19.948291778564453, 19.46979522705078, 18.983863830566406, 18.496177673339844, 18.011154174804688, 17.532102584838867, 17.061410903930664, 16.60071563720703, 16.151058197021484, 15.713032722473145, 15.286897659301758, 14.872671127319336, 14.470210075378418, 14.079261779785156, 13.69951057434082, 13.330605506896973, 12.972182273864746, 12.623878479003906, 12.28533935546875, 11.956225395202637, 11.636214256286621, 11.32500171661377, 11.022299766540527, 10.727837562561035, 10.44135856628418, 10.162620544433594, 9.89139461517334, 9.627461433410645, 9.370612144470215, 9.120646476745605, 8.877372741699219, 8.640604972839355, 8.410164833068848, 8.185880661010742, 7.967584609985352, 7.755115032196045, 7.54831600189209, 7.347034454345703, 7.151122570037842, 6.960436820983887, 6.774837017059326, 6.594188213348389, 6.418358325958252, 6.247217655181885, 6.080642223358154, 5.9185099601745605, 5.760702610015869, 5.607104778289795, 5.457604885101318, 5.312093257904053, 5.170464038848877, 5.032614231109619, 4.89844274520874, 4.767852306365967, 4.640747547149658, 4.517035961151123, 4.396626949310303, 4.279433727264404, 4.165370464324951, 4.054354190826416, 3.9463047981262207, 3.8411431312561035, 3.73879337310791, 3.639181137084961, 3.542234182357788, 3.447882652282715, 3.356058120727539, 3.2666945457458496, 3.179727554321289, 3.0950944423675537, 3.0127344131469727, 2.932588815689087, 2.854600191116333, 2.7787132263183594, 2.7048628330230713, 2.6329939365386963, 2.563053846359253, 2.494990825653076, 2.428755283355713, 2.3642985820770264, 2.3015737533569336, 2.240535259246826, 2.1811389923095703, 2.1233417987823486, 2.0671021938323975, 2.0123798847198486, 1.9591355323791504, 1.9073313474655151, 1.8569303750991821, 1.8078972101211548, 1.7601971626281738, 1.7137969732284546, 1.6686643362045288, 1.6247680187225342, 1.582077980041504, 1.5405652523040771, 1.500201940536499, 1.4609612226486206, 1.422817349433899, 1.385745882987976, 1.349723219871521, 1.3147271871566772, 1.2807364463806152, 1.247731328010559, 1.2156929969787598, 1.184604287147522, 1.1544491052627563, 1.1252130270004272, 1.096882939338684, 1.06944739818573, 1.0428967475891113, 1.0172232389450073, 0.9924208521842957, 0.9684858918190002, 0.9454169273376465, 0.9232151508331299, 0.9018843173980713, 0.8814314603805542, 0.8618668913841248, 0.8432045578956604, 0.8254625797271729, 0.8086637854576111, 0.7928358316421509, 0.7780122756958008, 0.7642330527305603, 0.7515450716018677, 0.7400033473968506, 0.7296720147132874, 0.7206251621246338, 0.7129483819007874, 0.706740140914917, 0.7021135091781616, 0.6991978287696838, 0.6981412768363953, 0.6991127729415894, 0.702305257320404, 0.7079384922981262, 0.7162626385688782, 0.7275625467300415, 0.7421621084213257, 0.7604293823242188, 0.7827826142311096, 0.8096965551376343, 0.8417100310325623, 0.8794340491294861, 0.9235610365867615, 0.9748752117156982, 1.0342637300491333, 1.102729082107544, 1.1814032793045044, 1.271561861038208, 1.3746397495269775, 1.4922486543655396, 1.6261932849884033, 1.778489351272583, 1.9513802528381348, 2.147352695465088, 2.3691492080688477, 2.6197783946990967, 2.9025161266326904, 3.220900058746338, 3.5787124633789062, 3.9799439907073975, 4.428741455078125, 4.929324150085449, 5.485874652862549, 6.102384090423584, 6.7824602127075195, 7.529083251953125, 8.344313621520996, 9.228950500488281, 10.182148933410645, 11.201011657714844, 12.28018569946289, 13.411492347717285, 14.582544326782227, 15.777406692504883, 16.976709365844727, 18.15807342529297, 19.29688262939453, 20.367401123046875, 21.344196319580078, 22.203765869140625, 22.926164627075195, 23.49649429321289, 23.905990600585938, 24.152591705322266, 24.24087142944336, 24.181373596191406, 23.989431381225586, 23.683673858642578, 23.28443145751953, 22.812232971191406, 22.28656005859375, 21.724946975708008, 21.142423629760742, 20.551300048828125, 19.96121597290039, 19.379352569580078, 18.810773849487305, 18.258787155151367, 17.725330352783203, 17.2112979888916, 16.716835021972656, 16.2415771484375, 15.784836769104004, 15.345739364624023, 14.923327445983887, 14.516627311706543, 14.124700546264648, 13.746663093566895, 13.381706237792969, 13.029098510742188, 12.688186645507812, 12.358393669128418, 12.039207458496094, 11.730180740356445, 11.430919647216797, 11.141081809997559, 10.860363960266113, 10.588504791259766, 10.325275421142578, 10.070476531982422, 9.82394027709961, 9.58552074432373, 9.355100631713867, 9.132583618164062, 8.917898178100586, 8.710996627807617, 8.511855125427246, 8.320472717285156, 8.136877059936523, 7.961122512817383, 7.793291091918945, 7.633497714996338, 7.48189115524292, 7.3386549949646, 7.204014301300049, 7.078235626220703, 6.961633682250977, 6.8545732498168945, 6.757473945617676, 6.670816421508789, 6.595146656036377, 6.531079292297363, 6.479306697845459, 6.440601825714111, 6.415823936462402, 6.4059247970581055, 6.411952495574951, 6.435056209564209, 6.476487159729004, 6.537601947784424, 6.619859218597412, 6.72481632232666, 6.854121208190918, 7.009498596191406, 7.192732810974121, 7.405639171600342, 7.650031089782715, 7.927675247192383, 8.240233421325684, 8.589198112487793, 8.975807189941406, 9.40095043182373, 9.86506462097168, 10.368008613586426, 10.908944129943848, 11.486201286315918, 12.097158432006836, 12.738128662109375, 13.404279708862305, 14.089580535888672, 14.786811828613281, 15.487629890441895, 16.18271255493164, 16.861984252929688, 17.51491355895996, 18.130884170532227, 18.699621200561523, 19.211633682250977, 19.65865135192871, 20.034011840820312, 20.33296012878418, 20.55284309387207, 20.693172454833984, 20.755544662475586, 20.743444442749023, 20.661945343017578, 20.517343521118164, 20.316757202148438, 20.067733764648438, 19.777896881103516, 19.454635620117188, 19.104875564575195, 18.73451805114746, 18.348861694335938, 17.95256233215332, 17.54962158203125, 17.143409729003906, 16.736719131469727, 16.331806182861328, 15.930471420288086, 15.53411865234375, 15.143818855285645, 14.760367393493652, 14.384334564208984, 14.01611614227295, 13.655963897705078, 13.304019927978516, 12.960344314575195, 12.624933242797852, 12.297734260559082, 11.978662490844727, 11.667604446411133, 11.364433288574219, 11.069007873535156, 10.781180381774902, 10.500798225402832, 10.227705001831055, 9.961746215820312, 9.702765464782715, 9.45060920715332, 9.205124855041504, 8.966163635253906, 8.7335786819458, 8.507225036621094, 8.286962509155273, 8.072652816772461, 7.864161014556885, 7.661357402801514, 7.464113235473633, 7.272304058074951, 7.085809707641602, 6.904512882232666, 6.728298664093018, 6.557057857513428, 6.390683174133301, 6.229071617126465, 6.0721235275268555, 5.919742584228516, 5.771836757659912, 5.628316402435303, 5.489096641540527, 5.354095458984375, 5.223234176635742, 5.096438407897949, 4.973637104034424, 4.854762077331543, 4.73923397064209, 4.626937389373779, 4.5177717208862305, 4.411647796630859, 4.3084869384765625, 4.208218574523926, 4.110780715942383, 4.016116619110107, 3.9241764545440674, 3.8349153995513916, 3.748293161392212, 3.664273977279663, 3.582826852798462, 3.5039238929748535, 3.4275424480438232, 3.3536629676818848, 3.282271146774292, 3.213355779647827, 3.146911144256592, 3.0829358100891113, 3.0214335918426514, 2.9624133110046387, 2.9058899879455566, 2.851884603500366, 2.800424814224243, 2.7515456676483154, 2.7052900791168213, 2.6617090702056885, 2.620863437652588, 2.5828239917755127, 2.5476725101470947, 2.515502691268921, 2.486421823501587, 2.4605510234832764, 2.4380276203155518, 2.419006109237671, 2.4036595821380615, 2.392181873321533, 2.384789228439331, 2.3817226886749268, 2.3832499980926514, 2.3896679878234863, 2.401305913925171, 2.418527126312256, 2.441732883453369, 2.471365213394165, 2.5079102516174316, 2.55190110206604, 2.603921890258789, 2.664611577987671, 2.7298264503479004, 2.799252510070801, 2.8726344108581543, 2.9497649669647217, 3.030478000640869, 3.1146421432495117, 3.202155113220215, 3.292938470840454, 3.386934757232666, 3.484102249145508, 3.5844130516052246, 3.687849760055542, 3.794402837753296, 3.9040679931640625, 4.016845226287842, 4.132735729217529, 4.251739025115967, 4.373854637145996, 4.4990763664245605, 4.6273932456970215, 4.758786678314209, 4.893230438232422, 5.03068733215332, 5.171109676361084, 5.3144354820251465, 5.460590362548828, 5.609485149383545, 5.761012554168701, 5.915050983428955, 6.07145881652832, 6.230078220367432, 6.3907318115234375, 6.553222179412842, 6.7173357009887695, 6.882837295532227, 7.049476146697998, 7.216982364654541, 7.385071277618408, 7.553442001342773, 7.721780776977539, 7.8897624015808105, 8.057051658630371, 8.223307609558105, 8.388184547424316, 8.551334381103516, 8.712409973144531, 8.871070861816406, 9.026981353759766, 9.17982006072998, 9.329275131225586, 9.475055694580078, 9.616887092590332, 9.754520416259766, 9.88772964477539, 10.016317367553711, 10.14011287689209, 10.258978843688965, 10.372809410095215, 10.481529235839844, 10.585098266601562, 10.683509826660156, 10.776787757873535, 10.864991188049316, 10.94820785522461, 11.026556968688965, 11.100187301635742, 11.169272422790527, 11.234013557434082, 11.294632911682129, 11.3513765335083, 11.40450668334961, 11.454305648803711, 11.501069068908691, 11.545106887817383, 11.586739540100098, 11.626296997070312, 11.664118766784668, 11.70054817199707, 11.735933303833008, 11.770627975463867, 11.804986000061035, 11.839362144470215, 11.874112129211426, 11.909590721130371, 11.946147918701172, 11.98413372039795, 12.023893356323242, 12.065767288208008, 12.110091209411621, 12.157194137573242, 12.207396507263184, 12.261012077331543, 12.318346977233887, 12.379693031311035, 12.445332527160645, 12.515535354614258, 12.590555191040039, 12.67063045501709, 12.755980491638184, 12.84680461883545, 12.943281173706055, 13.045150756835938, 13.152084350585938, 13.263675689697266, 13.379448890686035, 13.498858451843262, 13.621294975280762, 13.746084213256836, 13.872498512268066, 13.999760627746582, 14.127050399780273, 14.253515243530273, 14.378279685974121, 14.50045394897461, 14.619150161743164, 14.73348617553711, 14.842605590820312, 14.945687294006348, 15.041952133178711, 15.130681991577148, 15.211224555969238, 15.283002853393555, 15.345524787902832, 15.39838695526123, 15.441279411315918, 15.473989486694336, 15.496397972106934, 15.50848388671875, 15.51031494140625, 15.50204849243164, 15.48392391204834, 15.456252098083496, 15.419414520263672, 15.37385082244873, 15.320049285888672, 15.25854206085205, 15.18989372253418, 15.11469554901123, 15.033555030822754, 14.94709300994873, 14.85593318939209, 14.760699272155762, 14.662009239196777, 14.560473442077637, 14.456686973571777, 14.351232528686523, 14.244672775268555, 14.137554168701172, 14.030401229858398, 13.923722267150879, 13.818001747131348, 13.713706016540527, 13.611281394958496, 13.511154174804688, 13.413735389709473, 13.319415092468262, 13.228567123413086, 13.14155101776123, 13.058707237243652, 12.980364799499512, 12.90683650970459, 12.838420867919922, 12.775403022766113, 12.71805477142334, 12.666632652282715, 12.621380805969238, 12.582527160644531, 12.550284385681152, 12.524847984313965, 12.50639820098877, 12.495092391967773, 12.491069793701172, 12.49444580078125, 12.505311012268066, 12.523727416992188, 12.549729347229004, 12.5833158493042, 12.624452590942383, 12.673066139221191, 12.729040145874023, 12.792217254638672, 12.86238956451416, 12.939302444458008, 13.022647857666016, 13.112066268920898, 13.207141876220703, 13.307403564453125, 13.412324905395508, 13.521327018737793, 13.633776664733887, 13.748991012573242, 13.866243362426758, 13.984766006469727, 14.103755950927734, 14.22238540649414, 14.339804649353027, 14.455156326293945, 14.567583084106445, 14.676238059997559, 14.780293464660645, 14.87895393371582, 14.971468925476074, 15.057135581970215, 15.13531494140625, 15.205436706542969, 15.267007827758789, 15.31961727142334, 15.36293888092041, 15.396737098693848, 15.420866012573242, 15.435267448425293, 15.439970016479492, 15.435088157653809, 15.42081069946289, 15.397401809692383, 15.365190505981445, 15.324563026428223, 15.275958061218262, 15.219857215881348, 15.15677547454834, 15.087258338928223, 15.011869430541992, 14.93118953704834, 14.845804214477539, 14.756304740905762, 14.663278579711914, 14.567307472229004, 14.468962669372559, 14.368805885314941, 14.267382621765137, 14.165221214294434, 14.062835693359375, 13.960719108581543, 13.859349250793457, 13.75918197631836, 13.66065788269043, 13.564197540283203, 13.47020435333252, 13.379064559936523, 13.29114818572998, 13.206809997558594, 13.126387596130371, 13.05020523071289, 12.978570938110352, 12.911781311035156, 12.850115776062012, 12.793840408325195, 12.743209838867188, 12.698461532592773, 12.659817695617676, 12.627486228942871, 12.60165786743164, 12.58250617980957, 12.570185661315918, 12.564828872680664, 12.566546440124512, 12.57542610168457, 12.591526985168457, 12.61488151550293, 12.645488739013672, 12.683314323425293, 12.728289604187012, 12.780303001403809, 12.839204788208008, 12.904799461364746, 12.976844787597656, 13.05505084991455, 13.139078140258789, 13.228536605834961, 13.322983741760254, 13.42192554473877, 13.524818420410156, 13.631070137023926, 13.740041732788086, 13.851054191589355, 13.963386535644531, 14.07629108428955, 14.18898868560791, 14.300687789916992, 14.410581588745117, 14.517867088317871, 14.621745109558105, 14.721437454223633, 14.816192626953125, 14.905296325683594, 14.988080978393555, 15.063932418823242, 15.132302284240723, 15.192708015441895, 15.244745254516602, 15.288086891174316, 15.322486877441406, 15.347784042358398, 15.363899230957031, 15.370832443237305, 15.36866569519043, 15.357551574707031, 15.337715148925781, 15.309441566467285, 15.273075103759766, 15.229009628295898, 15.177682876586914, 15.11956787109375, 15.05516529083252, 14.985001564025879, 14.90961742401123, 14.829564094543457, 14.745399475097656, 14.623223304748535, 14.463884353637695, 14.269842147827148, 14.044723510742188, 13.792901992797852, 13.519125938415527, 13.228192329406738, 12.92470645904541, 12.612897872924805, 12.2965087890625, 11.978742599487305, 11.66224479675293, 11.34913444519043, 11.041044235229492, 10.739182472229004, 10.444395065307617, 10.157230377197266, 9.877997398376465, 9.60682201385498, 9.343692779541016, 9.088496208190918, 8.84105110168457, 8.6011323928833, 8.368488311767578, 8.142858505249023, 7.923975944519043, 7.711583137512207, 7.505430221557617, 7.30527925491333, 7.110906600952148, 6.922101974487305, 6.738667964935303, 6.560421466827393, 6.387190341949463, 6.218814373016357, 6.055142879486084, 5.896035671234131, 5.741359710693359, 5.5909905433654785, 5.444810390472412, 5.302708148956299, 5.164579391479492, 5.030323505401611, 4.899847507476807, 4.773062229156494, 4.64988374710083, 4.530232906341553, 4.414035797119141, 4.301223278045654, 4.191730499267578, 4.085498809814453, 3.982473134994507, 3.8826050758361816, 3.78585147857666, 3.6921751499176025, 3.6015448570251465, 3.51393723487854, 3.429335117340088, 3.3477299213409424, 3.2691214084625244, 3.193519353866577, 3.120943307876587, 3.051424980163574, 2.9850077629089355, 2.921750545501709, 2.861726760864258, 2.805027723312378, 2.7517647743225098, 2.7020702362060547, 2.656102180480957, 2.6140453815460205, 2.576115846633911, 2.542564868927002, 2.5136826038360596, 2.4898035526275635, 2.4713127613067627, 2.4586503505706787, 2.4523203372955322, 2.4528980255126953, 2.46103835105896, 2.4774858951568604, 2.5030860900878906, 2.538796901702881, 2.5857014656066895, 2.6450228691101074, 2.7181384563446045, 2.80659556388855, 2.9121286869049072, 3.036674737930298, 3.1823902130126953, 3.3516645431518555, 3.547133684158325, 3.7716867923736572, 4.028470039367676, 4.32088041305542, 4.652546405792236, 5.027299404144287, 5.449118614196777, 5.922054767608643, 6.4501261711120605, 7.037173271179199, 7.686159610748291, 8.39925479888916, 9.177534103393555, 10.020636558532715, 10.926399230957031, 11.890491485595703, 12.813940048217773, 13.669175148010254, 14.431827545166016, 15.081947326660156, 15.605043411254883, 15.99278736114502, 16.243234634399414, 16.360532760620117, 16.354135513305664, 16.237632751464844, 16.027368545532227, 15.741020202636719, 15.3962984085083, 15.009894371032715, 14.596718788146973, 14.169466018676758, 13.738438606262207, 13.311601638793945, 12.894783973693848, 12.491965293884277, 12.105606079101562, 11.736970901489258, 11.386423110961914, 11.05368423461914, 10.738046646118164, 10.438538551330566, 10.15404987335205, 9.883429527282715, 9.625540733337402, 9.379312515258789, 9.143757820129395, 8.917984962463379, 8.701208114624023, 8.492738723754883, 8.291980743408203, 8.09842586517334, 7.911640167236328, 7.731259822845459, 7.556978702545166, 7.388543128967285, 7.225742816925049, 7.068406581878662, 6.916396617889404, 6.769604206085205, 6.627945899963379, 6.491361141204834, 6.3598103523254395, 6.233274936676025, 6.111752033233643, 5.9952592849731445, 5.8838300704956055, 5.777517318725586, 5.676392078399658, 5.5805439949035645, 5.490083694458008, 5.405143737792969, 5.325879096984863, 5.252470970153809, 5.185126304626465, 5.124083042144775, 5.06960916519165, 5.022008895874023, 4.98162317276001, 4.9488348960876465, 4.924070835113525, 4.907805442810059, 4.900566577911377, 4.902936935424805, 4.915560245513916, 4.939144134521484, 4.9744648933410645, 5.022371768951416, 5.083788871765137, 5.159718990325928, 5.251245975494385, 5.359535217285156, 5.4858317375183105, 5.631457805633545, 5.797808647155762, 5.986340045928955, 6.198558330535889, 6.435998916625977, 6.700205326080322, 6.992695331573486, 7.314922332763672, 7.668229103088379, 8.053789138793945, 8.472539901733398, 8.925106048583984, 9.411715507507324, 9.932104110717773, 10.485421180725098, 11.070128440856934, 11.683910369873047, 12.323587417602539, 12.985061645507812, 13.663275718688965, 14.352225303649902, 15.045005798339844, 15.733919143676758, 16.410640716552734, 17.065458297729492, 17.68839454650879, 18.269594192504883, 18.799732208251953, 19.270421981811523, 19.674612045288086, 20.00690460205078, 20.263792037963867, 20.44378089904785, 20.547378540039062, 20.57697105407715, 20.536603927612305, 20.43165397644043, 20.268489837646484, 20.05409049987793, 19.795698165893555, 19.500499725341797, 19.175378799438477, 18.826719284057617, 18.460281372070312, 18.081132888793945, 17.693635940551758, 17.301462173461914, 16.90764617919922, 16.51464080810547, 16.12440299987793, 15.738454818725586, 15.357964515686035, 14.983804702758789, 14.616615295410156, 14.256850242614746, 13.904818534851074, 13.56071949005127, 13.2246675491333, 12.89671802520752, 12.576879501342773, 12.265130043029785, 11.961423873901367, 11.665704727172852, 11.37790298461914, 11.097949028015137, 10.825769424438477, 10.561295509338379, 10.304459571838379, 10.055201530456543, 9.813468933105469, 9.579217910766602, 9.352415084838867, 9.133038520812988, 8.921080589294434, 8.716547966003418, 8.519465446472168, 8.329874038696289, 8.14783763885498, 7.973442077636719, 7.806798934936523, 7.64804744720459, 7.4973578453063965, 7.354934215545654, 7.221018314361572, 7.095892429351807, 6.979884147644043, 6.87337064743042, 6.776783466339111, 6.690612316131592, 6.615411758422852, 6.551804542541504, 6.500489711761475, 6.462246894836426, 6.4379401206970215, 6.428525924682617, 6.435056686401367, 6.458683013916016, 6.500659942626953, 6.562343597412109, 6.645192623138428, 6.750762939453125, 6.8806986808776855, 7.0367207527160645, 7.220605373382568, 7.434159278869629, 7.6791839599609375, 7.957431316375732, 8.270545959472656, 8.61999797821045, 9.007002830505371, 9.432422637939453, 9.896662712097168, 10.39954948425293, 10.940210342407227, 11.516939163208008, 12.127080917358398, 12.766918182373047, 13.431591033935547, 14.1150484085083, 14.810063362121582, 15.508296966552734, 16.2004451751709, 16.876466751098633, 17.52587890625, 18.137123107910156, 18.698884963989258, 19.200632095336914, 19.633121490478516, 19.988876342773438, 20.2625732421875, 20.451274871826172, 20.55453109741211, 20.57430076599121, 20.514726638793945, 20.381776809692383, 20.182815551757812, 19.926116943359375, 19.620405197143555, 19.2744140625, 18.896543502807617, 18.494577407836914, 18.07550811767578, 17.645429611206055, 17.209518432617188, 16.77204132080078, 16.336435317993164, 15.905384063720703, 15.48092269897461, 15.06454086303711, 14.65727710723877, 14.259808540344238, 13.872532844543457, 13.495628356933594, 13.129115104675293, 12.772895812988281, 12.426793098449707, 12.090571403503418, 11.763967514038086, 11.446695327758789, 11.13846206665039, 10.838974952697754, 10.547948837280273, 10.26510238647461, 9.990168571472168, 9.722888946533203, 9.463018417358398, 9.210315704345703, 8.964569091796875, 8.725571632385254, 8.493119239807129, 8.267011642456055, 8.047059059143066, 7.833074569702148, 7.624881744384766, 7.422309875488281, 7.22519588470459, 7.033382415771484, 6.846718788146973, 6.6650614738464355, 6.488270282745361, 6.316211700439453, 6.148756504058838, 5.985780715942383, 5.8271636962890625, 5.672788619995117, 5.522542953491211, 5.376318454742432, 5.2340087890625, 5.095511436462402, 4.960727691650391, 4.82956075668335, 4.7019171714782715, 4.577706813812256, 4.456840991973877, 4.339235305786133, 4.224807262420654, 4.113476276397705, 4.005165100097656, 3.899799346923828, 3.7973060607910156, 3.697615623474121, 3.600660562515259, 3.506376028060913, 3.4146993160247803, 3.325570583343506, 3.2389323711395264, 3.1547300815582275, 3.072911262512207, 2.99342679977417, 2.916229724884033, 2.8412766456604004, 2.768526315689087, 2.697941541671753, 2.629488229751587, 2.5631353855133057, 2.49885630607605, 2.4366281032562256, 2.376431941986084, 2.3182544708251953, 2.262086868286133, 2.207925796508789, 2.1557741165161133, 2.1056418418884277, 2.0575456619262695, 2.0115110874176025, 1.9675724506378174, 1.925774097442627, 1.8861720561981201, 1.8488348722457886, 1.813845157623291, 1.7813018560409546, 1.7513216733932495, 1.7240415811538696, 1.6996214389801025, 1.6782469749450684, 1.6601331233978271, 1.6455274820327759, 1.6347153186798096, 1.6280239820480347, 1.6258286237716675, 1.6285581588745117, 1.6367028951644897, 1.6508221626281738, 1.6715530157089233, 1.6996207237243652, 1.735849380493164, 1.7811744213104248, 1.8366563320159912, 1.9034948348999023, 1.9830455780029297, 2.076836347579956, 2.1865861415863037, 2.314222812652588, 2.4619014263153076, 2.632023811340332, 2.8272526264190674, 3.0505261421203613, 3.3050661087036133, 3.5943777561187744, 3.922241687774658, 4.292690277099609, 4.709963798522949, 5.1784467697143555, 5.702569007873535, 6.286675453186035, 6.934846878051758, 7.6506757736206055, 8.436370849609375, 9.292798042297363, 10.21906852722168, 11.212108612060547, 12.266223907470703, 13.37271499633789, 14.519579887390137, 15.691393852233887, 16.869401931762695, 18.03190803527832, 19.15500259399414, 20.213603973388672, 21.182830810546875, 22.03952407836914, 22.76384925842285, 23.340730667114258, 23.76094627380371, 24.0217227935791, 24.12674903869629, 24.085582733154297, 23.912574768066406, 23.625455856323242, 23.243812561035156, 22.787622451782227, 22.27600860595703, 21.726333618164062, 21.153610229492188, 20.570253372192383, 19.98607635498047, 19.40848731994629, 18.842784881591797, 18.29251480102539, 17.759828567504883, 17.245811462402344, 16.75077247619629, 16.274484634399414, 15.816367149353027, 15.375616073608398, 14.951345443725586, 14.542648315429688, 14.148636817932129, 13.768465995788574, 13.401351928710938, 13.046574592590332, 12.703481674194336, 12.371482849121094, 12.050047874450684, 11.738700866699219, 11.437015533447266, 11.144606590270996, 10.861130714416504, 10.586274147033691, 10.319754600524902, 10.061315536499023, 9.810721397399902, 9.56775951385498, 9.332230567932129, 9.103957176208496, 8.882770538330078, 8.668519973754883, 8.461063385009766, 8.260272979736328, 8.066028594970703, 7.878222942352295, 7.6967573165893555, 7.521542549133301, 7.352498531341553, 7.189553260803223, 7.032645225524902, 6.881720066070557, 6.736732006072998, 6.597643852233887, 6.4644269943237305, 6.337059020996094, 6.2155280113220215, 6.099828243255615, 5.98996114730835, 5.885937213897705, 5.7877726554870605, 5.695490837097168, 5.609121799468994, 5.528700828552246, 5.4542694091796875, 5.385872840881348, 5.323561191558838, 5.267387390136719, 5.217405796051025, 5.173672676086426, 5.136242866516113, 5.105170249938965, 5.080504417419434, 5.058221817016602, 5.037883758544922, 5.0191450119018555, 5.001740455627441, 4.985472202301025, 4.97020149230957, 4.955836772918701, 4.942329406738281, 4.929663181304932, 4.917853355407715, 4.906938076019287, 4.896976470947266, 4.888044834136963, 4.880234241485596, 4.873648166656494, 4.868401527404785, 4.864617824554443, 4.862428665161133, 4.861972808837891, 4.863397121429443, 4.866852760314941, 4.872498512268066, 4.880497932434082, 4.89102029800415, 4.904240608215332, 4.920340061187744, 4.939504623413086, 4.9619269371032715, 4.987805366516113, 5.017343521118164, 5.050752639770508, 5.088248252868652, 5.1300530433654785, 5.176395893096924, 5.227510929107666, 5.283637523651123, 5.345020294189453, 5.411908149719238, 5.48455286026001, 5.5632100105285645, 5.648134708404541, 5.739583492279053, 5.837809085845947, 5.943061351776123, 6.055582046508789, 6.175604820251465, 6.303348541259766, 6.439017295837402, 6.582793712615967, 6.734835624694824, 6.895270824432373, 7.0641913414001465, 7.2416486740112305, 7.427647590637207, 7.622140407562256, 7.825018882751465, 8.036109924316406, 8.255169868469238, 8.4818754196167, 8.71582317352295, 8.956522941589355, 9.203390121459961, 9.455753326416016, 9.712843894958496, 9.97380256652832, 10.237679481506348, 10.50344181060791, 10.769980430603027, 11.03611946105957, 11.300625801086426, 11.562227249145508, 11.819628715515137, 12.071527481079102, 12.316631317138672, 12.553685188293457, 12.78148365020752, 12.998895645141602, 13.20488166809082, 13.398512840270996, 13.578980445861816, 13.74561595916748, 13.897895812988281, 14.035446166992188, 14.158048629760742, 14.26563835144043, 14.358299255371094, 14.436258316040039, 14.499872207641602, 14.549622535705566, 14.586094856262207, 14.609970092773438, 14.622008323669434, 14.623034477233887, 14.613921165466309, 14.5955810546875, 14.568950653076172, 14.534979820251465, 14.494623184204102, 14.448832511901855, 14.398550033569336, 14.344701766967773, 14.287834167480469, 14.22846794128418, 14.167102813720703, 14.104218482971191, 14.040273666381836, 13.975706100463867, 13.910937309265137, 13.846366882324219, 13.782378196716309, 13.719338417053223, 13.65759563446045, 13.597481727600098, 13.539313316345215, 13.483389854431152, 13.429996490478516, 13.379403114318848, 13.331863403320312, 13.287616729736328, 13.246885299682617, 13.209878921508789, 13.176791191101074, 13.147797584533691, 13.12306022644043, 13.10272216796875, 13.086912155151367, 13.075737953186035, 13.069291114807129, 13.06764030456543, 13.07083797454834, 13.078911781311035, 13.09186840057373, 13.10969066619873, 13.132338523864746, 13.159743309020996, 13.191813468933105, 13.228426933288574, 13.269436836242676, 13.314665794372559, 13.363908767700195, 13.416930198669434, 13.473467826843262, 13.533227920532227, 13.595890998840332, 13.661111831665039, 13.728516578674316, 13.797710418701172, 13.868277549743652, 13.93978214263916, 14.011775016784668, 14.083791732788086, 14.155363082885742, 14.226014137268066, 14.295269966125488, 14.36266040802002, 14.427724838256836, 14.490015983581543, 14.549104690551758, 14.604586601257324, 14.656082153320312, 14.703243255615234, 14.745758056640625, 14.78334903717041, 14.815781593322754, 14.84286117553711, 14.864436149597168, 14.880401611328125, 14.890693664550781, 14.895295143127441, 14.894229888916016, 14.88756275177002, 14.87540054321289, 14.857885360717773, 14.835193634033203, 14.807534217834473, 14.775145530700684, 14.738289833068848, 14.697251319885254, 14.652335166931152, 14.603859901428223, 14.55215835571289, 14.497572898864746, 14.440451622009277, 14.381150245666504, 14.320023536682129, 14.257428169250488, 14.193717956542969, 14.129244804382324, 14.064353942871094, 13.999385833740234, 13.934672355651855, 13.870539665222168, 13.807303428649902, 13.745268821716309, 13.684732437133789, 13.625980377197266, 13.569287300109863, 13.514917373657227, 13.46312141418457, 13.414139747619629, 13.368199348449707, 13.325516700744629, 13.286293029785156, 13.250717163085938, 13.218964576721191, 13.191195487976074, 13.167555809020996, 13.148176193237305, 13.133170127868652, 13.122635841369629, 13.11665153503418, 13.115279197692871, 13.118559837341309, 13.126513481140137, 13.139140129089355, 13.156416893005371, 13.17829704284668, 13.204710960388184, 13.235563278198242, 13.270731925964355, 13.31006908416748, 13.353401184082031, 13.40052604675293, 13.451214790344238, 13.505210876464844, 13.562233924865723, 13.621578216552734, 13.682476043701172, 13.744105339050293, 13.805597305297852, 13.866046905517578, 13.924528121948242, 13.980104446411133, 14.031839370727539, 14.078816413879395, 14.120146751403809, 14.154986381530762, 14.182548522949219, 14.20211124420166, 14.213035583496094, 14.214766502380371, 14.206847190856934, 14.188916206359863, 14.160719871520996, 14.122103691101074, 14.073017120361328, 14.013508796691895, 13.943719863891602, 13.836982727050781, 13.694648742675781, 13.519371032714844, 13.314728736877441, 13.084869384765625, 12.834195137023926, 12.567102432250977, 12.287781715393066, 12.00007152557373, 11.707371711730957, 11.412601470947266, 11.118194580078125, 10.826118469238281, 10.537914276123047, 10.25475025177002, 9.977472305297852, 9.706659317016602, 9.442676544189453, 9.18571662902832, 8.935844421386719, 8.693028450012207, 8.457164764404297, 8.228106498718262, 8.005672454833984, 7.789665222167969, 7.579878330230713, 7.376104831695557, 7.178139686584473, 6.985784530639648, 6.798848628997803, 6.617149829864502, 6.440515041351318, 6.26878023147583, 6.101790904998779, 5.939399242401123, 5.781466007232666, 5.6278581619262695, 5.478450775146484, 5.333123207092285, 5.191761016845703, 5.05425500869751, 4.920499801635742, 4.790395736694336, 4.663846492767334, 4.540759563446045, 4.421046257019043, 4.304622173309326, 4.191405296325684, 4.08131742477417, 3.9742844104766846, 3.870234489440918, 3.7690999507904053, 3.670815944671631, 3.5753211975097656, 3.482558012008667, 3.392472505569458, 3.30501389503479, 3.2201359272003174, 3.13779616355896, 3.0579569339752197, 2.9805843830108643, 2.9056506156921387, 2.833132266998291, 2.763012409210205, 2.6952803134918213, 2.629931926727295, 2.5669713020324707, 2.5064103603363037, 2.4482712745666504, 2.3925862312316895, 2.3393988609313965, 2.288766384124756, 2.240760564804077, 2.195469856262207, 2.153001546859741, 2.1134836673736572, 2.077068567276001, 2.043935775756836, 2.0142955780029297, 1.9883930683135986, 1.9665133953094482, 1.9489867687225342, 1.9361950159072876, 1.92857825756073, 1.9266433715820312, 1.9309725761413574, 1.9422341585159302, 1.9611939191818237, 1.9887280464172363, 2.0258378982543945, 2.0736658573150635, 2.1335132122039795, 2.206860065460205, 2.2953855991363525, 2.400991201400757, 2.5258243083953857, 2.672302007675171, 2.843135118484497, 3.041350841522217, 3.270312547683716, 3.533733367919922, 3.835454225540161, 4.179561138153076, 4.570336818695068, 5.01218843460083, 5.509541988372803, 6.066699028015137, 6.687646865844727, 7.375819683074951, 8.133805274963379, 8.962994575500488, 9.86318588256836, 10.8321533203125, 11.865208625793457, 12.954782485961914, 14.090086936950684, 15.256917953491211, 16.437652587890625, 17.611530303955078, 18.75523567199707, 19.843847274780273, 20.852092742919922, 21.75583839416504, 22.533700942993164, 23.1685733795166, 23.648880004882812, 23.96938705444336, 24.131425857543945, 24.14252471923828, 24.015487670898438, 23.76707649230957, 23.41648292541504, 22.983810424804688, 22.488733291625977, 21.949438095092773, 21.38192367553711, 20.79962730407715, 20.213342666625977, 19.631349563598633, 19.059690475463867, 18.50250816345215, 17.962419509887695, 17.44085121154785, 16.9383487701416, 16.454845428466797, 15.989852905273438, 15.542633056640625, 15.112310409545898, 14.697957038879395, 14.298650741577148, 13.913507461547852, 13.541707038879395, 13.18249797821045, 12.835206031799316, 12.499226570129395, 12.174026489257812, 11.859132766723633, 11.55368423461914, 11.257065773010254, 10.968730926513672, 10.68820571899414, 10.415079116821289, 10.148998260498047, 9.889664649963379, 9.636819839477539, 9.390246391296387, 9.149754524230957, 8.915177345275879, 8.686368942260742, 8.463194847106934, 8.24553394317627, 8.033270835876465, 7.826295852661133, 7.624504566192627, 7.427793979644775, 7.2360639572143555, 7.049214839935303, 6.867149353027344, 6.689769744873047, 6.5169806480407715, 6.348687171936035, 6.184794902801514, 6.025211811065674, 5.869846820831299, 5.7186102867126465, 5.571415424346924, 5.428176403045654, 5.2888102531433105, 5.15323543548584, 5.021373748779297, 4.893149375915527, 4.768489360809326, 4.647324085235596, 4.529585838317871, 4.415212154388428, 4.304141998291016, 4.196320056915283, 4.091692924499512, 3.990213394165039, 3.8918368816375732, 3.7965247631073, 3.7042429447174072, 3.6149630546569824, 3.5286624431610107, 3.445324659347534, 3.3649404048919678, 3.2875077724456787, 3.213033437728882, 3.1415324211120605, 3.0730302333831787, 3.0075626373291016, 2.9451777935028076, 2.885936975479126, 2.82991623878479, 2.777208089828491, 2.7279229164123535, 2.6821916103363037, 2.640166997909546, 2.602027416229248, 2.5679798126220703, 2.538261651992798, 2.513145685195923, 2.4929440021514893, 2.4780125617980957, 2.4687564373016357, 2.465634822845459, 2.4691684246063232, 2.4799461364746094, 2.4986321926116943, 2.525975227355957, 2.562817335128784, 2.6101036071777344, 2.6688926219940186, 2.7403676509857178, 2.82584810256958, 2.9268012046813965, 3.0448524951934814, 3.181797504425049, 3.3396100997924805, 3.5204508304595947, 3.7266693115234375, 3.960803985595703, 4.225574970245361, 4.523869037628174, 4.858709812164307, 5.233221054077148, 5.650565147399902, 6.113867282867432, 6.626110553741455, 7.190006256103516, 7.807833194732666, 8.481245994567871, 9.211051940917969, 9.99696159362793, 10.837324142456055, 11.728853225708008, 12.666370391845703, 13.642593383789062, 14.646973609924316, 15.666424751281738, 16.685476303100586, 17.68663787841797, 18.65097999572754, 19.55893898010254, 20.391298294067383, 21.130279541015625, 21.76062774658203, 22.27060317993164, 22.65271759033203, 22.904165267944336, 23.0268497467041, 23.02703285217285, 22.91465187072754, 22.701478958129883, 22.401243209838867, 22.02864646911621, 21.598472595214844, 21.12481689453125, 20.620529174804688, 20.096858978271484, 19.563289642333984, 19.027515411376953, 18.49555778503418, 17.971927642822266, 17.45985221862793, 16.96149444580078, 16.478168487548828, 16.010540008544922, 15.558791160583496, 15.122759819030762, 14.70205020904541, 14.296119689941406, 13.904341697692871, 13.526055335998535, 13.160595893859863, 12.8073148727417, 12.465596199035645, 12.13486385345459, 11.814583778381348, 11.504263877868652, 11.203454971313477, 10.91174602508545, 10.62876033782959, 10.354156494140625, 10.08761978149414, 9.828862190246582, 9.577617645263672, 9.333641052246094, 9.096705436706543, 8.866598129272461, 8.643121719360352, 8.426091194152832, 8.21533203125, 8.01068115234375, 7.811981678009033, 7.619088649749756, 7.4318623542785645, 7.249423027038574, 7.071575164794922, 6.898153305053711, 6.729015350341797, 6.564039707183838, 6.4031195640563965, 6.246161460876465, 6.093080520629883, 5.943800449371338, 5.798250675201416, 5.656364440917969, 5.518078804016113, 5.383334636688232, 5.252074241638184, 5.124242782592773, 4.999786376953125, 4.878653526306152, 4.760794639587402, 4.646162033081055, 4.534709930419922, 4.426393985748291, 4.321174144744873, 4.219010353088379, 4.119867324829102, 4.023712635040283, 3.9305155277252197, 3.8402509689331055, 3.752896785736084, 3.6684350967407227, 3.586852788925171, 3.5081424713134766, 3.4323010444641113, 3.359332799911499, 3.289247989654541, 3.2220637798309326, 3.157805919647217, 3.096508502960205, 3.038214921951294, 2.9829790592193604, 2.930866241455078, 2.8819541931152344, 2.836334466934204, 2.7941136360168457, 2.755415201187134, 2.7203805446624756, 2.689171314239502, 2.6619720458984375, 2.638990879058838, 2.6204633712768555, 2.6066553592681885, 2.5978643894195557, 2.5944249629974365, 2.596710681915283, 2.6051392555236816, 2.620175361633301, 2.642336368560791, 2.672196388244629, 2.7103915214538574, 2.757624864578247, 2.8146727085113525, 2.8823885917663574, 2.961709976196289, 3.0536627769470215, 3.159365653991699, 3.2800352573394775, 3.4169867038726807, 3.571636915206909, 3.74550199508667, 3.940194606781006, 4.157414436340332, 4.3989386558532715, 4.666600704193115, 4.962268352508545, 5.287808895111084, 5.645046710968018, 6.035710334777832, 6.461366176605225, 6.923340797424316, 7.422628402709961, 7.959788799285889, 8.534828186035156, 9.14708137512207, 9.795077323913574, 10.476424217224121, 11.187690734863281, 11.924318313598633, 12.680569648742676, 13.449519157409668, 14.223106384277344, 14.992267608642578, 15.74713134765625, 16.477304458618164, 17.172222137451172, 17.821552276611328, 18.415637969970703, 18.9459171295166, 19.40532875061035, 19.78862953186035, 20.09260368347168, 20.3161563873291, 20.460275650024414, 20.526952743530273, 20.519927978515625, 20.444406509399414, 20.306711196899414, 20.1138973236084, 19.87339210510254, 19.5926513671875, 19.278886795043945, 18.9388484954834, 18.578664779663086, 18.203771591186523, 17.81887435913086, 17.42795181274414, 17.03430938720703, 16.64063835144043, 16.249088287353516, 15.861344337463379, 15.47869873046875, 15.102129936218262, 14.732354164123535, 14.369884490966797, 14.015076637268066, 13.668160438537598, 13.329276084899902, 12.998493194580078, 12.675832748413086, 12.361278533935547, 12.054789543151855, 11.75631046295166, 11.465773582458496, 11.183107376098633, 10.908236503601074, 10.641088485717773, 10.38159465789795, 10.129691123962402, 9.885319709777832, 9.648431777954102, 9.418990135192871, 9.196967124938965, 8.98234748840332, 8.775131225585938, 8.575335502624512, 8.382993698120117, 8.198158264160156, 8.020907402038574, 7.851339340209961, 7.689581394195557, 7.53579044342041, 7.390154838562012, 7.252900123596191, 7.124290943145752, 7.004634857177734, 6.894287109375, 6.793656349182129, 6.7032060623168945, 6.6234636306762695, 6.555022239685059, 6.498548984527588, 6.454789161682129, 6.424570560455322, 6.408812522888184, 6.408527374267578, 6.424826145172119, 6.458921909332275, 6.512131214141846, 6.585873603820801, 6.681670188903809, 6.801133632659912, 6.945962429046631, 7.117918491363525, 7.318809986114502, 7.550455093383789, 7.814644813537598, 8.113090515136719, 8.447359085083008, 8.81879997253418, 9.22845458984375, 9.676950454711914, 10.164392471313477, 10.69023323059082, 11.253149032592773, 11.850912094116211, 12.480271339416504, 13.136860847473145, 13.815129280090332, 14.508330345153809, 15.208558082580566, 15.906862258911133, 16.59343910217285, 17.257904052734375, 17.88862419128418, 18.474023818969727, 19.00309944152832, 19.465953826904297, 19.854299545288086, 20.16188621520996, 20.38479995727539, 20.521625518798828, 20.573427200317383, 20.543582916259766, 20.437467575073242, 20.26203727722168, 20.025352478027344, 19.73609733581543, 19.40312957763672, 19.035083770751953, 18.64006233215332, 18.225431442260742, 17.79766845703125, 17.362327575683594, 16.924034118652344, 16.48653793334961, 16.05280303955078, 15.625092506408691, 15.205086708068848, 14.793973922729492, 14.392547607421875, 14.00129222869873, 13.620450019836426, 13.25008487701416, 12.890128135681152, 12.540417671203613, 12.200732231140137, 11.870805740356445, 11.550353050231934, 11.2390775680542, 10.936680793762207, 10.642868995666504, 10.357354164123535, 10.079861640930176, 9.810127258300781, 9.547897338867188, 9.29293155670166, 9.045001029968262, 8.803887367248535, 8.569382667541504, 8.341288566589355, 8.119414329528809, 7.903579235076904, 7.693609237670898, 7.489336967468262, 7.29060173034668, 7.0972490310668945, 6.909129619598389, 6.726099491119385, 6.548019886016846, 6.374756336212158, 6.206178665161133, 6.042160987854004, 5.8825812339782715, 5.727321147918701, 5.576266765594482, 5.429306507110596, 5.286332130432129, 5.1472392082214355, 5.011926174163818, 4.8802947998046875, 4.752248764038086, 4.627695083618164, 4.506543159484863, 4.388706207275391, 4.274097919464111, 4.162635803222656, 4.054239749908447, 3.9488308429718018, 3.8463332653045654, 3.746673583984375, 3.6497795581817627, 3.555581569671631, 3.4640114307403564, 3.3750035762786865, 3.2884936332702637, 3.2043678760528564, 3.122565269470215, 3.043027400970459, 2.965698719024658, 2.890526294708252, 2.817460536956787, 2.746453285217285, 2.677459478378296, 2.610436201095581, 2.545342445373535, 2.482140064239502, 2.4207923412323, 2.3612658977508545, 2.3035285472869873, 2.247551202774048, 2.1933066844940186, 2.140770673751831, 2.089921236038208, 2.0407395362854004, 1.9932085275650024, 1.9473154544830322, 1.9030499458312988, 1.8604053258895874, 1.8193782567977905, 1.7799696922302246, 1.7421845197677612, 1.706032156944275, 1.6715271472930908, 1.6386891603469849, 1.607543706893921, 1.5781227350234985, 1.5504653453826904, 1.5246179103851318, 1.5006355047225952, 1.4785822629928589, 1.458532691001892, 1.4405723810195923, 1.4247993230819702, 1.4113255739212036, 1.4002779722213745, 1.3918004035949707, 1.3860554695129395, 1.3832262754440308, 1.3835190534591675, 1.3871651887893677, 1.394424319267273, 1.405587077140808, 1.4209789037704468, 1.4409632682800293, 1.4659454822540283, 1.4963778257369995, 1.5327636003494263, 1.575662612915039, 1.6256965398788452, 1.6835544109344482, 1.7499996423721313, 1.8258752822875977, 1.9121116399765015, 2.0097317695617676, 2.119858503341675, 2.243720531463623, 2.3826565742492676, 2.538120746612549, 2.7116832733154297, 2.9050323963165283, 3.119968891143799, 3.358400821685791, 3.6223294734954834, 3.9138307571411133, 4.23502779006958, 4.588054656982422, 4.975007057189941, 5.397881984710693, 5.858500957489014, 6.358420372009277, 6.898821830749512, 7.480390548706055, 8.10317611694336, 8.766448020935059, 9.468541145324707, 10.206707000732422, 10.976983070373535, 11.77408504486084, 12.591349601745605, 13.420730590820312, 14.25287914276123, 15.07730770111084, 15.882657051086426, 16.65705108642578, 17.388540267944336, 18.06560707092285, 18.677688598632812, 19.215696334838867, 19.67245101928711, 20.04303741455078, 20.324989318847656, 20.51833152770996, 20.625457763671875, 20.65085220336914, 20.600709915161133, 20.482486724853516, 20.303693771362305, 20.072328567504883, 19.796493530273438, 19.484067916870117, 19.14246368408203, 18.778430938720703, 18.397964477539062, 18.006250381469727, 17.607677459716797, 17.20587921142578, 16.803802490234375, 16.403789520263672, 16.007667541503906, 15.616823196411133, 15.232295989990234, 14.85483455657959, 14.484966278076172, 14.12304401397705, 13.769285202026367, 13.423811912536621, 13.086671829223633, 12.757859230041504, 12.437334060668945, 12.125027656555176, 11.820858001708984, 11.524731636047363, 11.236553192138672, 10.956222534179688, 10.683642387390137, 10.418718338012695, 10.16136360168457, 9.91149616241455, 9.669039726257324, 9.433931350708008, 9.20611572265625, 8.98554801940918, 8.772197723388672, 8.566047668457031, 8.367096900939941, 8.175358772277832, 7.990869522094727, 7.813683032989502, 7.6438775062561035, 7.481555461883545, 7.32684850692749, 7.1799187660217285, 7.040961742401123, 6.910210609436035, 6.78794002532959, 6.674469470977783, 6.570168972015381, 6.475462436676025, 6.390833377838135, 6.316830635070801, 6.2540740966796875, 6.2032599449157715, 6.165168285369873, 6.14066743850708, 6.130721569061279, 6.136394023895264, 6.15885591506958, 6.199386119842529, 6.259376525878906, 6.340330123901367, 6.4438605308532715, 6.571682929992676, 6.7256059646606445, 6.907512664794922, 7.11933708190918, 7.363030433654785, 7.640519618988037, 7.953649044036865, 8.304115295410156, 8.69338321685791, 9.122587203979492, 9.592422485351562, 10.10301399230957, 10.653786659240723, 11.24332046508789, 11.80312728881836, 12.317873001098633, 12.77469539642334, 13.163540840148926, 13.47740364074707, 13.712420463562012, 13.867785453796387, 13.945505142211914, 13.949995040893555, 13.887575149536133, 13.765908241271973, 13.593430519104004, 13.37883186340332, 13.13060474395752, 12.856706619262695, 12.564311981201172, 12.259675979614258, 11.948079109191895, 11.633843421936035, 11.320398330688477, 11.010370254516602, 10.705698013305664, 10.407745361328125, 10.117412567138672, 9.835233688354492, 9.561463356018066, 9.296154975891113, 9.039212226867676, 8.79044246673584, 8.549591064453125, 8.316367149353027, 8.090466499328613, 7.871580600738525, 7.659411430358887, 7.453671932220459, 7.254092216491699, 7.060420989990234, 6.872424125671387, 6.68988561630249, 6.5126051902771, 6.340398788452148, 6.173095703125, 6.010537624359131, 5.8525776863098145, 5.6990790367126465, 5.549914360046387, 5.404964447021484, 5.26411771774292, 5.127269744873047, 4.994322299957275, 4.865184307098389, 4.739769458770752, 4.617998123168945, 4.499796390533447, 4.385095596313477, 4.273833274841309, 4.165953159332275, 4.061404228210449, 3.960143566131592, 3.862133264541626, 3.767343521118164, 3.675752878189087, 3.5873470306396484, 3.502121686935425, 3.4200825691223145, 3.3412458896636963, 3.2656400203704834, 3.1933066844940186, 3.124302864074707, 3.058701276779175, 2.996593713760376, 2.9380922317504883, 2.8833320140838623, 2.8324742317199707, 2.7857091426849365, 2.743260383605957, 2.705387830734253, 2.672393798828125, 2.644627809524536, 2.6224918365478516, 2.6064491271972656, 2.597029447555542, 2.5948400497436523, 2.6005735397338867, 2.6150197982788086, 2.639077663421631, 2.67376708984375, 2.720244884490967, 2.7798194885253906, 2.8539679050445557, 2.9443531036376953, 3.0528416633605957, 3.181523323059082, 3.3327274322509766, 3.509040594100952, 3.713318109512329, 3.948695421218872, 4.218587875366211, 4.5266852378845215, 4.876928329467773, 5.273473739624023, 5.720278263092041, 6.221213340759277, 6.779910087585449, 7.3995680809021, 8.082716941833496, 8.830934524536133, 9.64452075958252, 10.522139549255371, 11.460450172424316, 12.453744888305664, 13.49362850189209, 14.568804740905762, 15.664993286132812, 16.765052795410156, 17.849355697631836, 18.896425247192383, 19.883867263793945, 20.789522171020508, 21.592782974243164, 22.275922775268555, 22.825321197509766, 23.23238754272461, 23.49408531188965, 23.612974166870117, 23.596757888793945, 23.457426071166992, 23.210100173950195, 22.871755599975586, 22.459978103637695, 21.991878509521484, 21.48325538635254, 20.948034286499023, 20.397977828979492, 19.842618942260742, 19.28937339782715, 18.743755340576172, 18.209657669067383, 17.689651489257812, 17.185264587402344, 16.697240829467773, 16.22575569152832, 15.770593643188477, 15.331284523010254, 14.907208442687988, 14.49767017364502, 14.101951599121094, 13.719347953796387, 13.349187850952148, 12.990845680236816, 12.643747329711914, 12.307369232177734, 11.981240272521973, 11.664934158325195, 11.358068466186523, 11.060296058654785, 10.771307945251465, 10.49082088470459, 10.218582153320312, 9.954358100891113, 9.697941780090332, 9.449140548706055, 9.207782745361328, 8.973712921142578, 8.746790885925293, 8.526893615722656, 8.313911437988281, 8.10775089263916, 7.908336639404297, 7.715606212615967, 7.529516696929932, 7.350042819976807, 7.177179336547852, 7.010941028594971, 6.851365566253662, 6.698515892028809, 6.552481174468994, 6.413380146026611, 6.281363487243652, 6.156617164611816, 6.039367198944092, 5.9298810958862305, 5.828474521636963, 5.735515117645264, 5.65142822265625, 5.576701641082764, 5.511893272399902, 5.457636833190918, 5.41464900970459, 5.3837385177612305, 5.365810394287109, 5.361877918243408, 5.373067378997803, 5.400627136230469, 5.445932865142822, 5.510494232177734, 5.595959186553955, 5.7041120529174805, 5.836874485015869, 5.996295928955078, 6.184540748596191, 6.403868198394775, 6.629928112030029, 6.858486175537109, 7.085743427276611, 7.308318138122559, 7.523231029510498, 7.727895259857178, 7.920112609863281, 8.098065376281738, 8.260310173034668, 8.40576171875, 8.533681869506836, 8.643651962280273, 8.735555648803711, 8.809542655944824, 8.866003036499023, 8.905526161193848, 8.928873062133789, 8.93693733215332, 8.93071460723877, 8.911269187927246, 8.879707336425781, 8.837154388427734, 8.78472900390625, 8.723530769348145, 8.654623031616211, 8.579021453857422, 8.497692108154297, 8.411539077758789, 8.321407318115234, 8.228083610534668, 8.132288932800293, 8.034692764282227, 7.9359049797058105, 7.836487293243408, 7.7369537353515625, 7.63777494430542, 7.539384365081787, 7.44218111038208, 7.346534729003906, 7.25278902053833, 7.1612653732299805, 7.072268486022949, 6.986086368560791, 6.9029974937438965, 6.823270797729492, 6.7471699714660645, 6.67495584487915, 6.606889724731445, 6.543234825134277, 6.484259128570557, 6.430238246917725, 6.3814568519592285, 6.338212013244629, 6.300813674926758, 6.269588470458984, 6.2448811531066895, 6.227055549621582, 6.216498851776123, 6.213620185852051, 6.218856334686279, 6.232668876647949, 6.255548477172852, 6.288014888763428, 6.330617427825928, 6.383935451507568, 6.4485764503479, 6.525177955627441, 6.614400863647461, 6.7169318199157715, 6.833474636077881, 6.96474552154541, 7.111467361450195, 7.274358749389648, 7.454123497009277, 7.651436805725098, 7.866929054260254, 8.101166725158691, 8.354630470275879, 8.627693176269531, 8.920589447021484, 9.23338794708252, 9.565960884094238, 9.917948722839355, 10.288732528686523, 10.677396774291992, 11.08270263671875, 11.503066062927246, 11.93653392791748, 12.380779266357422, 12.833100318908691, 13.290433883666992, 13.74938678741455, 14.20627498626709, 14.65718936920166, 15.098067283630371, 15.524784088134766, 15.933252334594727, 16.319530487060547, 16.6799259185791, 17.0111083984375, 17.310197830200195, 17.574058532714844, 17.800125122070312, 17.986499786376953, 18.131980895996094, 18.236101150512695, 18.299108505249023, 18.321918487548828, 18.306062698364258, 18.253589630126953, 18.166967391967773, 18.04897689819336, 17.90260887145996, 17.730958938598633, 17.53714370727539, 17.32421112060547, 17.095096588134766, 16.85256004333496, 16.599164962768555, 16.33725929260254, 16.06895637512207, 15.796152114868164, 15.520523071289062, 15.243542671203613, 14.966498374938965, 14.690508842468262, 14.416543006896973, 14.145440101623535, 13.877923011779785, 13.614620208740234, 13.356074333190918, 13.102763175964355, 12.85510540008545, 12.613472938537598, 12.378201484680176, 12.149599075317383, 11.927948951721191, 11.713521957397461, 11.506575584411621, 11.307365417480469, 11.116144180297852, 10.933170318603516, 10.758708000183105, 10.59303092956543, 10.43642807006836, 10.289205551147461, 10.151688575744629, 10.024222373962402, 9.907180786132812, 9.800960540771484, 9.705988883972168, 9.622722625732422, 9.551650047302246, 9.493291854858398, 9.448200225830078, 9.416960716247559, 9.400187492370605, 9.398523330688477, 9.412633895874023, 9.443206787109375, 9.49094009399414, 9.556534767150879, 9.64068603515625, 9.744068145751953, 9.867319107055664, 10.011019706726074, 10.175674438476562, 10.361684799194336, 10.569321632385254, 10.798693656921387, 11.049715042114258, 11.32206916809082, 11.615174293518066, 11.928147315979004, 12.259770393371582, 12.6084623336792, 12.97225570678711, 13.348784446716309, 13.73527717590332, 14.128572463989258, 14.525139808654785, 14.921131134033203, 15.312434196472168, 15.694756507873535, 16.063718795776367, 16.414960861206055, 16.744264602661133, 17.04766845703125, 17.321578979492188, 17.56288719177246, 17.769052505493164, 17.93817710876465, 18.06903648376465, 18.161104202270508, 18.214536666870117, 18.230127334594727, 18.209245681762695, 18.153757095336914, 18.06592559814453, 17.948322296142578, 17.803714752197266, 17.634986877441406, 17.445045471191406, 17.23674964904785, 17.012863159179688, 16.775991439819336, 16.528566360473633, 16.272823333740234, 16.010787963867188, 15.744279861450195, 15.474920272827148, 15.204141616821289, 14.93320083618164, 14.663196563720703, 14.395086288452148, 14.129704475402832, 13.867773056030273, 13.609926223754883, 13.35671329498291, 13.108622550964355, 12.866082191467285, 12.629478454589844, 12.399158477783203, 12.175443649291992, 11.95863151550293, 11.749005317687988, 11.546838760375977, 11.352399826049805, 11.165955543518066, 10.987775802612305, 10.818138122558594, 10.657329559326172, 10.50565242767334, 10.363423347473145, 10.230978012084961, 10.108674049377441, 9.996892929077148, 9.896039962768555, 9.806549072265625, 9.728882789611816, 9.663533210754395, 9.611019134521484, 9.571893692016602, 9.546733856201172, 9.536144256591797, 9.540754318237305, 9.561210632324219, 9.598172187805176, 9.652304649353027, 9.724268913269043, 9.814708709716797, 9.924240112304688, 10.05342960357666, 10.202778816223145, 10.372698783874512, 10.563488960266113, 10.775303840637207, 11.008126258850098, 11.261736869812012, 11.535676002502441, 11.829214096069336, 12.140830039978027, 12.468564987182617, 12.757622718811035, 12.999189376831055, 13.187108993530273, 13.317831039428711, 13.39024543762207, 13.40542221069336, 13.366267204284668, 13.277122497558594, 13.143353462219238, 12.970931053161621, 12.766069412231445, 12.534903526306152, 12.283244132995605, 12.016406059265137, 11.739091873168945, 11.455349922180176, 11.16856575012207, 10.881494522094727, 10.596320152282715, 10.314718246459961, 10.037934303283691, 9.766851425170898, 9.502067565917969, 9.243946075439453, 8.992676734924316, 8.748316764831543, 8.510825157165527, 8.280097007751465, 8.055978775024414, 7.838292121887207, 7.6268415451049805, 7.4214253425598145, 7.2218427658081055, 7.027894973754883, 6.839392185211182, 6.6561503410339355, 6.477995872497559, 6.304762363433838, 6.136293888092041, 5.972440242767334, 5.813061237335205, 5.658021926879883, 5.507194519042969, 5.360456943511963, 5.2176923751831055, 5.078789710998535, 4.94364070892334, 4.812143325805664, 4.684197902679443, 4.559708595275879, 4.438583850860596, 4.32073450088501, 4.206075191497803, 4.094522953033447, 3.9859979152679443, 3.8804233074188232, 3.777724504470825, 3.677830457687378, 3.580672264099121, 3.4861836433410645, 3.394301414489746, 3.304965019226074, 3.2181167602539062, 3.1337010860443115, 3.051666736602783, 2.971964120864868, 2.894547700881958, 2.8193752765655518, 2.7464072704315186, 2.6756091117858887, 2.6069493293762207, 2.540400981903076, 2.475942373275757, 2.4135560989379883, 2.353231191635132, 2.2949624061584473, 2.2387516498565674, 2.1846084594726562, 2.1325507164001465, 2.082606554031372, 2.0348143577575684, 1.989225149154663, 1.945904016494751, 1.904931664466858, 1.8664065599441528, 1.8304482698440552, 1.7971993684768677, 1.766829252243042, 1.7395380735397339, 1.7155612707138062, 1.6951745748519897, 1.6786998510360718, 1.666512131690979, 1.6590477228164673, 1.6568127870559692, 1.6603940725326538, 1.6704708337783813, 1.6878280639648438, 1.7133724689483643, 1.7481495141983032, 1.7933635711669922, 1.8503414392471313, 1.9205870628356934, 2.0058014392852783, 2.1079018115997314, 2.22904372215271, 2.3716397285461426, 2.5383787155151367, 2.732241630554199, 2.956511974334717, 3.2147793769836426, 3.5109336376190186, 3.849142551422119, 4.233810901641846, 4.669516563415527, 5.1609110832214355, 5.712584495544434, 6.328884124755859, 7.013677597045898, 7.7700605392456055, 8.600005149841309, 9.503948211669922, 10.48034381866455, 11.52518367767334, 12.631540298461914, 13.789163589477539, 14.984217643737793, 16.19919776916504, 17.41313934326172, 18.602149963378906, 19.740314483642578, 20.80097007751465, 21.758262634277344, 22.58885955810547, 23.273643493652344, 23.79915428161621, 24.158567428588867, 24.352081298828125, 24.38663673400879, 24.275012969970703, 24.034460067749023, 23.685068130493164, 23.248106002807617, 22.744531631469727, 22.193805694580078, 21.61309242248535, 21.016815185546875, 20.416549682617188, 19.821157455444336, 19.23706817626953, 18.668659210205078, 18.118648529052734, 17.588481903076172, 17.07865333557129, 16.589006423950195, 16.118942260742188, 15.6676025390625, 15.233994483947754, 14.817078590393066, 14.415831565856934, 14.029282569885254, 13.656533241271973, 13.296770095825195, 12.94926643371582, 12.61337661743164, 12.288533210754395, 11.974239349365234, 11.670062065124512, 11.37562370300293, 11.090595245361328, 10.814692497253418, 10.547670364379883, 10.289318084716797, 10.03945541381836, 9.797932624816895, 9.56462574005127, 9.339437484741211, 9.122297286987305, 8.913158416748047, 8.711999893188477, 8.518826484680176, 8.333671569824219, 8.156596183776855, 7.9876909255981445, 7.827081203460693, 7.674925327301025, 7.5314202308654785, 7.396803855895996, 7.271356582641602, 7.155407905578613, 7.049339294433594, 6.953587532043457, 6.868650436401367, 6.795091152191162, 6.733543872833252, 6.684718132019043, 6.649404048919678, 6.628476619720459, 6.6229023933410645, 6.633739471435547, 6.662144660949707, 6.709370136260986, 6.776767253875732, 6.865779876708984, 6.977940559387207, 7.114857196807861, 7.278200149536133, 7.469677448272705, 7.691007614135742, 7.9438796043396, 8.196869850158691, 8.444259643554688, 8.681071281433105, 8.903059959411621, 9.106707572937012, 9.289217948913574, 9.44849681854248, 9.583122253417969, 9.692304611206055, 9.775833129882812, 9.83401107788086, 9.867588996887207, 9.877681732177734, 9.865697860717773, 9.833259582519531, 9.782132148742676, 9.714159965515137, 9.631208419799805, 9.535120010375977, 9.42767333984375, 9.310555458068848, 9.185343742370605, 9.053491592407227, 8.916321754455566, 8.775029182434082, 8.630678176879883, 8.484216690063477, 8.33647632598877, 8.188188552856445, 8.039989471435547, 7.892432689666748, 7.745999813079834, 7.601108074188232, 7.458118915557861, 7.317347049713135, 7.179068088531494, 7.04352331161499, 6.910926342010498, 6.781467914581299, 6.655320167541504, 6.530147075653076, 6.406069278717041, 6.283217430114746, 6.161727428436279, 6.0417327880859375, 5.923364162445068, 5.806745529174805, 5.69199275970459, 5.579213619232178, 5.468506336212158, 5.359961986541748, 5.253661632537842, 5.149680137634277, 5.048085689544678, 4.948939323425293, 4.852298736572266, 4.758216381072998, 4.66674280166626, 4.577925205230713, 4.491809844970703, 4.408443450927734, 4.327872276306152, 4.250144958496094, 4.175311088562012, 4.103425025939941, 4.034543514251709, 3.9687294960021973, 3.9060511589050293, 3.846583604812622, 3.790409564971924, 3.7376203536987305, 3.6883177757263184, 3.6426141262054443, 3.6006336212158203, 3.5625147819519043, 3.5284104347229004, 3.4984896183013916, 3.4729394912719727, 3.4519665241241455, 3.4357988834381104, 3.424687385559082, 3.41890811920166, 3.418764591217041, 3.424589157104492, 3.43674635887146, 3.455634355545044, 3.4816877841949463, 3.5153794288635254, 3.5572237968444824, 3.6077778339385986, 3.6676440238952637, 3.73747181892395, 3.8179593086242676, 3.909852981567383, 4.013949394226074, 4.1310930252075195, 4.2621750831604, 4.408130168914795, 4.5699310302734375, 4.748580455780029, 4.945102691650391, 5.160531520843506, 5.3958916664123535, 5.652180194854736, 5.930344104766846, 6.2312493324279785, 6.555646896362305, 6.904138088226318, 7.277126789093018, 7.674774169921875, 8.09694766998291, 8.543167114257812, 9.01254940032959, 9.503758430480957, 10.014958381652832, 10.543771743774414, 11.087255477905273, 11.641894340515137, 12.203604698181152, 12.767777442932129, 13.329339027404785, 13.882843017578125, 14.422589302062988, 14.942774772644043, 15.437653541564941, 15.901718139648438, 16.329879760742188, 16.7176456451416, 17.061262130737305, 17.35784339904785, 17.605457305908203, 17.803159713745117, 17.95098304748535, 18.04989242553711, 18.10169219970703, 18.108896255493164, 18.074594497680664, 18.00229835510254, 17.895790100097656, 17.758975982666016, 17.595775604248047, 17.409526824951172, 17.20347023010254, 16.980684280395508, 16.744047164916992, 16.49620819091797, 16.239582061767578, 15.976338386535645, 15.708405494689941, 15.437490463256836, 15.165087699890137, 14.892501831054688, 14.62086296081543, 14.351151466369629, 14.08421516418457, 13.820786476135254, 13.56149959564209, 13.30690860748291, 13.0574951171875, 12.813688278198242, 12.575867652893066, 12.344378471374512, 12.119534492492676, 11.901632308959961, 11.690947532653809, 11.487750053405762, 11.292304992675781, 11.104873657226562, 10.925724983215332, 10.755131721496582, 10.59338092803955, 10.440770149230957, 10.297616004943848, 10.164253234863281, 10.041040420532227, 9.928357124328613, 9.826613426208496, 9.736245155334473, 9.65771770477295, 9.591526985168457, 9.538199424743652, 9.498295783996582, 9.47240161895752, 9.461133003234863, 9.465131759643555, 9.48505973815918, 9.52159309387207, 9.575417518615723, 9.647214889526367, 9.737655639648438, 9.847380638122559, 9.976985931396484, 10.127004623413086, 10.297882080078125, 10.489950180053711, 10.703400611877441, 10.938250541687012, 11.194314002990723, 11.471163749694824, 11.768096923828125, 12.084105491638184, 12.417840957641602, 12.767590522766113, 13.131260871887207, 13.506366729736328, 13.890032768249512, 14.279011726379395, 14.669717788696289, 15.058274269104004, 15.440581321716309, 15.812397003173828, 16.169437408447266, 16.50748634338379, 16.822498321533203, 17.110733032226562, 17.36884307861328, 17.593990325927734, 17.783910751342773, 17.93698501586914, 18.052255630493164, 18.12944221496582, 18.168914794921875, 18.171642303466797, 18.139131546020508, 18.073335647583008, 17.9765682220459, 17.851409912109375, 17.700603485107422, 17.526975631713867, 17.333358764648438, 17.122520446777344, 16.89711570739746, 16.65964698791504, 16.412439346313477, 16.15761947631836, 15.897119522094727, 15.632667541503906, 15.365804672241211, 15.09788990020752, 14.830120086669922, 14.563541412353516, 14.299067497253418, 14.037493705749512, 13.779516220092773, 13.525742530822754, 13.276705741882324, 13.032878875732422, 12.794681549072266, 12.562492370605469, 12.336655616760254, 12.117491722106934, 11.905299186706543, 11.700364112854004, 11.50296401977539, 11.313371658325195, 11.13186264038086, 10.958714485168457, 10.79421329498291, 10.638657569885254, 10.49235725402832, 10.355640411376953, 10.228856086730957, 10.112371444702148, 10.00658130645752, 9.911901473999023, 9.828779220581055, 9.757685661315918, 9.69912338256836, 9.653621673583984, 9.621737480163574, 9.604053497314453, 9.601176261901855, 9.613731384277344, 9.642359733581543, 9.687707901000977, 9.750423431396484, 9.831140518188477, 9.93047046661377, 10.048983573913574, 10.187191009521484, 10.345529556274414, 10.524330139160156, 10.723796844482422, 10.943979263305664, 11.184737205505371, 11.445714950561523, 11.726304054260254, 12.025615692138672, 12.342449188232422, 12.67526912689209, 13.022185325622559, 13.380941390991211, 13.74891185760498, 14.123120307922363, 14.50025749206543, 14.876726150512695, 15.248698234558105, 15.612183570861816, 15.963116645812988, 16.297456741333008, 16.611289978027344, 16.900930404663086, 17.163036346435547, 17.39469337463379, 17.593505859375, 17.75765037536621, 17.885923385620117, 17.977746963500977, 18.033172607421875, 18.052833557128906, 18.037899017333984, 17.99000358581543, 17.91115951538086, 17.803678512573242, 17.67007827758789, 17.51300048828125, 17.335124969482422, 17.13912010192871, 16.92757225036621, 16.70294761657715, 16.46756362915039, 16.223562240600586, 15.972906112670898, 15.717371940612793, 15.458553314208984, 15.197872161865234, 14.936583518981934, 14.675797462463379, 14.416487693786621, 14.15950870513916, 13.905610084533691, 13.655449867248535, 13.4096097946167, 13.168601989746094, 12.932886123657227, 12.702875137329102, 12.47894287109375, 12.26143741607666, 12.050680160522461, 11.846978187561035, 11.650626182556152, 11.4619140625, 11.2811279296875, 11.108556747436523, 10.94449520111084, 10.78924560546875, 10.643122673034668, 10.50645637512207, 10.379594802856445, 10.262901306152344, 10.15676498413086, 10.061596870422363, 9.97783088684082, 9.905927658081055, 9.846373558044434, 9.79967975616455, 9.766382217407227, 9.747040748596191, 9.742234230041504, 9.75256061553955, 9.756792068481445, 9.752321243286133, 9.737265586853027, 9.710389137268066, 9.671011924743652, 9.618927955627441, 9.554320335388184, 9.477682113647461, 9.389741897583008, 9.291396141052246, 9.18365478515625, 9.067587852478027, 8.944284439086914, 8.814824104309082, 8.680246353149414, 8.541535377502441, 8.39961051940918, 8.255313873291016, 8.109411239624023, 7.962590217590332, 7.815464496612549, 7.668576240539551, 7.522402763366699, 7.377361297607422, 7.233815670013428, 7.092082500457764, 6.9524359703063965, 6.8151140213012695, 6.680324554443359, 6.548247814178467, 6.419042587280273, 6.292849540710449, 6.169793128967285, 6.04998779296875, 5.933537483215332, 5.820539951324463, 5.71108865737915, 5.605275630950928, 5.503190994262695, 5.404928207397461, 5.310583114624023, 5.220256805419922, 5.134057521820068, 5.052100658416748, 4.974513530731201, 4.901434421539307, 4.833014488220215, 4.7694220542907715, 4.710842132568359, 4.6574788093566895, 4.609559059143066, 4.567333221435547, 4.531078338623047, 4.501100540161133, 4.477737903594971, 4.461362838745117, 4.452385902404785, 4.451258659362793, 4.458476543426514, 4.474581241607666, 4.500165939331055, 4.535876750946045, 4.5824174880981445, 4.640549182891846, 4.711095333099365, 4.794942378997803, 4.893039703369141, 5.006400108337402, 5.136097431182861, 5.283262252807617, 5.449077129364014, 5.634765148162842, 5.841580390930176, 6.070788860321045, 6.323648929595947, 6.601384162902832, 6.905149936676025, 7.235997200012207, 7.594822883605957, 7.9823198318481445, 8.39891529083252, 8.844707489013672, 9.319389343261719, 9.822184562683105, 10.351764678955078, 10.906189918518066, 11.482841491699219, 12.07837963104248, 12.688720703125, 13.309039115905762, 13.93380069732666, 14.556838989257812, 15.17147159576416, 15.770652770996094, 16.347169876098633, 16.893863677978516, 17.40387725830078, 17.87090492248535, 18.28942108154297, 18.6549015045166, 18.963973999023438, 19.213626861572266, 19.402172088623047, 19.5292911529541, 19.595983505249023, 19.604461669921875, 19.557987213134766, 19.460660934448242, 19.317201614379883, 19.13271141052246, 18.912460327148438, 18.661691665649414, 18.385461807250977, 18.08852195739746, 17.775232315063477, 17.44951057434082, 17.114809036254883, 16.774126052856445, 16.430023193359375, 16.08465576171875, 15.739821434020996, 15.396995544433594, 15.057380676269531, 14.72194766998291, 14.391471862792969, 14.066569328308105, 13.747724533081055, 13.435319900512695, 13.12965202331543, 12.830955505371094, 12.539411544799805, 12.25516414642334, 11.978327751159668, 11.708998680114746, 11.447256088256836, 11.193172454833984, 10.946818351745605, 10.708261489868164, 10.477574348449707, 10.254837036132812, 10.034626007080078, 9.816718101501465, 9.601027488708496, 9.387572288513184, 9.176441192626953, 8.967771530151367, 8.761727333068848, 8.55848503112793, 8.358219146728516, 8.161096572875977, 7.9672698974609375, 7.776872634887695, 7.590019226074219, 7.406804084777832, 7.227301597595215, 7.051567554473877, 6.879642009735107, 6.711548328399658, 6.547297954559326, 6.3868889808654785, 6.230311870574951, 6.077547550201416, 5.928570747375488, 5.783351421356201, 5.641855716705322, 5.504045486450195, 5.369881629943848, 5.239324569702148, 5.112332820892334, 4.988867282867432, 4.8688883781433105, 4.752358913421631, 4.639243125915527, 4.5295090675354, 4.423127174377441, 4.320071697235107, 4.2203216552734375, 4.1238603591918945, 4.03067684173584, 3.940765857696533, 3.8541290760040283, 3.770775079727173, 3.690720796585083, 3.6139919757843018, 3.5406246185302734, 3.4706647396087646, 3.4041712284088135, 3.3412153720855713, 3.281883478164673, 3.2262778282165527, 3.1745188236236572, 3.12674617767334, 3.0831215381622314, 3.0438308715820312, 3.0090863704681396, 2.979130268096924, 2.954237461090088, 2.9347188472747803, 2.9209253787994385, 2.913252353668213, 2.9121434688568115, 2.9180965423583984, 2.931668519973755, 2.9534809589385986, 2.9842262268066406, 3.024674892425537, 3.07568097114563, 3.1381900310516357, 3.2132458686828613, 3.3019964694976807, 3.4057016372680664, 3.5257375240325928, 3.663601875305176, 3.8209152221679688, 3.999422550201416, 4.20098876953125, 4.427591800689697, 4.681307792663574, 4.964293003082275, 5.278752326965332, 5.626902103424072, 6.010915756225586, 6.432860374450684, 6.894613265991211, 7.397765159606934, 7.943502426147461, 8.532475471496582, 9.164650917053223, 9.839151382446289, 10.554096221923828, 11.306438446044922, 12.091830253601074, 12.904512405395508, 13.737255096435547, 14.58137321472168, 15.426817893981934, 16.262372970581055, 17.075952529907227, 17.855009078979492, 18.587017059326172, 19.260019302368164, 19.86203956604004, 20.38272476196289, 20.813913345336914, 21.150070190429688, 21.388547897338867, 21.529645919799805, 21.576454162597656, 21.534528732299805, 21.411413192749023, 21.216073989868164, 20.95831298828125, 20.64822006225586, 20.29567527770996, 19.909975051879883, 19.499557495117188, 19.071847915649414, 18.633180618286133, 18.18882179260254, 17.74302864074707, 17.299152374267578, 16.85976219177246, 16.4267635345459, 16.001523971557617, 15.584980010986328, 15.177734375, 14.780136108398438, 14.392343521118164, 14.014381408691406, 13.646178245544434, 13.287598609924316, 12.93846607208252, 12.598579406738281, 12.26772403717041, 11.945683479309082, 11.632238388061523, 11.327174186706543, 11.03028392791748, 10.74136734008789, 10.460229873657227, 10.186687469482422, 9.920563697814941, 9.661687850952148, 9.40989875793457, 9.165040969848633, 8.926968574523926, 8.695542335510254, 8.470629692077637, 8.252106666564941, 8.03985595703125, 7.833769798278809, 7.633748531341553, 7.43970251083374, 7.25154972076416, 7.069221019744873, 6.8926568031311035, 6.721810340881348, 6.556647777557373, 6.397150039672852, 6.243313312530518, 6.095151901245117, 5.95269775390625, 5.816005229949951, 5.685150623321533, 5.560237407684326, 5.4413957595825195, 5.328788757324219, 5.222613334655762, 5.123106956481934, 5.030549049377441, 4.945267677307129, 4.867644786834717, 4.798121929168701, 4.737205505371094, 4.685476303100586, 4.643595218658447, 4.612313270568848, 4.592478275299072, 4.585046768188477, 4.591092109680176, 4.611813545227051, 4.648549556732178, 4.702783584594727, 4.776154518127441, 4.870462894439697, 4.98767614364624, 5.129929065704346, 5.299520015716553, 5.498901844024658, 5.730663776397705, 5.997501373291016, 6.302176475524902, 6.647459983825684, 7.036054611206055, 7.470499515533447, 7.953047275543213, 8.485518455505371, 9.06912899017334, 9.704292297363281, 10.390403747558594, 11.1256103515625, 11.906585693359375, 12.728321075439453, 13.583953857421875, 14.464672088623047, 15.359701156616211, 16.256431579589844, 17.140674591064453, 17.997095108032227, 18.809776306152344, 19.562936782836914, 20.241718292236328, 20.832998275756836, 21.32613754272461, 21.713594436645508, 21.9913272857666, 22.158926010131836, 22.219493865966797, 22.17924690246582, 22.046939849853516, 21.833145141601562, 21.54950714111328, 21.20801544189453, 20.820384979248047, 20.39756965637207, 19.949419021606445, 19.48448371887207, 19.00995445251465, 18.531686782836914, 18.054306030273438, 17.58134651184082, 17.11541748046875, 16.658357620239258, 16.211400985717773, 15.775304794311523, 15.350470542907715, 14.937039375305176, 14.534966468811035, 14.144082069396973, 13.764138221740723, 13.394838333129883, 13.03586196899414, 12.686882019042969, 12.34757137298584, 12.01761531829834, 11.696708679199219, 11.384560585021973, 11.080897331237793, 10.785457611083984, 10.497993469238281, 10.218271255493164, 9.946064949035645, 9.681163787841797, 9.423360824584961, 9.172459602355957, 8.928271293640137, 8.690614700317383, 8.459314346313477, 8.234199523925781, 8.015107154846191, 7.801878929138184, 7.594359397888184, 7.392399311065674, 7.195854187011719, 7.004582405090332, 6.818447113037109, 6.6373162269592285, 6.461060047149658, 6.289553642272949, 6.122675895690918, 5.960252285003662, 5.80216121673584, 5.648284912109375, 5.498509407043457, 5.352725505828857, 5.2108259201049805, 5.0727081298828125, 4.938271999359131, 4.80742073059082, 4.680060386657715, 4.556098937988281, 4.435448169708252, 4.318021774291992, 4.203735828399658, 4.092508792877197, 3.9842617511749268, 3.878917932510376, 3.776402473449707, 3.676643133163452, 3.5795695781707764, 3.4851133823394775, 3.3932085037231445, 3.303790330886841, 3.216797351837158, 3.1321685314178467, 3.0498464107513428, 2.969774007797241, 2.891897201538086, 2.8161637783050537, 2.742522716522217, 2.670926094055176, 2.6013269424438477, 2.5336809158325195, 2.4679455757141113, 2.4040801525115967, 2.3420467376708984, 2.2818093299865723, 2.2233338356018066, 2.1665890216827393, 2.1115458011627197, 2.058178424835205, 2.006463050842285, 1.9563792943954468, 1.9079097509384155, 1.861040472984314, 1.8157612085342407, 1.7720656394958496, 1.7299518585205078, 1.689422607421875, 1.6504857540130615, 1.6131551265716553, 1.5774505138397217, 1.5433990955352783, 1.5110355615615845, 1.480403184890747, 1.4515552520751953, 1.4245554208755493, 1.399479627609253, 1.376417636871338, 1.3554739952087402, 1.33677077293396, 1.3204492330551147, 1.3066723346710205, 1.2956279516220093, 1.2875311374664307, 1.2826288938522339, 1.281203269958496, 1.2835763692855835, 1.2901153564453125, 1.3012385368347168, 1.317421793937683, 1.3392058610916138, 1.3672044277191162, 1.402113914489746, 1.4447228908538818, 1.4959237575531006, 1.556725263595581, 1.628265142440796, 1.7118253707885742, 1.8088473081588745, 1.920947790145874, 2.0499355792999268, 2.197828531265259, 2.366868734359741, 2.559537410736084, 2.778566598892212, 3.0269455909729004, 3.307921886444092, 3.624992847442627, 3.981884479522705, 4.382513999938965, 4.830931663513184, 5.331235885620117, 5.887457370758057, 6.50340461730957, 7.182467460632324, 7.927371978759766, 8.73989200592041, 9.62050724029541, 10.568037033081055, 11.579240798950195, 12.647491455078125, 13.763079643249512, 14.912983894348145, 16.0808162689209, 17.24702262878418, 18.389379501342773, 19.483823776245117, 20.505590438842773, 21.430625915527344, 22.237123489379883, 22.905603408813477, 23.421669006347656, 23.777124404907227, 23.97051429748535, 24.00705337524414, 23.897924423217773, 23.65907859802246, 23.309715270996094, 22.870668411254883, 22.36288070678711, 21.8061580657959, 21.218250274658203, 20.61431121826172, 20.00668716430664, 19.40496063232422, 18.81618309020996, 18.245222091674805, 17.695138931274414, 17.16756820678711, 16.663074493408203, 16.18144416809082, 15.721942901611328, 15.283499717712402, 14.864862442016602, 14.464703559875488, 14.081693649291992, 13.714554786682129, 13.362089157104492, 13.02319622039795, 12.696880340576172, 12.382248878479004, 12.078506469726562, 11.784954071044922, 11.500972747802734, 11.226018905639648, 10.959615707397461, 10.701342582702637, 10.45082950592041, 10.207748413085938, 9.971808433532715, 9.742749214172363, 9.520339012145996, 9.304367065429688, 9.09464168548584, 8.890989303588867, 8.693248748779297, 8.501274108886719, 8.314927101135254, 8.134079933166504, 7.958611011505127, 7.788407325744629, 7.623362064361572, 7.463373184204102, 7.308342456817627, 7.1563239097595215, 7.007151126861572, 6.860712051391602, 6.716935634613037, 6.575782299041748, 6.4372382164001465, 6.301304340362549, 6.167994499206543, 6.037330150604248, 5.909336566925049, 5.784041404724121, 5.661472797393799, 5.541658878326416, 5.424625396728516, 5.310398101806641, 5.198999404907227, 5.090452194213867, 4.984776496887207, 4.881992340087891, 4.7821197509765625, 4.685179233551025, 4.591190814971924, 4.500176906585693, 4.412162780761719, 4.327175140380859, 4.245244026184082, 4.166405200958252, 4.090697765350342, 4.018167018890381, 3.9488649368286133, 3.882850408554077, 3.820190668106079, 3.7609620094299316, 3.7052512168884277, 3.653156280517578, 3.6047873497009277, 3.5602688789367676, 3.519739866256714, 3.483356237411499, 3.4512925148010254, 3.4237422943115234, 3.400921583175659, 3.3830697536468506, 3.370452404022217, 3.3633627891540527, 3.3621251583099365, 3.3670966625213623, 3.378669500350952, 3.397274971008301, 3.4233856201171875, 3.457517385482788, 3.5002336502075195, 3.552147150039673, 3.6139228343963623, 3.6862804889678955, 3.76999568939209, 3.8659017086029053, 3.97489070892334, 4.097911357879639, 4.235968589782715, 4.390119552612305, 4.561467170715332, 4.751153945922852, 4.960348606109619, 5.190232276916504, 5.441980361938477, 5.716736793518066, 6.015588760375977, 6.339529037475586, 6.68941593170166, 7.065928936004639, 7.469512462615967, 7.900321006774902, 8.358155250549316, 8.842394828796387, 9.351937294006348, 9.8851318359375, 10.439724922180176, 11.012819290161133, 11.60084056854248, 12.199540138244629, 12.804012298583984, 13.408753395080566, 14.007752418518066, 14.594614028930664, 15.162726402282715, 15.705445289611816, 16.216312408447266, 16.689271926879883, 17.11888885498047, 17.41895866394043, 17.584535598754883, 17.618175506591797, 17.528932571411133, 17.330894470214844, 17.04149055480957, 16.679746627807617, 16.264724731445312, 15.814257621765137, 15.344085693359375, 14.867358207702637, 14.3944730758667, 13.933175086975098, 13.4888277053833, 13.064774513244629, 12.662734985351562, 12.283186912536621, 11.925711631774902, 11.589282035827637, 11.272500038146973, 10.973774909973145, 10.691455841064453, 10.42392635345459, 10.169663429260254, 9.927275657653809, 9.695521354675293, 9.473310470581055, 9.259705543518066, 9.053906440734863, 8.855244636535645, 8.663162231445312, 8.477201461791992, 8.296990394592285, 8.12222957611084, 7.952680587768555, 7.788155555725098, 7.628510475158691, 7.473635673522949, 7.323452472686768, 7.177906513214111, 7.03696346282959, 6.900609970092773, 6.768846035003662, 6.641688346862793, 6.519166469573975, 6.4013237953186035, 6.288216590881348, 6.179914474487305, 6.076500415802002, 5.9780731201171875, 5.8847455978393555, 5.7966485023498535, 5.713929653167725, 5.636756896972656, 5.565320014953613, 5.499830722808838, 5.440526962280273, 5.387673854827881, 5.341566562652588, 5.302532196044922, 5.270933628082275, 5.247171878814697, 5.231688499450684, 5.224969387054443, 5.227548599243164, 5.240009784698486, 5.262989521026611, 5.297181606292725, 5.343338489532471, 5.402273178100586, 5.474862098693848, 5.562044620513916, 5.664821147918701, 5.784254550933838, 5.9214630126953125, 6.077616214752197, 6.25392484664917, 6.4516282081604, 6.67197847366333, 6.916219234466553, 7.185559272766113, 7.481140613555908, 7.803997993469238, 8.155014991760254, 8.534872055053711, 8.943984985351562, 9.382441520690918, 9.849929809570312, 10.345667839050293, 10.868328094482422, 11.415972709655762, 11.985992431640625, 12.575060844421387, 13.179112434387207, 13.793342590332031, 14.412242889404297, 15.02967643737793, 15.63899040222168, 16.233165740966797, 16.80501937866211, 17.347412109375, 17.852548599243164, 18.31310272216797, 18.722522735595703, 19.075300216674805, 19.367204666137695, 19.595447540283203, 19.758758544921875, 19.857397079467773, 19.893051147460938, 19.86869239807129, 19.78835105895996, 19.65687370300293, 19.479658126831055, 19.26238441467285, 19.01079559326172, 18.730487823486328, 18.426761627197266, 18.104503631591797, 17.768117904663086, 17.42149543762207, 17.068004608154297, 16.710521697998047, 16.35145378112793, 15.992793083190918, 15.636168479919434, 15.282889366149902, 14.933998107910156, 14.590315818786621, 14.252481460571289, 13.920988082885742, 13.596209526062012, 13.278426170349121, 12.967849731445312, 12.664631843566895, 12.368886947631836, 12.080695152282715, 11.800114631652832, 11.527189254760742, 11.261954307556152, 11.004437446594238, 10.754666328430176, 10.512673377990723, 10.278493881225586, 10.05217170715332, 9.833761215209961, 9.623332023620605, 9.420967102050781, 9.226766586303711, 9.040854454040527, 8.863374710083008, 8.694499015808105, 8.53442668914795, 8.383389472961426, 8.241654396057129, 8.109524726867676, 7.987348556518555, 7.875517845153809, 7.774474620819092, 7.684712886810303, 7.606785774230957, 7.541306495666504, 7.488953113555908, 7.450472354888916, 7.426682949066162, 7.418476104736328, 7.426819801330566, 7.452756881713867, 7.497405052185059, 7.561951160430908, 7.647647857666016, 7.755803108215332, 7.887765407562256, 8.044907569885254, 8.228602409362793, 8.440191268920898, 8.680949211120605, 8.95203685760498, 9.254448890686035, 9.588950157165527, 9.95600414276123, 10.355697631835938, 10.787652015686035, 11.250936508178711, 11.74398422241211, 12.264503479003906, 12.80941390991211, 13.374789237976074, 13.955836296081543, 14.54690170288086, 15.141528129577637, 15.732549667358398, 16.3122501373291, 16.872562408447266, 17.405315399169922, 17.902515411376953, 18.356651306152344, 18.760990142822266, 19.109844207763672, 19.398818969726562, 19.624954223632812, 19.78683090209961, 19.88455581665039, 19.919689178466797, 19.895084381103516, 19.814672470092773, 19.682546615600586, 19.50347328186035, 19.282665252685547, 19.025548934936523, 18.737567901611328, 18.423995971679688, 18.089815139770508, 17.73961067199707, 17.377504348754883, 17.007139205932617, 16.63166618347168, 16.253761291503906, 15.8756685256958, 15.49923038482666, 15.12593936920166, 14.756982803344727, 14.393287658691406, 14.035563468933105, 13.68433952331543, 13.34000015258789, 13.002809524536133, 12.672937393188477, 12.350480079650879, 12.03547477722168, 11.727913856506348, 11.427756309509277, 11.134932518005371, 10.849357604980469, 10.570927619934082, 10.299530982971191, 10.035048484802246, 9.777355194091797, 9.526323318481445, 9.28182315826416, 9.04372501373291, 8.811898231506348, 8.586214065551758, 8.366544723510742, 8.152762413024902, 7.944743633270264, 7.74236536026001, 7.54550838470459, 7.354054927825928, 7.1678900718688965, 6.98690128326416, 6.810979843139648, 6.640019416809082, 6.473916530609131, 6.312570571899414, 6.155884265899658, 6.003763198852539, 5.85611629486084, 5.712855339050293, 5.57389497756958, 5.43915319442749, 5.30855131149292, 5.182013034820557, 5.059464931488037, 4.940837860107422, 4.826064109802246, 4.715079307556152, 4.607821941375732, 4.504233360290527, 4.404257774353027, 4.307840824127197, 4.214932441711426, 4.12548303604126, 4.039446830749512, 3.9567792415618896, 3.8774378299713135, 3.801382303237915, 3.728573799133301, 3.6589748859405518, 3.5925495624542236, 3.5292630195617676, 3.469081163406372, 3.411970376968384, 3.357897996902466, 3.306830406188965, 3.258735179901123, 3.213578224182129, 3.17069149017334, 3.1300203800201416, 3.0915277004241943, 3.055192470550537, 3.0210070610046387, 2.9889771938323975, 2.9591195583343506, 2.9314615726470947, 2.906041145324707, 2.8829054832458496, 2.8621115684509277, 2.8437254428863525, 2.827822208404541, 2.8144869804382324, 2.80381441116333, 2.7959089279174805, 2.7908852100372314, 2.7888693809509277, 2.789998769760132, 2.7944223880767822, 2.802302360534668, 2.813814163208008, 2.8291473388671875, 2.8485066890716553, 2.8721120357513428, 2.900200366973877, 2.9330263137817383, 2.9708621501922607, 3.0139992237091064, 3.062748908996582, 3.1174423694610596, 3.178431749343872, 3.2460906505584717, 3.3208134174346924, 3.403015613555908, 3.4931328296661377, 3.5916213989257812, 3.6989552974700928, 3.815624713897705, 3.942134380340576, 4.078998565673828, 4.226738452911377, 4.385876178741455, 4.556927680969238, 4.740396976470947, 4.936764717102051, 5.146480560302734, 5.369948863983154, 5.607515811920166, 5.859455108642578, 6.125951766967773, 6.4070820808410645, 6.7027974128723145, 7.012903213500977, 7.337038516998291, 7.674659252166748, 8.025017738342285, 8.387147903442383, 8.759849548339844, 9.141684532165527, 9.530969619750977, 9.92577838897705, 10.323954582214355, 10.723128318786621, 11.120745658874512, 11.51409912109375, 11.90038013458252, 12.276724815368652, 12.640274047851562, 12.988237380981445, 13.31795597076416, 13.626967430114746, 13.91306209564209, 14.174342155456543, 14.409258842468262, 14.616646766662598, 14.795745849609375, 14.946200370788574, 15.068058967590332, 15.161746978759766, 15.22803783416748, 15.268013000488281, 15.283016204833984, 15.2746000289917, 15.24448013305664, 15.194480895996094, 15.126492500305176, 15.042427062988281, 14.944186210632324, 14.83362865447998, 14.71254825592041, 14.582656860351562, 14.445575714111328, 14.302824020385742, 14.15582275390625, 14.005891799926758, 13.854255676269531, 13.702051162719727, 13.550332069396973, 13.400077819824219, 13.252204895019531, 13.107337951660156, 12.966053009033203, 12.828890800476074, 12.69613265991211, 12.568024635314941, 12.444780349731445, 12.326581001281738, 12.213581085205078, 12.10590648651123, 12.003657341003418, 11.906907081604004, 11.815705299377441, 11.730079650878906, 11.650029182434082, 11.57553482055664, 11.506549835205078, 11.443005561828613, 11.384808540344238, 11.331843376159668, 11.283967018127441, 11.241015434265137, 11.202798843383789, 11.16910171508789, 11.139688491821289, 11.114294052124023, 11.092635154724121, 11.074402809143066, 11.059267044067383, 11.04687786102295, 11.036867141723633, 11.028848648071289, 11.022422790527344, 11.017176628112793, 11.012688636779785, 11.008530616760254, 11.00426959991455, 10.999476432800293, 10.993721008300781, 10.98658561706543, 10.977660179138184, 10.966550827026367, 10.952881813049316, 10.936300277709961, 10.916475296020508, 10.893108367919922, 10.865925788879395, 10.834691047668457, 10.799200057983398, 10.759282112121582, 10.714805603027344, 10.665672302246094, 10.611823081970215, 10.553231239318848, 10.48990535736084, 10.421886444091797, 10.349247932434082, 10.272088050842285, 10.190535545349121, 10.10473918914795, 10.014871597290039, 9.921120643615723, 9.823690414428711, 9.722799301147461, 9.618673324584961, 9.511547088623047, 9.401658058166504, 9.289249420166016, 9.174561500549316, 9.05783462524414, 8.939305305480957, 8.819208145141602, 8.69776725769043, 8.571085929870605, 8.439717292785645, 8.304280281066895, 8.165427207946777, 8.02381706237793, 7.880097389221191, 7.734885215759277, 7.588758945465088, 7.442251682281494, 7.295848846435547, 7.149985313415527, 7.0050482749938965, 6.8613786697387695, 6.719273567199707, 6.578991889953613, 6.440755844116211, 6.304756164550781, 6.1711554527282715, 6.040092468261719, 5.911684989929199, 5.7860331535339355, 5.66322135925293, 5.5433220863342285, 5.426397800445557, 5.312502861022949, 5.201685905456543, 5.093989849090576, 4.989455699920654, 4.88812255859375, 4.790030002593994, 4.695217132568359, 4.603726387023926, 4.515603065490723, 4.430896759033203, 4.3496623039245605, 4.271961688995361, 4.197864055633545, 4.127448081970215, 4.060801982879639, 3.998025894165039, 3.939232349395752, 3.8845481872558594, 3.8341164588928223, 3.788097858428955, 3.7466723918914795, 3.710041046142578, 3.678428888320923, 3.6520862579345703, 3.6312925815582275, 3.61635684967041, 3.6076228618621826, 3.6054704189300537, 3.610318899154663, 3.6226305961608887, 3.6429147720336914, 3.671729564666748, 3.709686756134033, 3.7574548721313477, 3.8157618045806885, 3.8853988647460938, 3.9672224521636963, 4.0621562004089355, 4.1711931228637695, 4.295392990112305, 4.435883522033691, 4.593855857849121, 4.770557403564453, 4.967284202575684, 5.185368537902832, 5.426161289215088, 5.69101095199585, 5.981234550476074, 6.298086643218994, 6.642714977264404, 7.016113758087158, 7.419065952301025, 7.852081775665283, 8.315324783325195, 8.808537483215332, 9.330962181091309, 9.881258964538574, 10.457433700561523, 11.056767463684082, 11.67577075958252, 12.310151100158691, 12.954815864562988, 13.603914260864258, 14.250910758972168, 14.888714790344238, 15.509849548339844, 16.106666564941406, 16.671585083007812, 17.197368621826172, 17.677391052246094, 18.10589599609375, 18.47821617126465, 18.79095458984375, 19.042083740234375, 19.230987548828125, 19.35841178894043, 19.426361083984375, 19.43715476989746, 19.394075393676758, 19.30118751525879, 19.163116455078125, 18.984840393066406, 18.77147674560547, 18.528108596801758, 18.2596435546875, 17.97068214416504, 17.665456771850586, 17.3477725982666, 17.020999908447266, 16.688066482543945, 16.351482391357422, 16.013376235961914, 15.675520896911621, 15.339391708374023, 15.00619125366211, 14.676901817321777, 14.352312088012695, 14.03305721282959, 13.719643592834473, 13.412474632263184, 13.111870765686035, 12.818087577819824, 12.531329154968262, 12.251763343811035, 11.979525566101074, 11.71473217010498, 11.457486152648926, 11.207880020141602, 10.966002464294434, 10.73194408416748, 10.505797386169434, 10.287664413452148, 10.077655792236328, 9.875895500183105, 9.682524681091309, 9.497700691223145, 9.321606636047363, 9.154446601867676, 8.996455192565918, 8.847894668579102, 8.709063529968262, 8.58029556274414, 8.461966514587402, 8.354493141174316, 8.258341789245605, 8.174026489257812, 8.102115631103516, 8.043235778808594, 7.998067855834961, 7.967357158660889, 7.951910495758057, 7.952597141265869, 7.970347881317139, 8.006153106689453, 8.061059951782227, 8.136163711547852, 8.232596397399902, 8.351520538330078, 8.49410343170166, 8.66150188446045, 8.854830741882324, 9.075132369995117, 9.323336601257324, 9.600212097167969, 9.906316757202148, 10.241935729980469]}, {"name": "y", "type": "scatter", "y": [5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 9.5, 9.399999618530273, 9.300000190734863, 9.199999809265137, 9.100000381469727, 9.0, 8.899999618530273, 8.800000190734863, 8.699999809265137, 8.600000381469727, 8.5, 8.399999618530273, 8.300000190734863, 8.199999809265137, 8.100000381469727, 8.0, 7.900000095367432, 7.800000190734863, 7.699999809265137, 7.599999904632568, 7.5, 7.400000095367432, 7.300000190734863, 7.199999809265137, 7.099999904632568, 7.0, 6.900000095367432, 6.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 9.5, 9.399999618530273, 9.300000190734863, 9.199999809265137, 9.100000381469727, 9.0, 8.899999618530273, 8.800000190734863, 8.699999809265137, 8.600000381469727, 8.5, 8.399999618530273, 8.300000190734863, 8.199999809265137, 8.100000381469727, 8.0, 7.900000095367432, 7.800000190734863, 7.699999809265137, 7.599999904632568, 7.5, 7.400000095367432, 7.300000190734863, 7.199999809265137, 7.099999904632568, 7.0, 6.900000095367432, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 14.899999618530273, 14.800000190734863, 14.699999809265137, 14.600000381469727, 14.5, 14.399999618530273, 14.300000190734863, 14.199999809265137, 14.100000381469727, 14.0, 13.899999618530273, 13.800000190734863, 13.699999809265137, 13.600000381469727, 13.5, 13.399999618530273, 13.300000190734863, 13.199999809265137, 13.100000381469727, 13.0, 12.899999618530273, 12.800000190734863, 12.699999809265137, 12.600000381469727, 12.5, 12.399999618530273, 12.300000190734863, 12.199999809265137, 12.100000381469727, 12.0, 11.899999618530273, 11.800000190734863, 11.699999809265137, 11.600000381469727, 11.5, 11.399999618530273, 11.300000190734863, 11.199999809265137, 11.100000381469727, 11.0, 10.899999618530273, 10.800000190734863, 10.699999809265137, 10.600000381469727, 10.5, 10.399999618530273, 10.300000190734863, 10.199999809265137, 10.100000381469727, 10.0, 9.899999618530273, 9.800000190734863, 9.699999809265137, 9.600000381469727, 9.5, 9.399999618530273, 9.300000190734863, 9.199999809265137, 9.100000381469727, 9.0, 8.899999618530273, 8.800000190734863, 8.699999809265137, 8.600000381469727, 8.5, 8.399999618530273, 8.300000190734863, 8.199999809265137, 8.100000381469727, 5.0, 5.099999904632568, 5.199999809265137, 5.300000190734863, 5.400000095367432, 5.5, 5.599999904632568, 5.699999809265137, 5.800000190734863, 5.900000095367432, 6.0, 6.099999904632568, 6.199999809265137, 6.300000190734863, 6.400000095367432, 6.5, 6.599999904632568, 6.699999809265137, 6.800000190734863, 6.900000095367432, 7.0, 7.099999904632568, 7.199999809265137, 7.300000190734863, 7.400000095367432, 7.5, 7.599999904632568, 7.699999809265137, 7.800000190734863, 7.900000095367432, 8.0, 8.100000381469727, 8.199999809265137, 8.300000190734863, 8.399999618530273, 8.5, 8.600000381469727, 8.699999809265137, 8.800000190734863, 8.899999618530273, 9.0, 9.100000381469727, 9.199999809265137, 9.300000190734863, 9.399999618530273, 9.5, 9.600000381469727, 9.699999809265137, 9.800000190734863, 9.899999618530273, 10.0, 10.100000381469727, 10.199999809265137, 10.300000190734863, 10.399999618530273, 10.5, 10.600000381469727, 10.699999809265137, 10.800000190734863, 10.899999618530273, 11.0, 11.100000381469727, 11.199999809265137, 11.300000190734863, 11.399999618530273, 11.5, 11.600000381469727, 11.699999809265137, 11.800000190734863, 11.899999618530273, 12.0, 12.100000381469727, 12.199999809265137, 12.300000190734863, 12.399999618530273, 12.5, 12.600000381469727, 12.699999809265137, 12.800000190734863, 12.899999618530273, 13.0, 13.100000381469727, 13.199999809265137, 13.300000190734863, 13.399999618530273, 13.5, 13.600000381469727, 13.699999809265137, 13.800000190734863, 13.899999618530273, 14.0, 14.100000381469727, 14.199999809265137, 14.300000190734863, 14.399999618530273, 14.5, 14.600000381469727, 14.699999809265137, 14.800000190734863, 14.899999618530273, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0]}],                        {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Trajectory of the Lorenz solution, projected along the z-axis"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('4b11ae47-19d3-4899-8e01-08ded158e132');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Resampling the time series
--------------------------

It is important to find the correct time scale at which key signals take
place. Here we propose one possible resampling period: *10h*. Recall
that the unit time is *1h*. The resampler method is used to perform the
resampling.

.. code:: ipython3

    period = 10
    periodicSampler = Resampler(period=period)
    
    X_sampled, y_sampled = periodicSampler.fit_transform_resample(X, y)

.. code:: ipython3

    fig = px.line(title='Trajectory of the Lorenz solution, projected along the z-axis and resampled every 10h')
    fig.add_scatter(y=X_sampled.flatten(), name='X_sampled')
    fig.add_scatter(y=y_sampled, name='y_sampled')
    fig.show()



.. raw:: html

    <div>                            <div id="d5380b88-4eda-48ca-bf86-ab0f79aa83dc" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("d5380b88-4eda-48ca-bf86-ab0f79aa83dc")) {                    Plotly.newPlot(                        "d5380b88-4eda-48ca-bf86-ab0f79aa83dc",                        [{"name": "X_sampled", "type": "scatter", "y": [10.0, 9.880752563476562, 10.774194717407227, 9.310019493103027, 7.257726669311523, 5.550174236297607, 4.236861705780029, 3.2340033054351807, 2.4685113430023193, 1.8843207359313965, 1.4386281967163086, 1.09886634349823, 0.8404794931411743, 0.6455944180488586, 0.5032125115394592, 0.413541704416275, 0.4067001938819885, 0.6162614226341248, 1.5636451244354248, 5.103882312774658, 14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867, 7.48189115524292, 6.479306697845459, 6.854121208190918, 9.86506462097168, 16.18271255493164, 20.693172454833984, 18.73451805114746, 14.760367393493652, 11.364433288574219, 8.7335786819458, 6.728298664093018, 5.223234176635742, 4.110780715942383, 3.282271146774292, 2.7052900791168213, 2.4036595821380615, 2.5079102516174316, 3.202155113220215, 4.251739025115967, 5.609485149383545, 7.216982364654541, 8.871070861816406, 10.258978843688965, 11.169272422790527, 11.664118766784668, 12.023893356323242, 12.590555191040039, 13.621294975280762, 14.842605590820312, 15.496397972106934, 15.18989372253418, 14.244672775268555, 13.228567123413086, 12.582527160644531, 12.5833158493042, 13.307403564453125, 14.455156326293945, 15.31961727142334, 15.324563026428223, 14.567307472229004, 13.564197540283203, 12.793840408325195, 12.57542610168457, 13.05505084991455, 14.07629108428955, 15.063932418823242, 15.357551574707031, 14.829564094543457, 12.612897872924805, 9.60682201385498, 7.30527925491333, 5.5909905433654785, 4.301223278045654, 3.3477299213409424, 2.7020702362060547, 2.4528980255126953, 3.036674737930298, 5.922054767608643, 13.669175148010254, 15.741020202636719, 11.736970901489258, 8.917984962463379, 7.068406581878662, 5.777517318725586, 5.022008895874023, 5.022371768951416, 6.435998916625977, 10.485421180725098, 17.065458297729492, 20.57697105407715, 18.081132888793945, 14.256850242614746, 11.097949028015137, 8.716547966003418, 7.095892429351807, 6.428525924682617, 7.434159278869629, 11.516939163208008, 18.137123107910156, 20.381776809692383, 16.77204132080078, 12.772895812988281, 9.722888946533203, 7.422309875488281, 5.672788619995117, 4.339235305786133, 3.325570583343506, 2.5631353855133057, 2.0115110874176025, 1.6782469749450684, 1.6996207237243652, 2.632023811340332, 6.286675453186035, 15.691393852233887, 24.0217227935791, 20.570253372192383, 15.375616073608398, 11.738700866699219, 9.103957176208496, 7.189553260803223, 5.885937213897705, 5.173672676086426, 4.955836772918701, 4.864617824554443, 4.939504623413086, 5.345020294189453, 6.303348541259766, 8.036109924316406, 10.50344181060791, 12.998895645141602, 14.436258316040039, 14.534979820251465, 13.975706100463867, 13.379403114318848, 13.075737953186035, 13.228426933288574, 13.797710418701172, 14.490015983581543, 14.880401611328125, 14.738289833068848, 14.193717956542969, 13.569287300109863, 13.167555809020996, 13.17829704284668, 13.621578216552734, 14.154986381530762, 14.013508796691895, 12.00007152557373, 9.18571662902832, 6.985784530639648, 5.333123207092285, 4.08131742477417, 3.13779616355896, 2.4482712745666504, 2.0142955780029297, 1.9887280464172363, 3.041350841522217, 7.375819683074951, 17.611530303955078, 24.14252471923828, 19.631349563598633, 14.697957038879395, 11.257065773010254, 8.686368942260742, 6.689769744873047, 5.15323543548584, 3.990213394165039, 3.1415324211120605, 2.602027416229248, 2.4986321926116943, 3.3396100997924805, 6.626110553741455, 14.646973609924316, 22.65271759033203, 20.620529174804688, 15.558791160583496, 11.814583778381348, 9.096705436706543, 7.071575164794922, 5.518078804016113, 4.321174144744873, 3.4323010444641113, 2.836334466934204, 2.5944249629974365, 2.961709976196289, 4.666600704193115, 9.14708137512207, 16.477304458618164, 20.526952743530273, 18.203771591186523, 14.369884490966797, 11.183107376098633, 8.775131225585938, 7.124290943145752, 6.408812522888184, 7.318809986114502, 11.253149032592773, 17.88862419128418, 20.437467575073242, 16.924034118652344, 12.890128135681152, 9.810127258300781, 7.489336967468262, 5.727321147918701, 4.388706207275391, 3.3750035762786865, 2.610436201095581, 2.0407395362854004, 1.6386891603469849, 1.4113255739212036, 1.4409632682800293, 2.0097317695617676, 3.9138307571411133, 8.766448020935059, 16.65705108642578, 20.65085220336914, 18.006250381469727, 14.12304401397705, 10.956222534179688, 8.566047668457031, 6.910210609436035, 6.14066743850708, 6.907512664794922, 10.653786659240723, 13.949995040893555, 11.633843421936035, 8.79044246673584, 6.68988561630249, 5.127269744873047, 3.960143566131592, 3.124302864074707, 2.644627809524536, 2.7798194885253906, 4.5266852378845215, 10.522139549255371, 20.789522171020508, 22.871755599975586, 17.689651489257812, 13.349187850952148, 10.218582153320312, 7.908336639404297, 6.281363487243652, 5.41464900970459, 5.836874485015869, 7.920112609863281, 8.928873062133789, 8.497692108154297, 7.539384365081787, 6.67495584487915, 6.227055549621582, 6.525177955627441, 8.101166725158691, 11.503066062927246, 15.933252334594727, 18.299108505249023, 17.095096588134766, 14.416543006896973, 11.927948951721191, 10.151688575744629, 9.400187492370605, 10.175674438476562, 12.97225570678711, 16.744264602661133, 18.209245681762695, 16.528566360473633, 13.867773056030273, 11.546838760375977, 9.996892929077148, 9.561210632324219, 10.775303840637207, 13.317831039428711, 12.016406059265137, 9.243946075439453, 7.027894973754883, 5.360456943511963, 4.094522953033447, 3.1337010860443115, 2.4135560989379883, 1.904931664466858, 1.6590477228164673, 2.0058014392852783, 4.233810901641846, 11.52518367767334, 22.58885955810547, 22.744531631469727, 17.07865333557129, 12.94926643371582, 10.03945541381836, 7.9876909255981445, 6.795091152191162, 6.865779876708984, 8.903059959411621, 9.865697860717773, 8.916321754455566, 7.458118915557861, 6.161727428436279, 5.048085689544678, 4.175311088562012, 3.6006336212158203, 3.424589157104492, 3.909852981567383, 5.652180194854736, 9.503758430480957, 14.942774772644043, 18.04989242553711, 16.980684280395508, 14.351151466369629, 11.901632308959961, 10.164253234863281, 9.461133003234863, 10.297882080078125, 13.131260871887207, 16.822498321533203, 18.139131546020508, 16.412439346313477, 13.779516220092773, 11.50296401977539, 10.00658130645752, 9.642359733581543, 10.943979263305664, 14.123120307922363, 17.39469337463379, 17.803678512573242, 15.717371940612793, 13.168601989746094, 11.108556747436523, 9.905927658081055, 9.710389137268066, 8.814824104309082, 7.377361297607422, 6.04998779296875, 5.052100658416748, 4.501100540161133, 4.640549182891846, 6.070788860321045, 9.822184562683105, 15.770652770996094, 19.5292911529541, 18.08852195739746, 14.72194766998291, 11.708998680114746, 9.387572288513184, 7.406804084777832, 5.783351421356201, 4.5295090675354, 3.6139919757843018, 3.0438308715820312, 2.9534809589385986, 3.8209152221679688, 6.894613265991211, 13.737255096435547, 20.813913345336914, 20.29567527770996, 16.001523971557617, 12.26772403717041, 9.40989875793457, 7.25154972076416, 5.685150623321533, 4.737205505371094, 4.776154518127441, 7.036054611206055, 13.583953857421875, 21.32613754272461, 20.820384979248047, 16.211400985717773, 12.34757137298584, 9.423360824584961, 7.195854187011719, 5.498509407043457, 4.203735828399658, 3.216797351837158, 2.4679455757141113, 1.9079097509384155, 1.5110355615615845, 1.2956279516220093, 1.402113914489746, 2.366868734359741, 5.887457370758057, 14.912983894348145, 23.777124404907227, 20.61431121826172, 15.283499717712402, 11.784954071044922, 9.304367065429688, 7.463373184204102, 6.037330150604248, 4.881992340087891, 4.018167018890381, 3.483356237411499, 3.397274971008301, 4.097911357879639, 6.339529037475586, 11.012819290161133, 16.689271926879883, 15.814257621765137, 11.589282035827637, 9.053906440734863, 7.323452472686768, 6.076500415802002, 5.341566562652588, 5.343338489532471, 6.67197847366333, 10.345667839050293, 16.233165740966797, 19.857397079467773, 18.104503631591797, 14.590315818786621, 11.527189254760742, 9.226766586303711, 7.774474620819092, 7.497405052185059, 9.254448890686035, 13.955836296081543, 19.109844207763672, 19.282665252685547, 15.8756685256958, 12.350480079650879, 9.526323318481445, 7.354054927825928, 5.712855339050293, 4.504233360290527, 3.6589748859405518, 3.1300203800201416, 2.8437254428863525, 2.813814163208008, 3.178431749343872, 4.226738452911377, 6.4070820808410645, 9.92577838897705, 13.626967430114746, 15.268013000488281, 14.582656860351562, 13.107337951660156, 11.906907081604004, 11.241015434265137, 11.028848648071289, 10.966550827026367, 10.665672302246094, 9.921120643615723, 8.819208145141602, 7.442251682281494, 6.040092468261719, 4.88812255859375, 4.060801982879639, 3.6312925815582275, 3.8157618045806885, 5.185368537902832, 8.808537483215332, 14.888714790344238, 19.230987548828125, 18.2596435546875, 15.00619125366211, 11.979525566101074, 9.682524681091309, 8.258341789245605, 8.061059951782227, 9.906316757202148]}, {"name": "y_sampled", "type": "scatter", "y": [5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.0, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.5, 13.5, 12.5, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 10.699999809265137, 9.699999809265137, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 10.699999809265137, 9.699999809265137, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 14.199999809265137, 13.199999809265137, 12.199999809265137, 11.199999809265137, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 12.699999809265137, 11.699999809265137, 10.699999809265137, 9.699999809265137, 8.699999809265137, 7.699999809265137, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.800000190734863, 6.800000190734863, 7.800000190734863, 8.800000190734863, 9.800000190734863, 10.800000190734863, 11.800000190734863, 12.800000190734863, 13.800000190734863, 14.800000190734863, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.699999809265137, 13.699999809265137, 5.5, 6.5, 7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.0, 14.5, 13.5, 12.5, 11.5, 10.5, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 14.5, 13.5, 12.5, 11.5, 10.5, 9.5, 8.5, 7.5, 5.300000190734863, 6.300000190734863, 7.300000190734863, 8.300000190734863, 9.300000190734863, 10.300000190734863, 11.300000190734863, 12.300000190734863, 13.300000190734863, 14.300000190734863, 15.0, 14.0, 13.0, 12.0, 11.0, 10.0, 9.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0, 15.0]}],                        {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Trajectory of the Lorenz solution, projected along the z-axis and resampled every 10h"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('d5380b88-4eda-48ca-bf86-ab0f79aa83dc');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Takens Embedding
----------------

In order to obtain meaningful topological features from a time series,
we use a *time-delay embedding* technique named after F. Takens who used
it in the 1960s in his foundational work on dynamical systems.

The idea is simple: given a time series :math:`X(t)`, one can extract a
sequence of vectors of the form
:math:`X_i := [(X(t_i)), X(t_i + 2 \tau), ..., X(t_i + M \tau)]`. The
difference between :math:`t_i` and :math:`t_{i-1}` is called *stride*.

:math:`M` and :math:`\tau` are optimized automatically in this example
according to known heuristics implemented in ``giotto-tda`` in the
``takens_embedding_optimal_parameters`` function. They can also be set
by hand if preferred.

.. code:: ipython3

    max_time_delay = 3
    max_embedding_dimension = 10
    stride = 1
    optimal_time_delay, optimal_embedding_dimension = takens_embedding_optimal_parameters(
        X_sampled, max_time_delay, max_embedding_dimension, stride=stride
        )
    
    print(f"Optimal embedding time delay based on mutual information: {optimal_time_delay}")
    print(f"Optimal embedding dimension based on false nearest neighbors: {optimal_embedding_dimension}")


.. parsed-literal::

    Optimal embedding time delay based on mutual information: 3
    Optimal embedding dimension based on false nearest neighbors: 10


Having computed reasonable values for the parameters by looking at the
whole time series, we can now perform the embedding procedure (which
transforms a single time series into a single point cloud) on local
sliding windows over the data. The result of this will be a “time series
of point clouds” with possibly interesting topologies, which we will be
able to feed directly to our homology transformers.

We first construct sliding windows using ``SlidingWindow``
transformer-resampler, and then use the ``TakensEmbedding`` transformer
to perform the embedding in parallel on each window, using the
parameters ``optimal_time_delay`` and ``optimal_embedding_dimension``
found above.

.. code:: ipython3

    window_size = 41
    window_stride = 5
    SW = SlidingWindow(size=window_size, stride=window_stride)
    
    X_windows, y_windows = SW.fit_transform_resample(X_sampled, y_sampled)
    
    TE = TakensEmbedding(time_delay=optimal_time_delay, dimension=optimal_embedding_dimension, stride=stride)
    X_embedded = TE.fit_transform(X_windows)

We can plot the Takens embedding of a specific window either by using
``plot_point_cloud``, or by using the ``plot`` method of
``SlidingWindow``, as shown below.

*Note*: only the first three coordinates are plotted!

.. code:: ipython3

    window_number = 3
    TE.plot(X_embedded, sample=window_number)



.. raw:: html

    <div>                            <div id="1f5ffe70-a86d-49aa-8830-4adc38bab36a" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("1f5ffe70-a86d-49aa-8830-4adc38bab36a")) {                    Plotly.newPlot(                        "1f5ffe70-a86d-49aa-8830-4adc38bab36a",                        [{"marker": {"color": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13], "colorscale": [[0.0, "#440154"], [0.1111111111111111, "#482878"], [0.2222222222222222, "#3e4989"], [0.3333333333333333, "#31688e"], [0.4444444444444444, "#26828e"], [0.5555555555555556, "#1f9e89"], [0.6666666666666666, "#35b779"], [0.7777777777777778, "#6ece58"], [0.8888888888888888, "#b5de2b"], [1.0, "#fde725"]], "opacity": 0.8, "size": 4}, "mode": "markers", "type": "scatter3d", "x": [5.103882312774658, 14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777], "y": [19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867], "z": [10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045]}],                        {"scene": {"xaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "0th"}, "type": "linear"}, "yaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "1st"}, "type": "linear"}, "zaxis": {"exponentformat": "e", "showexponent": "all", "title": {"text": "2nd"}, "type": "linear"}}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('1f5ffe70-a86d-49aa-8830-4adc38bab36a');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


For comparison, here is the portion of time series containing the data
which originates this point cloud. Notice the quasi-periodicity,
corresponding to the loop in the point cloud.

.. code:: ipython3

    embedded_begin, embedded_end = SW.slice_windows(X_windows)[window_number]
    window_indices = np.arange(embedded_begin, embedded_end + optimal_time_delay * (optimal_embedding_dimension - 1))
    fig = px.line(title=f"Resampled Lorenz solution over sliding window {window_number}")
    fig.add_scatter(x=window_indices, y=X_sampled[window_indices], name="X_sampled")
    fig.show()



.. raw:: html

    <div>                            <div id="a79e7960-6fb8-42dc-acd6-a12c3ae5326d" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("a79e7960-6fb8-42dc-acd6-a12c3ae5326d")) {                    Plotly.newPlot(                        "a79e7960-6fb8-42dc-acd6-a12c3ae5326d",                        [{"name": "X_sampled", "type": "scatter", "x": [15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82], "y": [0.413541704416275, 0.4067001938819885, 0.6162614226341248, 1.5636451244354248, 5.103882312774658, 14.98863410949707, 24.83124542236328, 19.75218963623047, 15.319019317626953, 13.157721519470215, 10.593717575073242, 8.285785675048828, 6.472849369049072, 5.140614986419678, 4.313628673553467, 4.2408599853515625, 5.819314479827881, 11.148825645446777, 19.808977127075195, 21.932401657104492, 17.532102584838867, 13.330605506896973, 10.162620544433594, 7.755115032196045, 5.9185099601745605, 4.517035961151123, 3.447882652282715, 2.6329939365386963, 2.0123798847198486, 1.5405652523040771, 1.184604287147522, 0.9232151508331299, 0.7515450716018677, 0.702305257320404, 0.9235610365867615, 1.9513802528381348, 5.485874652862549, 14.582544326782227, 23.905990600585938, 21.142423629760742, 15.784836769104004, 12.039207458496094, 9.355100631713867, 7.48189115524292, 6.479306697845459, 6.854121208190918, 9.86506462097168, 16.18271255493164, 20.693172454833984, 18.73451805114746, 14.760367393493652, 11.364433288574219, 8.7335786819458, 6.728298664093018, 5.223234176635742, 4.110780715942383, 3.282271146774292, 2.7052900791168213, 2.4036595821380615, 2.5079102516174316, 3.202155113220215, 4.251739025115967, 5.609485149383545, 7.216982364654541, 8.871070861816406, 10.258978843688965, 11.169272422790527, 11.664118766784668]}],                        {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Resampled Lorenz solution over sliding window 3"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('a79e7960-6fb8-42dc-acd6-a12c3ae5326d');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Persistence diagram
-------------------

The topological information in the embedding is synthesised via the
persistence diagram. The horizontal axis corresponds to the moment in
which a homological generator is born, while the vertical axis
corresponds to the moments in which a homological generator dies. The
generators of the homology groups (at given rank) are colored
differently.

.. code:: ipython3

    homology_dimensions = (0, 1, 2)
    WA = WeakAlphaPersistence(homology_dimensions=homology_dimensions)
    
    X_diagrams = WA.fit_transform(X_embedded)

We can plot the persistence diagram for the embedding of the same
sliding window as before:

.. code:: ipython3

    WA.plot(X_diagrams, sample=window_number)



.. raw:: html

    <div>                            <div id="d476c5d6-8e9e-4639-901c-6178ff0f8725" class="plotly-graph-div" style="height:500px; width:500px;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("d476c5d6-8e9e-4639-901c-6178ff0f8725")) {                    Plotly.newPlot(                        "d476c5d6-8e9e-4639-901c-6178ff0f8725",                        [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-0.6702337646484375, 34.18192199707031], "y": [-0.6702337646484375, 34.18192199707031]}, {"hoverinfo": "text", "hovertext": ["(0.0, 7.32454252243042)", "(0.0, 9.037557601928711)", "(0.0, 10.516725540161133)", "(0.0, 10.829265594482422)", "(0.0, 10.96535873413086)", "(0.0, 11.142565727233887)", "(0.0, 11.520899772644043)", "(0.0, 11.595913887023926)", "(0.0, 12.204551696777344)", "(0.0, 12.556045532226562)", "(0.0, 12.568832397460938)", "(0.0, 13.35400104522705)", "(0.0, 14.200610160827637)"], "mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [7.32454252243042, 9.037557601928711, 10.516725540161133, 10.829265594482422, 10.96535873413086, 11.142565727233887, 11.520899772644043, 11.595913887023926, 12.204551696777344, 12.556045532226562, 12.568832397460938, 13.35400104522705, 14.200610160827637]}, {"hoverinfo": "text", "hovertext": ["(29.68315887451172, 32.791072845458984)"], "mode": "markers", "name": "H1", "type": "scatter", "x": [29.68315887451172], "y": [32.791072845458984]}, {"hoverinfo": "text", "hovertext": ["(33.088470458984375, 33.511688232421875)"], "mode": "markers", "name": "H2", "type": "scatter", "x": [33.088470458984375], "y": [33.511688232421875]}],                        {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.6702337646484375, 34.18192199707031], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.6702337646484375, 34.18192199707031], "scaleanchor": "x", "scaleratio": 1, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('d476c5d6-8e9e-4639-901c-6178ff0f8725');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Scikit-learn–style pipeline
---------------------------

One of the advantages of ``giotto-tda`` is the compatibility with
``scikit-learn``. It is possible to set up and run a full pipeline such
as the one above in a few lines:

.. code:: ipython3

    # Steps of the Pipeline
    steps = [('sampling', periodicSampler),
             ('window', SW),
             ('embedding', TE),
             ('diagrams', WA)]
    
    # Define the Pipeline
    pipeline = Pipeline(steps)
    
    # Run the pipeline
    X_diagrams = pipeline.fit_transform(X)

The final result is the same as before:

.. code:: ipython3

    pipeline[-1].plot(X_diagrams, sample=window_number)



.. raw:: html

    <div>                            <div id="ac2a025c-bd7a-408a-8e96-73a51612dadc" class="plotly-graph-div" style="height:500px; width:500px;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("ac2a025c-bd7a-408a-8e96-73a51612dadc")) {                    Plotly.newPlot(                        "ac2a025c-bd7a-408a-8e96-73a51612dadc",                        [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-0.6702337646484375, 34.18192199707031], "y": [-0.6702337646484375, 34.18192199707031]}, {"hoverinfo": "text", "hovertext": ["(0.0, 7.32454252243042)", "(0.0, 9.037557601928711)", "(0.0, 10.516725540161133)", "(0.0, 10.829265594482422)", "(0.0, 10.96535873413086)", "(0.0, 11.142565727233887)", "(0.0, 11.520899772644043)", "(0.0, 11.595913887023926)", "(0.0, 12.204551696777344)", "(0.0, 12.556045532226562)", "(0.0, 12.568832397460938)", "(0.0, 13.35400104522705)", "(0.0, 14.200610160827637)"], "mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [7.32454252243042, 9.037557601928711, 10.516725540161133, 10.829265594482422, 10.96535873413086, 11.142565727233887, 11.520899772644043, 11.595913887023926, 12.204551696777344, 12.556045532226562, 12.568832397460938, 13.35400104522705, 14.200610160827637]}, {"hoverinfo": "text", "hovertext": ["(29.68315887451172, 32.791072845458984)"], "mode": "markers", "name": "H1", "type": "scatter", "x": [29.68315887451172], "y": [32.791072845458984]}, {"hoverinfo": "text", "hovertext": ["(33.088470458984375, 33.511688232421875)"], "mode": "markers", "name": "H2", "type": "scatter", "x": [33.088470458984375], "y": [33.511688232421875]}],                        {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.6702337646484375, 34.18192199707031], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.6702337646484375, 34.18192199707031], "scaleanchor": "x", "scaleratio": 1, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('ac2a025c-bd7a-408a-8e96-73a51612dadc');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Rescaling the diagram
---------------------

By default, rescaling a diagram via ``Scaler`` means normalizing points
such that the maximum “bottleneck distance” from the *empty diagram*
(across all homology dimensions) is equal to 1. Notice that this means
the birth and death scales are modified. We can do this as follows:

.. code:: ipython3

    diagramScaler = Scaler()
    
    X_scaled = diagramScaler.fit_transform(X_diagrams)
    
    diagramScaler.plot(X_scaled, sample=window_number)



.. raw:: html

    <div>                            <div id="9a916de2-8e67-46d0-a8b3-087c33717d29" class="plotly-graph-div" style="height:500px; width:500px;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("9a916de2-8e67-46d0-a8b3-087c33717d29")) {                    Plotly.newPlot(                        "9a916de2-8e67-46d0-a8b3-087c33717d29",                        [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-0.0734645757567886, 3.746693363596218], "y": [-0.0734645757567886, 3.746693363596218]}, {"hoverinfo": "text", "hovertext": ["(0.0, 0.8028458687174012)", "(0.0, 0.9906100977343238)", "(0.0, 1.1527422533894305)", "(0.0, 1.1869998866343936)", "(0.0, 1.2019171070058952)", "(0.0, 1.2213408323627917)", "(0.0, 1.262810169788646)", "(0.0, 1.2710324951613166)", "(0.0, 1.3377455150679303)", "(0.0, 1.3762728869557792)", "(0.0, 1.3776744600773532)", "(0.0, 1.4637370917263648)", "(0.0, 1.5565342362301948)"], "mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [0.8028458687174012, 0.9906100977343238, 1.1527422533894305, 1.1869998866343936, 1.2019171070058952, 1.2213408323627917, 1.262810169788646, 1.2710324951613166, 1.3377455150679303, 1.3762728869557792, 1.3776744600773532, 1.4637370917263648, 1.5565342362301948]}, {"hoverinfo": "text", "hovertext": ["(3.2535822407890707, 3.5942418634566935)"], "mode": "markers", "name": "H1", "type": "scatter", "x": [3.2535822407890707], "y": [3.5942418634566935]}, {"hoverinfo": "text", "hovertext": ["(3.626839728054256, 3.6732287878394296)"], "mode": "markers", "name": "H2", "type": "scatter", "x": [3.626839728054256], "y": [3.6732287878394296]}],                        {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.0734645757567886, 3.746693363596218], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.0734645757567886, 3.746693363596218], "scaleanchor": "x", "scaleratio": 1, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('9a916de2-8e67-46d0-a8b3-087c33717d29');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Filtering diagrams
------------------

Filtering a diagram means eliminating the homology generators whose
lifespan is considered too short to be significant. We can use
``Filtering`` as follows:

.. code:: ipython3

    diagramFiltering = Filtering(epsilon=0.1, homology_dimensions=(1, 2))
    
    X_filtered = diagramFiltering.fit_transform(X_scaled)
    
    diagramFiltering.plot(X_filtered, sample=window_number)



.. raw:: html

    <div>                            <div id="34c5be31-89a3-4bfa-987c-a89ac447b95a" class="plotly-graph-div" style="height:500px; width:500px;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("34c5be31-89a3-4bfa-987c-a89ac447b95a")) {                    Plotly.newPlot(                        "34c5be31-89a3-4bfa-987c-a89ac447b95a",                        [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-0.07188483726913387, 3.6661267007258274], "y": [-0.07188483726913387, 3.6661267007258274]}, {"hoverinfo": "text", "hovertext": ["(3.2535822407890707, 3.5942418634566935)"], "mode": "markers", "name": "H1", "type": "scatter", "x": [3.2535822407890707], "y": [3.5942418634566935]}, {"hoverinfo": "text", "hovertext": [], "mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],                        {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.07188483726913387, 3.6661267007258274], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.07188483726913387, 3.6661267007258274], "scaleanchor": "x", "scaleratio": 1, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('34c5be31-89a3-4bfa-987c-a89ac447b95a');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


We can add the steps above to our pipeline:

.. code:: ipython3

    steps_new = [
        ('scaler', diagramScaler),
        ('filtering', diagramFiltering)
    ]
    
    pipeline_filter = Pipeline(steps + steps_new)
    
    X_filtered = pipeline_filter.fit_transform(X)

Persistence entropy
-------------------

The *entropy* of persistence diagrams can be calculated via
``PersistenceEntropy``:

.. code:: ipython3

    PE = PersistenceEntropy()
    
    X_persistence_entropy = PE.fit_transform(X_scaled)

.. code:: ipython3

    fig = px.line(title='Persistence entropies, indexed by sliding window number')
    for dim in range(X_persistence_entropy.shape[1]):
        fig.add_scatter(y=X_persistence_entropy[:, dim], name=f"PE in homology dimension {dim}")
    fig.show()



.. raw:: html

    <div>                            <div id="c8bc9eea-72ed-446c-a481-1b302bf4af2f" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("c8bc9eea-72ed-446c-a481-1b302bf4af2f")) {                    Plotly.newPlot(                        "c8bc9eea-72ed-446c-a481-1b302bf4af2f",                        [{"name": "PE in homology dimension 0", "type": "scatter", "y": [3.6618706536736534, 3.6534608929742522, 3.6659240529164996, 3.6830506947533044, 3.692999663406622, 3.6808416686842595, 3.6739702633665194, 3.674251291287843, 3.6601731517572658, 3.6398035846611694, 3.653917477900733, 3.615623240271989, 3.667282586545643, 3.6905676516473975, 3.6896629001153043, 3.5958037701782373, 3.6058608822811107, 3.631211969029339, 3.6643170625508787, 3.6888504446797, 3.6953107618660144, 3.689087388902629, 3.6764349743907494, 3.6744979022826487, 3.6780617956707524, 3.6661731531712434, 3.6592121895035468, 3.6644137219562074, 3.592926814145323, 3.574096970247507, 3.6945587351240836, 3.5553604937540206, 3.608058089979931, 3.6695050790974246, 3.6632603245157758, 3.6696375241519235, 3.673397242748361, 3.6764562434971526, 3.6689514537562085, 3.6602013045030466, 3.66806933836673, 3.6698456128212675, 3.67931913576496, 3.6820331256475876, 3.6799766633018884, 3.6769271843232567, 3.6626926459118474, 3.6415654599851788, 3.6467189712629824, 3.64152410087454, 3.6401791931429335, 3.640714934266756, 3.6314714153278795, 3.6317764187461865, 3.6847946937122, 3.69114171862304, 3.636040582998011, 3.6274712130796045, 3.616336474781388, 3.624865266715492, 3.627864066562541, 3.6187120914944306, 3.6235756068104457, 3.6451490812193224, 3.6800288286753537, 3.6771196027887703, 3.67468688102875, 3.676090132369573, 3.6763280018668505, 3.6769901464866113, 3.6718031921818914, 3.6755505491952296, 3.6805897491108497, 3.69179256904678, 3.6895892424981613, 3.6870213734922537, 3.691429666196427, 3.6960121972962736, 3.6884569170003982, 3.68541898298102, 3.6827469287067855, 3.679980915247228, 3.6857441966461577, 3.6964826762786114, 3.683893996646591, 3.6832026524720094, 3.679589653377382, 3.6795751623483106, 3.67320031815878, 3.6780151479101435, 3.6794173760013074]}, {"name": "PE in homology dimension 1", "type": "scatter", "y": [0.0, 0.0, 0.0, 0.0, 0.8819781861673371, 0.959215112658857, 0.0, 0.0, 0.7214780354421667, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, 0.0, 1.2622513973082734, 0.878528179492763, 1.071330714436566, 0.7057031073218191, 0.7878574199037476, 0.8342529367728426, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, -1.0, -1.0, -1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.4680696645183901, 0.0, -1.0, 0.0, 0.0, 0.0, 0.9727887226835126, 0.0, 0.0, 1.3555567647322253, 1.4400411998250722, 1.0523661105006465, 0.0, -1.0, -1.0, -1.0, 0.0, 0.0, 0.0, 0.8969281781479476, 1.282828625118989, 0.3679232121436474, 1.0829606825375504, 1.2035353923595484, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.35118980909783254, 0.4772621121995154, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.3002697479790928, 0.6823816635862229, 0.6720189515450625, 0.938259553998425, -1.0, -1.0, -1.0, 0.0]}, {"name": "PE in homology dimension 2", "type": "scatter", "y": [-1.0, -1.0, -1.0, 0.0, -1.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, -1.0, -1.0, -1.0, 0.0, 0.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, 0.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, -1.0, -1.0, -1.0, 0.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, -1.0, 0.0, -1.0, -1.0, 0.0, -1.0, 0.8908918969971262, -1.0, -1.0, -1.0, -1.0, 0.0]}],                        {"legend": {"tracegroupgap": 0}, "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Persistence entropies, indexed by sliding window number"}, "xaxis": {"anchor": "y", "domain": [0.0, 1.0]}, "yaxis": {"anchor": "x", "domain": [0.0, 1.0]}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('c8bc9eea-72ed-446c-a481-1b302bf4af2f');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Betti Curves
------------

The Betti curves of a persistence diagram can be computed and plotted
using ``BettiCurve``:

.. code:: ipython3

    BC = BettiCurve()
    
    X_betti_curves = BC.fit_transform(X_scaled)
    
    BC.plot(X_betti_curves, sample=window_number)



.. raw:: html

    <div>                            <div id="a7053dd6-c488-4925-9444-eaec20db8867" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("a7053dd6-c488-4925-9444-eaec20db8867")) {                    Plotly.newPlot(                        "a7053dd6-c488-4925-9444-eaec20db8867",                        [{"mode": "lines", "name": "H0", "showlegend": true, "type": "scatter", "x": [0.0, 0.01680896903532268, 0.03361793807064536, 0.05042690710596803, 0.06723587614129072, 0.0840448451766134, 0.10085381421193607, 0.11766278324725875, 0.13447175228258143, 0.1512807213179041, 0.1680896903532268, 0.18489865938854946, 0.20170762842387213, 0.21851659745919483, 0.2353255664945175, 0.25213453552984016, 0.26894350456516286, 0.28575247360048556, 0.3025614426358082, 0.3193704116711309, 0.3361793807064536, 0.35298834974177623, 0.3697973187770989, 0.3866062878124216, 0.40341525684774426, 0.42022422588306696, 0.43703319491838966, 0.45384216395371235, 0.470651132989035, 0.4874601020243577, 0.5042690710596803, 0.521078040095003, 0.5378870091303257, 0.5546959781656484, 0.5715049472009711, 0.5883139162362938, 0.6051228852716164, 0.6219318543069391, 0.6387408233422618, 0.6555497923775845, 0.6723587614129072, 0.6891677304482299, 0.7059766994835525, 0.7227856685188752, 0.7395946375541979, 0.7564036065895205, 0.7732125756248432, 0.7900215446601659, 0.8068305136954885, 0.8236394827308112, 0.8404484517661339, 0.8572574208014566, 0.8740663898367793, 0.890875358872102, 0.9076843279074247, 0.9244932969427473, 0.94130226597807, 0.9581112350133927, 0.9749202040487154, 0.9917291730840381, 1.0085381421193607, 1.0253471111546835, 1.042156080190006, 1.0589650492253289, 1.0757740182606514, 1.092582987295974, 1.1093919563312968, 1.1262009253666194, 1.1430098944019422, 1.1598188634372648, 1.1766278324725876, 1.1934368015079102, 1.2102457705432328, 1.2270547395785556, 1.2438637086138782, 1.260672677649201, 1.2774816466845236, 1.2942906157198462, 1.311099584755169, 1.3279085537904916, 1.3447175228258144, 1.361526491861137, 1.3783354608964598, 1.3951444299317823, 1.411953398967105, 1.4287623680024277, 1.4455713370377503, 1.4623803060730731, 1.4791892751083957, 1.4959982441437185, 1.512807213179041, 1.5296161822143637, 1.5464251512496865, 1.563234120285009, 1.5800430893203319, 1.5968520583556545, 1.613661027390977, 1.6304699964262999, 1.6472789654616224, 1.664087934496945], "y": [13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 12, 11, 11, 11, 11, 11, 11, 11, 11, 11, 11, 10, 10, 9, 8, 7, 7, 7, 5, 5, 5, 5, 4, 4, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0]}, {"mode": "lines", "name": "H1", "showlegend": true, "type": "scatter", "x": [1.135349178350232, 1.1610678168488069, 1.1867864553473817, 1.2125050938459565, 1.2382237323445315, 1.2639423708431063, 1.2896610093416812, 1.315379647840256, 1.3410982863388308, 1.3668169248374056, 1.3925355633359806, 1.4182542018345554, 1.4439728403331302, 1.469691478831705, 1.4954101173302798, 1.5211287558288547, 1.5468473943274295, 1.5725660328260045, 1.5982846713245793, 1.624003309823154, 1.649721948321729, 1.675440586820304, 1.7011592253188788, 1.7268778638174536, 1.7525965023160284, 1.7783151408146032, 1.804033779313178, 1.8297524178117528, 1.8554710563103276, 1.8811896948089024, 1.9069083333074772, 1.9326269718060523, 1.958345610304627, 1.9840642488032019, 2.009782887301777, 2.0355015258003517, 2.0612201642989265, 2.0869388027975013, 2.112657441296076, 2.138376079794651, 2.1640947182932257, 2.1898133567918006, 2.215531995290376, 2.24125063378895, 2.2669692722875254, 2.2926879107861, 2.318406549284675, 2.3441251877832494, 2.3698438262818247, 2.3955624647803995, 2.4212811032789743, 2.446999741777549, 2.472718380276124, 2.4984370187746987, 2.5241556572732735, 2.5498742957718488, 2.575592934270423, 2.6013115727689984, 2.6270302112675727, 2.652748849766148, 2.6784674882647224, 2.7041861267632976, 2.7299047652618724, 2.7556234037604472, 2.781342042259022, 2.807060680757597, 2.8327793192561717, 2.8584979577547465, 2.8842165962533217, 2.909935234751896, 2.9356538732504713, 2.9613725117490457, 2.987091150247621, 3.0128097887461953, 3.0385284272447706, 3.0642470657433454, 3.08996570424192, 3.115684342740495, 3.14140298123907, 3.1671216197376446, 3.1928402582362194, 3.2185588967347942, 3.244277535233369, 3.269996173731944, 3.295714812230519, 3.321433450729094, 3.3471520892276687, 3.3728707277262435, 3.3985893662248183, 3.424308004723393, 3.450026643221968, 3.4757452817205428, 3.5014639202191176, 3.5271825587176924, 3.552901197216267, 3.578619835714842, 3.6043384742134172, 3.630057112711992, 3.655775751210567, 3.6814943897091417], "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0]}, {"mode": "lines", "name": "H2", "showlegend": true, "type": "scatter", "x": [1.8432298441413684, 1.8617146819565003, 1.8801995197716321, 1.8986843575867642, 1.9171691954018961, 1.935654033217028, 1.9541388710321599, 1.972623708847292, 1.9911085466624239, 2.0095933844775558, 2.0280782222926876, 2.0465630601078195, 2.0650478979229514, 2.0835327357380833, 2.1020175735532156, 2.1205024113683475, 2.1389872491834794, 2.1574720869986113, 2.175956924813743, 2.194441762628875, 2.212926600444007, 2.231411438259139, 2.2498962760742707, 2.2683811138894026, 2.286865951704535, 2.3053507895196668, 2.3238356273347986, 2.3423204651499305, 2.3608053029650624, 2.3792901407801943, 2.397774978595326, 2.4162598164104585, 2.4347446542255904, 2.4532294920407223, 2.471714329855854, 2.490199167670986, 2.508684005486118, 2.52716884330125, 2.5456536811163817, 2.5641385189315136, 2.5826233567466454, 2.6011081945617773, 2.619593032376909, 2.6380778701920415, 2.6565627080071734, 2.6750475458223053, 2.693532383637437, 2.712017221452569, 2.730502059267701, 2.748986897082833, 2.767471734897965, 2.785956572713097, 2.804441410528229, 2.822926248343361, 2.8414110861584927, 2.8598959239736246, 2.8783807617887565, 2.8968655996038883, 2.9153504374190202, 2.933835275234152, 2.952320113049284, 2.970804950864416, 2.989289788679548, 3.00777462649468, 3.026259464309812, 3.044744302124944, 3.0632291399400757, 3.081713977755208, 3.10019881557034, 3.118683653385472, 3.1371684912006037, 3.1556533290157356, 3.1741381668308675, 3.1926230046459994, 3.2111078424611312, 3.229592680276263, 3.248077518091395, 3.266562355906527, 3.2850471937216588, 3.3035320315367906, 3.322016869351923, 3.340501707167055, 3.3589865449821867, 3.3774713827973186, 3.3959562206124505, 3.414441058427583, 3.4329258962427147, 3.4514107340578466, 3.4698955718729785, 3.4883804096881104, 3.5068652475032422, 3.525350085318374, 3.543834923133506, 3.562319760948638, 3.5808045987637698, 3.5992894365789017, 3.6177742743940335, 3.6362591122091654, 3.6547439500242973, 3.6732287878394296], "y": [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0]}],                        {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "Betti curves from diagram 3"}, "xaxis": {"anchor": "y", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Filtration parameter"}, "type": "linear", "zeroline": true}, "yaxis": {"anchor": "x", "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Betti number"}, "type": "linear", "zeroline": true}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('a7053dd6-c488-4925-9444-eaec20db8867');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Distances among diagrams
------------------------

In this section we show how to compute several notions of distances
among persistence diagrams.

In each case, we will obtain distance matrices whose i-th row encodes
the distance of the i-th diagram from all the others.

We start with the so-called “landscape :math:`L^2` distance”: when
``order`` is ``None``, the output is one distance matrix per sample and
homology dimension.

.. code:: ipython3

    p_L = 2
    n_layers = 5
    PD = PairwiseDistance(metric='landscape',
                          metric_params={'p': p_L, 'n_layers': n_layers, 'n_bins': 1000},
                          order=None)
    
    X_distance_L = PD.fit_transform(X_diagrams)
    X_distance_L.shape




.. parsed-literal::

    (91, 91, 3)



This is what distances in homology dimension 0 look like:

.. code:: ipython3

    plot_heatmap(X_distance_L[:, :, 0], colorscale='blues')



.. raw:: html

    <div>                            <div id="ac419f71-5d0a-4325-a44e-aebcb7761688" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("ac419f71-5d0a-4325-a44e-aebcb7761688")) {                    Plotly.newPlot(                        "ac419f71-5d0a-4325-a44e-aebcb7761688",                        [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 1.785202126536179, 0.5146193782585691, 5.790956132511109, 8.058290867080816, 7.083625020860852, 6.078178815735095, 7.259073080296583, 8.184316833868314, 16.070617408127873, 26.434802454726764, 29.966471009635416, 32.52253000766098, 32.89769494337693, 32.74183177277882, 28.914230822063594, 26.51474956379757, 22.043982746859964, 19.575743409948306, 18.085384056971268, 17.43449682137818, 17.168186320996185, 11.67451686760092, 8.658389685462696, 5.691712780350093, 6.477158100689947, 12.448028495210874, 14.946011353140584, 16.903083704076263, 26.27097984166872, 32.5136403578091, 24.414041091903222, 19.30302752541057, 14.53495895697677, 7.523835090372282, 5.277156392990728, 5.025626049965584, 2.2665795162869333, 3.498600909937818, 3.639761866454164, 5.9455983959018175, 11.631226912138379, 15.833319392956927, 14.454620956821525, 12.940548972023903, 16.04824694535002, 15.109686114789824, 10.008599204512036, 7.321417378751415, 8.63959609366827, 6.746821181923364, 10.817382871474868, 13.690948617340739, 18.52407413659895, 26.9545620584382, 28.352095823580726, 17.66830676469995, 10.855319615114162, 9.333584897212232, 8.375744296871206, 9.63069494835154, 8.404015269672744, 9.13040396908509, 19.02290321669731, 25.97621802353965, 25.263016270122776, 25.119524468139662, 25.669399952989874, 24.942807481427614, 22.541032781212625, 19.712853145169603, 16.66965474220196, 12.383012457446222, 9.803875928171271, 10.798366058245907, 7.770891414899623, 6.283029329798854, 6.9728819021137625, 8.207553715450103, 10.48667880285496, 7.2248147272313625, 8.145068598856485, 15.708627267779715, 20.23387349979602, 19.768114328006547, 20.30058923617565, 21.96819568468684, 24.971394570984607, 27.794910180835384, 28.57638068808142, 28.30517759871284], [1.785202126536179, 0.0, 2.186339890736154, 6.857058802682822, 9.015944840416573, 7.965903780678786, 6.961938475538486, 8.02063347582723, 9.25083252573991, 17.074556504457142, 27.157442004996724, 30.613210130823077, 33.11946231460063, 33.48794049350497, 33.33483723893056, 29.583035429639633, 27.23751072389813, 22.839580496453973, 20.380378183235297, 18.906340972472105, 18.256404909360338, 17.98541773613007, 12.758915622748448, 9.868049903590396, 6.044282287411324, 7.610880155177117, 13.378045819747365, 15.741547380336982, 17.82246351396121, 27.002702562372104, 33.11073293096961, 25.196680019091733, 20.223822755767422, 15.24432419263705, 8.682825277929412, 6.465885531801972, 4.107356835868407, 3.2703577405285693, 4.523225660112336, 4.676569344192012, 6.986319345884324, 12.753106940863361, 16.74657887693874, 15.405862295836476, 13.886159324664654, 16.915431578460737, 16.0685795500506, 11.074683978731384, 7.69852680353084, 9.417069384198262, 7.673321358092782, 11.4562801071725, 14.750618079157679, 19.46102757960541, 27.667358758947287, 29.03261769335634, 18.600082158712144, 11.969828432829406, 10.178339502274579, 9.321393662894659, 10.470964991071483, 9.305034198346283, 10.198161209642164, 19.95448013840254, 26.69957340605761, 25.99008620697718, 25.841358755123277, 26.41442883593341, 25.680605516542364, 23.335168771770338, 20.53930945267859, 17.504849173798082, 13.34612044639513, 10.606369961336148, 11.557452160995116, 8.741008554474599, 7.207676286269743, 7.846808640746455, 9.046688246140755, 11.522896216815287, 8.19012947917291, 9.099605644814776, 16.702936323357275, 21.037174003531906, 20.5937894054431, 21.1090184388382, 22.768105918984958, 25.727666280021708, 28.49027270460721, 29.253668737797994, 28.988927876025972], [0.5146193782585691, 2.186339890736154, 0.0, 5.8228374945504395, 8.056327468158761, 7.104910648594383, 6.140398408739068, 7.312778639392986, 8.12163214836173, 15.957467994396021, 26.40917722656298, 29.944336974294906, 32.502207099279346, 32.87760393965357, 32.72164506961997, 28.890321347252463, 26.483778815503506, 22.020665344845384, 19.55364327773442, 18.06831729119367, 17.419631783396042, 17.155847971583636, 11.625404848166815, 8.4697969142823, 5.788436104993624, 6.338828387791136, 12.431217317808672, 14.943864975703905, 16.842705343228666, 26.241963112315634, 32.493311889405625, 24.380469405907835, 19.23206798720694, 14.533422800797966, 7.472837138599545, 4.975299188144853, 5.193021254960265, 2.309368780172104, 3.575037800606093, 3.7527827084229606, 5.9113021957432705, 11.548521069447837, 15.81107136755141, 14.42580061988827, 12.918871542138609, 16.025909318590177, 15.078366965331602, 9.713583010246436, 7.221502573760424, 8.65084150181776, 6.786892346490735, 10.83521416626394, 13.551135963290703, 18.466812726363745, 26.93110011909561, 28.32978078907324, 17.600087357504947, 10.74177969419225, 9.334928674433048, 8.395209407677788, 9.652635110013225, 8.40748130856208, 9.06681799725187, 18.968699965503568, 25.95271472720724, 25.240568484877475, 25.0994253361355, 25.63744129831319, 24.919067027440995, 22.517068542505584, 19.68871746903375, 16.64827030383642, 12.367042223883926, 9.819081814615311, 10.81295312626527, 7.768308130228736, 6.325796521696077, 7.00060984416909, 8.232450230695557, 10.41730083016834, 7.2511011754635435, 8.148700675542528, 15.660441534304109, 20.215407859142086, 19.74460637829439, 20.281277836663087, 21.938226525127313, 24.94594628687473, 27.77112043568775, 28.55339850401561, 28.281679371391704], [5.790956132511109, 6.857058802682822, 5.8228374945504395, 0.0, 3.790027101250778, 3.3983580189981475, 3.650007323133205, 3.8701024604532877, 4.179761066908832, 11.89695015979394, 22.516992172257325, 26.45544665404017, 29.31868828127797, 29.734304381017996, 29.56176706951881, 25.307501211198282, 22.682399644254705, 17.762886297515678, 15.255568550879259, 13.796500592813768, 13.13784914775766, 12.882413980593128, 6.521998379597547, 5.378988624964327, 4.583584229102261, 3.4902993957484187, 7.242541928721393, 10.574650597915783, 12.55299037788013, 22.334353151299588, 29.308826891441598, 20.268047551589692, 14.935168272109573, 10.34913263167912, 3.658651007088712, 5.887249500010255, 8.516562462968729, 5.421002588049485, 3.3129608791628145, 2.720231175856052, 2.0765919928963377, 6.60256408182744, 10.907676469389914, 9.42202014778033, 7.971860920304423, 11.568173443269497, 9.978606335075849, 9.21415712732634, 8.0864918799619, 4.51085977139692, 3.2657313501200576, 7.019623512675956, 9.593173563667602, 13.939579219864104, 23.07322751033219, 24.64581001912692, 13.202231805630547, 6.498145088138482, 4.929170261399358, 4.129191870852974, 5.369221164569818, 4.266287631768144, 4.845464512230193, 14.331480506453198, 22.03866216268034, 21.294404431171024, 21.147512104049095, 21.703013158335093, 20.91359120007364, 18.228212185014556, 15.264778888354224, 12.253394769082615, 7.55353676964199, 5.671560346730318, 6.53523847767666, 4.011478499060129, 3.372873259085133, 3.2883907236776535, 4.105429853507819, 6.151296067317971, 3.166944884368286, 3.7709650199972904, 10.741470022614829, 15.957342814005433, 15.447764529763488, 15.99265232528127, 17.779878576279337, 20.8642359591948, 24.014496872926003, 24.88808706144296, 24.57963297157653], [8.058290867080816, 9.015944840416573, 8.056327468158761, 3.790027101250778, 0.0, 1.3535066665131097, 2.838147142361526, 1.7228411075516443, 1.391454327599676, 10.398982399510297, 20.045551741874423, 24.258703128893263, 27.312082404835124, 27.75775963179996, 27.57285685282256, 23.15168395335091, 20.290681105179342, 15.124712394132148, 12.424797057561584, 10.809711636234464, 10.110444061735958, 9.831968784012524, 6.617100257932051, 6.125479057146618, 6.357905280802337, 4.273345619206371, 5.597806398397705, 7.445957371798354, 9.680143715834548, 20.39958984829629, 27.30149623200619, 18.392037263535705, 12.764730169461362, 7.6991237753184185, 6.390525419241894, 8.223020990175606, 10.819775311377262, 8.378183767556385, 6.351722906328086, 4.879325336335984, 3.6218747811467824, 6.10249348475395, 8.67827909288857, 7.19529639428248, 5.463323029439332, 8.57608673944825, 9.058601650418938, 10.813862158784746, 10.368850037972958, 6.418305965577479, 1.825639214763175, 5.052094033153132, 8.039955465420121, 12.722409574362928, 20.624960907225386, 22.260513992191438, 11.71533905716486, 4.514463199125062, 2.840036669291371, 1.157028593458856, 1.8543295096644512, 1.0822252894839706, 1.8946054026499337, 12.566019159583256, 19.520024421326042, 18.722242790859333, 18.564607666802214, 19.222196376944186, 18.365734011932982, 15.669393180870491, 12.59257070636194, 9.27282732318348, 4.96728170729896, 2.353192365943172, 3.6900897231153604, 0.9710311607721562, 2.330048203170486, 1.3925156654727882, 1.3813066203751563, 3.070906976880997, 1.3367454796892875, 0.9289445504889328, 9.082438289860711, 13.123480749804404, 12.625323024948605, 13.190073935428588, 15.036905272040524, 18.39363137854132, 21.59888501717485, 22.53715472765395, 22.208605263712627], [7.083625020860852, 7.965903780678786, 7.104910648594383, 3.3983580189981475, 1.3535066665131097, 0.0, 2.2872732237928655, 0.7139049958576565, 1.8687739563752477, 11.022398335101993, 20.883834540892348, 25.007466220706746, 27.979253518141096, 28.414468179444945, 28.23386649345339, 23.902803127453108, 21.098775439771966, 16.036475189850172, 13.331567423856287, 11.768760733964784, 11.068364249805096, 10.783963540308331, 7.250204576955417, 6.048821465594298, 5.337142875237813, 3.7497258425161273, 6.517663001700564, 8.342051640435255, 10.619553078476311, 21.207085953514667, 27.968919869207582, 19.214465868563344, 13.609163968407747, 8.266755034841283, 6.253014626289736, 7.531126498911679, 9.706309952408077, 7.481938612819801, 5.6923430381363955, 4.070591658152201, 2.927161463434615, 6.796853872325709, 9.806442916401512, 8.295119743937498, 6.631748238780771, 9.576169733469508, 10.08627533136158, 10.47776481883814, 9.501724390174509, 6.284241526371109, 1.6111844448641695, 5.0497814634991265, 8.643320832966207, 13.46999969621619, 21.464724964069177, 23.051208180520696, 12.42568815849632, 5.167007482661313, 3.005106277639895, 2.1626928666261396, 2.7494191042881093, 1.4530421143172139, 2.7240098009429308, 13.47549824433456, 20.354180307426958, 19.55602743279108, 19.394925190449026, 20.072013625740528, 19.214558002712142, 16.605393196709084, 13.521795915049847, 10.207003291980964, 5.96256156194473, 2.904222633609133, 4.144870647637228, 1.4233520255942067, 1.8213872253024075, 0.24134186240744765, 1.3030838698590195, 4.002914916399975, 1.2658805069352397, 1.4126635197796569, 10.019555284511775, 14.073880921507367, 13.576820109582782, 14.149714032147783, 15.948980460990859, 19.275210117849184, 22.412868828755816, 23.323620282110443, 23.00705853268799], [6.078178815735095, 6.961938475538486, 6.140398408739068, 3.650007323133205, 2.838147142361526, 2.2872732237928655, 0.0, 2.3670062864882, 3.5087449628927323, 12.647708863123533, 21.88759196114699, 25.86534443192488, 28.74858784766182, 29.172327259288164, 28.99644621281146, 24.798924838631603, 22.10878038508751, 17.144741624551557, 14.531736688786534, 12.828305136660516, 12.1398106062571, 11.85210373392718, 8.560013284965247, 7.479969883489079, 6.253777735332739, 5.081598051898341, 8.126099350544777, 9.651599401495064, 11.958137137508821, 22.212230199646253, 28.738530833229323, 20.315485109771277, 15.004612792533297, 9.977851815250999, 6.838159663694953, 7.896380792652731, 9.558562811426377, 6.7874577149245505, 4.965798794445269, 2.9749425649074692, 4.082879759108509, 8.29787515555118, 10.986751804061676, 9.642652107974971, 7.924079226524663, 10.78077193990752, 11.257345372367164, 11.493315169480937, 10.268736896857735, 7.516351591744316, 1.132193551297554, 7.052382273681792, 10.362589552208732, 14.887270880523095, 22.42200801378516, 23.972470193544872, 13.962859900947887, 6.896472775849671, 5.106780267629606, 2.7351015238111143, 4.138867173608147, 3.3671230814018402, 4.309361137939436, 14.833408562489492, 21.370696038771207, 20.59819862444615, 20.44010034059747, 21.113851098946764, 20.27991192687343, 17.701368685734014, 14.750417824335122, 11.492520042843736, 7.27761095941618, 4.661566038736825, 6.040760393416774, 2.226144510892906, 0.5598316575197207, 2.160228859980746, 3.3584596724867137, 5.588765370784717, 1.946358806253073, 3.123126920422376, 11.415109392719376, 15.116846362091508, 14.660455736689359, 15.199381191115613, 17.035389144605777, 20.31754221390846, 23.349065455326578, 24.239021291445102, 23.92843604842682], [7.259073080296583, 8.02063347582723, 7.312778639392986, 3.8701024604532877, 1.7228411075516443, 0.7139049958576565, 2.3670062864882, 0.0, 2.3446306699364956, 11.273745126690219, 20.827803828521766, 24.951386244426693, 27.920758811974, 28.356871250628195, 28.17590038267036, 23.862689088913328, 21.059104528453677, 15.99322610492013, 13.269773434206742, 11.697348752599838, 10.992341684982751, 10.700588426734823, 7.681431139065507, 6.594411578931918, 5.423161778236436, 4.258846612901215, 6.742378056745097, 8.238614995329076, 10.652108777971241, 21.23349339890727, 27.910403505756918, 19.270619565244843, 13.721392738987698, 8.157440063188051, 6.773286054384952, 7.980164312826244, 9.739711154979465, 7.7506804496696216, 6.007581261827804, 4.318313307444854, 3.405974477681983, 7.241907239502731, 9.93215931920339, 8.457009170641696, 6.785988435704982, 9.549684454418143, 10.37221131963814, 10.969927892003474, 9.743487220349598, 6.628482755523699, 1.8530010695051264, 4.9366387728392, 8.959819667297968, 13.684807565238252, 21.406035464920855, 22.98096296570467, 12.61613887394843, 5.538146795856839, 3.117475438574478, 2.374170109167614, 2.6868166955321025, 1.6101200968469993, 3.0932779449028076, 13.641122224492312, 20.287768799906697, 19.482299516265883, 19.315320138377146, 20.032766833986067, 19.15260403143849, 16.577838228406097, 13.496160011253862, 10.15442951977498, 6.085587201032328, 2.7824020064782538, 4.038420460057914, 1.6980481965623566, 2.001914430223564, 0.7528234643570664, 1.3450742471461559, 4.236743501233051, 1.6544282963367514, 1.759382386071682, 10.242254095672335, 14.010621798709376, 13.529225620398165, 14.09514000439661, 15.898340291789848, 19.237444839103908, 22.349947227899584, 23.25858765475325, 22.944598970937363], [8.184316833868314, 9.25083252573991, 8.12163214836173, 4.179761066908832, 1.391454327599676, 1.8687739563752477, 3.5087449628927323, 2.3446306699364956, 0.0, 9.730841373153387, 19.956735313596194, 24.19112926448627, 27.24534814972327, 27.692099420013424, 27.506755270976054, 23.05943898840869, 20.143476028613858, 15.037247182693704, 12.32459007342833, 10.785616714436442, 10.094678769423219, 9.826567830529616, 6.393590665448384, 5.275489272606751, 6.39337287360678, 3.7163232336511585, 5.661328538848695, 7.459325244383075, 9.372385564409992, 20.307050842466214, 27.23473603722593, 18.254778028332503, 12.376451429022667, 7.553183311151185, 6.250696426941514, 7.7498952015909355, 10.898256127390056, 8.441979800972698, 6.732303718581696, 5.299904683173934, 3.531401381281123, 5.670201134561262, 8.840180556236056, 7.2348931791679565, 5.648081551065536, 8.524334540703274, 9.257706381284448, 9.992825233847817, 10.046089274933134, 6.58490533844191, 2.7260744132509767, 4.9073465294692395, 7.272381132297805, 12.384899621865953, 20.558812635274265, 22.185710020354474, 11.29855086570644, 3.5982477972605222, 2.647906233789911, 2.259018058708028, 2.4518945946417308, 1.327587143320862, 1.057791617535395, 12.333843394323896, 19.432413105220583, 18.63260106217959, 18.4844934701407, 19.093420664289102, 18.277757068077946, 15.618272698945834, 12.487547366169792, 9.180480337097643, 4.877809642610282, 2.5465167746470088, 3.681233423108768, 1.640014291104837, 3.025947082278935, 2.0246563391714427, 1.7483737951878764, 2.4679880257337983, 2.0635820301986554, 1.3078440397792237, 8.858008373893831, 13.09685998260358, 12.553520985081217, 13.165433094113645, 14.9272734633058, 18.316194526542283, 21.51993706291842, 22.45701581080855, 22.125711537033403], [16.070617408127873, 17.074556504457142, 15.957467994396021, 11.89695015979394, 10.398982399510297, 11.022398335101993, 12.647708863123533, 11.273745126690219, 9.730841373153387, 0.0, 15.107577828574875, 19.55771086347753, 23.206694347509394, 23.729602546755885, 23.513044300482743, 18.11021153674959, 14.709706762912788, 10.947297679705123, 9.244430658224296, 9.701966071026467, 9.478074702120646, 9.491082331075589, 7.530378552357668, 8.85581109892828, 12.781892958392818, 10.559507057362634, 6.948954051708374, 8.394289597231262, 6.588698152892961, 14.575200557971451, 23.19423449386653, 11.995964145617753, 5.152288071586314, 6.898215192836571, 11.38535568887179, 13.594510299544162, 17.515294987248613, 15.725447218647759, 14.460352532184453, 13.75991757446995, 11.126920731483038, 6.398774664172236, 8.073495368384021, 6.909115925504889, 7.917547304604133, 8.14862089517914, 8.340958055378136, 11.966873079137235, 14.559591453779055, 10.918713458388455, 11.861313500558946, 8.351233607012198, 3.382569174422081, 5.022263190432138, 16.06070902634758, 17.684254113286382, 3.2364983750551817, 6.548180750919157, 8.759195740530325, 10.808969256144751, 9.922788727295842, 10.003404076082703, 8.999234369576255, 5.706966834156562, 14.75244073153214, 14.07201661473582, 14.030244300460705, 13.898247647722258, 13.505487201080852, 11.333556984192752, 8.702388648634273, 7.977061490204836, 7.723127317803594, 9.466927710092243, 8.49672534326615, 10.899436885388738, 12.226300933839076, 11.159734328465824, 10.176337879724871, 8.0822787189468, 11.113023222261843, 10.096568289495169, 5.275510968397886, 10.682540758711115, 9.935354817180368, 10.596688044537105, 11.106737475646153, 13.499636747128074, 16.963290851994813, 17.802099357072244, 17.51872899011668], [26.434802454726764, 27.157442004996724, 26.40917722656298, 22.516992172257325, 20.045551741874423, 20.883834540892348, 21.88759196114699, 20.827803828521766, 19.956735313596194, 15.107577828574875, 0.0, 6.796611675103743, 12.370715531708829, 13.314530119966587, 12.924721235246803, 7.235329571879769, 3.340427584451284, 6.266356676710808, 9.052266676409767, 10.793411492298874, 11.46134854656364, 11.750972397108578, 18.853610346259998, 21.561809341921645, 23.8954004128567, 22.165707942546565, 16.946039928402303, 13.889970297749427, 12.00525723597432, 7.652985632315128, 12.340793138468406, 8.036365134588003, 10.781329812961843, 14.936922861186362, 22.919044010531557, 25.47811563791911, 28.15500826714246, 26.54905445845776, 24.89561950122978, 23.86417691205275, 22.267129472417604, 18.399389829592792, 13.729762951204867, 14.80371293023798, 16.043906660572464, 12.735480339185603, 16.165038714359948, 24.8273079765398, 26.48090063231528, 22.290260265953542, 21.238884331480403, 18.61478477423298, 16.779248153992647, 13.383673538968935, 1.923619931950194, 3.6128625163468944, 13.571416213508813, 18.164661515370494, 19.265079861383168, 19.87016178194634, 18.73608034963017, 19.765256275349945, 19.164420746846396, 11.577250471678543, 1.237954404863856, 2.350871719420246, 2.686675807970937, 2.042172995854035, 2.4289467328904477, 5.753470190783642, 8.93167408268705, 12.111378017383437, 16.42182319320039, 18.632961273954166, 17.93741215499815, 20.29513996942498, 21.625659865153253, 20.982477588893836, 19.99455416564098, 18.00207633560469, 20.784015715376565, 19.98434565782195, 14.328912654915962, 8.479127416082788, 8.92570955686287, 8.37917109684436, 6.351388128733858, 2.7587702964248244, 2.6960798837987174, 3.790605431410084, 3.530264671201476], [29.966471009635416, 30.613210130823077, 29.944336974294906, 26.45544665404017, 24.258703128893263, 25.007466220706746, 25.86534443192488, 24.951386244426693, 24.19112926448627, 19.55771086347753, 6.796611675103743, 0.0, 7.332443906449993, 8.681817136887858, 8.166391874308912, 4.789356000543012, 6.8559075357750885, 12.093578197073493, 14.630835712957065, 16.07274505637876, 16.665639697744318, 16.918645790431125, 23.090759980774575, 25.591687797731538, 27.702883460536235, 26.167267291547184, 21.488172451804264, 18.84236432856504, 17.17330676252909, 8.656132865018197, 7.374644751231791, 10.891387287963367, 15.639863296423137, 19.731030446979187, 26.780085138091255, 29.115268190759686, 31.529318635625, 30.075886524888446, 28.584838824789703, 27.65052428878729, 26.256220094477246, 22.733072570065215, 18.512889592956533, 19.557701146889727, 20.679282195137407, 17.812838989297873, 20.547656723371173, 28.435112543543795, 30.011942402810483, 26.24815164142142, 25.2975935927146, 22.992766061995727, 21.23814060068214, 17.69100486502317, 6.227476826717404, 5.049841667281257, 18.07665138736155, 22.596109018796255, 23.59285465856058, 24.077582342539213, 23.09309053169424, 24.02026101497664, 23.488882551943814, 16.249756008863766, 7.641386503503597, 8.658996812061526, 8.893140378734763, 7.767543111019966, 8.825922784661472, 11.502670840655274, 14.471412411502339, 17.29833000670482, 21.030141884346385, 23.020282196140535, 22.416302667010207, 24.468390016512462, 25.640404993994597, 25.09337164816012, 24.224217597362344, 22.465481719112894, 24.90266784311523, 24.209187669530223, 19.00715230861721, 14.010182712001518, 14.434944207725021, 13.913185827942785, 12.216551107313748, 8.632609125024118, 5.273565361830453, 4.31085944528612, 4.639566166094087], [32.52253000766098, 33.11946231460063, 32.502207099279346, 29.31868828127797, 27.312082404835124, 27.979253518141096, 28.74858784766182, 27.920758811974, 27.24534814972327, 23.206694347509394, 12.370715531708829, 7.332443906449993, 0.0, 2.229150882965447, 2.053995359092942, 9.323912079855495, 12.394075789694112, 16.75017156273405, 18.84059521717326, 20.020094237366447, 20.53328750064669, 20.74497214720607, 26.317351563008675, 28.541706872647545, 30.44904430184351, 29.05194996296081, 24.904448145484054, 22.46880091787854, 21.0688895703568, 13.532198222434479, 1.6475057319165876, 15.683502818540699, 19.86832371099577, 23.27853655096636, 29.620212943462274, 31.747267256772403, 33.97481523246072, 32.629685880839524, 31.26151025240794, 30.395607891366883, 29.13298095441901, 26.001363106055347, 22.327717713198687, 23.221575956410348, 24.17924477978877, 21.60334098057319, 24.106216380220957, 31.127689724864705, 32.574439811500355, 29.143488240677307, 28.2444015750888, 26.175452019843885, 24.674504895525143, 21.611535385188333, 11.751515295618992, 9.98438565652321, 21.93594278579969, 25.842469070344563, 26.71837811284109, 27.147300968944933, 26.252937174807666, 27.087240953895282, 26.617161509180224, 20.43539289003042, 12.873730670085981, 13.649290396179943, 13.808553075045326, 13.276466094633458, 14.004440534912492, 16.375466262582012, 18.799467781123965, 21.14638585273091, 24.443376922970234, 26.18195769393975, 25.65249363197459, 27.486849969155664, 28.549161705557196, 28.0588946059298, 27.272006974961172, 25.703127720923572, 27.887084473013214, 27.263555810169077, 22.754106772342034, 18.274383999408723, 18.65813403843455, 18.226476703876852, 16.771438920543236, 14.015739130683647, 10.70028830627623, 9.63449436944076, 10.017084138038774], [32.89769494337693, 33.48794049350497, 32.87760393965357, 29.734304381017996, 27.75775963179996, 28.414468179444945, 29.172327259288164, 28.356871250628195, 27.692099420013424, 23.729602546755885, 13.314530119966587, 8.681817136887858, 2.229150882965447, 0.0, 1.083129251917315, 10.505415255158624, 13.339129018911294, 17.46741077158926, 19.481052400362024, 20.6239556768655, 21.122482573610817, 21.328320231012924, 26.779588640964498, 28.968472615801055, 30.849435544008067, 29.471327950037445, 25.392418394461433, 23.008485156036222, 21.643509008849954, 14.399437501052347, 2.1031540116398366, 16.446850323671157, 20.476661387374556, 23.79986635346836, 30.03165645288867, 32.131485380561124, 34.33411487963716, 33.003632757175936, 31.651625515124564, 30.79669387408338, 29.551209007057913, 26.46911894758146, 22.870731356223935, 23.744156426110717, 24.68155693243886, 22.164108734871167, 24.610019151929, 31.51946132305762, 32.94901369572902, 29.561567639805165, 28.6755923186106, 26.64015133086576, 25.166933987428287, 22.17209589086082, 12.730814788558726, 11.03969284639033, 22.48841836124002, 26.31304965487645, 27.173794425310298, 27.595639590101147, 26.716288754104266, 27.536557464263055, 27.074280439082123, 21.027331192003093, 13.780145256662136, 14.508794687932053, 14.658722079487655, 14.167151599362347, 14.85153278907512, 17.108456090636608, 19.441279879210565, 21.718955065123573, 24.940369882715714, 26.646543550253007, 26.12649620647163, 27.929738554364462, 28.975817651592376, 28.49289281548919, 27.718328573898724, 26.176213422234873, 28.32371541470599, 27.710013531257676, 23.28717993865768, 18.93399894456814, 19.30464556225959, 18.88776925751807, 17.487398969128154, 14.8649959393858, 11.737613177015374, 10.746607090053534, 11.103166849917411], [32.74183177277882, 33.33483723893056, 32.72164506961997, 29.56176706951881, 27.57285685282256, 28.23386649345339, 28.99644621281146, 28.17590038267036, 27.506755270976054, 23.513044300482743, 12.924721235246803, 8.166391874308912, 2.053995359092942, 1.083129251917315, 0.0, 10.169314529942254, 12.956169362379992, 17.17206028154143, 19.216675515684578, 20.37441442129742, 20.87890048163343, 21.08711595088563, 26.587884139749363, 28.79134628567891, 30.683169468511053, 29.29724195872572, 25.190159331946354, 22.785074158865477, 21.405856616020507, 14.076640286884903, 1.4287015674291728, 16.14140148680019, 20.225302885807572, 23.58395330924007, 29.860837304968374, 31.971887151225125, 34.1848015910226, 32.848272259283256, 31.48959531335941, 30.63014150838134, 29.37759637935482, 26.27514934516408, 22.645961406352896, 23.527732139691558, 24.47342370529063, 21.93209819558202, 24.40127574344777, 31.356748194689867, 32.79339443806934, 29.38801620681867, 28.496645593343437, 26.447436136247482, 24.96284802615747, 21.94016981344919, 12.322517088871772, 10.567912090335826, 22.25978831075483, 26.11792100052098, 26.984890563396505, 27.40964318695554, 26.524126753620724, 27.350159272518344, 26.884677356135875, 20.782633911697676, 13.40380268602027, 14.15183163219607, 14.30550062923765, 13.801361170439517, 14.503013446921189, 16.806798774742937, 19.176354674214217, 21.482137332451742, 24.734414590528182, 26.45387492268365, 25.92996373457234, 27.745981888637726, 28.79873649707211, 28.312791389130382, 27.53316099143124, 25.980057051050707, 28.142531338575687, 27.524790011041762, 23.066468406431028, 18.661873734498567, 19.03781908554468, 18.614968245331628, 17.192391862533977, 14.516794395713415, 11.2936072338079, 10.265696220133888, 10.634738823905616], [28.914230822063594, 29.583035429639633, 28.890321347252463, 25.307501211198282, 23.15168395335091, 23.902803127453108, 24.798924838631603, 23.862689088913328, 23.05943898840869, 18.11021153674959, 7.235329571879769, 4.789356000543012, 9.323912079855495, 10.505415255158624, 10.169314529942254, 0.0, 6.026136610891279, 11.30543849047248, 13.762101511924921, 15.261157876847522, 15.811318736105205, 16.056258542100466, 21.766746725157294, 24.368304118215224, 26.576860485943712, 25.009614422567964, 20.264376615864332, 17.8387851919505, 16.0847627830991, 5.996255092339899, 9.638726190454301, 8.577526364780626, 14.153942256525788, 18.590787082933073, 25.569982013358647, 27.993536491996927, 30.494546523197336, 28.994654301727405, 27.495064652801602, 26.559196768744666, 25.104352873669413, 21.42591685686949, 17.480852641840507, 18.379883933301734, 19.57317334119742, 16.800444699151793, 19.394318622811415, 27.262412968880863, 28.90329085608446, 25.067873368136006, 24.21574702889763, 21.83508425009867, 19.934550377923877, 16.02744640370043, 7.334591628912373, 7.097426394309411, 16.504330548730984, 21.370331764357058, 22.421632434943685, 22.985580161842478, 22.00666163430341, 22.899871487418203, 22.341861570864495, 14.7242986399552, 7.931947287203628, 8.756168881541628, 8.998162943002985, 7.465000007195451, 8.661227149515172, 10.85613271147598, 13.440069906488016, 16.29893219479993, 19.823290202560866, 21.919822426423675, 21.28459856462393, 23.37573073231126, 24.563970707141696, 23.992406909644092, 23.101932484339503, 21.319969529837675, 23.78624493986085, 23.07448232181819, 17.611657082470128, 13.36739485491781, 13.621173253889506, 13.249280083260633, 11.646963455975088, 8.249821621292147, 6.900798297585445, 6.087627073600485, 6.272431217497212], [26.51474956379757, 27.23751072389813, 26.483778815503506, 22.682399644254705, 20.290681105179342, 21.098775439771966, 22.10878038508751, 21.059104528453677, 20.143476028613858, 14.709706762912788, 3.340427584451284, 6.8559075357750885, 12.394075789694112, 13.339129018911294, 12.956169362379992, 6.026136610891279, 0.0, 7.271554784061365, 9.772924016077805, 11.552846057636332, 12.166651559787372, 12.445108053531428, 18.960934009540875, 21.54374061881523, 23.989991463600422, 22.25372163048692, 17.214216686903402, 14.398909536635738, 12.252057602408868, 6.663242176520005, 12.399392489155941, 7.222979412811532, 10.312412283721542, 15.205293289511841, 23.00080201956265, 25.485923740205948, 28.19574743260241, 26.61211014566362, 25.028290805886698, 24.016090751305573, 22.39783663122135, 18.456435820416118, 14.272185745454705, 15.168991410358306, 16.43525443127898, 13.258995352120914, 16.515856935808966, 24.679993497232548, 26.472401414252584, 22.426010421111382, 21.476826711139726, 18.79737867923701, 16.62116987830501, 13.053177817757124, 4.598174987366356, 5.379789331572117, 13.222348850532322, 18.236776053679538, 19.463411465981487, 20.150881024613305, 19.04663413875278, 19.997992672203825, 19.35745039896175, 11.399883978301197, 3.9061220682591618, 4.464537002795659, 4.807016900755587, 2.3705377167306145, 4.302537529686114, 6.956801501536124, 9.554125600106044, 12.63721672297369, 16.71944373659993, 18.914641895829835, 18.205345798512376, 20.53445274126672, 21.847671888745076, 21.201191187708382, 20.22528656573966, 18.20836841745959, 21.007920150544994, 20.208594391161117, 14.447763701329848, 9.506560055494818, 9.741134379488793, 9.404650289476056, 7.329986388523284, 4.47003409926166, 4.619348163506528, 5.034071556054335, 4.8532417837688495], [22.043982746859964, 22.839580496453973, 22.020665344845384, 17.762886297515678, 15.124712394132148, 16.036475189850172, 17.144741624551557, 15.99322610492013, 15.037247182693704, 10.947297679705123, 6.266356676710808, 12.093578197073493, 16.75017156273405, 17.46741077158926, 17.17206028154143, 11.30543849047248, 7.271554784061365, 0.0, 3.378195963874068, 5.278570338366291, 5.965241021611473, 6.280542744334419, 13.947114866315596, 16.9389077026512, 19.36761991121785, 17.47715363245251, 11.864783925379292, 8.540628831954205, 6.665346377496754, 9.361798725903318, 16.73286932336754, 7.974316824096759, 6.763543495700294, 10.08115670611223, 18.235912316629026, 21.073300110434737, 23.95600579329748, 22.131173871902092, 20.372657591070446, 19.2428724964107, 17.526509637091696, 13.482032932193178, 8.607970737132586, 9.537668210114296, 10.854867187828608, 7.207382251890249, 11.498203728906095, 20.695972840474024, 22.26187760291332, 17.70451927161467, 16.427642667143058, 13.837464396190226, 12.223413390032748, 9.530814641965724, 6.959432291041946, 9.122738514081785, 9.609148233004534, 13.1945191840848, 14.304956362714961, 14.934027504597454, 13.716983371431724, 14.816088887383685, 14.17064005285901, 7.346273619762467, 5.61987487026373, 4.822059662392646, 4.735436716270302, 5.525932968091945, 4.373460742348935, 1.6459851295362562, 3.096252417461419, 6.5930598549000745, 11.106821059713837, 13.626810089907849, 12.917128497783876, 15.402348202887238, 16.85161919154782, 16.145111134557233, 15.066902150220654, 12.93973098245902, 15.896967454293886, 15.028509389290107, 9.214341528112922, 2.9693433307940924, 3.146454259938352, 2.8002874403414912, 1.514545276008544, 4.184569028791584, 8.19633536832247, 9.42368794377667, 8.961406654459124], [19.575743409948306, 20.380378183235297, 19.55364327773442, 15.255568550879259, 12.424797057561584, 13.331567423856287, 14.531736688786534, 13.269773434206742, 12.32459007342833, 9.244430658224296, 9.052266676409767, 14.630835712957065, 18.84059521717326, 19.481052400362024, 19.216675515684578, 13.762101511924921, 9.772924016077805, 3.378195963874068, 0.0, 2.551133112698098, 3.105359025041268, 3.3976174800389134, 11.80666083449847, 14.507299428051859, 16.803437813420974, 14.880340996401022, 9.368414845881249, 5.4914464982570745, 3.9241921129453154, 11.652818557048942, 18.82524579799988, 9.898129138279742, 6.000958027675717, 7.240294401648055, 15.933903426537414, 18.65973598098968, 21.525167608767955, 19.716224198937002, 17.925749622117525, 16.722162632908763, 14.929765340110102, 11.20134076146248, 6.564255365881315, 7.1571017984710545, 8.272641814128686, 4.281183601137845, 9.805444504892384, 18.528192149370774, 19.87908731762915, 15.307525590265852, 13.795568386696136, 11.055621986920778, 9.980358814663733, 8.930766507008302, 9.812752441554402, 11.747367066007008, 8.371495500366427, 10.566971743104881, 11.549501591722812, 12.28129658790567, 10.941448045690906, 12.06791445088998, 11.450511909445522, 6.877567691870402, 8.352354344228937, 7.39609675274386, 7.228377973821537, 8.233059312950832, 7.033848628194483, 4.389160272546988, 1.4671011939922016, 3.473390837100874, 8.466661514487383, 10.79652896860254, 10.057648023893536, 12.711851335256688, 14.223413856444049, 13.448323450795248, 12.321801918957956, 10.170968380478882, 13.250939513326706, 12.327101894209978, 7.440025042410281, 2.031117791074942, 1.5258513983605408, 2.0955331563480337, 3.2331119439002354, 7.265141424469762, 10.947870850320983, 12.104216830705038, 11.711716686696747], [18.085384056971268, 18.906340972472105, 18.06831729119367, 13.796500592813768, 10.809711636234464, 11.768760733964784, 12.828305136660516, 11.697348752599838, 10.785616714436442, 9.701966071026467, 10.793411492298874, 16.07274505637876, 20.020094237366447, 20.6239556768655, 20.37441442129742, 15.261157876847522, 11.552846057636332, 5.278570338366291, 2.551133112698098, 0.0, 0.793937294008362, 1.139075149678134, 10.911538134909826, 13.533269783143094, 15.64760597036508, 13.624423298096096, 8.410777585983734, 3.988370461555391, 3.528296373022277, 13.260347477353884, 20.005649814259318, 11.596974424715851, 7.26983238730808, 6.965703494521914, 14.724906463314667, 17.46263618977231, 20.291122767182905, 18.306140769662058, 16.439351500542035, 15.153610341848694, 13.582489577736641, 10.326037123329256, 5.6104788950068505, 6.13440845274208, 6.835519023889765, 2.64340534316768, 9.150561182652426, 17.796352866701564, 18.96587066689072, 14.308165907360014, 12.112613462252986, 10.221759475625612, 9.747822454305688, 9.877379796456006, 11.370974667690666, 13.289020266307098, 9.289794043677206, 9.452535283433528, 10.296801688477636, 10.563155886711423, 9.284943915127629, 10.519877515813938, 9.921937079990949, 7.885139851549652, 10.12126975018592, 9.216523298983873, 9.048420316615013, 10.045045534527627, 8.937427892749636, 6.129530728485061, 3.3885447764835934, 2.3873192883483885, 7.003758806932887, 9.277962504084808, 8.801344471550937, 11.03045542482957, 12.53928922101506, 11.877669856152798, 10.81419850974469, 8.683711431282935, 11.617939203148874, 10.76632999306132, 7.225197903974508, 2.681423196193682, 2.2715107159911723, 2.857465570067008, 4.950485543205743, 9.039144595743691, 12.490092278688294, 13.677009832229926, 13.247162491736185], [17.43449682137818, 18.256404909360338, 17.419631783396042, 13.13784914775766, 10.110444061735958, 11.068364249805096, 12.1398106062571, 10.992341684982751, 10.094678769423219, 9.478074702120646, 11.46134854656364, 16.665639697744318, 20.53328750064669, 21.122482573610817, 20.87890048163343, 15.811318736105205, 12.166651559787372, 5.965241021611473, 3.105359025041268, 0.793937294008362, 0.0, 0.36305646286789994, 10.40724434533478, 12.956533468396845, 14.999109437908801, 12.977221481012332, 7.851010315751857, 3.268272310883612, 3.3175043888613898, 13.736769677536092, 20.519204341347013, 12.010115173593137, 7.396438999158127, 6.447930294030546, 14.127300675307277, 16.852014374300776, 19.660299588460145, 17.665508716801376, 15.79413752157876, 14.485676689449035, 12.91770243534213, 9.809899280176902, 5.33407312893907, 5.671528715108246, 6.235961007986674, 2.0069935876697222, 8.865497607489537, 17.292144603191936, 18.374508271526278, 13.719008440929128, 11.421222985112273, 9.589213934111841, 9.357098862446115, 9.864406747306978, 12.046833517467633, 13.934970783644259, 9.189479911405616, 8.847539233820717, 9.612635390167108, 9.866489380644573, 8.565781176964911, 9.812063319448423, 9.23291107048915, 7.986753407023442, 10.792812244264347, 9.886378462167311, 9.714025070312406, 10.702800802061466, 9.60225815404923, 6.801580804206978, 3.8603506504085576, 1.8949081153258185, 6.3423368866519185, 8.559545726582886, 8.105576486535577, 10.329058001580682, 11.848659598430858, 11.17855190777952, 10.107652376721472, 7.99999674496061, 10.92171250241891, 10.06456397349991, 6.972146857113275, 3.442974727728947, 2.996816486920525, 3.6051504853199474, 5.6748481301987175, 9.71463729947679, 13.152851276086201, 14.315740384111336, 13.897557507398338], [17.168186320996185, 17.98541773613007, 17.155847971583636, 12.882413980593128, 9.831968784012524, 10.783963540308331, 11.85210373392718, 10.700588426734823, 9.826567830529616, 9.491082331075589, 11.750972397108578, 16.918645790431125, 20.74497214720607, 21.328320231012924, 21.08711595088563, 16.056258542100466, 12.445108053531428, 6.280542744334419, 3.3976174800389134, 1.139075149678134, 0.36305646286789994, 0.0, 10.262440934970227, 12.768034549033212, 14.743878898868491, 12.737106508942345, 7.683490702486442, 2.9915536781155736, 3.3800664552978397, 13.984794678093648, 20.731032791592813, 12.246984643983675, 7.564330615482399, 6.276419584452746, 13.912873419370815, 16.626484310465347, 19.402975224457226, 17.409436884159252, 15.53906262937591, 14.213886139168517, 12.66239902919099, 9.668278368022483, 5.3305174014843155, 5.576713597988712, 6.0491970497741425, 1.8588280686069774, 8.840447235032986, 17.136918944919106, 18.15462058040203, 13.511588476705409, 11.13778024371524, 9.350338572909088, 9.290457266589833, 9.962217123455945, 12.333962386169143, 14.202261666746638, 9.25409487423549, 8.654005987492154, 9.349991897434826, 9.58489398025994, 8.272371137609651, 9.52775613076672, 8.971058539515326, 8.145495268995504, 11.079140112633592, 10.170704559772838, 9.994628405863462, 10.99950134153803, 9.893569205176053, 7.120623466681836, 4.143733683082538, 1.8319809711890196, 6.10754073418695, 8.268189369866933, 7.833060230873531, 10.043664166861712, 11.563181203533409, 10.894517816218727, 9.822239396982894, 7.749355557281535, 10.639150809928452, 9.784792677013318, 6.977857959028205, 3.772742455467538, 3.333952542019165, 3.938966034010452, 5.9973194397819976, 10.018719113006304, 13.431257377387462, 14.583041918448068, 14.170393483585615], [11.67451686760092, 12.758915622748448, 11.625404848166815, 6.521998379597547, 6.617100257932051, 7.250204576955417, 8.560013284965247, 7.681431139065507, 6.393590665448384, 7.530378552357668, 18.853610346259998, 23.090759980774575, 26.317351563008675, 26.779588640964498, 26.587884139749363, 21.766746725157294, 18.960934009540875, 13.947114866315596, 11.80666083449847, 10.911538134909826, 10.40724434533478, 10.262440934970227, 0.0, 5.546131838924945, 8.829487415402438, 6.79134810017687, 3.9286040155937068, 8.488826356080454, 9.205861641001272, 18.24552735940146, 26.306365094948774, 15.82219120793673, 10.395745549835045, 8.325655245088395, 5.3542544711382645, 9.608478194983286, 13.55888431220509, 10.881990910511211, 9.342422445730305, 8.952083134917265, 6.640861898230977, 1.780593807348709, 7.317354853670133, 5.653203027215681, 5.628196136984178, 8.718165378153717, 5.722287101331008, 9.691750364926303, 11.128641971730552, 5.991455566928027, 7.702495607897264, 7.193479505420077, 6.263942443871492, 8.46784317300059, 19.463493363177307, 21.185814540318688, 8.239050461594996, 4.822769378590917, 5.7105847964343255, 6.82583695252721, 6.809394573902551, 6.578671524402197, 5.879873375884575, 9.208810813943437, 18.41643982446066, 17.715347360848504, 17.603622198302716, 17.93541563342256, 17.23500340069658, 14.344429564524091, 11.413721544918944, 9.298283407445696, 5.150190427078058, 6.836600562720491, 6.566143005104533, 7.225190953819932, 8.134059077940192, 7.31479138654664, 6.66382625730184, 5.88051005120289, 6.890560229929056, 6.235554325477108, 5.451289804261385, 12.649663454217206, 12.00818021303893, 12.599891693691701, 14.19304565056159, 16.996567386428612, 20.47115582194503, 21.38563161660086, 21.04029021637218], [8.658389685462696, 9.868049903590396, 8.4697969142823, 5.378988624964327, 6.125479057146618, 6.048821465594298, 7.479969883489079, 6.594411578931918, 5.275489272606751, 8.85581109892828, 21.561809341921645, 25.591687797731538, 28.541706872647545, 28.968472615801055, 28.79134628567891, 24.368304118215224, 21.54374061881523, 16.9389077026512, 14.507299428051859, 13.533269783143094, 12.956533468396845, 12.768034549033212, 5.546131838924945, 0.0, 5.885292579582054, 3.0475807359101363, 6.844352861439292, 10.546954311540821, 11.34918184945973, 21.208974736597387, 28.531576935421572, 18.974533489836777, 12.968103028695376, 9.534905293720305, 4.630660434349747, 5.237283270786591, 10.172948426867906, 8.015800343978364, 7.2167065709182445, 7.093517293352032, 4.141300362582388, 4.790001349159475, 10.68713119226131, 8.995779320523459, 8.197110327792288, 11.26679363288848, 9.550287785894158, 5.254440113467056, 7.117047201631445, 5.022636629298882, 6.912988154660932, 6.646498539595274, 6.2990037099466285, 11.890634632262788, 22.222246573830276, 23.785399394138153, 10.89333523830601, 4.564473063219308, 5.349276617284025, 6.9790013326208165, 7.179537222220106, 6.032205550393639, 5.438154298474713, 12.654961529557458, 21.1204408750782, 20.387298151002703, 20.274207824793084, 20.612087876211415, 19.964224217296845, 17.40269599558065, 14.400725287530111, 11.725260983695987, 7.775973225115459, 6.857115974888871, 6.895104811764208, 6.588371503055044, 7.061033188106005, 6.126679486113475, 6.040826144782238, 6.009224610017554, 6.35348482471008, 5.864242973970581, 9.415455450383064, 15.493969124374791, 14.873974235839652, 15.502539074779722, 16.939977542331917, 19.93531491038127, 23.136200378095758, 24.00187783601522, 23.693932106767658], [5.691712780350093, 6.044282287411324, 5.788436104993624, 4.583584229102261, 6.357905280802337, 5.337142875237813, 6.253777735332739, 5.423161778236436, 6.39337287360678, 12.781892958392818, 23.8954004128567, 27.702883460536235, 30.44904430184351, 30.849435544008067, 30.683169468511053, 26.576860485943712, 23.989991463600422, 19.36761991121785, 16.803437813420974, 15.64760597036508, 14.999109437908801, 14.743878898868491, 8.829487415402438, 5.885292579582054, 0.0, 3.9023657419473, 9.147182052825286, 12.184641413919513, 14.177188915843331, 23.71012596889081, 30.439549111532067, 21.680157189411474, 16.29061515700014, 10.902828304559186, 5.97112653562392, 5.231411005932976, 5.687460049833513, 5.442518982593553, 4.995618783336343, 4.909369888385158, 3.4123209540718036, 8.672724182629425, 13.165738787975323, 11.62489613398508, 10.361806567713462, 13.472216613008708, 12.32133929831713, 8.302444712348468, 4.995704023913736, 4.882141082668625, 6.166957284052853, 6.723527884732979, 10.46419194612097, 15.299062387705497, 24.50375053137455, 25.961095149838812, 14.287507605400585, 8.103230921469219, 5.9488459084535945, 7.182078971839537, 7.516350735356937, 6.220028078466576, 7.136653378537229, 15.9592593741203, 23.40803256947098, 22.647614232125992, 22.488626619843718, 23.092618877402856, 22.28244671883517, 19.86331012414904, 16.86867054746946, 13.893451254012438, 9.902827477811497, 7.17769476167273, 7.492377923657465, 6.660209884570847, 6.0692246639708305, 5.298906840837484, 5.784735762542138, 8.192193486915082, 6.07261600994337, 6.174518612801665, 12.714723378871593, 17.736222089753415, 17.232323892342148, 17.786722677953513, 19.380190379223034, 22.366129746862843, 25.386786569135033, 26.196920129302843, 25.924591314227776], [6.477158100689947, 7.610880155177117, 6.338828387791136, 3.4902993957484187, 4.273345619206371, 3.7497258425161273, 5.081598051898341, 4.258846612901215, 3.7163232336511585, 10.559507057362634, 22.165707942546565, 26.167267291547184, 29.05194996296081, 29.471327950037445, 29.29724195872572, 25.009614422567964, 22.25372163048692, 17.47715363245251, 14.880340996401022, 13.624423298096096, 12.977221481012332, 12.737106508942345, 6.79134810017687, 3.0475807359101363, 3.9023657419473, 0.0, 7.175603279647218, 10.305252436299687, 11.874357352497265, 22.074214386444925, 29.041998000621835, 19.980211695174535, 14.160548141511068, 9.48141179078197, 4.780078297828981, 4.5541448791604235, 8.382653089118742, 6.337012487539197, 5.155664840391626, 4.6854844978438, 1.6654542664288918, 6.211356940082239, 11.044408994285916, 9.420997302177673, 8.110072687799793, 11.352054814541363, 10.362221451608425, 6.9927430917815645, 6.673066985551741, 4.6938886371518524, 4.648411611518656, 5.8519100207945085, 7.8770933303566535, 13.463892971096048, 22.787144656290934, 24.334995309412104, 12.39123728434639, 5.150857897328542, 4.268878355543848, 5.235605443320093, 5.6863605718351735, 4.28924599193267, 4.404436246631121, 13.926281581121124, 21.685242010844107, 20.920464496710775, 20.781153866249817, 21.290125891663585, 20.537352804238793, 17.97742334502611, 14.929906770138766, 11.880128870114573, 7.688565151212257, 5.454858498126954, 5.964342135854071, 4.633858365167432, 4.690319653693698, 3.781521215461956, 4.177358289472971, 5.476683119594268, 4.342470743083054, 4.167322235106534, 10.545600130971373, 15.772452149205783, 15.219820881662319, 15.815111900466318, 17.42602309569842, 20.568903090553302, 23.706873142996596, 24.57705964617995, 24.27455194965851], [12.448028495210874, 13.378045819747365, 12.431217317808672, 7.242541928721393, 5.597806398397705, 6.517663001700564, 8.126099350544777, 6.742378056745097, 5.661328538848695, 6.948954051708374, 16.946039928402303, 21.488172451804264, 24.904448145484054, 25.392418394461433, 25.190159331946354, 20.264376615864332, 17.214216686903402, 11.864783925379292, 9.368414845881249, 8.410777585983734, 7.851010315751857, 7.683490702486442, 3.9286040155937068, 6.844352861439292, 9.147182052825286, 7.175603279647218, 0.0, 5.498072009098641, 6.831460502762977, 16.920429392738626, 24.892838099518666, 14.613764228864778, 8.95031145094761, 5.303225670663766, 7.766749548429654, 11.06089218837476, 14.300597391034518, 12.194493128373619, 10.136246670549546, 9.410108564031962, 7.038742418527459, 3.3519379417691946, 4.723837467225202, 2.9400449556627293, 2.630396741144394, 6.053830673097191, 4.541645112989898, 11.51738413177405, 12.315102832488899, 6.650318748105174, 7.102419491600869, 5.10838298883611, 5.374199310768738, 8.292459110812022, 17.615464921423285, 19.398363892537336, 7.467467128087129, 4.111594069381675, 4.443442535610248, 5.793412611105469, 5.009580806463973, 5.483812050245802, 4.948624527273215, 8.078235153440787, 16.454784301476504, 15.670474271597852, 15.52324495627185, 16.05702793883747, 15.182108408021252, 12.250724915241525, 9.142274136922182, 6.548917412496052, 3.4478872235452838, 4.923085166778518, 4.228028341320876, 6.369907402978049, 7.657682129485873, 6.581149913498286, 5.603623419696562, 4.299695078432861, 6.450892894774476, 5.478737383215464, 4.557391886180334, 10.30935124555094, 9.740212726696033, 10.27920299881919, 12.02038493260461, 15.096607445682201, 18.67847540937305, 19.64748390832341, 19.31275287446546], [14.946011353140584, 15.741547380336982, 14.943864975703905, 10.574650597915783, 7.445957371798354, 8.342051640435255, 9.651599401495064, 8.238614995329076, 7.459325244383075, 8.394289597231262, 13.889970297749427, 18.84236432856504, 22.46880091787854, 23.008485156036222, 22.785074158865477, 17.8387851919505, 14.398909536635738, 8.540628831954205, 5.4914464982570745, 3.988370461555391, 3.268272310883612, 2.9915536781155736, 8.488826356080454, 10.546954311540821, 12.184641413919513, 10.305252436299687, 5.498072009098641, 0.0, 3.687239630313281, 15.398459707892867, 22.455931641884746, 13.433422341307809, 7.941662964842163, 3.908378066682995, 11.796356644133239, 14.377218467429698, 17.02798142629835, 15.18172635580375, 13.301932837947444, 11.966574851471572, 10.20563496006333, 7.785019830917123, 4.938040472532709, 4.272937398212872, 4.157579539273402, 1.9429484018878038, 7.931207595814056, 15.117976034226983, 15.737936555535585, 11.110459983490578, 8.878357323383636, 6.56907614707624, 7.615880985828131, 9.674947626289919, 14.550012426991156, 16.336423395575515, 8.595925604540144, 6.468186333537212, 6.679192925277103, 7.349425882587698, 5.814412423976364, 7.040778988205847, 6.629935929672334, 8.381196834933263, 13.249629840444143, 12.339694108173418, 12.153230032719188, 13.087594330149361, 11.999617492112636, 9.269783768802364, 5.9261271030963565, 2.203986068017837, 4.081828222933047, 5.650443170470281, 5.0388596533865195, 7.756117473637244, 9.321386109772666, 8.4603855231137, 7.288456152126168, 5.413413079663855, 8.331943981063699, 7.363865886303222, 6.253631526046092, 6.396491920078467, 5.89011555209624, 6.504192922558823, 8.401514185524398, 12.170916177121597, 15.617230514109988, 16.679829170303698, 16.320160128094606], [16.903083704076263, 17.82246351396121, 16.842705343228666, 12.55299037788013, 9.680143715834548, 10.619553078476311, 11.958137137508821, 10.652108777971241, 9.372385564409992, 6.588698152892961, 12.00525723597432, 17.17330676252909, 21.0688895703568, 21.643509008849954, 21.405856616020507, 16.0847627830991, 12.252057602408868, 6.665346377496754, 3.9241921129453154, 3.528296373022277, 3.3175043888613898, 3.3800664552978397, 9.205861641001272, 11.34918184945973, 14.177188915843331, 11.874357352497265, 6.831460502762977, 3.687239630313281, 0.0, 13.476053107188582, 21.055164662040294, 11.396679196305424, 5.060919311340005, 5.377248799155115, 13.196454606787638, 15.689853487938839, 18.984129259858626, 17.02287308002967, 15.266186904499593, 14.083268111643177, 12.083952209322785, 8.246653872337305, 5.142784196200327, 4.85320354302303, 5.760347277645328, 2.562719508439248, 8.086456076250135, 15.47431711906637, 17.166335267085156, 12.722446913575226, 11.175375759262533, 8.581542831380577, 6.698184411755234, 7.924710416224507, 12.779625465213119, 14.65847316873514, 6.843160374743711, 7.233732063234828, 8.791514207524104, 9.670828319616021, 8.359573120469765, 9.322603957121359, 8.448917746133187, 6.194543755029038, 11.44075337385114, 10.57391499030788, 10.463953223073897, 10.952128402466348, 10.158386140992377, 7.393627476416779, 4.071626161729661, 2.210827542301474, 5.85497199258822, 8.159269582394266, 7.464854568174797, 9.997303178047742, 11.601550232119394, 10.751620495042177, 9.632566891159039, 7.069853000383172, 10.579857335283625, 9.577716980856898, 5.373112089197127, 5.102951909041479, 4.346622940564004, 5.127749777507951, 6.433707699804266, 10.231482964269201, 13.843050999919868, 14.956707212713988, 14.55328049479502], [26.27097984166872, 27.002702562372104, 26.241963112315634, 22.334353151299588, 20.39958984829629, 21.207085953514667, 22.212230199646253, 21.23349339890727, 20.307050842466214, 14.575200557971451, 7.652985632315128, 8.656132865018197, 13.532198222434479, 14.399437501052347, 14.076640286884903, 5.996255092339899, 6.663242176520005, 9.361798725903318, 11.652818557048942, 13.260347477353884, 13.736769677536092, 13.984794678093648, 18.24552735940146, 21.208974736597387, 23.71012596889081, 22.074214386444925, 16.920429392738626, 15.398459707892867, 13.476053107188582, 0.0, 13.59775650096011, 3.4530079158489446, 10.694848584850435, 15.847306794738687, 22.37274828040451, 25.07654264014763, 27.83571039664158, 26.210037829837425, 24.623503316821303, 23.810392547407307, 22.175941771804094, 17.975356193467746, 14.193188722271913, 15.067821946592385, 16.489886982012347, 14.260688771018332, 15.691959373760778, 24.138422131619105, 25.9699151344857, 21.809224519706117, 21.538162370045004, 19.01591949615305, 16.611597736419743, 11.817658852008178, 8.170286975245888, 9.214360404745811, 12.615294744169447, 18.34445566586532, 19.55063861505805, 20.263665469232457, 19.348371522194217, 20.187063194164004, 19.552632153568183, 10.633635202759244, 8.219791920897903, 8.734957210260248, 8.93542823124525, 7.218908888870448, 8.063637013347966, 8.654101628612821, 10.826254577598332, 13.841118814602012, 16.87994630226883, 19.2722857824493, 18.546618467237145, 20.725545684022123, 21.932934133553694, 21.290855598670245, 20.38043481507479, 18.531939093169797, 21.057762989390408, 20.306409524996422, 13.923953035917808, 11.584505629938231, 11.616816497786807, 11.347633907863653, 10.192808046408954, 7.039324928645694, 8.600293825275424, 8.449439210494214, 8.424387663275972], [32.5136403578091, 33.11073293096961, 32.493311889405625, 29.308826891441598, 27.30149623200619, 27.968919869207582, 28.738530833229323, 27.910403505756918, 27.23473603722593, 23.19423449386653, 12.340793138468406, 7.374644751231791, 1.6475057319165876, 2.1031540116398366, 1.4287015674291728, 9.638726190454301, 12.399392489155941, 16.73286932336754, 18.82524579799988, 20.005649814259318, 20.519204341347013, 20.731032791592813, 26.306365094948774, 28.531576935421572, 30.439549111532067, 29.041998000621835, 24.892838099518666, 22.455931641884746, 21.055164662040294, 13.59775650096011, 0.0, 15.696913739927984, 19.853768868974417, 23.2661151714767, 29.610451972805055, 31.738160461669455, 33.96630567632549, 32.620825432536215, 31.25226190980664, 30.38609600299895, 29.123056682090994, 25.990243065248155, 22.314767072457368, 23.209124091983238, 24.167286346188806, 21.58995582998385, 24.094221701224907, 31.11840161102736, 32.565564331833734, 29.13356754762864, 28.23416496999022, 26.16440596804929, 24.662786603647167, 21.598161717293998, 11.70656380881123, 9.892212187610797, 21.9229945148547, 25.8312806277478, 26.70755661228653, 27.13665051394925, 26.241923738974293, 27.076566874552718, 26.606298841130254, 20.421242219503878, 12.841376500089098, 13.61902743961545, 13.77863992228886, 13.255092773277509, 13.982471775717844, 16.35780384204135, 18.784084754686837, 21.132711275421297, 24.43154777364988, 26.170914388018524, 25.6412222945054, 27.476331131441416, 28.539034414426087, 28.048590298345115, 27.261405240010554, 25.691878597250412, 27.876716657861962, 27.252950787611017, 22.741398950479784, 18.258553961427737, 18.642634390394786, 18.210609661807208, 16.75373389531201, 13.994595466095669, 10.634248788772952, 9.56948663687213, 9.947400540545306], [24.414041091903222, 25.196680019091733, 24.380469405907835, 20.268047551589692, 18.392037263535705, 19.214465868563344, 20.315485109771277, 19.270619565244843, 18.254778028332503, 11.995964145617753, 8.036365134588003, 10.891387287963367, 15.683502818540699, 16.446850323671157, 16.14140148680019, 8.577526364780626, 7.222979412811532, 7.974316824096759, 9.898129138279742, 11.596974424715851, 12.010115173593137, 12.246984643983675, 15.82219120793673, 18.974533489836777, 21.680157189411474, 19.980211695174535, 14.613764228864778, 13.433422341307809, 11.396679196305424, 3.4530079158489446, 15.696913739927984, 0.0, 8.131222393119714, 13.661394063136164, 20.150411895345727, 23.040106567567083, 25.994966051990783, 24.26409821856164, 22.690412696879203, 21.875729926894756, 20.0916603125226, 15.567523060139001, 12.158953240193972, 12.826351993420703, 14.387521435793538, 12.290924673392665, 13.515912403050143, 21.99686673158573, 23.92702067413284, 19.64098954688121, 19.60124180271943, 16.86442904610593, 14.238298319418528, 8.89466275888593, 8.86808035880621, 10.23330156182965, 9.799770475541674, 16.09410766903037, 17.3906201201343, 18.288239667131915, 17.353662435601603, 18.14697719031798, 17.462332982511555, 7.8819664098817945, 8.298474198521655, 8.476759607672884, 8.623693557562413, 7.269890467258901, 7.689126456735999, 7.47946022511105, 8.859511959668936, 11.864706988073365, 14.659370751409464, 17.243652445292533, 16.436181144177564, 18.754458098309303, 20.01229046459133, 19.30708649099161, 18.33777433938701, 16.42622088027496, 19.04779441973927, 18.245334990450967, 11.352988117162718, 10.186733809648542, 10.008054778470028, 9.934277081066583, 8.984741232400543, 6.794842651842165, 9.558562122793255, 9.739297764423288, 9.66039071358743], [19.30302752541057, 20.223822755767422, 19.23206798720694, 14.935168272109573, 12.764730169461362, 13.609163968407747, 15.004612792533297, 13.721392738987698, 12.376451429022667, 5.152288071586314, 10.781329812961843, 15.639863296423137, 19.86832371099577, 20.476661387374556, 20.225302885807572, 14.153942256525788, 10.312412283721542, 6.763543495700294, 6.000958027675717, 7.26983238730808, 7.396438999158127, 7.564330615482399, 10.395745549835045, 12.968103028695376, 16.29061515700014, 14.160548141511068, 8.95031145094761, 7.941662964842163, 5.060919311340005, 10.694848584850435, 19.853768868974417, 8.131222393119714, 0.0, 7.842920276241821, 14.85797366606589, 17.53555270833708, 21.021273802711175, 19.15884345765817, 17.59960240916692, 16.67360615251434, 14.46817337086856, 9.628395551173044, 7.457313951396093, 7.31494529825616, 8.856138543897929, 6.904148264256814, 9.110218813581582, 16.39160069488024, 18.64771699869313, 14.380897410242055, 14.216224498289973, 11.022964587766783, 7.440356893988721, 4.734577458541942, 11.80160567984982, 13.612619277725338, 4.113913446004081, 9.6641129203733, 11.50984621679078, 12.844134610658738, 11.741099350728884, 12.412529027230825, 11.496874536680789, 3.1411915337802396, 10.479503782547924, 9.863002576610711, 9.883318850612772, 9.408468957709987, 9.219139995581143, 7.081274230207049, 5.150307384559081, 6.461401654495567, 8.913045164204602, 11.475271749270698, 10.565234327872808, 13.169231987636543, 14.634689171615516, 13.736225131709709, 12.649816327887915, 10.292980654220825, 13.548616200609116, 12.564120652064938, 5.732544193874607, 7.278941711027182, 6.570655792241833, 7.124221236378749, 7.033719758769407, 9.045912241548177, 12.759821970359962, 13.695727375938931, 13.344155316872516], [14.53495895697677, 15.24432419263705, 14.533422800797966, 10.34913263167912, 7.6991237753184185, 8.266755034841283, 9.977851815250999, 8.157440063188051, 7.553183311151185, 6.898215192836571, 14.936922861186362, 19.731030446979187, 23.27853655096636, 23.79986635346836, 23.58395330924007, 18.590787082933073, 15.205293289511841, 10.08115670611223, 7.240294401648055, 6.965703494521914, 6.447930294030546, 6.276419584452746, 8.325655245088395, 9.534905293720305, 10.902828304559186, 9.48141179078197, 5.303225670663766, 3.908378066682995, 5.377248799155115, 15.847306794738687, 23.2661151714767, 13.661394063136164, 7.842920276241821, 0.0, 11.367607393082665, 13.497845673374526, 15.945548049220895, 14.663794715603153, 13.006819041532781, 11.84660676566576, 9.556255139548917, 7.44923955898688, 6.713246754158147, 5.5648390148719855, 5.585842984257361, 5.181524682800773, 8.568751784200645, 13.798588606773968, 14.130548499387444, 9.958521452865888, 9.205970463166793, 4.461151025674428, 6.282638764027033, 8.929351904805758, 15.790739792322675, 17.400413551416893, 7.262499346948072, 6.148497895791478, 5.911323909092325, 8.01414864735748, 6.390221974191143, 7.081450606658054, 6.89728111945603, 8.430722424298159, 14.323018805636966, 13.409916404483274, 13.215791953431387, 14.091015711176196, 12.999121748894478, 10.732267601597083, 7.4072291111648525, 4.7971824869573165, 5.422754430849218, 5.734433165608022, 4.393888658820237, 8.179934086533382, 9.605313000367296, 8.39931496158347, 7.147264757318059, 5.8679343418185965, 8.593501436031794, 7.4878013109282575, 6.6715934440114495, 8.756088002469706, 8.217925590978263, 8.816255079785705, 10.113746921461889, 13.363998580675286, 16.782162022528407, 17.682872229307943, 17.433050553939104], [7.523835090372282, 8.682825277929412, 7.472837138599545, 3.658651007088712, 6.390525419241894, 6.253014626289736, 6.838159663694953, 6.773286054384952, 6.250696426941514, 11.38535568887179, 22.919044010531557, 26.780085138091255, 29.620212943462274, 30.03165645288867, 29.860837304968374, 25.569982013358647, 23.00080201956265, 18.235912316629026, 15.933903426537414, 14.724906463314667, 14.127300675307277, 13.912873419370815, 5.3542544711382645, 4.630660434349747, 5.97112653562392, 4.780078297828981, 7.766749548429654, 11.796356644133239, 13.196454606787638, 22.37274828040451, 29.610451972805055, 20.150411895345727, 14.85797366606589, 11.367607393082665, 0.0, 5.523041150101612, 9.487321713359394, 6.157344645061362, 5.4499208202615685, 5.6384437413443855, 4.223017346297815, 5.893664878825935, 11.567101660924168, 9.983742366736996, 9.052043606758257, 12.51281328217427, 9.94930752159557, 7.5199341637406825, 7.557840538766656, 4.6239240358885985, 6.437832722018918, 8.453580312226384, 9.486847604845622, 13.123182849602228, 23.478222576218002, 25.03512654617726, 12.66348005448984, 7.010444840898657, 6.488014735070207, 6.738967929155454, 7.626860282469548, 6.578410763376066, 6.539462008752587, 14.027907920717986, 22.474984609998003, 21.773496722755283, 21.648437471637934, 22.070205537773727, 21.366612180115673, 18.68190318418952, 15.767883555965765, 13.150801581706089, 8.368061879558478, 7.762781047722766, 8.18813888624958, 6.693167260560728, 6.563436654912164, 6.246657762970086, 6.490495459126461, 7.564251697183018, 5.915750041704914, 6.047493219706318, 10.447666032779471, 16.703449885236616, 16.125690342695094, 16.706723919444574, 18.35237248021744, 21.233185816632087, 24.402626198295494, 25.250232269598914, 24.940904991242743], [5.277156392990728, 6.465885531801972, 4.975299188144853, 5.887249500010255, 8.223020990175606, 7.531126498911679, 7.896380792652731, 7.980164312826244, 7.7498952015909355, 13.594510299544162, 25.47811563791911, 29.115268190759686, 31.747267256772403, 32.131485380561124, 31.971887151225125, 27.993536491996927, 25.485923740205948, 21.073300110434737, 18.65973598098968, 17.46263618977231, 16.852014374300776, 16.626484310465347, 9.608478194983286, 5.237283270786591, 5.231411005932976, 4.5541448791604235, 11.06089218837476, 14.377218467429698, 15.689853487938839, 25.07654264014763, 31.738160461669455, 23.040106567567083, 17.53555270833708, 13.497845673374526, 5.523041150101612, 0.0, 6.412585375540682, 4.362670468128066, 5.303947897375794, 6.0026682150899004, 5.107873091922386, 9.399809142042567, 14.80045078359704, 13.266164318818136, 12.096465501453451, 15.3001444948159, 13.528063018055214, 5.032998225031288, 4.281230164062695, 6.759225780150812, 7.918945209000038, 9.884815979964372, 11.149154178895548, 16.388936486870683, 26.051347486126065, 27.483186372934377, 15.510864787826623, 9.02100457305516, 8.516688854571548, 8.935279918045358, 9.776514954293674, 8.370964855123024, 8.471957489899939, 17.21275317329391, 25.044325316094465, 24.339522951075026, 24.216937764748984, 24.627029082056836, 23.97240139055406, 21.537717462249606, 18.660343252660464, 15.831054231556706, 11.601006707267263, 9.666244678497327, 10.221594194743568, 8.314037733444941, 7.7302322468312195, 7.515045324206573, 8.247131468974885, 9.59737317668765, 7.848177902762122, 8.123635902896316, 13.981548519590069, 19.496799612047027, 18.94922983474141, 19.53163913990022, 21.03627231479901, 23.9638965934615, 26.90180987368488, 27.698112121988746, 27.416540647585144], [5.025626049965584, 4.107356835868407, 5.193021254960265, 8.516562462968729, 10.819775311377262, 9.706309952408077, 9.558562811426377, 9.739711154979465, 10.898256127390056, 17.515294987248613, 28.15500826714246, 31.529318635625, 33.97481523246072, 34.33411487963716, 34.1848015910226, 30.494546523197336, 28.19574743260241, 23.95600579329748, 21.525167608767955, 20.291122767182905, 19.660299588460145, 19.402975224457226, 13.55888431220509, 10.172948426867906, 5.687460049833513, 8.382653089118742, 14.300597391034518, 17.02798142629835, 18.984129259858626, 27.83571039664158, 33.96630567632549, 25.994966051990783, 21.021273802711175, 15.945548049220895, 9.487321713359394, 6.412585375540682, 0.0, 5.056537277928546, 6.6937447819408185, 7.348321399765235, 8.06727850804492, 13.55540187126713, 17.987241719093284, 16.589792545338536, 15.256941019617997, 18.27054908348436, 16.98547462848572, 10.143053378642403, 5.443752812956533, 9.414311173486176, 9.967673957118565, 11.923513845701681, 15.259835157934907, 19.988019970031676, 28.684971709726113, 30.004400098398033, 19.09169517041269, 12.999608478577253, 11.153356865128806, 11.404213882746651, 12.145335839976884, 10.885096440058733, 11.779720881915411, 20.730062385618695, 27.709758627549682, 27.007379579960773, 26.858556966108758, 27.40483811310394, 26.68561151445966, 24.4291699383206, 21.634251402186077, 18.728475639628513, 14.777141283547069, 12.003685446850936, 12.588496131666796, 10.801736384729695, 9.631081465689524, 9.6238896095627, 10.525865516563702, 12.969480055869075, 10.228498350060363, 10.774791408059363, 17.631756228908845, 22.32884500399091, 21.870591210759365, 22.389695738668834, 23.92909655822423, 26.753829652232312, 29.482347069474486, 30.21591110500583, 29.96185592629116], [2.2665795162869333, 3.2703577405285693, 2.309368780172104, 5.421002588049485, 8.378183767556385, 7.481938612819801, 6.7874577149245505, 7.7506804496696216, 8.441979800972698, 15.725447218647759, 26.54905445845776, 30.075886524888446, 32.629685880839524, 33.003632757175936, 32.848272259283256, 28.994654301727405, 26.61211014566362, 22.131173871902092, 19.716224198937002, 18.306140769662058, 17.665508716801376, 17.409436884159252, 10.881990910511211, 8.015800343978364, 5.442518982593553, 6.337012487539197, 12.194493128373619, 15.18172635580375, 17.02287308002967, 26.210037829837425, 32.620825432536215, 24.26409821856164, 19.15884345765817, 14.663794715603153, 6.157344645061362, 4.362670468128066, 5.056537277928546, 0.0, 3.32915614998789, 4.059414931159914, 5.7426728864017464, 11.030161297511242, 15.781242813533378, 14.341275856564538, 12.962379234331793, 16.215988251439803, 14.68617538626636, 8.973334171112281, 6.3127484905956095, 7.821506865864971, 7.259823816699115, 10.936235777436005, 13.470585702029492, 18.00178087242282, 27.071234491980864, 28.477002916792646, 17.270395976887045, 10.748863180617827, 9.353925803352235, 8.72354961251559, 9.974040502314258, 8.685038663989836, 9.30298486806186, 18.716975297393162, 26.100352103611996, 25.39822299783759, 25.259638771724394, 25.77158157114993, 25.059769998399513, 22.612890658709944, 19.76973467272437, 16.837686698405427, 12.336223356392985, 10.123505599780941, 10.986576081139805, 8.214053615354366, 6.8970205070309305, 7.388146183917007, 8.471339766227445, 10.663370966911485, 7.508505980414821, 8.333278382746139, 15.339645741692467, 20.4103481717522, 19.915248361031523, 20.46108932750334, 22.11308101609242, 25.048191439937952, 27.916796113306667, 28.695937476726545, 28.42382792074942], [3.498600909937818, 4.523225660112336, 3.575037800606093, 3.3129608791628145, 6.351722906328086, 5.6923430381363955, 4.965798794445269, 6.007581261827804, 6.732303718581696, 14.460352532184453, 24.89561950122978, 28.584838824789703, 31.26151025240794, 31.651625515124564, 31.48959531335941, 27.495064652801602, 25.028290805886698, 20.372657591070446, 17.925749622117525, 16.439351500542035, 15.79413752157876, 15.53906262937591, 9.342422445730305, 7.2167065709182445, 4.995618783336343, 5.155664840391626, 10.136246670549546, 13.301932837947444, 15.266186904499593, 24.623503316821303, 31.25226190980664, 22.690412696879203, 17.59960240916692, 13.006819041532781, 5.4499208202615685, 5.303947897375794, 6.6937447819408185, 3.32915614998789, 0.0, 2.304623083793058, 4.2285592836413795, 9.434361999024254, 13.564308991196405, 12.245898435987103, 10.746665406897131, 14.312308373068308, 12.385838177614922, 9.561737696166858, 7.521518289440668, 5.997381279200936, 5.194241707826613, 9.460730941121211, 12.047245952523308, 16.605389547214855, 25.424352912762924, 26.906264371365616, 15.861480766554616, 9.243528233402643, 7.752999202747131, 6.60531478900267, 8.004146375117397, 6.916266351254137, 7.572557741199649, 17.017914985086524, 24.443799867393505, 23.72844516041786, 23.5845955622695, 24.114657357183788, 23.36646206115976, 20.795375827158797, 17.974850873763017, 14.989963245835597, 10.549655420858354, 8.316979614754283, 9.264390278858857, 6.329821039944002, 4.986297122383463, 5.5322286414897865, 6.735917295506331, 8.891045890075747, 5.664024716186882, 6.546334418809002, 13.613786131768334, 18.560109092390785, 18.09724742358934, 18.600625823906253, 20.349013440614915, 23.333993906362515, 26.316359274925215, 27.1381763754297, 26.852605803890256], [3.639761866454164, 4.676569344192012, 3.7527827084229606, 2.720231175856052, 4.879325336335984, 4.070591658152201, 2.9749425649074692, 4.318313307444854, 5.299904683173934, 13.75991757446995, 23.86417691205275, 27.65052428878729, 30.395607891366883, 30.79669387408338, 30.63014150838134, 26.559196768744666, 24.016090751305573, 19.2428724964107, 16.722162632908763, 15.153610341848694, 14.485676689449035, 14.213886139168517, 8.952083134917265, 7.093517293352032, 4.909369888385158, 4.6854844978438, 9.410108564031962, 11.966574851471572, 14.083268111643177, 23.810392547407307, 30.38609600299895, 21.875729926894756, 16.67360615251434, 11.84660676566576, 5.6384437413443855, 6.0026682150899004, 7.348321399765235, 4.059414931159914, 2.304623083793058, 0.0, 3.5325141309475887, 8.934822365898725, 12.746029401194349, 11.359040235327013, 9.776240022503217, 13.047753938040888, 12.187195984624353, 10.216198148362261, 8.35172199491275, 6.632918420893365, 3.456357811729409, 8.375368028379635, 11.413953540208846, 15.968804432259327, 24.39596764337721, 25.899291215232665, 15.15572920374499, 8.241988069865124, 6.516526153919685, 5.059328477932911, 6.485982375221464, 5.374893994183295, 6.191380077551225, 16.2766938294654, 23.383081372050025, 22.643619121340304, 22.493494016521836, 23.084610350027965, 22.3025071474443, 19.739914078041306, 16.837584135784454, 13.733578312660732, 9.257233607397133, 6.83201944908778, 7.938052545557956, 4.642462982219937, 3.0980021986397794, 3.9213830525180775, 5.204578781899585, 7.584171800334487, 3.9508858357657908, 5.008539383228119, 12.811061038949582, 17.354319307780383, 16.88258265719547, 17.414536640568553, 19.193509176356798, 22.301043273597625, 25.29795746589653, 26.1411937498837, 25.84701497693072], [5.9455983959018175, 6.986319345884324, 5.9113021957432705, 2.0765919928963377, 3.6218747811467824, 2.927161463434615, 4.082879759108509, 3.405974477681983, 3.531401381281123, 11.126920731483038, 22.267129472417604, 26.256220094477246, 29.13298095441901, 29.551209007057913, 29.37759637935482, 25.104352873669413, 22.39783663122135, 17.526509637091696, 14.929765340110102, 13.582489577736641, 12.91770243534213, 12.66239902919099, 6.640861898230977, 4.141300362582388, 3.4123209540718036, 1.6654542664288918, 7.038742418527459, 10.20563496006333, 12.083952209322785, 22.175941771804094, 29.123056682090994, 20.0916603125226, 14.46817337086856, 9.556255139548917, 4.223017346297815, 5.107873091922386, 8.06727850804492, 5.7426728864017464, 4.2285592836413795, 3.5325141309475887, 0.0, 6.354130888239352, 10.94258697910598, 9.34461797641923, 7.93462020342247, 11.31376980571671, 10.247014635781337, 8.12416298425755, 7.03008593167644, 4.29815087670274, 3.660091646543966, 5.835063743564154, 8.629747223842518, 13.65631253681246, 22.864584042339523, 24.420490570490525, 12.699771633651656, 5.6281116322832245, 3.9911951713747276, 4.450086451145771, 5.141894974049129, 3.7409245325431306, 4.301360942010043, 14.09715634390914, 21.776922242063563, 21.01071338908521, 20.86237203426448, 21.42527237120197, 20.633032910241198, 18.028410635319833, 14.979896897654669, 11.893338216990509, 7.442270398415769, 5.075175985034853, 5.751950070884771, 3.966583056262664, 3.7146029073672624, 2.902943311388546, 3.5113080751733303, 5.554345901611116, 3.3787729679302356, 3.4847088202199616, 10.596680496979152, 15.763087590269832, 15.230454454556169, 15.808138708148133, 17.5081137714237, 20.648692450789657, 23.79484806052963, 24.666914853451164, 24.363632410213548], [11.631226912138379, 12.753106940863361, 11.548521069447837, 6.60256408182744, 6.10249348475395, 6.796853872325709, 8.29787515555118, 7.241907239502731, 5.670201134561262, 6.398774664172236, 18.399389829592792, 22.733072570065215, 26.001363106055347, 26.46911894758146, 26.27514934516408, 21.42591685686949, 18.456435820416118, 13.482032932193178, 11.20134076146248, 10.326037123329256, 9.809899280176902, 9.668278368022483, 1.780593807348709, 4.790001349159475, 8.672724182629425, 6.211356940082239, 3.3519379417691946, 7.785019830917123, 8.246653872337305, 17.975356193467746, 25.990243065248155, 15.567523060139001, 9.628395551173044, 7.44923955898688, 5.893664878825935, 9.399809142042567, 13.55540187126713, 11.030161297511242, 9.434361999024254, 8.934822365898725, 6.354130888239352, 0.0, 6.883471399490673, 5.096646792697562, 4.98980597131102, 8.043287922426526, 5.71209069641763, 9.22662498933195, 11.020133535909574, 6.077701995306806, 7.398136732378084, 6.377591427503262, 4.67860874752653, 8.25375481387685, 19.059828936213737, 20.788796370801574, 7.632504192275568, 3.4027400032470547, 5.043446579343771, 6.458099285862077, 6.25012546269428, 6.0114243615413505, 5.0690505356374205, 8.789022940906133, 17.95978637522932, 17.233790965504333, 17.126964004778173, 17.42299340706812, 16.751271139846224, 13.897966613379843, 10.87814520778796, 8.579403887665448, 4.698294984237699, 6.154547879857067, 5.795325824671885, 6.744007485362546, 7.833778741091939, 6.882917025813981, 6.157236552098958, 4.850352205646152, 6.600634265436358, 5.780035862996539, 5.110860168473208, 12.134448564071487, 11.472203194987197, 12.094876171906002, 13.62879417413817, 16.578320292329977, 20.062984797369182, 20.998503845347166, 20.651500138773677], [15.833319392956927, 16.74657887693874, 15.81107136755141, 10.907676469389914, 8.67827909288857, 9.806442916401512, 10.986751804061676, 9.93215931920339, 8.840180556236056, 8.073495368384021, 13.729762951204867, 18.512889592956533, 22.327717713198687, 22.870731356223935, 22.645961406352896, 17.480852641840507, 14.272185745454705, 8.607970737132586, 6.564255365881315, 5.6104788950068505, 5.33407312893907, 5.3305174014843155, 7.317354853670133, 10.68713119226131, 13.165738787975323, 11.044408994285916, 4.723837467225202, 4.938040472532709, 5.142784196200327, 14.193188722271913, 22.314767072457368, 12.158953240193972, 7.457313951396093, 6.713246754158147, 11.567101660924168, 14.80045078359704, 17.987241719093284, 15.781242813533378, 13.564308991196405, 12.746029401194349, 10.94258697910598, 6.883471399490673, 0.0, 2.1610053783084244, 3.4166997171489695, 4.1130605678616465, 4.008190537713685, 15.024204495499427, 16.325587089759356, 10.731256564290728, 10.037941896068622, 8.64125667200617, 7.474847009644108, 8.044864854276884, 14.307743333135381, 16.308298811249003, 7.6982678654118075, 7.266945882218075, 8.263340396401528, 8.483429431212953, 7.64279199588404, 8.70237348591999, 8.005284683936752, 6.338131862892893, 13.290813082023334, 12.558069629356964, 12.428968951342965, 12.887167397454938, 12.017734987694821, 8.718356618036585, 6.206515530166187, 4.706376333242735, 5.270889461789597, 7.827704877435954, 7.354183461205736, 9.225431606063578, 10.595179389302674, 9.857273111122685, 8.958395693112907, 6.9585892007636865, 9.582970866088331, 8.762700749868468, 4.369905519334537, 6.946294471608907, 6.556368696942149, 6.8314640984938, 8.753220552112952, 11.741961991606432, 15.481763353472589, 16.585612457325244, 16.186664035073488], [14.454620956821525, 15.405862295836476, 14.42580061988827, 9.42202014778033, 7.19529639428248, 8.295119743937498, 9.642652107974971, 8.457009170641696, 7.2348931791679565, 6.909115925504889, 14.80371293023798, 19.557701146889727, 23.221575956410348, 23.744156426110717, 23.527732139691558, 18.379883933301734, 15.168991410358306, 9.537668210114296, 7.1571017984710545, 6.13440845274208, 5.671528715108246, 5.576713597988712, 5.653203027215681, 8.995779320523459, 11.62489613398508, 9.420997302177673, 2.9400449556627293, 4.272937398212872, 4.85320354302303, 15.067821946592385, 23.209124091983238, 12.826351993420703, 7.31494529825616, 5.5648390148719855, 9.983742366736996, 13.266164318818136, 16.589792545338536, 14.341275856564538, 12.245898435987103, 11.359040235327013, 9.34461797641923, 5.096646792697562, 2.1610053783084244, 0.0, 2.061159150286118, 3.9426072405008137, 4.047992753137941, 13.513663507173307, 14.794855710833541, 9.308639248344386, 8.671139712473348, 7.046448184173477, 6.024690478995354, 7.5213440990677025, 15.441370885870509, 17.358198075433272, 6.932149811798648, 5.432732306482758, 6.518554918981117, 7.10915459638213, 6.2018863184865864, 7.120376381124978, 6.348498477279151, 6.412346368867247, 14.3225775822755, 13.549605723833617, 13.417237166514482, 13.89494942830988, 13.040452816171749, 9.87662025435375, 6.852571342306145, 4.590346971078804, 3.513233089346899, 6.290114746119821, 5.733513601422722, 7.7777516303975, 9.223120673210339, 8.368581648601271, 7.373138824082617, 5.290308321537297, 8.08643963238853, 7.165418720316831, 3.316085441411886, 7.897533887453027, 7.330754129289468, 7.834354913275176, 9.682791940640966, 12.85017666966819, 16.565061154004642, 17.618239681069177, 17.236401515316555], [12.940548972023903, 13.886159324664654, 12.918871542138609, 7.971860920304423, 5.463323029439332, 6.631748238780771, 7.924079226524663, 6.785988435704982, 5.648081551065536, 7.917547304604133, 16.043906660572464, 20.679282195137407, 24.17924477978877, 24.68155693243886, 24.47342370529063, 19.57317334119742, 16.43525443127898, 10.854867187828608, 8.272641814128686, 6.835519023889765, 6.235961007986674, 6.0491970497741425, 5.628196136984178, 8.197110327792288, 10.361806567713462, 8.110072687799793, 2.630396741144394, 4.157579539273402, 5.760347277645328, 16.489886982012347, 24.167286346188806, 14.387521435793538, 8.856138543897929, 5.585842984257361, 9.052043606758257, 12.096465501453451, 15.256941019617997, 12.962379234331793, 10.746665406897131, 9.776240022503217, 7.93462020342247, 4.98980597131102, 3.4166997171489695, 2.061159150286118, 0.0, 4.481869250099475, 4.893822423360061, 12.94314197002183, 13.822286166491716, 8.367465677261842, 6.930723481242513, 6.168769245064318, 6.360882203153532, 9.208158757671729, 16.65049180976001, 18.503334717385616, 8.41036114270301, 4.6604708837376805, 5.243141634490757, 5.339211283636811, 4.475197937264374, 5.497411229929888, 4.822898642775443, 8.246198697737725, 15.542522583493431, 14.748991793452715, 14.601635745961715, 15.179352026630566, 14.292993431897708, 11.238411167678613, 8.216342022248993, 5.285227051501571, 2.8202725657856726, 4.719696668638614, 4.517789476670786, 6.052875804728112, 7.500073374389861, 6.689232483374453, 5.781986312590537, 3.8807812286610384, 6.433148832288768, 5.559119010806166, 5.0440352711466145, 8.92222756513966, 8.421303748626531, 8.912827153730214, 10.868025481504898, 14.187484686388418, 17.744341885583747, 18.78861197964805, 18.41750944751977], [16.04824694535002, 16.915431578460737, 16.025909318590177, 11.568173443269497, 8.57608673944825, 9.576169733469508, 10.78077193990752, 9.549684454418143, 8.524334540703274, 8.14862089517914, 12.735480339185603, 17.812838989297873, 21.60334098057319, 22.164108734871167, 21.93209819558202, 16.800444699151793, 13.258995352120914, 7.207382251890249, 4.281183601137845, 2.64340534316768, 2.0069935876697222, 1.8588280686069774, 8.718165378153717, 11.26679363288848, 13.472216613008708, 11.352054814541363, 6.053830673097191, 1.9429484018878038, 2.562719508439248, 14.260688771018332, 21.58995582998385, 12.290924673392665, 6.904148264256814, 5.181524682800773, 12.51281328217427, 15.3001444948159, 18.27054908348436, 16.215988251439803, 14.312308373068308, 13.047753938040888, 11.31376980571671, 8.043287922426526, 4.1130605678616465, 3.9426072405008137, 4.481869250099475, 0.0, 7.501136086184516, 15.722223159463226, 16.8449702016033, 12.06680006476957, 9.99160340104943, 8.06232130352256, 7.750605580145376, 8.9282407283369, 13.374702873064331, 15.273046209030962, 8.106582206867968, 7.100463533292819, 7.972771757427436, 8.395895202517398, 7.073378006448916, 8.277312563966795, 7.618600986892155, 7.275399765146158, 12.125800403275887, 11.246316720799584, 11.087154439337828, 11.879038297940202, 10.87062743581935, 7.902966643183932, 4.585626680472049, 1.1982912880508112, 4.634681969462219, 7.043722664950816, 6.528094836685156, 8.87361180506232, 10.448654625460993, 9.689394378937656, 8.578975074974952, 6.334988706554486, 9.439694504076913, 8.513420891423955, 5.551538900578528, 5.0194323510979615, 4.431773244018191, 5.0852055518182055, 7.0772380128238215, 10.903084420223456, 14.485851415402898, 15.60707790444361, 15.205421444231492], [15.109686114789824, 16.0685795500506, 15.078366965331602, 9.978606335075849, 9.058601650418938, 10.08627533136158, 11.257345372367164, 10.37221131963814, 9.257706381284448, 8.340958055378136, 16.165038714359948, 20.547656723371173, 24.106216380220957, 24.610019151929, 24.40127574344777, 19.394318622811415, 16.515856935808966, 11.498203728906095, 9.805444504892384, 9.150561182652426, 8.865497607489537, 8.840447235032986, 5.722287101331008, 9.550287785894158, 12.32133929831713, 10.362221451608425, 4.541645112989898, 7.931207595814056, 8.086456076250135, 15.691959373760778, 24.094221701224907, 13.515912403050143, 9.110218813581582, 8.568751784200645, 9.94930752159557, 13.528063018055214, 16.98547462848572, 14.68617538626636, 12.385838177614922, 12.187195984624353, 10.247014635781337, 5.71209069641763, 4.008190537713685, 4.047992753137941, 4.893822423360061, 7.501136086184516, 0.0, 13.386814121051977, 14.883321244412764, 8.782578845780575, 10.253756808830232, 9.268209504184515, 7.505217771522761, 8.026326506439196, 16.734219987043744, 18.60961957027428, 8.046663412242307, 7.620597830481874, 8.629737740548082, 8.99687228479009, 8.663437647918954, 9.273489650224986, 8.59894401784791, 7.246882830428036, 15.810674499414402, 15.170651109308988, 15.067175686549952, 15.308275096134272, 14.599318217358924, 11.491375824026209, 9.251406969612999, 8.028834728847759, 6.731140027572297, 8.877098543549948, 8.442656094208294, 9.771905125467988, 10.827315556928367, 10.092091195049548, 9.441046718936562, 7.959601946224166, 9.832340093620553, 9.153747478527258, 4.948629792413188, 10.29985496740328, 9.874774297831049, 10.160431236825321, 11.776493929562056, 14.22750967427077, 17.834074409808558, 18.826710282597098, 18.460892735781634], [10.008599204512036, 11.074683978731384, 9.713583010246436, 9.21415712732634, 10.813862158784746, 10.47776481883814, 11.493315169480937, 10.969927892003474, 9.992825233847817, 11.966873079137235, 24.8273079765398, 28.435112543543795, 31.127689724864705, 31.51946132305762, 31.356748194689867, 27.262412968880863, 24.679993497232548, 20.695972840474024, 18.528192149370774, 17.796352866701564, 17.292144603191936, 17.136918944919106, 9.691750364926303, 5.254440113467056, 8.302444712348468, 6.9927430917815645, 11.51738413177405, 15.117976034226983, 15.47431711906637, 24.138422131619105, 31.11840161102736, 21.99686673158573, 16.39160069488024, 13.798588606773968, 7.5199341637406825, 5.032998225031288, 10.143053378642403, 8.973334171112281, 9.561737696166858, 10.216198148362261, 8.12416298425755, 9.22662498933195, 15.024204495499427, 13.513663507173307, 12.94314197002183, 15.722223159463226, 13.386814121051977, 0.0, 5.7832640484577515, 8.132289298707743, 11.204887611465608, 10.954704335341347, 9.887893349812204, 14.97718607116098, 25.464075368767368, 26.862645097358133, 14.110702522494028, 9.363380900661454, 10.156058508744932, 11.641233132459242, 11.986843950353274, 10.758748210406813, 10.300376214139211, 16.122150574043843, 24.45482237152364, 23.799049726921034, 23.711719043039917, 23.891497285691187, 23.38875487582733, 21.094669916893526, 18.369934640176208, 16.07632620735399, 12.593642532533382, 11.636780615319863, 11.638135808347478, 11.132734398902414, 11.1903650267444, 10.527224724372667, 10.711794422276755, 10.876718232167503, 10.840604255555345, 10.601379642353233, 13.448901728335702, 19.524728510957722, 18.919113271814496, 19.520417377659996, 20.698167085034697, 23.350982631139672, 26.276549907279854, 27.0418996618942, 26.76737280010165], [7.321417378751415, 7.69852680353084, 7.221502573760424, 8.0864918799619, 10.368850037972958, 9.501724390174509, 10.268736896857735, 9.743487220349598, 10.046089274933134, 14.559591453779055, 26.48090063231528, 30.011942402810483, 32.574439811500355, 32.94901369572902, 32.79339443806934, 28.90329085608446, 26.472401414252584, 22.26187760291332, 19.87908731762915, 18.96587066689072, 18.374508271526278, 18.15462058040203, 11.128641971730552, 7.117047201631445, 4.995704023913736, 6.673066985551741, 12.315102832488899, 15.737936555535585, 17.166335267085156, 25.9699151344857, 32.565564331833734, 23.92702067413284, 18.64771699869313, 14.130548499387444, 7.557840538766656, 4.281230164062695, 5.443752812956533, 6.3127484905956095, 7.521518289440668, 8.35172199491275, 7.03008593167644, 11.020133535909574, 16.325587089759356, 14.794855710833541, 13.822286166491716, 16.8449702016033, 14.883321244412764, 5.7832640484577515, 0.0, 7.111232401529962, 10.243201885740612, 10.27683749046067, 12.396861619534452, 17.21970116981843, 27.089157361928493, 28.43127274758772, 16.28221324425964, 10.901564104875549, 9.761081728528842, 11.214378710273001, 11.611088696010537, 10.255944735791756, 10.703320780334682, 18.29787066812364, 26.044270583855578, 25.33762294780609, 25.200189609678826, 25.671205421241016, 24.966601085542976, 22.709608463610504, 19.854466051768345, 17.18683215464565, 13.387402157572494, 11.219129108026701, 11.335566481044136, 10.639664283153312, 10.099002160355997, 9.491717075716998, 9.940505478634078, 11.647799862580689, 10.101145009079886, 10.156560528029697, 15.32944435952433, 20.8801447868204, 20.35020341643349, 20.911225596453413, 22.296508844459638, 25.03619022369623, 27.904738872317257, 28.638368796993625, 28.395259569761077], [8.63959609366827, 9.417069384198262, 8.65084150181776, 4.51085977139692, 6.418305965577479, 6.284241526371109, 7.516351591744316, 6.628482755523699, 6.58490533844191, 10.918713458388455, 22.290260265953542, 26.24815164142142, 29.143488240677307, 29.561567639805165, 29.38801620681867, 25.067873368136006, 22.426010421111382, 17.70451927161467, 15.307525590265852, 14.308165907360014, 13.719008440929128, 13.511588476705409, 5.991455566928027, 5.022636629298882, 4.882141082668625, 4.6938886371518524, 6.650318748105174, 11.110459983490578, 12.722446913575226, 21.809224519706117, 29.13356754762864, 19.64098954688121, 14.380897410242055, 9.958521452865888, 4.6239240358885985, 6.759225780150812, 9.414311173486176, 7.821506865864971, 5.997381279200936, 6.632918420893365, 4.29815087670274, 6.077701995306806, 10.731256564290728, 9.308639248344386, 8.367465677261842, 12.06680006476957, 8.782578845780575, 8.132289298707743, 7.111232401529962, 0.0, 6.8529773382346235, 6.73111458163715, 8.715935481253501, 12.851033423177343, 22.91550090659106, 24.460134974906946, 12.081535152418045, 7.033754701809428, 5.7886274807242675, 7.060955469853687, 7.378210071924263, 6.548792360486144, 6.873636993292799, 13.505497822717398, 21.84012383807941, 21.107373454159923, 20.960899298724396, 21.46069396797824, 20.66927278209867, 18.052092243014766, 15.166450789625967, 12.529732545779048, 8.602592399668634, 7.228197819747717, 7.19066245204803, 7.121293629131461, 7.1341382398334865, 6.2331356486835965, 6.295104363294263, 7.555223429275821, 6.576490143857322, 6.34649253529415, 10.265873975303604, 16.215615805920514, 15.70570281819061, 16.20984347336858, 17.819404522487556, 20.639117365205795, 23.852590176832074, 24.689801982103933, 24.409148669461477], [6.746821181923364, 7.673321358092782, 6.786892346490735, 3.2657313501200576, 1.825639214763175, 1.6111844448641695, 1.132193551297554, 1.8530010695051264, 2.7260744132509767, 11.861313500558946, 21.238884331480403, 25.2975935927146, 28.2444015750888, 28.6755923186106, 28.496645593343437, 24.21574702889763, 21.476826711139726, 16.427642667143058, 13.795568386696136, 12.112613462252986, 11.421222985112273, 11.13778024371524, 7.702495607897264, 6.912988154660932, 6.166957284052853, 4.648411611518656, 7.102419491600869, 8.878357323383636, 11.175375759262533, 21.538162370045004, 28.23416496999022, 19.60124180271943, 14.216224498289973, 9.205970463166793, 6.437832722018918, 7.918945209000038, 9.967673957118565, 7.259823816699115, 5.194241707826613, 3.456357811729409, 3.660091646543966, 7.398136732378084, 10.037941896068622, 8.671139712473348, 6.930723481242513, 9.99160340104943, 10.253756808830232, 11.204887611465608, 10.243201885740612, 6.8529773382346235, 0.0, 6.359182390505536, 9.539806082795405, 14.06898436348209, 21.78499675296817, 23.374445763262546, 13.144508291935336, 6.069507601909527, 4.295680306615706, 1.7735823337821819, 3.2757160076775436, 2.5414453390525797, 3.467756609795595, 13.972996091650575, 20.72323913595708, 19.945095975744845, 19.787166279879905, 20.449742846687407, 19.607188719291745, 16.962296316240504, 13.982064714289935, 10.715089239966883, 6.422801790394526, 3.861720936245507, 5.234314571195807, 1.427343468652828, 0.6459199753496735, 1.461089476555744, 2.581341778466283, 4.731367286646418, 1.146472792850097, 2.2515134384471396, 10.514094376700635, 14.404221669876742, 13.938699717524646, 14.476645675702553, 16.334589000892436, 19.628239513397247, 22.734487548317972, 23.64408792542123, 23.326033482215298], [10.817382871474868, 11.4562801071725, 10.83521416626394, 7.019623512675956, 5.052094033153132, 5.0497814634991265, 7.052382273681792, 4.9366387728392, 4.9073465294692395, 8.351233607012198, 18.61478477423298, 22.992766061995727, 26.175452019843885, 26.64015133086576, 26.447436136247482, 21.83508425009867, 18.79737867923701, 13.837464396190226, 11.055621986920778, 10.221759475625612, 9.589213934111841, 9.350338572909088, 7.193479505420077, 6.646498539595274, 6.723527884732979, 5.8519100207945085, 5.10838298883611, 6.56907614707624, 8.581542831380577, 19.01591949615305, 26.16440596804929, 16.86442904610593, 11.022964587766783, 4.461151025674428, 8.453580312226384, 9.884815979964372, 11.923513845701681, 10.936235777436005, 9.460730941121211, 8.375368028379635, 5.835063743564154, 6.377591427503262, 8.64125667200617, 7.046448184173477, 6.168769245064318, 8.06232130352256, 9.268209504184515, 10.954704335341347, 10.27683749046067, 6.73111458163715, 6.359182390505536, 0.0, 6.433190536917513, 11.022874989032253, 19.354973091192193, 20.91364999600088, 9.55312363985556, 4.761161704164215, 2.6903556060156544, 5.820238561139866, 4.529703978441374, 4.300886899703742, 4.763823847952038, 11.152278152083673, 18.052034685544054, 17.199095600048384, 17.0188481914956, 17.776296927312785, 16.812484888182958, 14.427504210544795, 11.19214336999757, 8.172620211510743, 5.70053465770214, 3.5562888028101267, 2.3630957568072026, 5.630619157597743, 6.659377042637837, 5.175538940887961, 4.08834717166007, 4.598981057189239, 5.776448835458317, 4.749435887699127, 8.317934332034053, 12.276456672273099, 11.742173110325476, 12.338444990742598, 13.842396384569154, 17.044477322266232, 20.306562975188747, 21.180676484150187, 20.91266431660345], [13.690948617340739, 14.750618079157679, 13.551135963290703, 9.593173563667602, 8.039955465420121, 8.643320832966207, 10.362589552208732, 8.959819667297968, 7.272381132297805, 3.382569174422081, 16.779248153992647, 21.23814060068214, 24.674504895525143, 25.166933987428287, 24.96284802615747, 19.934550377923877, 16.62116987830501, 12.223413390032748, 9.980358814663733, 9.747822454305688, 9.357098862446115, 9.290457266589833, 6.263942443871492, 6.2990037099466285, 10.46419194612097, 7.8770933303566535, 5.374199310768738, 7.615880985828131, 6.698184411755234, 16.611597736419743, 24.662786603647167, 14.238298319418528, 7.440356893988721, 6.282638764027033, 9.486847604845622, 11.149154178895548, 15.259835157934907, 13.470585702029492, 12.047245952523308, 11.413953540208846, 8.629747223842518, 4.67860874752653, 7.474847009644108, 6.024690478995354, 6.360882203153532, 7.750605580145376, 7.505217771522761, 9.887893349812204, 12.396861619534452, 8.715935481253501, 9.539806082795405, 6.433190536917513, 0.0, 7.490938435123663, 17.609315749395318, 19.279592103600596, 5.9229200445601435, 4.021398948054972, 6.5666218619001615, 8.621202412080713, 7.837366496431176, 7.728578581483512, 6.638725284374237, 7.682424107450997, 16.367769317057355, 15.626429363174626, 15.546846952831636, 15.661808570668455, 15.120505206405383, 12.641079919014704, 9.710932662435422, 7.834284728174859, 6.4640020837036145, 7.354078867610131, 6.557862173721926, 8.601344731355328, 9.901565860569313, 8.77054068694327, 7.922631433202628, 5.799649728497928, 8.885054504097646, 7.859244429821855, 5.656588716864083, 11.25053432261479, 10.55608553428034, 11.21000719575495, 12.217362184914096, 15.126246865801011, 18.55631116244642, 19.470898935800104, 19.152783806074446], [18.52407413659895, 19.46102757960541, 18.466812726363745, 13.939579219864104, 12.722409574362928, 13.46999969621619, 14.887270880523095, 13.684807565238252, 12.384899621865953, 5.022263190432138, 13.383673538968935, 17.69100486502317, 21.611535385188333, 22.17209589086082, 21.94016981344919, 16.02744640370043, 13.053177817757124, 9.530814641965724, 8.930766507008302, 9.877379796456006, 9.864406747306978, 9.962217123455945, 8.46784317300059, 11.890634632262788, 15.299062387705497, 13.463892971096048, 8.292459110812022, 9.674947626289919, 7.924710416224507, 11.817658852008178, 21.598161717293998, 8.89466275888593, 4.734577458541942, 8.929351904805758, 13.123182849602228, 16.388936486870683, 19.988019970031676, 18.00178087242282, 16.605389547214855, 15.968804432259327, 13.65631253681246, 8.25375481387685, 8.044864854276884, 7.5213440990677025, 9.208158757671729, 8.9282407283369, 8.026326506439196, 14.97718607116098, 17.21970116981843, 12.851033423177343, 14.06898436348209, 11.022874989032253, 7.490938435123663, 0.0, 14.263631731066486, 15.961938455961059, 2.6534654147804324, 9.62280869512031, 11.247696018226359, 12.847964825470411, 12.060346234800377, 12.421270751870523, 11.589025418392527, 3.048940069258289, 13.112720468345707, 12.591811236148228, 12.575050283039076, 12.286897561130944, 11.922141356233025, 9.695429422080295, 7.831158163663918, 8.760075349061733, 9.056130496303927, 11.827200429893685, 10.870614835595203, 13.239788835866088, 14.498843000840605, 13.578826719727996, 12.564401005347694, 10.725389995445482, 13.302656844502978, 12.396143033803513, 4.703147083372049, 10.075847224154737, 9.39168539327825, 9.884220878352604, 10.220823549802313, 11.561007865184612, 15.215804816898887, 15.972610452201588, 15.69424455885168], [26.9545620584382, 27.667358758947287, 26.93110011909561, 23.07322751033219, 20.624960907225386, 21.464724964069177, 22.42200801378516, 21.406035464920855, 20.558812635274265, 16.06070902634758, 1.923619931950194, 6.227476826717404, 11.751515295618992, 12.730814788558726, 12.322517088871772, 7.334591628912373, 4.598174987366356, 6.959432291041946, 9.812752441554402, 11.370974667690666, 12.046833517467633, 12.333962386169143, 19.463493363177307, 22.222246573830276, 24.50375053137455, 22.787144656290934, 17.615464921423285, 14.550012426991156, 12.779625465213119, 8.170286975245888, 11.70656380881123, 8.86808035880621, 11.80160567984982, 15.790739792322675, 23.478222576218002, 26.051347486126065, 28.684971709726113, 27.071234491980864, 25.424352912762924, 24.39596764337721, 22.864584042339523, 19.059828936213737, 14.307743333135381, 15.441370885870509, 16.65049180976001, 13.374702873064331, 16.734219987043744, 25.464075368767368, 27.089157361928493, 22.91550090659106, 21.78499675296817, 19.354973091192193, 17.609315749395318, 14.263631731066486, 0.0, 2.9717245071563996, 14.60514729096667, 18.850862056435826, 19.919327478813535, 20.422022607256814, 19.32202232174074, 20.3634713029762, 19.7758857775688, 12.4141103187433, 2.497692730025302, 3.5350126642039164, 3.79993433918927, 3.4459912160294333, 3.8169888347598357, 6.390791556171126, 9.712305400521014, 12.815120592377072, 17.026616448281512, 19.252236657254038, 18.608935785528246, 20.859892294767157, 22.16872786185536, 21.55977491039109, 20.595013268818946, 18.638374157821037, 21.343347667823632, 20.5715862616768, 15.011787277104236, 9.016403309394994, 9.524346247775698, 8.917124536329602, 7.0507929863969245, 3.4039060011167686, 1.6527496663524623, 3.26877071174147, 2.6143462086096063], [28.352095823580726, 29.03261769335634, 28.32978078907324, 24.64581001912692, 22.260513992191438, 23.051208180520696, 23.972470193544872, 22.98096296570467, 22.185710020354474, 17.684254113286382, 3.6128625163468944, 5.049841667281257, 9.98438565652321, 11.03969284639033, 10.567912090335826, 7.097426394309411, 5.379789331572117, 9.122738514081785, 11.747367066007008, 13.289020266307098, 13.934970783644259, 14.202261666746638, 21.185814540318688, 23.785399394138153, 25.961095149838812, 24.334995309412104, 19.398363892537336, 16.336423395575515, 14.65847316873514, 9.214360404745811, 9.892212187610797, 10.23330156182965, 13.612619277725338, 17.400413551416893, 25.03512654617726, 27.483186372934377, 30.004400098398033, 28.477002916792646, 26.906264371365616, 25.899291215232665, 24.420490570490525, 20.788796370801574, 16.308298811249003, 17.358198075433272, 18.503334717385616, 15.273046209030962, 18.60961957027428, 26.862645097358133, 28.43127274758772, 24.460134974906946, 23.374445763262546, 20.91364999600088, 19.279592103600596, 15.961938455961059, 2.9717245071563996, 0.0, 16.211063734421664, 20.542211772655616, 21.544320741071413, 22.07149708447235, 20.98564956525304, 21.986631144096418, 21.436436959954555, 14.344527463730701, 4.006241366847076, 4.99617437963407, 5.206826937038241, 5.215652144469984, 5.578050714528689, 8.74213347464434, 11.744434972695283, 14.681729744915705, 18.815674605606162, 20.894235817408255, 20.25335834165744, 22.473080222192912, 23.73520324446475, 23.146035940306586, 22.205586813300368, 20.336648356876346, 22.948751619926085, 22.201122622660268, 16.919058625753355, 11.069098937941023, 11.559197601916988, 11.015116538765666, 9.12316003358696, 5.870956862229355, 1.6392897036762055, 1.221638696529751, 1.6034527016501567], [17.66830676469995, 18.600082158712144, 17.600087357504947, 13.202231805630547, 11.71533905716486, 12.42568815849632, 13.962859900947887, 12.61613887394843, 11.29855086570644, 3.2364983750551817, 13.571416213508813, 18.07665138736155, 21.93594278579969, 22.48841836124002, 22.25978831075483, 16.504330548730984, 13.222348850532322, 9.609148233004534, 8.371495500366427, 9.289794043677206, 9.189479911405616, 9.25409487423549, 8.239050461594996, 10.89333523830601, 14.287507605400585, 12.39123728434639, 7.467467128087129, 8.595925604540144, 6.843160374743711, 12.615294744169447, 21.9229945148547, 9.799770475541674, 4.113913446004081, 7.262499346948072, 12.66348005448984, 15.510864787826623, 19.09169517041269, 17.270395976887045, 15.861480766554616, 15.15572920374499, 12.699771633651656, 7.632504192275568, 7.6982678654118075, 6.932149811798648, 8.41036114270301, 8.106582206867968, 8.046663412242307, 14.110702522494028, 16.28221324425964, 12.081535152418045, 13.144508291935336, 9.55312363985556, 5.9229200445601435, 2.6534654147804324, 14.60514729096667, 16.211063734421664, 0.0, 8.423226813091789, 10.086169052343608, 11.948100625036796, 11.012262425523723, 11.346949102774497, 10.512362901840511, 3.8720141222724687, 13.224952217493275, 12.576262524353377, 12.521971073518191, 12.442676224186197, 11.927042632930089, 9.897409060383598, 7.529743721328297, 7.809652228739537, 8.317785118514722, 10.656679251789747, 9.593595832279094, 12.241533101844576, 13.561107887906399, 12.546417719955768, 11.490370200751508, 9.564093014131858, 12.395169394729212, 11.40955929284699, 4.768381998507588, 9.829542928024493, 9.124034534029207, 9.692659459443165, 10.071658538325686, 11.91913816699556, 15.532032022733484, 16.27586184116126, 16.061816416555423], [10.855319615114162, 11.969828432829406, 10.74177969419225, 6.498145088138482, 4.514463199125062, 5.167007482661313, 6.896472775849671, 5.538146795856839, 3.5982477972605222, 6.548180750919157, 18.164661515370494, 22.596109018796255, 25.842469070344563, 26.31304965487645, 26.11792100052098, 21.370331764357058, 18.236776053679538, 13.1945191840848, 10.566971743104881, 9.452535283433528, 8.847539233820717, 8.654005987492154, 4.822769378590917, 4.564473063219308, 8.103230921469219, 5.150857897328542, 4.111594069381675, 6.468186333537212, 7.233732063234828, 18.34445566586532, 25.8312806277478, 16.09410766903037, 9.6641129203733, 6.148497895791478, 7.010444840898657, 9.02100457305516, 12.999608478577253, 10.748863180617827, 9.243528233402643, 8.241988069865124, 5.6281116322832245, 3.4027400032470547, 7.266945882218075, 5.432732306482758, 4.6604708837376805, 7.100463533292819, 7.620597830481874, 9.363380900661454, 10.901564104875549, 7.033754701809428, 6.069507601909527, 4.761161704164215, 4.021398948054972, 9.62280869512031, 18.850862056435826, 20.542211772655616, 8.423226813091789, 0.0, 3.436657468548853, 5.119684868891844, 4.479781507746248, 4.162464761963627, 2.876537341752602, 9.68711521411868, 17.66869974860751, 16.876820300142874, 16.75547711358816, 17.182732824587305, 16.460286229552295, 13.755577802269263, 10.548305625915981, 7.604750985749271, 3.9544544690018255, 4.111354324807576, 3.9157640944494094, 5.006671288623221, 6.426608698215681, 5.320898465740199, 4.444873897314195, 2.303975134031046, 5.292474345535525, 4.22806073085729, 6.311629843749954, 11.560226318176273, 10.905666138235246, 11.586610789269153, 13.134981764634222, 16.45619182262817, 19.830750537102432, 20.79019162865746, 20.444642814500952], [9.333584897212232, 10.178339502274579, 9.334928674433048, 4.929170261399358, 2.840036669291371, 3.005106277639895, 5.106780267629606, 3.117475438574478, 2.647906233789911, 8.759195740530325, 19.265079861383168, 23.59285465856058, 26.71837811284109, 27.173794425310298, 26.984890563396505, 22.421632434943685, 19.463411465981487, 14.304956362714961, 11.549501591722812, 10.296801688477636, 9.612635390167108, 9.349991897434826, 5.7105847964343255, 5.349276617284025, 5.9488459084535945, 4.268878355543848, 4.443442535610248, 6.679192925277103, 8.791514207524104, 19.55063861505805, 26.70755661228653, 17.3906201201343, 11.50984621679078, 5.911323909092325, 6.488014735070207, 8.516688854571548, 11.153356865128806, 9.353925803352235, 7.752999202747131, 6.516526153919685, 3.9911951713747276, 5.043446579343771, 8.263340396401528, 6.518554918981117, 5.243141634490757, 7.972771757427436, 8.629737740548082, 10.156058508744932, 9.761081728528842, 5.7886274807242675, 4.295680306615706, 2.6903556060156544, 6.5666218619001615, 11.247696018226359, 19.919327478813535, 21.544320741071413, 10.086169052343608, 3.436657468548853, 0.0, 3.658606514692651, 2.751749996578816, 2.0689982041490595, 2.5315213745011707, 11.384856162905692, 18.719939200161278, 17.895664000338375, 17.731353517023702, 18.411522384506355, 17.51616913331045, 14.893858120780305, 11.6503617870912, 8.433083356339395, 4.408518300472348, 2.037209092165815, 1.9411173805242825, 3.4820822374672336, 4.6539775382981485, 3.1586450383405045, 1.9171310829556285, 2.9348551400165372, 3.4907048164824057, 2.336795464842867, 7.949507323940322, 12.529597417946272, 11.968656372418108, 12.58793436263095, 14.29551510120822, 17.6030396464972, 20.893530865584136, 21.813033254538322, 21.500628881357326], [8.375744296871206, 9.321393662894659, 8.395209407677788, 4.129191870852974, 1.157028593458856, 2.1626928666261396, 2.7351015238111143, 2.374170109167614, 2.259018058708028, 10.808969256144751, 19.87016178194634, 24.077582342539213, 27.147300968944933, 27.595639590101147, 27.40964318695554, 22.985580161842478, 20.150881024613305, 14.934027504597454, 12.28129658790567, 10.563155886711423, 9.866489380644573, 9.58489398025994, 6.82583695252721, 6.9790013326208165, 7.182078971839537, 5.235605443320093, 5.793412611105469, 7.349425882587698, 9.670828319616021, 20.263665469232457, 27.13665051394925, 18.288239667131915, 12.844134610658738, 8.01414864735748, 6.738967929155454, 8.935279918045358, 11.404213882746651, 8.72354961251559, 6.60531478900267, 5.059328477932911, 4.450086451145771, 6.458099285862077, 8.483429431212953, 7.10915459638213, 5.339211283636811, 8.395895202517398, 8.99687228479009, 11.641233132459242, 11.214378710273001, 7.060955469853687, 1.7735823337821819, 5.820238561139866, 8.621202412080713, 12.847964825470411, 20.422022607256814, 22.07149708447235, 11.948100625036796, 5.119684868891844, 3.658606514692651, 0.0, 1.913217913792475, 1.919140425819562, 2.4821803144341548, 12.578518982851204, 19.34487213371427, 18.555596715932914, 18.39755749283513, 19.0691522041906, 18.20564914820594, 15.472374671620628, 12.452593146249349, 9.166006884273534, 4.839634455225415, 2.815352951557495, 4.20408689880544, 1.147584463861377, 2.3314348584186226, 2.146068366137983, 2.224400095748088, 3.460430932083903, 1.4868065361242098, 1.6396762750605034, 9.095978328292748, 12.877502449018651, 12.400386551931287, 12.944568045520008, 14.851325616869975, 18.204906820680222, 21.404142973251314, 22.34999694169682, 22.01602822681145], [9.63069494835154, 10.470964991071483, 9.652635110013225, 5.369221164569818, 1.8543295096644512, 2.7494191042881093, 4.138867173608147, 2.6868166955321025, 2.4518945946417308, 9.922788727295842, 18.73608034963017, 23.09309053169424, 26.252937174807666, 26.716288754104266, 26.524126753620724, 22.00666163430341, 19.04663413875278, 13.716983371431724, 10.941448045690906, 9.284943915127629, 8.565781176964911, 8.272371137609651, 6.809394573902551, 7.179537222220106, 7.516350735356937, 5.6863605718351735, 5.009580806463973, 5.814412423976364, 8.359573120469765, 19.348371522194217, 26.241923738974293, 17.353662435601603, 11.741099350728884, 6.390221974191143, 7.626860282469548, 9.776514954293674, 12.145335839976884, 9.974040502314258, 8.004146375117397, 6.485982375221464, 5.141894974049129, 6.25012546269428, 7.64279199588404, 6.2018863184865864, 4.475197937264374, 7.073378006448916, 8.663437647918954, 11.986843950353274, 11.611088696010537, 7.378210071924263, 3.2757160076775436, 4.529703978441374, 7.837366496431176, 12.060346234800377, 19.32202232174074, 20.98564956525304, 11.012262425523723, 4.479781507746248, 2.751749996578816, 1.913217913792475, 0.0, 1.597672576397746, 2.2015334589613924, 11.66842124225543, 18.178929189180117, 17.353691849034785, 17.184982437714453, 17.930242974742416, 17.009812215381988, 14.308103858331764, 11.172294408050519, 7.749190928196, 3.827263651149269, 1.1362393605062837, 2.558853403236095, 2.198478238000696, 3.7466789562762095, 2.8428985192235445, 1.9042730095889864, 2.511919266154153, 2.7529523518110657, 1.9181551671746104, 8.300895244511828, 11.650641343543851, 11.162534016867554, 11.731443302527472, 13.620653705064246, 17.072735592628998, 20.315437063179857, 21.280261560512493, 20.944427531642276], [8.404015269672744, 9.305034198346283, 8.40748130856208, 4.266287631768144, 1.0822252894839706, 1.4530421143172139, 3.3671230814018402, 1.6101200968469993, 1.327587143320862, 10.003404076082703, 19.765256275349945, 24.02026101497664, 27.087240953895282, 27.536557464263055, 27.350159272518344, 22.899871487418203, 19.997992672203825, 14.816088887383685, 12.06791445088998, 10.519877515813938, 9.812063319448423, 9.52775613076672, 6.578671524402197, 6.032205550393639, 6.220028078466576, 4.28924599193267, 5.483812050245802, 7.040778988205847, 9.322603957121359, 20.187063194164004, 27.076566874552718, 18.14697719031798, 12.412529027230825, 7.081450606658054, 6.578410763376066, 8.370964855123024, 10.885096440058733, 8.685038663989836, 6.916266351254137, 5.374893994183295, 3.7409245325431306, 6.0114243615413505, 8.70237348591999, 7.120376381124978, 5.497411229929888, 8.277312563966795, 9.273489650224986, 10.758748210406813, 10.255944735791756, 6.548792360486144, 2.5414453390525797, 4.300886899703742, 7.728578581483512, 12.421270751870523, 20.3634713029762, 21.986631144096418, 11.346949102774497, 4.162464761963627, 2.0689982041490595, 1.919140425819562, 1.597672576397746, 0.0, 1.6690745418098096, 12.336677363245018, 19.221356798019183, 18.40752341297554, 18.245695086546913, 18.936964723433302, 18.06050643788035, 15.412457637695496, 12.256565491426686, 8.902508034466381, 4.652999931845228, 1.6311530868369541, 2.9351563906734808, 1.5000281259065, 2.9112258154419126, 1.6247850379099669, 0.5843154928110004, 2.7466936423961203, 1.7947492800515683, 0.708369736589859, 8.868946520654443, 12.85059133955381, 12.32978884621496, 12.926768707627001, 14.733450778605672, 18.12410375216273, 21.331170441983225, 22.26575485871281, 21.939844931104574], [9.13040396908509, 10.198161209642164, 9.06681799725187, 4.845464512230193, 1.8946054026499337, 2.7240098009429308, 4.309361137939436, 3.0932779449028076, 1.057791617535395, 8.999234369576255, 19.164420746846396, 23.488882551943814, 26.617161509180224, 27.074280439082123, 26.884677356135875, 22.341861570864495, 19.35745039896175, 14.17064005285901, 11.450511909445522, 9.921937079990949, 9.23291107048915, 8.971058539515326, 5.879873375884575, 5.438154298474713, 7.136653378537229, 4.404436246631121, 4.948624527273215, 6.629935929672334, 8.448917746133187, 19.552632153568183, 26.606298841130254, 17.462332982511555, 11.496874536680789, 6.89728111945603, 6.539462008752587, 8.471957489899939, 11.779720881915411, 9.30298486806186, 7.572557741199649, 6.191380077551225, 4.301360942010043, 5.0690505356374205, 8.005284683936752, 6.348498477279151, 4.822898642775443, 7.618600986892155, 8.59894401784791, 10.300376214139211, 10.703320780334682, 6.873636993292799, 3.467756609795595, 4.763823847952038, 6.638725284374237, 11.589025418392527, 19.7758857775688, 21.436436959954555, 10.512362901840511, 2.876537341752602, 2.5315213745011707, 2.4821803144341548, 2.2015334589613924, 1.6690745418098096, 0.0, 11.463577813673904, 18.636478226613683, 17.831682216385193, 17.686368684459556, 18.283433841782635, 17.467965296021593, 14.761164187256576, 11.592436716141084, 8.29193292448622, 3.934588666903636, 2.281968986879781, 3.2446471584169077, 2.239470506135748, 3.8425533264579057, 2.8794711411102805, 2.163275315469338, 1.5029821587829846, 2.7115816890191593, 1.697426551295417, 7.9644529377612105, 12.237025998710852, 11.672040178960776, 12.300788633792816, 14.069028401150897, 17.491195570899855, 20.753031084067164, 21.709435010669157, 21.368439686771563], [19.02290321669731, 19.95448013840254, 18.968699965503568, 14.331480506453198, 12.566019159583256, 13.47549824433456, 14.833408562489492, 13.641122224492312, 12.333843394323896, 5.706966834156562, 11.577250471678543, 16.249756008863766, 20.43539289003042, 21.027331192003093, 20.782633911697676, 14.7242986399552, 11.399883978301197, 7.346273619762467, 6.877567691870402, 7.885139851549652, 7.986753407023442, 8.145495268995504, 9.208810813943437, 12.654961529557458, 15.9592593741203, 13.926281581121124, 8.078235153440787, 8.381196834933263, 6.194543755029038, 10.633635202759244, 20.421242219503878, 7.8819664098817945, 3.1411915337802396, 8.430722424298159, 14.027907920717986, 17.21275317329391, 20.730062385618695, 18.716975297393162, 17.017914985086524, 16.2766938294654, 14.09715634390914, 8.789022940906133, 6.338131862892893, 6.412346368867247, 8.246198697737725, 7.275399765146158, 7.246882830428036, 16.122150574043843, 18.29787066812364, 13.505497822717398, 13.972996091650575, 11.152278152083673, 7.682424107450997, 3.048940069258289, 12.4141103187433, 14.344527463730701, 3.8720141222724687, 9.68711521411868, 11.384856162905692, 12.578518982851204, 11.66842124225543, 12.336677363245018, 11.463577813673904, 0.0, 11.315223614409463, 10.77612306102279, 10.775341911343652, 10.396627291595422, 10.069773611682063, 7.382233135761702, 5.682946377406677, 7.095315706085954, 8.620442791518867, 11.532106496706918, 10.650004950632798, 13.069841375996045, 14.44528124917345, 13.575061538140137, 12.544213468512872, 10.386858662810422, 13.308290716271436, 12.382743679829952, 4.289797960003358, 7.829287741394711, 7.190896629556575, 7.595862711440538, 7.966158635282273, 9.567634493137582, 13.472979369152647, 14.407013800553035, 14.036191166672427], [25.97621802353965, 26.69957340605761, 25.95271472720724, 22.03866216268034, 19.520024421326042, 20.354180307426958, 21.370696038771207, 20.287768799906697, 19.432413105220583, 14.75244073153214, 1.237954404863856, 7.641386503503597, 12.873730670085981, 13.780145256662136, 13.40380268602027, 7.931947287203628, 3.9061220682591618, 5.61987487026373, 8.352354344228937, 10.12126975018592, 10.792812244264347, 11.079140112633592, 18.41643982446066, 21.1204408750782, 23.40803256947098, 21.685242010844107, 16.454784301476504, 13.249629840444143, 11.44075337385114, 8.219791920897903, 12.841376500089098, 8.298474198521655, 10.479503782547924, 14.323018805636966, 22.474984609998003, 25.044325316094465, 27.709758627549682, 26.100352103611996, 24.443799867393505, 23.383081372050025, 21.776922242063563, 17.95978637522932, 13.290813082023334, 14.3225775822755, 15.542522583493431, 12.125800403275887, 15.810674499414402, 24.45482237152364, 26.044270583855578, 21.84012383807941, 20.72323913595708, 18.052034685544054, 16.367769317057355, 13.112720468345707, 2.497692730025302, 4.006241366847076, 13.224952217493275, 17.66869974860751, 18.719939200161278, 19.34487213371427, 18.178929189180117, 19.221356798019183, 18.636478226613683, 11.315223614409463, 0.0, 1.237214082761109, 1.5721044894018086, 2.419200751827966, 1.7270014940498246, 5.305891881074997, 8.313700884956722, 11.469915471844898, 15.868957289982703, 18.06456808119787, 17.360583644111205, 19.763794770473236, 21.109320351306916, 20.455787008933786, 19.44960386021157, 17.466467703700427, 20.259662741515502, 19.450000959579853, 13.903683680435783, 7.806671798624834, 8.262732578208983, 7.734891481649908, 5.673294169474345, 2.69746850678287, 3.288859477249353, 4.347865194205678, 4.120919816487139], [25.263016270122776, 25.99008620697718, 25.240568484877475, 21.294404431171024, 18.722242790859333, 19.55602743279108, 20.59819862444615, 19.482299516265883, 18.63260106217959, 14.07201661473582, 2.350871719420246, 8.658996812061526, 13.649290396179943, 14.508794687932053, 14.15183163219607, 8.756168881541628, 4.464537002795659, 4.822059662392646, 7.39609675274386, 9.216523298983873, 9.886378462167311, 10.170704559772838, 17.715347360848504, 20.387298151002703, 22.647614232125992, 20.920464496710775, 15.670474271597852, 12.339694108173418, 10.57391499030788, 8.734957210260248, 13.61902743961545, 8.476759607672884, 9.863002576610711, 13.409916404483274, 21.773496722755283, 24.339522951075026, 27.007379579960773, 25.39822299783759, 23.72844516041786, 22.643619121340304, 21.01071338908521, 17.233790965504333, 12.558069629356964, 13.549605723833617, 14.748991793452715, 11.246316720799584, 15.170651109308988, 23.799049726921034, 25.33762294780609, 21.107373454159923, 19.945095975744845, 17.199095600048384, 15.626429363174626, 12.591811236148228, 3.5350126642039164, 4.99617437963407, 12.576262524353377, 16.876820300142874, 17.895664000338375, 18.555596715932914, 17.353691849034785, 18.40752341297554, 17.831682216385193, 10.77612306102279, 1.237214082761109, 0.0, 0.4408785411196919, 2.825249294790404, 1.1599579960814175, 4.699824811164319, 7.439930992493221, 10.55198218008004, 15.057287280222601, 17.223789977315153, 16.503646425399577, 18.96800319657814, 20.333282105810493, 19.660303119425354, 18.635349024107505, 16.646735010930588, 19.474465845214855, 18.648385590223533, 13.20989583138863, 6.931714873197786, 7.385698875242108, 6.883403499723823, 4.798830450819602, 2.8683713399234985, 4.370064036205193, 5.406173705832523, 5.197938909723577], [25.119524468139662, 25.841358755123277, 25.0994253361355, 21.147512104049095, 18.564607666802214, 19.394925190449026, 20.44010034059747, 19.315320138377146, 18.4844934701407, 14.030244300460705, 2.686675807970937, 8.893140378734763, 13.808553075045326, 14.658722079487655, 14.30550062923765, 8.998162943002985, 4.807016900755587, 4.735436716270302, 7.228377973821537, 9.048420316615013, 9.714025070312406, 9.994628405863462, 17.603622198302716, 20.274207824793084, 22.488626619843718, 20.781153866249817, 15.52324495627185, 12.153230032719188, 10.463953223073897, 8.93542823124525, 13.77863992228886, 8.623693557562413, 9.883318850612772, 13.215791953431387, 21.648437471637934, 24.216937764748984, 26.858556966108758, 25.259638771724394, 23.5845955622695, 22.493494016521836, 20.86237203426448, 17.126964004778173, 12.428968951342965, 13.417237166514482, 14.601635745961715, 11.087154439337828, 15.067175686549952, 23.711719043039917, 25.200189609678826, 20.960899298724396, 19.787166279879905, 17.0188481914956, 15.546846952831636, 12.575050283039076, 3.79993433918927, 5.206826937038241, 12.521971073518191, 16.75547711358816, 17.731353517023702, 18.39755749283513, 17.184982437714453, 18.245695086546913, 17.686368684459556, 10.775341911343652, 1.5721044894018086, 0.4408785411196919, 0.0, 3.1948220669390657, 1.2753151941622909, 4.658518260953791, 7.30437781149854, 10.381456970811945, 14.909404611261204, 17.051898987566343, 16.326674712559974, 18.81127225596187, 20.175877311243106, 19.498991027748684, 18.470068371105558, 16.503290923760467, 19.31781471654246, 18.49062460209144, 13.124851426354223, 6.7786798634856185, 7.249497882215636, 6.739460731337793, 4.720679504240946, 3.0758122800779324, 4.643193615887261, 5.642209741565989, 5.466490923811222], [25.669399952989874, 26.41442883593341, 25.63744129831319, 21.703013158335093, 19.222196376944186, 20.072013625740528, 21.113851098946764, 20.032766833986067, 19.093420664289102, 13.898247647722258, 2.042172995854035, 7.767543111019966, 13.276466094633458, 14.167151599362347, 13.801361170439517, 7.465000007195451, 2.3705377167306145, 5.525932968091945, 8.233059312950832, 10.045045534527627, 10.702800802061466, 10.99950134153803, 17.93541563342256, 20.612087876211415, 23.092618877402856, 21.290125891663585, 16.05702793883747, 13.087594330149361, 10.952128402466348, 7.218908888870448, 13.255092773277509, 7.269890467258901, 9.408468957709987, 14.091015711176196, 22.070205537773727, 24.627029082056836, 27.40483811310394, 25.77158157114993, 24.114657357183788, 23.084610350027965, 21.42527237120197, 17.42299340706812, 12.887167397454938, 13.89494942830988, 15.179352026630566, 11.879038297940202, 15.308275096134272, 23.891497285691187, 25.671205421241016, 21.46069396797824, 20.449742846687407, 17.776296927312785, 15.661808570668455, 12.286897561130944, 3.4459912160294333, 5.215652144469984, 12.442676224186197, 17.182732824587305, 18.411522384506355, 19.0691522041906, 17.930242974742416, 18.936964723433302, 18.283433841782635, 10.396627291595422, 2.419200751827966, 2.825249294790404, 3.1948220669390657, 0.0, 2.4806076026071477, 5.072834498146993, 8.03686808396308, 11.253211059335557, 15.54741719391558, 17.81328494431356, 17.10253170640691, 19.482340571138568, 20.84035905612914, 20.174447179376486, 19.17507901229627, 17.095788715282183, 19.976633000390965, 19.15423045919545, 13.313521434631653, 7.8159267269773425, 8.13970131040553, 7.6977315212776665, 5.555509698407859, 2.5310988389141342, 4.154490353663648, 5.247962168964058, 4.838234130995147], [24.942807481427614, 25.680605516542364, 24.919067027440995, 20.91359120007364, 18.365734011932982, 19.214558002712142, 20.27991192687343, 19.15260403143849, 18.277757068077946, 13.505487201080852, 2.4289467328904477, 8.825922784661472, 14.004440534912492, 14.85153278907512, 14.503013446921189, 8.661227149515172, 4.302537529686114, 4.373460742348935, 7.033848628194483, 8.937427892749636, 9.60225815404923, 9.893569205176053, 17.23500340069658, 19.964224217296845, 22.28244671883517, 20.537352804238793, 15.182108408021252, 11.999617492112636, 10.158386140992377, 8.063637013347966, 13.982471775717844, 7.689126456735999, 9.219139995581143, 12.999121748894478, 21.366612180115673, 23.97240139055406, 26.68561151445966, 25.059769998399513, 23.36646206115976, 22.3025071474443, 20.633032910241198, 16.751271139846224, 12.017734987694821, 13.040452816171749, 14.292993431897708, 10.87062743581935, 14.599318217358924, 23.38875487582733, 24.966601085542976, 20.66927278209867, 19.607188719291745, 16.812484888182958, 15.120505206405383, 11.922141356233025, 3.8169888347598357, 5.578050714528689, 11.927042632930089, 16.460286229552295, 17.51616913331045, 18.20564914820594, 17.009812215381988, 18.06050643788035, 17.467965296021593, 10.069773611682063, 1.7270014940498246, 1.1599579960814175, 1.2753151941622909, 2.4806076026071477, 0.0, 4.041776135172188, 6.940013195017115, 10.180534501451582, 14.66143183483508, 16.88106867819693, 16.137664703708737, 18.633720424678977, 20.005755427265388, 19.317329277147117, 18.287703384675552, 16.2740016788862, 19.13126049817888, 18.294593251151102, 12.650658451686509, 6.644381966312887, 7.064103942488522, 6.55059504742195, 4.517289449096159, 2.239378627908755, 4.845454643346735, 5.860894887966405, 5.660568879218197], [22.541032781212625, 23.335168771770338, 22.517068542505584, 18.228212185014556, 15.669393180870491, 16.605393196709084, 17.701368685734014, 16.577838228406097, 15.618272698945834, 11.333556984192752, 5.753470190783642, 11.502670840655274, 16.375466262582012, 17.108456090636608, 16.806798774742937, 10.85613271147598, 6.956801501536124, 1.6459851295362562, 4.389160272546988, 6.129530728485061, 6.801580804206978, 7.120623466681836, 14.344429564524091, 17.40269599558065, 19.86331012414904, 17.97742334502611, 12.250724915241525, 9.269783768802364, 7.393627476416779, 8.654101628612821, 16.35780384204135, 7.47946022511105, 7.081274230207049, 10.732267601597083, 18.68190318418952, 21.537717462249606, 24.4291699383206, 22.612890658709944, 20.795375827158797, 19.739914078041306, 18.028410635319833, 13.897966613379843, 8.718356618036585, 9.87662025435375, 11.238411167678613, 7.902966643183932, 11.491375824026209, 21.094669916893526, 22.709608463610504, 18.052092243014766, 16.962296316240504, 14.427504210544795, 12.641079919014704, 9.695429422080295, 6.390791556171126, 8.74213347464434, 9.897409060383598, 13.755577802269263, 14.893858120780305, 15.472374671620628, 14.308103858331764, 15.412457637695496, 14.761164187256576, 7.382233135761702, 5.305891881074997, 4.699824811164319, 4.658518260953791, 5.072834498146993, 4.041776135172188, 0.0, 3.8942248516176794, 7.364002091651218, 11.732614101915305, 14.24949124911297, 13.543542273179632, 15.980402020234534, 17.401350509235904, 16.70337098345783, 15.660143283139766, 13.540871507646722, 16.463587588074294, 15.611153188384023, 9.578382342208304, 3.787281033489541, 4.118572004251731, 3.517417808917832, 2.467265408949891, 3.450635005233201, 7.740082254171905, 9.014514388334318, 8.541347466696031], [19.712853145169603, 20.53930945267859, 19.68871746903375, 15.264778888354224, 12.59257070636194, 13.521795915049847, 14.750417824335122, 13.496160011253862, 12.487547366169792, 8.702388648634273, 8.93167408268705, 14.471412411502339, 18.799467781123965, 19.441279879210565, 19.176354674214217, 13.440069906488016, 9.554125600106044, 3.096252417461419, 1.4671011939922016, 3.3885447764835934, 3.8603506504085576, 4.143733683082538, 11.413721544918944, 14.400725287530111, 16.86867054746946, 14.929906770138766, 9.142274136922182, 5.9261271030963565, 4.071626161729661, 10.826254577598332, 18.784084754686837, 8.859511959668936, 5.150307384559081, 7.4072291111648525, 15.767883555965765, 18.660343252660464, 21.634251402186077, 19.76973467272437, 17.974850873763017, 16.837584135784454, 14.979896897654669, 10.87814520778796, 6.206515530166187, 6.852571342306145, 8.216342022248993, 4.585626680472049, 9.251406969612999, 18.369934640176208, 19.854466051768345, 15.166450789625967, 13.982064714289935, 11.19214336999757, 9.710932662435422, 7.831158163663918, 9.712305400521014, 11.744434972695283, 7.529743721328297, 10.548305625915981, 11.6503617870912, 12.452593146249349, 11.172294408050519, 12.256565491426686, 11.592436716141084, 5.682946377406677, 8.313700884956722, 7.439930992493221, 7.30437781149854, 8.03686808396308, 6.940013195017115, 3.8942248516176794, 0.0, 3.9013832914193687, 8.451072110561846, 11.041237775933967, 10.254582301316146, 12.922834795057003, 14.427415437259521, 13.635725537074, 12.503996812505688, 10.324173335586824, 13.405930874533164, 12.474045002827413, 6.705254268641407, 2.6575934791013855, 2.0630771713830693, 2.511969235322482, 3.4578191140526577, 6.921098780265011, 10.896875235540488, 12.032244616830845, 11.632774970912347], [16.66965474220196, 17.504849173798082, 16.64827030383642, 12.253394769082615, 9.27282732318348, 10.207003291980964, 11.492520042843736, 10.15442951977498, 9.180480337097643, 7.977061490204836, 12.111378017383437, 17.29833000670482, 21.14638585273091, 21.718955065123573, 21.482137332451742, 16.29893219479993, 12.63721672297369, 6.5930598549000745, 3.473390837100874, 2.3873192883483885, 1.8949081153258185, 1.8319809711890196, 9.298283407445696, 11.725260983695987, 13.893451254012438, 11.880128870114573, 6.548917412496052, 2.203986068017837, 2.210827542301474, 13.841118814602012, 21.132711275421297, 11.864706988073365, 6.461401654495567, 4.7971824869573165, 13.150801581706089, 15.831054231556706, 18.728475639628513, 16.837686698405427, 14.989963245835597, 13.733578312660732, 11.893338216990509, 8.579403887665448, 4.706376333242735, 4.590346971078804, 5.285227051501571, 1.1982912880508112, 8.028834728847759, 16.07632620735399, 17.18683215464565, 12.529732545779048, 10.715089239966883, 8.172620211510743, 7.834284728174859, 8.760075349061733, 12.815120592377072, 14.681729744915705, 7.809652228739537, 7.604750985749271, 8.433083356339395, 9.166006884273534, 7.749190928196, 8.902508034466381, 8.29193292448622, 7.095315706085954, 11.469915471844898, 10.55198218008004, 10.381456970811945, 11.253211059335557, 10.180534501451582, 7.364002091651218, 3.9013832914193687, 0.0, 5.401697053846641, 7.597076238063719, 6.902502032481513, 9.58682739945854, 11.159195482129705, 10.327524960626393, 9.171461758135646, 6.985096214900692, 10.150263308682057, 9.180751575736084, 5.844475806900619, 4.55918288538385, 3.9524885945513097, 4.642711052294122, 6.4524455975025505, 10.32733335667065, 13.915743601203104, 15.022274945812708, 14.641996059238036], [12.383012457446222, 13.34612044639513, 12.367042223883926, 7.55353676964199, 4.96728170729896, 5.96256156194473, 7.27761095941618, 6.085587201032328, 4.877809642610282, 7.723127317803594, 16.42182319320039, 21.030141884346385, 24.443376922970234, 24.940369882715714, 24.734414590528182, 19.823290202560866, 16.71944373659993, 11.106821059713837, 8.466661514487383, 7.003758806932887, 6.3423368866519185, 6.10754073418695, 5.150190427078058, 7.775973225115459, 9.902827477811497, 7.688565151212257, 3.4478872235452838, 4.081828222933047, 5.85497199258822, 16.87994630226883, 24.43154777364988, 14.659370751409464, 8.913045164204602, 5.422754430849218, 8.368061879558478, 11.601006707267263, 14.777141283547069, 12.336223356392985, 10.549655420858354, 9.257233607397133, 7.442270398415769, 4.698294984237699, 5.270889461789597, 3.513233089346899, 2.8202725657856726, 4.634681969462219, 6.731140027572297, 12.593642532533382, 13.387402157572494, 8.602592399668634, 6.422801790394526, 5.70053465770214, 6.4640020837036145, 9.056130496303927, 17.026616448281512, 18.815674605606162, 8.317785118514722, 3.9544544690018255, 4.408518300472348, 4.839634455225415, 3.827263651149269, 4.652999931845228, 3.934588666903636, 8.620442791518867, 15.868957289982703, 15.057287280222601, 14.909404611261204, 15.54741719391558, 14.66143183483508, 11.732614101915305, 8.451072110561846, 5.401697053846641, 0.0, 3.932022727004349, 3.7920100737420803, 5.332373640575361, 6.897481546018573, 6.087651898852256, 4.955163817324181, 3.083610839739472, 5.622994211322592, 4.666963931524136, 5.013461358951599, 9.24435503152933, 8.61756622331176, 9.278976516934444, 11.160835220495951, 14.583607101726013, 18.07778283401929, 19.087178448463806, 18.714740809881878], [9.803875928171271, 10.606369961336148, 9.819081814615311, 5.671560346730318, 2.353192365943172, 2.904222633609133, 4.661566038736825, 2.7824020064782538, 2.5465167746470088, 9.466927710092243, 18.632961273954166, 23.020282196140535, 26.18195769393975, 26.646543550253007, 26.45387492268365, 21.919822426423675, 18.914641895829835, 13.626810089907849, 10.79652896860254, 9.277962504084808, 8.559545726582886, 8.268189369866933, 6.836600562720491, 6.857115974888871, 7.17769476167273, 5.454858498126954, 4.923085166778518, 5.650443170470281, 8.159269582394266, 19.2722857824493, 26.170914388018524, 17.243652445292533, 11.475271749270698, 5.734433165608022, 7.762781047722766, 9.666244678497327, 12.003685446850936, 10.123505599780941, 8.316979614754283, 6.83201944908778, 5.075175985034853, 6.154547879857067, 7.827704877435954, 6.290114746119821, 4.719696668638614, 7.043722664950816, 8.877098543549948, 11.636780615319863, 11.219129108026701, 7.228197819747717, 3.861720936245507, 3.5562888028101267, 7.354078867610131, 11.827200429893685, 19.252236657254038, 20.894235817408255, 10.656679251789747, 4.111354324807576, 2.037209092165815, 2.815352951557495, 1.1362393605062837, 1.6311530868369541, 2.281968986879781, 11.532106496706918, 18.06456808119787, 17.223789977315153, 17.051898987566343, 17.81328494431356, 16.88106867819693, 14.24949124911297, 11.041237775933967, 7.597076238063719, 3.932022727004349, 0.0, 1.6274663885719172, 2.7681786472642136, 4.260037929738007, 3.045737866063008, 1.7825541339764481, 2.3857824735393267, 3.2565105173861526, 2.188479149111562, 8.229710838592545, 11.632123912577299, 11.122250258715226, 11.71824805916608, 13.530349815602662, 16.992499244789908, 20.23495172624333, 21.188702400267243, 20.86182257543491], [10.798366058245907, 11.557452160995116, 10.81295312626527, 6.53523847767666, 3.6900897231153604, 4.144870647637228, 6.040760393416774, 4.038420460057914, 3.681233423108768, 8.49672534326615, 17.93741215499815, 22.416302667010207, 25.65249363197459, 26.12649620647163, 25.92996373457234, 21.28459856462393, 18.205345798512376, 12.917128497783876, 10.057648023893536, 8.801344471550937, 8.105576486535577, 7.833060230873531, 6.566143005104533, 6.895104811764208, 7.492377923657465, 5.964342135854071, 4.228028341320876, 5.0388596533865195, 7.464854568174797, 18.546618467237145, 25.6412222945054, 16.436181144177564, 10.565234327872808, 4.393888658820237, 8.18813888624958, 10.221594194743568, 12.588496131666796, 10.986576081139805, 9.264390278858857, 7.938052545557956, 5.751950070884771, 5.795325824671885, 7.354183461205736, 5.733513601422722, 4.517789476670786, 6.528094836685156, 8.442656094208294, 11.638135808347478, 11.335566481044136, 7.19066245204803, 5.234314571195807, 2.3630957568072026, 6.557862173721926, 10.870614835595203, 18.608935785528246, 20.25335834165744, 9.593595832279094, 3.9157640944494094, 1.9411173805242825, 4.20408689880544, 2.558853403236095, 2.9351563906734808, 3.2446471584169077, 10.650004950632798, 17.360583644111205, 16.503646425399577, 16.326674712559974, 17.10253170640691, 16.137664703708737, 13.543542273179632, 10.254582301316146, 6.902502032481513, 3.7920100737420803, 1.6274663885719172, 0.0, 4.225706483005286, 5.632890924174912, 4.287907497491276, 2.941033090678529, 2.847446915393916, 4.567043575310474, 3.4094442498707194, 7.479229409959395, 11.070186094831339, 10.534015967101553, 11.145702327306992, 12.871980569164977, 16.287329023179847, 19.599067080797475, 20.542846154362564, 20.22928839404291], [7.770891414899623, 8.741008554474599, 7.768308130228736, 4.011478499060129, 0.9710311607721562, 1.4233520255942067, 2.226144510892906, 1.6980481965623566, 1.640014291104837, 10.899436885388738, 20.29513996942498, 24.468390016512462, 27.486849969155664, 27.929738554364462, 27.745981888637726, 23.37573073231126, 20.53445274126672, 15.402348202887238, 12.711851335256688, 11.03045542482957, 10.329058001580682, 10.043664166861712, 7.225190953819932, 6.588371503055044, 6.660209884570847, 4.633858365167432, 6.369907402978049, 7.756117473637244, 9.997303178047742, 20.725545684022123, 27.476331131441416, 18.754458098309303, 13.169231987636543, 8.179934086533382, 6.693167260560728, 8.314037733444941, 10.801736384729695, 8.214053615354366, 6.329821039944002, 4.642462982219937, 3.966583056262664, 6.744007485362546, 9.225431606063578, 7.7777516303975, 6.052875804728112, 8.87361180506232, 9.771905125467988, 11.132734398902414, 10.639664283153312, 7.121293629131461, 1.427343468652828, 5.630619157597743, 8.601344731355328, 13.239788835866088, 20.859892294767157, 22.473080222192912, 12.241533101844576, 5.006671288623221, 3.4820822374672336, 1.147584463861377, 2.198478238000696, 1.5000281259065, 2.239470506135748, 13.069841375996045, 19.763794770473236, 18.96800319657814, 18.81127225596187, 19.482340571138568, 18.633720424678977, 15.980402020234534, 12.922834795057003, 9.58682739945854, 5.332373640575361, 2.7681786472642136, 4.225706483005286, 0.0, 1.7886838739866588, 1.468845812654964, 1.8160970799319078, 3.458193182625162, 1.0669330357867342, 1.33627720771578, 9.61728703755103, 13.365477578499632, 12.87230340195022, 13.444825992135955, 15.287400107580059, 18.67175060381135, 21.818865774421223, 22.7507905016868, 22.422783373243238], [6.283029329798854, 7.207676286269743, 6.325796521696077, 3.372873259085133, 2.330048203170486, 1.8213872253024075, 0.5598316575197207, 2.001914430223564, 3.025947082278935, 12.226300933839076, 21.625659865153253, 25.640404993994597, 28.549161705557196, 28.975817651592376, 28.79873649707211, 24.563970707141696, 21.847671888745076, 16.85161919154782, 14.223413856444049, 12.53928922101506, 11.848659598430858, 11.563181203533409, 8.134059077940192, 7.061033188106005, 6.0692246639708305, 4.690319653693698, 7.657682129485873, 9.321386109772666, 11.601550232119394, 21.932934133553694, 28.539034414426087, 20.01229046459133, 14.634689171615516, 9.605313000367296, 6.563436654912164, 7.7302322468312195, 9.631081465689524, 6.8970205070309305, 4.986297122383463, 3.0980021986397794, 3.7146029073672624, 7.833778741091939, 10.595179389302674, 9.223120673210339, 7.500073374389861, 10.448654625460993, 10.827315556928367, 11.1903650267444, 10.099002160355997, 7.1341382398334865, 0.6459199753496735, 6.659377042637837, 9.901565860569313, 14.498843000840605, 22.16872786185536, 23.73520324446475, 13.561107887906399, 6.426608698215681, 4.6539775382981485, 2.3314348584186226, 3.7466789562762095, 2.9112258154419126, 3.8425533264579057, 14.44528124917345, 21.109320351306916, 20.333282105810493, 20.175877311243106, 20.84035905612914, 20.005755427265388, 17.401350509235904, 14.427415437259521, 11.159195482129705, 6.897481546018573, 4.260037929738007, 5.632890924174912, 1.7886838739866588, 0.0, 1.6862772906843269, 2.9184045198623774, 5.141743105333308, 1.4989208239892384, 2.6529873454441626, 11.004788296546355, 14.832045016203852, 14.366655108606142, 14.910244388840567, 16.747389022705235, 20.0386706964449, 23.104494910830912, 24.00271046050759, 23.688907758406874], [6.9728819021137625, 7.846808640746455, 7.00060984416909, 3.2883907236776535, 1.3925156654727882, 0.24134186240744765, 2.160228859980746, 0.7528234643570664, 2.0246563391714427, 11.159734328465824, 20.982477588893836, 25.09337164816012, 28.0588946059298, 28.49289281548919, 28.312791389130382, 23.992406909644092, 21.201191187708382, 16.145111134557233, 13.448323450795248, 11.877669856152798, 11.17855190777952, 10.894517816218727, 7.31479138654664, 6.126679486113475, 5.298906840837484, 3.781521215461956, 6.581149913498286, 8.4603855231137, 10.751620495042177, 21.290855598670245, 28.048590298345115, 19.30708649099161, 13.736225131709709, 8.39931496158347, 6.246657762970086, 7.515045324206573, 9.6238896095627, 7.388146183917007, 5.5322286414897865, 3.9213830525180775, 2.902943311388546, 6.882917025813981, 9.857273111122685, 8.368581648601271, 6.689232483374453, 9.689394378937656, 10.092091195049548, 10.527224724372667, 9.491717075716998, 6.2331356486835965, 1.461089476555744, 5.175538940887961, 8.77054068694327, 13.578826719727996, 21.55977491039109, 23.146035940306586, 12.546417719955768, 5.320898465740199, 3.1586450383405045, 2.146068366137983, 2.8428985192235445, 1.6247850379099669, 2.8794711411102805, 13.575061538140137, 20.455787008933786, 19.660303119425354, 19.498991027748684, 20.174447179376486, 19.317329277147117, 16.70337098345783, 13.635725537074, 10.327524960626393, 6.087651898852256, 3.045737866063008, 4.287907497491276, 1.468845812654964, 1.6862772906843269, 0.0, 1.4688357742489706, 4.153162953838556, 1.2586609259113508, 1.5532066976466636, 10.121468075639957, 14.177613819226503, 13.687297153592569, 14.251912314484729, 16.058988432796564, 19.373824335640897, 22.508382773691025, 23.418001683535337, 23.102115535076013], [8.207553715450103, 9.046688246140755, 8.232450230695557, 4.105429853507819, 1.3813066203751563, 1.3030838698590195, 3.3584596724867137, 1.3450742471461559, 1.7483737951878764, 10.176337879724871, 19.99455416564098, 24.224217597362344, 27.272006974961172, 27.718328573898724, 27.53316099143124, 23.101932484339503, 20.22528656573966, 15.066902150220654, 12.321801918957956, 10.81419850974469, 10.107652376721472, 9.822239396982894, 6.66382625730184, 6.040826144782238, 5.784735762542138, 4.177358289472971, 5.603623419696562, 7.288456152126168, 9.632566891159039, 20.38043481507479, 27.261405240010554, 18.33777433938701, 12.649816327887915, 7.147264757318059, 6.490495459126461, 8.247131468974885, 10.525865516563702, 8.471339766227445, 6.735917295506331, 5.204578781899585, 3.5113080751733303, 6.157236552098958, 8.958395693112907, 7.373138824082617, 5.781986312590537, 8.578975074974952, 9.441046718936562, 10.711794422276755, 9.940505478634078, 6.295104363294263, 2.581341778466283, 4.08834717166007, 7.922631433202628, 12.564401005347694, 20.595013268818946, 22.205586813300368, 11.490370200751508, 4.444873897314195, 1.9171310829556285, 2.224400095748088, 1.9042730095889864, 0.5843154928110004, 2.163275315469338, 12.544213468512872, 19.44960386021157, 18.635349024107505, 18.470068371105558, 19.17507901229627, 18.287703384675552, 15.660143283139766, 12.503996812505688, 9.171461758135646, 4.955163817324181, 1.7825541339764481, 2.941033090678529, 1.8160970799319078, 2.9184045198623774, 1.4688357742489706, 0.0, 3.1903045849161664, 1.8649351180256453, 0.9639319014452039, 9.08294871098478, 13.127782635281012, 12.611995391837954, 13.203401176307578, 15.001250894371351, 18.36022093376975, 21.558530646264536, 22.482890764717194, 22.162632660071253], [10.48667880285496, 11.522896216815287, 10.41730083016834, 6.151296067317971, 3.070906976880997, 4.002914916399975, 5.588765370784717, 4.236743501233051, 2.4679880257337983, 8.0822787189468, 18.00207633560469, 22.465481719112894, 25.703127720923572, 26.176213422234873, 25.980057051050707, 21.319969529837675, 18.20836841745959, 12.93973098245902, 10.170968380478882, 8.683711431282935, 7.99999674496061, 7.749355557281535, 5.88051005120289, 6.009224610017554, 8.192193486915082, 5.476683119594268, 4.299695078432861, 5.413413079663855, 7.069853000383172, 18.531939093169797, 25.691878597250412, 16.42622088027496, 10.292980654220825, 5.8679343418185965, 7.564251697183018, 9.59737317668765, 12.969480055869075, 10.663370966911485, 8.891045890075747, 7.584171800334487, 5.554345901611116, 4.850352205646152, 6.9585892007636865, 5.290308321537297, 3.8807812286610384, 6.334988706554486, 7.959601946224166, 10.876718232167503, 11.647799862580689, 7.555223429275821, 4.731367286646418, 4.598981057189239, 5.799649728497928, 10.725389995445482, 18.638374157821037, 20.336648356876346, 9.564093014131858, 2.303975134031046, 2.9348551400165372, 3.460430932083903, 2.511919266154153, 2.7466936423961203, 1.5029821587829846, 10.386858662810422, 17.466467703700427, 16.646735010930588, 16.503290923760467, 17.095788715282183, 16.2740016788862, 13.540871507646722, 10.324173335586824, 6.985096214900692, 3.083610839739472, 2.3857824735393267, 2.847446915393916, 3.458193182625162, 5.141743105333308, 4.153162953838556, 3.1903045849161664, 0.0, 4.047645654649161, 2.959057682713494, 7.011405548223143, 11.003700534265493, 10.421029676437728, 11.065926438726718, 12.816523059976783, 16.30949516058414, 19.633253828441475, 20.617285128369264, 20.266650051171297], [7.2248147272313625, 8.19012947917291, 7.2511011754635435, 3.166944884368286, 1.3367454796892875, 1.2658805069352397, 1.946358806253073, 1.6544282963367514, 2.0635820301986554, 11.113023222261843, 20.784015715376565, 24.90266784311523, 27.887084473013214, 28.32371541470599, 28.142531338575687, 23.78624493986085, 21.007920150544994, 15.896967454293886, 13.250939513326706, 11.617939203148874, 10.92171250241891, 10.639150809928452, 6.890560229929056, 6.35348482471008, 6.07261600994337, 4.342470743083054, 6.450892894774476, 8.331943981063699, 10.579857335283625, 21.057762989390408, 27.876716657861962, 19.04779441973927, 13.548616200609116, 8.593501436031794, 5.915750041704914, 7.848177902762122, 10.228498350060363, 7.508505980414821, 5.664024716186882, 3.9508858357657908, 3.3787729679302356, 6.600634265436358, 9.582970866088331, 8.08643963238853, 6.433148832288768, 9.439694504076913, 9.832340093620553, 10.840604255555345, 10.101145009079886, 6.576490143857322, 1.146472792850097, 5.776448835458317, 8.885054504097646, 13.302656844502978, 21.343347667823632, 22.948751619926085, 12.395169394729212, 5.292474345535525, 3.4907048164824057, 1.4868065361242098, 2.7529523518110657, 1.7947492800515683, 2.7115816890191593, 13.308290716271436, 20.259662741515502, 19.474465845214855, 19.31781471654246, 19.976633000390965, 19.13126049817888, 16.463587588074294, 13.405930874533164, 10.150263308682057, 5.622994211322592, 3.2565105173861526, 4.567043575310474, 1.0669330357867342, 1.4989208239892384, 1.2586609259113508, 1.8649351180256453, 4.047645654649161, 0.0, 1.3139864357121676, 9.761361389894764, 13.919087238149292, 13.416001849346507, 13.989111142428188, 15.832708243122193, 19.144358456011087, 22.300194191686412, 23.216481833906784, 22.892804839070166], [8.145068598856485, 9.099605644814776, 8.148700675542528, 3.7709650199972904, 0.9289445504889328, 1.4126635197796569, 3.123126920422376, 1.759382386071682, 1.3078440397792237, 10.096568289495169, 19.98434565782195, 24.209187669530223, 27.263555810169077, 27.710013531257676, 27.524790011041762, 23.07448232181819, 20.208594391161117, 15.028509389290107, 12.327101894209978, 10.76632999306132, 10.06456397349991, 9.784792677013318, 6.235554325477108, 5.864242973970581, 6.174518612801665, 4.167322235106534, 5.478737383215464, 7.363865886303222, 9.577716980856898, 20.306409524996422, 27.252950787611017, 18.245334990450967, 12.564120652064938, 7.4878013109282575, 6.047493219706318, 8.123635902896316, 10.774791408059363, 8.333278382746139, 6.546334418809002, 5.008539383228119, 3.4847088202199616, 5.780035862996539, 8.762700749868468, 7.165418720316831, 5.559119010806166, 8.513420891423955, 9.153747478527258, 10.601379642353233, 10.156560528029697, 6.34649253529415, 2.2515134384471396, 4.749435887699127, 7.859244429821855, 12.396143033803513, 20.5715862616768, 22.201122622660268, 11.40955929284699, 4.22806073085729, 2.336795464842867, 1.6396762750605034, 1.9181551671746104, 0.708369736589859, 1.697426551295417, 12.382743679829952, 19.450000959579853, 18.648385590223533, 18.49062460209144, 19.15423045919545, 18.294593251151102, 15.611153188384023, 12.474045002827413, 9.180751575736084, 4.666963931524136, 2.188479149111562, 3.4094442498707194, 1.33627720771578, 2.6529873454441626, 1.5532066976466636, 0.9639319014452039, 2.959057682713494, 1.3139864357121676, 0.0, 8.829855293893495, 13.079822065279316, 12.551462077283462, 13.147908006031802, 14.96946184873383, 18.32374737379201, 21.541640284411088, 22.473458187292913, 22.145202047123526], [15.708627267779715, 16.702936323357275, 15.660441534304109, 10.741470022614829, 9.082438289860711, 10.019555284511775, 11.415109392719376, 10.242254095672335, 8.858008373893831, 5.275510968397886, 14.328912654915962, 19.00715230861721, 22.754106772342034, 23.28717993865768, 23.066468406431028, 17.611657082470128, 14.447763701329848, 9.214341528112922, 7.440025042410281, 7.225197903974508, 6.972146857113275, 6.977857959028205, 5.451289804261385, 9.415455450383064, 12.714723378871593, 10.545600130971373, 4.557391886180334, 6.253631526046092, 5.373112089197127, 13.923953035917808, 22.741398950479784, 11.352988117162718, 5.732544193874607, 6.6715934440114495, 10.447666032779471, 13.981548519590069, 17.631756228908845, 15.339645741692467, 13.613786131768334, 12.811061038949582, 10.596680496979152, 5.110860168473208, 4.369905519334537, 3.316085441411886, 5.0440352711466145, 5.551538900578528, 4.948629792413188, 13.448901728335702, 15.32944435952433, 10.265873975303604, 10.514094376700635, 8.317934332034053, 5.656588716864083, 4.703147083372049, 15.011787277104236, 16.919058625753355, 4.768381998507588, 6.311629843749954, 7.949507323940322, 9.095978328292748, 8.300895244511828, 8.868946520654443, 7.9644529377612105, 4.289797960003358, 13.903683680435783, 13.20989583138863, 13.124851426354223, 13.313521434631653, 12.650658451686509, 9.578382342208304, 6.705254268641407, 5.844475806900619, 5.013461358951599, 8.229710838592545, 7.479229409959395, 9.61728703755103, 11.004788296546355, 10.121468075639957, 9.08294871098478, 7.011405548223143, 9.761361389894764, 8.829855293893495, 0.0, 8.365606359611427, 7.6407518663150436, 8.240336978595177, 9.601357655425895, 12.304028880131847, 16.101903340851, 17.095561058759753, 16.707493631483086], [20.23387349979602, 21.037174003531906, 20.215407859142086, 15.957342814005433, 13.123480749804404, 14.073880921507367, 15.116846362091508, 14.010621798709376, 13.09685998260358, 10.682540758711115, 8.479127416082788, 14.010182712001518, 18.274383999408723, 18.93399894456814, 18.661873734498567, 13.36739485491781, 9.506560055494818, 2.9693433307940924, 2.031117791074942, 2.681423196193682, 3.442974727728947, 3.772742455467538, 12.649663454217206, 15.493969124374791, 17.736222089753415, 15.772452149205783, 10.30935124555094, 6.396491920078467, 5.102951909041479, 11.584505629938231, 18.258553961427737, 10.186733809648542, 7.278941711027182, 8.756088002469706, 16.703449885236616, 19.496799612047027, 22.32884500399091, 20.4103481717522, 18.560109092390785, 17.354319307780383, 15.763087590269832, 12.134448564071487, 6.946294471608907, 7.897533887453027, 8.92222756513966, 5.0194323510979615, 10.29985496740328, 19.524728510957722, 20.8801447868204, 16.215615805920514, 14.404221669876742, 12.276456672273099, 11.25053432261479, 10.075847224154737, 9.016403309394994, 11.069098937941023, 9.829542928024493, 11.560226318176273, 12.529597417946272, 12.877502449018651, 11.650641343543851, 12.85059133955381, 12.237025998710852, 7.829287741394711, 7.806671798624834, 6.931714873197786, 6.7786798634856185, 7.8159267269773425, 6.644381966312887, 3.787281033489541, 2.6575934791013855, 4.55918288538385, 9.24435503152933, 11.632123912577299, 11.070186094831339, 13.365477578499632, 14.832045016203852, 14.177613819226503, 13.127782635281012, 11.003700534265493, 13.919087238149292, 13.079822065279316, 8.365606359611427, 0.0, 0.9978790389552227, 0.39329771101934263, 2.5966718543102365, 6.660507578828871, 10.206143632581368, 11.472359292396307, 11.006422775958004], [19.768114328006547, 20.5937894054431, 19.74460637829439, 15.447764529763488, 12.625323024948605, 13.576820109582782, 14.660455736689359, 13.529225620398165, 12.553520985081217, 9.935354817180368, 8.92570955686287, 14.434944207725021, 18.65813403843455, 19.30464556225959, 19.03781908554468, 13.621173253889506, 9.741134379488793, 3.146454259938352, 1.5258513983605408, 2.2715107159911723, 2.996816486920525, 3.333952542019165, 12.00818021303893, 14.873974235839652, 17.232323892342148, 15.219820881662319, 9.740212726696033, 5.89011555209624, 4.346622940564004, 11.616816497786807, 18.642634390394786, 10.008054778470028, 6.570655792241833, 8.217925590978263, 16.125690342695094, 18.94922983474141, 21.870591210759365, 19.915248361031523, 18.09724742358934, 16.88258265719547, 15.230454454556169, 11.472203194987197, 6.556368696942149, 7.330754129289468, 8.421303748626531, 4.431773244018191, 9.874774297831049, 18.919113271814496, 20.35020341643349, 15.70570281819061, 13.938699717524646, 11.742173110325476, 10.55608553428034, 9.39168539327825, 9.524346247775698, 11.559197601916988, 9.124034534029207, 10.905666138235246, 11.968656372418108, 12.400386551931287, 11.162534016867554, 12.32978884621496, 11.672040178960776, 7.190896629556575, 8.262732578208983, 7.385698875242108, 7.249497882215636, 8.13970131040553, 7.064103942488522, 4.118572004251731, 2.0630771713830693, 3.9524885945513097, 8.61756622331176, 11.122250258715226, 10.534015967101553, 12.87230340195022, 14.366655108606142, 13.687297153592569, 12.611995391837954, 10.421029676437728, 13.416001849346507, 12.551462077283462, 7.6407518663150436, 0.9978790389552227, 0.0, 1.0539476558761165, 2.9204100160959063, 7.0431523010608466, 10.69178105730477, 11.923892704558941, 11.459829475942438], [20.30058923617565, 21.1090184388382, 20.281277836663087, 15.99265232528127, 13.190073935428588, 14.149714032147783, 15.199381191115613, 14.09514000439661, 13.165433094113645, 10.596688044537105, 8.37917109684436, 13.913185827942785, 18.226476703876852, 18.88776925751807, 18.614968245331628, 13.249280083260633, 9.404650289476056, 2.8002874403414912, 2.0955331563480337, 2.857465570067008, 3.6051504853199474, 3.938966034010452, 12.599891693691701, 15.502539074779722, 17.786722677953513, 15.815111900466318, 10.27920299881919, 6.504192922558823, 5.127749777507951, 11.347633907863653, 18.210609661807208, 9.934277081066583, 7.124221236378749, 8.816255079785705, 16.706723919444574, 19.53163913990022, 22.389695738668834, 20.46108932750334, 18.600625823906253, 17.414536640568553, 15.808138708148133, 12.094876171906002, 6.8314640984938, 7.834354913275176, 8.912827153730214, 5.0852055518182055, 10.160431236825321, 19.520417377659996, 20.911225596453413, 16.20984347336858, 14.476645675702553, 12.338444990742598, 11.21000719575495, 9.884220878352604, 8.917124536329602, 11.015116538765666, 9.692659459443165, 11.586610789269153, 12.58793436263095, 12.944568045520008, 11.731443302527472, 12.926768707627001, 12.300788633792816, 7.595862711440538, 7.734891481649908, 6.883403499723823, 6.739460731337793, 7.6977315212776665, 6.55059504742195, 3.517417808917832, 2.511969235322482, 4.642711052294122, 9.278976516934444, 11.71824805916608, 11.145702327306992, 13.444825992135955, 14.910244388840567, 14.251912314484729, 13.203401176307578, 11.065926438726718, 13.989111142428188, 13.147908006031802, 8.240336978595177, 0.39329771101934263, 1.0539476558761165, 0.0, 2.5435175312443943, 6.488832632511444, 10.131286987686284, 11.40376202184154, 10.932335103087164], [21.96819568468684, 22.768105918984958, 21.938226525127313, 17.779878576279337, 15.036905272040524, 15.948980460990859, 17.035389144605777, 15.898340291789848, 14.9272734633058, 11.106737475646153, 6.351388128733858, 12.216551107313748, 16.771438920543236, 17.487398969128154, 17.192391862533977, 11.646963455975088, 7.329986388523284, 1.514545276008544, 3.2331119439002354, 4.950485543205743, 5.6748481301987175, 5.9973194397819976, 14.19304565056159, 16.939977542331917, 19.380190379223034, 17.42602309569842, 12.02038493260461, 8.401514185524398, 6.433707699804266, 10.192808046408954, 16.75373389531201, 8.984741232400543, 7.033719758769407, 10.113746921461889, 18.35237248021744, 21.03627231479901, 23.92909655822423, 22.11308101609242, 20.349013440614915, 19.193509176356798, 17.5081137714237, 13.62879417413817, 8.753220552112952, 9.682791940640966, 10.868025481504898, 7.0772380128238215, 11.776493929562056, 20.698167085034697, 22.296508844459638, 17.819404522487556, 16.334589000892436, 13.842396384569154, 12.217362184914096, 10.220823549802313, 7.0507929863969245, 9.12316003358696, 10.071658538325686, 13.134981764634222, 14.29551510120822, 14.851325616869975, 13.620653705064246, 14.733450778605672, 14.069028401150897, 7.966158635282273, 5.673294169474345, 4.798830450819602, 4.720679504240946, 5.555509698407859, 4.517289449096159, 2.467265408949891, 3.4578191140526577, 6.4524455975025505, 11.160835220495951, 13.530349815602662, 12.871980569164977, 15.287400107580059, 16.747389022705235, 16.058988432796564, 15.001250894371351, 12.816523059976783, 15.832708243122193, 14.96946184873383, 9.601357655425895, 2.5966718543102365, 2.9204100160959063, 2.5435175312443943, 0.0, 4.6526094494526395, 8.20764724700466, 9.5080479264854, 9.027567453903897], [24.971394570984607, 25.727666280021708, 24.94594628687473, 20.8642359591948, 18.39363137854132, 19.275210117849184, 20.31754221390846, 19.237444839103908, 18.316194526542283, 13.499636747128074, 2.7587702964248244, 8.632609125024118, 14.015739130683647, 14.8649959393858, 14.516794395713415, 8.249821621292147, 4.47003409926166, 4.184569028791584, 7.265141424469762, 9.039144595743691, 9.71463729947679, 10.018719113006304, 16.996567386428612, 19.93531491038127, 22.366129746862843, 20.568903090553302, 15.096607445682201, 12.170916177121597, 10.231482964269201, 7.039324928645694, 13.994595466095669, 6.794842651842165, 9.045912241548177, 13.363998580675286, 21.233185816632087, 23.9638965934615, 26.753829652232312, 25.048191439937952, 23.333993906362515, 22.301043273597625, 20.648692450789657, 16.578320292329977, 11.741961991606432, 12.85017666966819, 14.187484686388418, 10.903084420223456, 14.22750967427077, 23.350982631139672, 25.03619022369623, 20.639117365205795, 19.628239513397247, 17.044477322266232, 15.126246865801011, 11.561007865184612, 3.4039060011167686, 5.870956862229355, 11.91913816699556, 16.45619182262817, 17.6030396464972, 18.204906820680222, 17.072735592628998, 18.12410375216273, 17.491195570899855, 9.567634493137582, 2.69746850678287, 2.8683713399234985, 3.0758122800779324, 2.5310988389141342, 2.239378627908755, 3.450635005233201, 6.921098780265011, 10.32733335667065, 14.583607101726013, 16.992499244789908, 16.287329023179847, 18.67175060381135, 20.0386706964449, 19.373824335640897, 18.36022093376975, 16.30949516058414, 19.144358456011087, 18.32374737379201, 12.304028880131847, 6.660507578828871, 7.0431523010608466, 6.488832632511444, 4.6526094494526395, 0.0, 4.756458895876092, 5.996228621482214, 5.501265106147343], [27.794910180835384, 28.49027270460721, 27.77112043568775, 24.014496872926003, 21.59888501717485, 22.412868828755816, 23.349065455326578, 22.349947227899584, 21.51993706291842, 16.963290851994813, 2.6960798837987174, 5.273565361830453, 10.70028830627623, 11.737613177015374, 11.2936072338079, 6.900798297585445, 4.619348163506528, 8.19633536832247, 10.947870850320983, 12.490092278688294, 13.152851276086201, 13.431257377387462, 20.47115582194503, 23.136200378095758, 25.386786569135033, 23.706873142996596, 18.67847540937305, 15.617230514109988, 13.843050999919868, 8.600293825275424, 10.634248788772952, 9.558562122793255, 12.759821970359962, 16.782162022528407, 24.402626198295494, 26.90180987368488, 29.482347069474486, 27.916796113306667, 26.316359274925215, 25.29795746589653, 23.79484806052963, 20.062984797369182, 15.481763353472589, 16.565061154004642, 17.744341885583747, 14.485851415402898, 17.834074409808558, 26.276549907279854, 27.904738872317257, 23.852590176832074, 22.734487548317972, 20.306562975188747, 18.55631116244642, 15.215804816898887, 1.6527496663524623, 1.6392897036762055, 15.532032022733484, 19.830750537102432, 20.893530865584136, 21.404142973251314, 20.315437063179857, 21.331170441983225, 20.753031084067164, 13.472979369152647, 3.288859477249353, 4.370064036205193, 4.643193615887261, 4.154490353663648, 4.845454643346735, 7.740082254171905, 10.896875235540488, 13.915743601203104, 18.07778283401929, 20.23495172624333, 19.599067080797475, 21.818865774421223, 23.104494910830912, 22.508382773691025, 21.558530646264536, 19.633253828441475, 22.300194191686412, 21.541640284411088, 16.101903340851, 10.206143632581368, 10.69178105730477, 10.131286987686284, 8.20764724700466, 4.756458895876092, 0.0, 1.9555053017404047, 1.20883619646763], [28.57638068808142, 29.253668737797994, 28.55339850401561, 24.88808706144296, 22.53715472765395, 23.323620282110443, 24.239021291445102, 23.25858765475325, 22.45701581080855, 17.802099357072244, 3.790605431410084, 4.31085944528612, 9.63449436944076, 10.746607090053534, 10.265696220133888, 6.087627073600485, 5.034071556054335, 9.42368794377667, 12.104216830705038, 13.677009832229926, 14.315740384111336, 14.583041918448068, 21.38563161660086, 24.00187783601522, 26.196920129302843, 24.57705964617995, 19.64748390832341, 16.679829170303698, 14.956707212713988, 8.449439210494214, 9.56948663687213, 9.739297764423288, 13.695727375938931, 17.682872229307943, 25.250232269598914, 27.698112121988746, 30.21591110500583, 28.695937476726545, 27.1381763754297, 26.1411937498837, 24.666914853451164, 20.998503845347166, 16.585612457325244, 17.618239681069177, 18.78861197964805, 15.60707790444361, 18.826710282597098, 27.0418996618942, 28.638368796993625, 24.689801982103933, 23.64408792542123, 21.180676484150187, 19.470898935800104, 15.972610452201588, 3.26877071174147, 1.221638696529751, 16.27586184116126, 20.79019162865746, 21.813033254538322, 22.34999694169682, 21.280261560512493, 22.26575485871281, 21.709435010669157, 14.407013800553035, 4.347865194205678, 5.406173705832523, 5.642209741565989, 5.247962168964058, 5.860894887966405, 9.014514388334318, 12.032244616830845, 15.022274945812708, 19.087178448463806, 21.188702400267243, 20.542846154362564, 22.7507905016868, 24.00271046050759, 23.418001683535337, 22.482890764717194, 20.617285128369264, 23.216481833906784, 22.473458187292913, 17.095561058759753, 11.472359292396307, 11.923892704558941, 11.40376202184154, 9.5080479264854, 5.996228621482214, 1.9555053017404047, 0.0, 1.3071274109745739], [28.30517759871284, 28.988927876025972, 28.281679371391704, 24.57963297157653, 22.208605263712627, 23.00705853268799, 23.92843604842682, 22.944598970937363, 22.125711537033403, 17.51872899011668, 3.530264671201476, 4.639566166094087, 10.017084138038774, 11.103166849917411, 10.634738823905616, 6.272431217497212, 4.8532417837688495, 8.961406654459124, 11.711716686696747, 13.247162491736185, 13.897557507398338, 14.170393483585615, 21.04029021637218, 23.693932106767658, 25.924591314227776, 24.27455194965851, 19.31275287446546, 16.320160128094606, 14.55328049479502, 8.424387663275972, 9.947400540545306, 9.66039071358743, 13.344155316872516, 17.433050553939104, 24.940904991242743, 27.416540647585144, 29.96185592629116, 28.42382792074942, 26.852605803890256, 25.84701497693072, 24.363632410213548, 20.651500138773677, 16.186664035073488, 17.236401515316555, 18.41750944751977, 15.205421444231492, 18.460892735781634, 26.76737280010165, 28.395259569761077, 24.409148669461477, 23.326033482215298, 20.91266431660345, 19.152783806074446, 15.69424455885168, 2.6143462086096063, 1.6034527016501567, 16.061816416555423, 20.444642814500952, 21.500628881357326, 22.01602822681145, 20.944427531642276, 21.939844931104574, 21.368439686771563, 14.036191166672427, 4.120919816487139, 5.197938909723577, 5.466490923811222, 4.838234130995147, 5.660568879218197, 8.541347466696031, 11.632774970912347, 14.641996059238036, 18.714740809881878, 20.86182257543491, 20.22928839404291, 22.422783373243238, 23.688907758406874, 23.102115535076013, 22.162632660071253, 20.266650051171297, 22.892804839070166, 22.145202047123526, 16.707493631483086, 11.006422775958004, 11.459829475942438, 10.932335103087164, 9.027567453903897, 5.501265106147343, 1.20883619646763, 1.3071274109745739, 0.0]]}],                        {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('ac419f71-5d0a-4325-a44e-aebcb7761688');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


We now change metric and compute the “:math:`2`-Wasserstein distances”
between the diagrams. This one takes longer!

.. code:: ipython3

    p_W = 2
    PD = PairwiseDistance(metric='wasserstein',
                          metric_params={'p': p_W, 'delta': 0.1},
                          order=None)
    
    X_distance_W = PD.fit_transform(X_diagrams)

And again this is what distances in homology dimension 0 look like:

.. code:: ipython3

    plot_heatmap(X_distance_W[:, :, 0], colorscale='blues')



.. raw:: html

    <div>                            <div id="94dd314f-0e14-4595-a9e4-14c5b2cf8072" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("94dd314f-0e14-4595-a9e4-14c5b2cf8072")) {                    Plotly.newPlot(                        "94dd314f-0e14-4595-a9e4-14c5b2cf8072",                        [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 4.397647247755057, 4.086968578327853, 5.669472897497943, 6.676228320806384, 5.120563737341231, 3.6816548525789528, 4.0743725101143, 8.981919401117683, 13.658986622512804, 19.290162824091436, 20.881590510173947, 21.981533834567614, 22.37890031251298, 22.37237712414072, 20.74800163260067, 19.44251603115809, 16.67967530192204, 13.824925007315176, 10.681848989926035, 9.970739198044827, 9.785269421284196, 7.706723024302722, 6.782021154998778, 6.223661837399496, 6.396611439991136, 9.376901266512485, 9.880768158841692, 14.936048743762667, 19.6675513978758, 22.321490844955488, 19.390512391241273, 15.916143039551157, 12.176143431112951, 6.943458745012854, 5.130399357699267, 4.53528751800381, 4.081753176892288, 4.534109885999767, 5.999855394721442, 5.94704067196803, 7.898239564533547, 9.9870062625903, 8.926555511387981, 7.950725165507899, 11.901889221737108, 12.079994585036284, 8.778464618980665, 7.890415395982289, 9.60397098110586, 9.044484671312652, 9.951318698577403, 12.910596755343215, 15.921798161480666, 19.500272390669682, 20.327880110948655, 15.567544164124804, 11.633439847668507, 10.171653627984194, 8.134074940548906, 8.112343580454334, 9.484565962374829, 12.285155058185666, 15.836181753720455, 18.834050637269733, 18.397240908469062, 18.136337968675313, 18.52524753091184, 18.095337493680614, 16.36780802627528, 14.477486215745703, 10.56038032829912, 8.045051378696321, 7.514199169723781, 8.524665966728122, 6.769210489674785, 5.511131979008104, 7.063840328350222, 6.186459006236325, 7.200909892229921, 6.08993394682436, 7.843939600679199, 10.368453948088364, 12.354474399179235, 12.275180423861421, 12.66270059080621, 15.01201644698774, 17.630052389819237, 20.12210823417939, 20.53213140381453, 20.167722617424282], [4.399363221444179, 0.0, 4.518535789356163, 6.392968908154619, 7.444643677594157, 6.054591220246043, 5.30995206990915, 5.579753135622232, 8.081909375910413, 13.017529245483628, 18.69497600377908, 20.33529117161456, 21.62353895222057, 22.002416014419087, 22.028770878653315, 20.34690844233004, 18.9583471980749, 16.132041093458067, 13.266036154885246, 10.363879266204057, 10.148949068268431, 10.00103736353763, 8.045978484001463, 6.985818656653188, 6.275721616596906, 6.58907004337396, 8.723515126953858, 9.876151813115161, 13.984695322327592, 19.143183048725458, 21.903082615891535, 18.879683372872897, 15.372650183027497, 11.389038023006481, 6.314759028948754, 4.441681219265276, 4.248204822379638, 4.735816819650961, 5.046841762032378, 4.302883882115187, 5.896381088293893, 8.013718206652923, 9.592141870456556, 9.030416020639095, 8.0237414101702, 11.232817328555152, 11.39223104026969, 7.89953428831275, 7.326001292296579, 8.703297508177709, 8.51478938715703, 9.487717463920639, 11.701058295526964, 14.979013520615156, 18.901701994847624, 19.80132386576079, 14.792037986654922, 10.437137727976557, 8.361416898665992, 8.266595024718328, 8.251201877512878, 7.578775741692116, 11.087662493936747, 15.059537384199086, 18.274841103804942, 17.82775170752074, 17.602760302831328, 17.957603643372536, 17.523803958355597, 15.723211391053036, 13.671677825058437, 10.287722460342787, 8.131039734619877, 7.553388358396015, 8.376253038977513, 6.549527177440437, 6.369825818226123, 7.818329606988923, 6.5254495313848375, 7.498489958853507, 6.289892971542322, 7.472465917826809, 10.27247527558516, 12.135370511719222, 12.032205254728574, 12.41646518423894, 14.392537991020692, 17.147188311143402, 19.545572565856133, 19.9012860340763, 19.625902807409002], [4.0875493809669665, 4.517548836409702, 0.0, 4.01527665942943, 5.575215345243931, 3.8158606988650208, 3.0801956844121916, 3.571146613668711, 5.699526934854681, 11.044050717533025, 17.37778572072987, 19.640534898660015, 20.989685475642137, 21.395899727222904, 21.399311966455063, 19.677453566425655, 18.323181263684535, 14.945257500832776, 11.439644197764721, 8.664928501754666, 8.157746548277023, 8.037071989360985, 5.5956933717621595, 4.234053832536597, 3.459168212664046, 3.544765578276213, 7.056648157691991, 8.054333766245728, 13.180237038246336, 18.554716462547596, 21.43900996785309, 18.0877730551894, 13.835325137458739, 9.292421455828746, 4.151089605968448, 2.8129964365147275, 3.31687015281028, 2.31940619392244, 1.8849711885260523, 3.2299553529470164, 3.2763372387081313, 5.753135787550023, 7.874912128723131, 6.772556819991025, 5.976275675173923, 9.099510562867787, 9.257451705778092, 6.032875535747252, 4.729232176504881, 6.601085873453649, 6.346505995620741, 7.697801164288854, 10.266291012521885, 13.494232986678824, 17.476421730141034, 18.310703427532214, 12.949717897335283, 8.932235212441421, 8.400236987751148, 6.849616299192605, 6.952405614013421, 7.686342009467777, 9.244517338842702, 13.223221448142853, 16.717870267755025, 16.253614369706828, 15.979208882231385, 16.367549256047457, 15.847667346766077, 13.899990526633621, 11.990695864069169, 8.606145279717932, 5.856359929300256, 5.205991907555169, 5.926352819580088, 4.278816994961684, 4.526351191815757, 5.837083126498485, 4.443614421222358, 4.917214992461616, 3.3653862353238897, 4.739279423944138, 8.00316175078328, 10.190800611490367, 10.145187141878035, 10.558075902142708, 12.731421402753854, 15.441680059172983, 18.274926743261286, 18.681909504180403, 18.133058108270525], [5.660843220141534, 6.402186804968498, 4.01186386012786, 0.0, 2.4604977723893415, 2.9052612975651737, 4.150701321095489, 4.392102471806138, 7.017203995987801, 11.570763956767024, 17.67166256593544, 19.99240794349347, 21.074915872103393, 21.329909710223266, 21.475369192708637, 19.78304130716131, 18.468674036356376, 15.172826315657982, 11.287381111002517, 8.04659447476118, 6.453671608073234, 6.457654852666346, 3.9837582947956696, 3.5526731335397055, 3.1019667971128126, 4.533940434309008, 7.7365014824377925, 8.731227037544333, 13.830142654181314, 18.80197115050755, 21.553949447397432, 18.19243642102884, 13.983141496077613, 9.472348122729164, 5.223179726216823, 3.8041458331656663, 4.551443636155036, 2.836239672344985, 3.351824549848974, 5.451047382104006, 4.714567672826866, 5.938193368154829, 7.543249587322689, 6.203294854850851, 5.885520840341462, 9.252562443875462, 9.464808025886002, 7.70361299015111, 6.573473687530737, 7.868268269091115, 8.24523124530048, 9.146807431314299, 11.371396332261158, 13.842142406722882, 17.299705995319492, 18.08860045198071, 13.406479980777947, 10.51655906183467, 10.137549499015833, 8.829879459568735, 8.817285001684715, 9.599188945663837, 10.880427432259332, 13.543627724024367, 16.707553827517327, 16.286134144458405, 15.987809548658754, 16.233384710847368, 15.729231559862429, 13.83654755077518, 12.071476472368474, 8.805196954952907, 4.6528850574201845, 3.9745430975818827, 4.878994139261549, 3.7289998616654776, 2.4285152710595725, 3.6421098809230563, 2.1658419090284573, 4.6240430080349695, 3.5372812957885063, 4.9874649151379, 7.070226637675066, 9.196922687732311, 9.531961796348476, 10.146706886216004, 12.73388339057737, 15.281392733903015, 18.487058855917006, 18.86217374067072, 18.114867105685427], [6.67057451338839, 7.445048667284085, 5.572112039628006, 2.455306230020958, 0.0, 3.7242592902457146, 5.061716701475473, 5.187326799579262, 8.060592398864829, 12.602694828124001, 18.092478356782703, 20.33324026243451, 21.352262815872148, 21.49345872925142, 21.63764520077875, 20.026145543120375, 18.828354127198775, 15.492618319530811, 11.812000218626512, 8.121206641093227, 6.009285475190856, 6.4587198092545375, 5.331876324253538, 4.872499390579865, 4.376421323234627, 6.062930052035401, 8.881855136280459, 9.480108657477329, 14.501078795751308, 19.24549449298051, 21.68203594769379, 18.557769207641712, 14.489115900352049, 10.059901817762483, 6.749364259534785, 5.201990806599484, 5.504292793852801, 4.3006265303405184, 5.170744494149982, 6.757337326893567, 6.079915243380124, 7.0907668115418, 8.132459785965432, 6.789259082238401, 6.4954988290246565, 9.761439560756992, 10.342993863119727, 9.145014691868354, 8.221626031642083, 9.496336270703297, 9.650349429404582, 10.331066769718635, 12.413439082639002, 14.761411752253474, 17.626114846302116, 18.327994083971543, 14.242358743888026, 11.739091489664796, 11.375495138069743, 10.226394613977691, 10.106748153668047, 10.8696230266979, 12.128391044801603, 14.354685468992583, 17.0279157914442, 16.57920980374663, 16.373658634742718, 16.632911828442797, 16.104322482336926, 14.196888281486256, 12.598293366833248, 9.320255863365444, 5.554972063404391, 3.609149818059211, 4.86080283026518, 3.8457628264862467, 1.8543048097153882, 2.24443112383732, 2.4871081945473983, 5.018419211509885, 4.247745009333616, 5.702672458852238, 7.420464190675276, 8.940771997411336, 9.866345056143233, 10.471457593655682, 13.089724203676498, 15.624030570403173, 18.895296506520566, 19.258358839317808, 18.42567767619921], [5.144671498653526, 6.064304361037102, 3.813849325558996, 2.9055454078806138, 3.723806263773464, 0.0, 3.027007396866887, 3.17606492210796, 6.6787544640205185, 11.117842416069498, 17.041986069179533, 19.416500603704325, 20.600049388816274, 21.008384621471503, 21.023689670852047, 19.288964752756964, 17.969765718385496, 14.52790563927844, 10.753121741140214, 7.208004553058148, 6.0618105271694, 5.865762504638319, 4.3443229678577095, 4.104270076477975, 3.410164884168444, 4.3500008908399215, 6.9980412966152405, 7.626397437323623, 13.148674767860966, 18.306947603740955, 21.051147145280144, 17.848014270941775, 13.61046478686314, 9.033169871160265, 5.356745378014676, 4.302799104844522, 4.797123821220429, 3.4595702159955866, 2.798766513831514, 5.117789857723529, 4.285512562148768, 5.546904508584813, 6.998950574197441, 5.652949284756231, 5.234822709441518, 8.743418561800762, 9.297925172447364, 7.5798791996212, 6.6815463553266214, 7.587606843654174, 7.561492458291044, 8.289612914670702, 10.862903452693937, 13.548248687198512, 16.782154172763608, 17.604687582001254, 12.987423868156371, 9.909780110702266, 9.316456570582854, 7.774251102019803, 7.659757001935952, 8.741199945099373, 10.401939683002512, 13.132874935194877, 16.040588209356297, 15.540288428523665, 15.395397754543744, 15.646726547310443, 15.163666773165415, 13.259160299046131, 11.515150133272552, 7.885183588695617, 4.401652166857646, 3.9903274019475017, 4.865499944808957, 3.7868952008376207, 3.017720106628926, 4.184774007262774, 2.5184545434132204, 4.139287279973383, 3.0788257587695442, 4.942149434504515, 6.986829721181177, 8.696365502115617, 8.88950747211879, 9.29031453683998, 11.888585761188933, 14.56601220916044, 17.95612107525682, 18.369716309658973, 17.624539036813527], [3.6790911843154634, 5.309535131386915, 3.080248698897761, 4.154327445987845, 5.074744210249892, 3.025746875297444, 0.0, 1.0228803028280207, 6.280613586430053, 10.94428216356048, 16.85122468736711, 19.189347064404366, 20.47727431660594, 20.879405941784356, 20.8562521239657, 19.07813973591493, 17.639906466098758, 14.273367665365782, 10.698468961590542, 7.297763659840142, 6.6838209888593205, 6.555948371754312, 5.17152919919358, 4.632355625917389, 4.264561724323172, 3.9205600641172857, 6.5528813651855256, 6.7719082308304355, 12.795520967402396, 18.00712932262424, 20.843424972843575, 17.66172592133446, 13.48369936272704, 8.971599954074545, 4.9115151457050095, 4.38000482142152, 4.630667456127063, 3.6942977911200123, 3.012096442930981, 4.231547899464271, 3.312245132729404, 5.100069933212499, 6.758817431013228, 5.649800610242226, 4.654781693725246, 8.51805050115767, 9.04238390069418, 7.15304956328298, 6.322254840371681, 7.2474846360337155, 6.445556948420719, 7.404594525103182, 10.377191680608245, 13.31465166041812, 16.613343618165093, 17.411327455563193, 12.756712344475178, 9.206563080498444, 8.418834249430567, 6.095259266387824, 6.075121639741692, 7.738524167291743, 9.697742580806556, 12.893564226449648, 15.835502359235091, 15.34036241274438, 15.079335356863597, 15.520241036526517, 15.054097465813927, 13.059684280386957, 11.254976763770626, 7.346851486966391, 5.004744309295802, 4.590844557263335, 5.412927285980525, 4.0813296333150975, 3.932565361369662, 5.349923262026155, 3.8109807043627706, 3.8862124469724315, 3.0246716480311555, 4.676404098483536, 7.175344947669134, 8.883462657375837, 8.950406973796191, 9.308272674503126, 11.734037431575308, 14.393293147928663, 17.711202477629303, 18.184154775001353, 17.478310468688147], [4.070740688497355, 5.57982792397583, 3.572277649955785, 4.391578937216572, 5.177111289251454, 3.179260919600588, 1.0251934105509766, 0.0, 6.154062024635212, 10.441595969405824, 16.51957259785564, 18.92155400151232, 20.211622097642714, 20.64437874915646, 20.629338263594153, 18.803482183309885, 17.360771239019364, 13.923902839642652, 10.257884956480812, 6.894041274710522, 6.325128975767979, 6.212753721478861, 4.986615144211131, 4.437311361877386, 4.167490356497567, 3.7175384212112204, 6.140665301156221, 6.271671848366624, 12.486652587257803, 17.73828649248582, 20.56797858590211, 17.439323150021387, 13.06697358230732, 8.467302096156896, 4.902483441505067, 4.457828596080859, 4.770352992421722, 4.15450061119117, 3.4757901563858113, 4.421436528967311, 3.0925532325234344, 4.693369201143742, 6.3746122022175316, 5.256971115263032, 4.244717579322883, 8.163070822712655, 8.735678344390015, 6.910653484687921, 6.118199334339062, 6.998867254891496, 6.335785887888454, 6.892361598057344, 9.974130756281031, 12.872851113570876, 16.17023517152025, 16.987856954915298, 12.234765169293585, 8.932848447966785, 8.103922447443711, 5.897052899070647, 5.777588522731503, 7.522684390912622, 9.506627265827584, 12.445664506623633, 15.34575360473279, 14.822137741399796, 14.689335925969539, 15.033217194366516, 14.547352490072047, 12.646654212164446, 10.841821817100511, 6.822853112684386, 4.787904314268396, 4.412403820993724, 5.0903222762524285, 4.155618690501487, 4.223271208576709, 5.461977705016026, 3.7893740934040663, 3.558628401287147, 3.1099878689547307, 4.537090539723518, 6.7763475737833305, 8.481756586897104, 8.55983200587063, 8.898440221218017, 11.259056467427312, 13.883831874012131, 17.306597631427238, 17.772607822477845, 17.041774432980542], [8.996816575211724, 8.109802842498642, 5.691173013986959, 7.013800293992298, 8.080573873066568, 6.66992863533007, 6.276461465116099, 6.155251079594819, 0.0, 6.6798679824278295, 13.453596868665608, 16.412089175201892, 18.384867488899445, 18.793791008179447, 18.76820892475884, 16.606660444017777, 14.717400648472605, 10.511324605527262, 7.016793890792814, 5.468600946562321, 6.381526003031309, 6.243660338022067, 5.402029422557444, 4.976853653944683, 5.684840816624858, 3.9375079911135136, 3.74587218745446, 4.955855594599521, 8.685165419656107, 15.256569019773611, 18.5425896542697, 14.82871236764063, 9.758745793865078, 5.056161008410346, 3.6256931307094518, 5.871326729589027, 7.743466732433108, 7.1714372726219695, 5.794301864580119, 3.9727416320605085, 4.011153050673287, 4.009708311393819, 4.743816865424286, 4.442240918561483, 4.189239526047766, 4.260513605855498, 4.933747066510867, 4.598035474553854, 4.520559232868277, 3.8664823950255953, 3.7905074642836407, 4.593762022029682, 5.644079980977648, 8.659433736675618, 12.787314900454923, 13.842019120368542, 8.200499799377399, 4.216156740355187, 5.545100218445453, 5.687701870120437, 5.54213784704873, 5.175133026341311, 4.395942174625487, 8.220857408352014, 11.984292005199546, 11.413546323354726, 11.352399875910413, 11.729371540534371, 11.184428847956736, 8.865511997463074, 7.056345004557778, 5.01228129693944, 4.574237758063526, 5.469572638882365, 5.086550738313263, 4.98117773848023, 7.639440830603404, 8.375241487936902, 6.334504497286482, 4.412790167110765, 4.4161812576667145, 3.3595030285080396, 5.1828980746145525, 6.642117405455607, 6.221235418304668, 6.643714124382771, 8.124702578081504, 10.78335800019832, 14.117580765982773, 14.630889963258069, 14.067330982979188], [13.637099568909273, 13.002190647400688, 11.051835211277227, 11.577807776809193, 12.613696304842057, 11.100102213240902, 10.917649983106092, 10.443232293219417, 6.681617858496254, 0.0, 8.912057646868545, 13.171655324976962, 15.600514179439228, 16.028294151827346, 15.820372963207928, 13.294497025287043, 10.71306365790547, 6.232368639024203, 4.542798768537436, 6.7346973813593145, 8.704245499272602, 8.273222158190944, 8.237256132891417, 8.47686034877454, 10.190929579106049, 7.83787170223743, 4.998106109722701, 5.587847478358851, 5.372707993510462, 11.422754971564181, 15.497925560588513, 10.790926703320444, 4.130595864363562, 4.38065445970462, 8.329283526366021, 10.532094020105982, 12.698501919118085, 12.202690686477247, 10.81736899157828, 9.62726466722405, 8.301521116102734, 6.282914039148009, 5.98217657749323, 6.565978407144893, 7.171131402378818, 4.885916355019469, 4.579695923582773, 6.658304195042315, 7.941833309635924, 5.655566321534474, 6.39298848547906, 4.94027972157041, 2.695061420926876, 3.3711990882675957, 8.7328150570724, 9.800798854083192, 2.5293445375096635, 4.319090832295821, 6.571099384856276, 7.56181367484031, 7.543039606973975, 7.354414146040687, 4.915569520037982, 3.332358159444915, 7.764387200311512, 7.306213631637122, 7.20327409025607, 7.095851535511791, 6.850763659308281, 5.686781889398063, 4.207454670300394, 5.2296532400680205, 7.893602883207095, 10.035911659983588, 8.836926557099288, 10.311306900621428, 12.62502783244631, 13.000322111584417, 10.803695179266665, 8.263082793455368, 9.68525615408129, 8.019311409085727, 6.308530719387157, 7.351159071670619, 5.733942158662447, 5.705584203060574, 5.179659107427819, 6.663388552855497, 9.947571670282336, 10.422984730854107, 9.815246313894887], [19.31384831281282, 18.65790798965502, 17.48603344528968, 17.666342636770626, 18.141748512735195, 17.058685309939307, 16.912358125645703, 16.52785552108912, 13.45156108247969, 8.93630633384157, 0.0, 6.275348969514242, 10.260320024923546, 10.89302436132069, 10.353170591350775, 6.714223756965737, 3.579248632049469, 3.8752013824899905, 7.751208318752291, 11.380712136589027, 13.48738636954839, 13.251045023345144, 14.99582724141841, 15.620248221393108, 16.762438886234097, 15.0398311375441, 11.934779589350002, 11.161277192882471, 7.038010896408452, 5.655871445243701, 9.618631807279597, 5.779697242685516, 6.192988372929322, 10.42308396604624, 15.201041834926835, 17.17157153773819, 18.723746266196983, 18.35752158639958, 17.107036891464766, 15.982504468027551, 15.215487160421556, 13.545085570841664, 11.734195125035479, 12.827223122959701, 13.386263267438114, 10.017589283657536, 10.672214853690594, 14.565467359554042, 15.414862782231888, 13.03894107679737, 12.968990069293255, 11.877575891203843, 9.826846105599094, 7.269016416752787, 2.860924998138321, 3.261483056322579, 7.5244025989627055, 10.996819232210065, 12.620397375875793, 13.589395739214932, 13.457234173119666, 13.296591922572619, 10.93530493335466, 6.706594724441662, 2.827305827369098, 3.1474608264414785, 3.1630034626120986, 3.0605853598399015, 3.382639960666074, 5.530283320779557, 7.04726494652788, 10.573481916206982, 14.168280837588554, 15.967245347254277, 15.046986093327751, 16.27492737736814, 18.18651189660176, 18.473565917808184, 16.812679929682695, 14.716996298266455, 15.891839728422648, 14.526255037612943, 12.567117235748677, 10.981465240433128, 9.653847097602345, 9.065521259766319, 6.383975656201876, 4.06869486424759, 1.8693767546585214, 2.3296240863151754, 2.4001447055130773], [20.880280063055707, 20.394092657729622, 19.648465971456574, 20.057983691273982, 20.359432239621793, 19.4129869499209, 19.281613617372727, 18.921507205379697, 16.392813065270722, 13.155291779416372, 6.2672609091654525, 0.0, 5.558879638822636, 6.58170113931714, 5.995044561458284, 3.0030410780501335, 4.46463620841211, 9.346092826365235, 12.568656887248356, 15.105264614636397, 16.688421689584423, 16.45004758011262, 17.905228186375208, 18.424740743891995, 19.38247861138548, 17.85942632460219, 15.4464427728519, 14.958662254761409, 11.41691485435321, 4.8220855104350955, 5.2017280125569325, 6.12108774046585, 10.80084099709725, 14.488757478694927, 17.941554368323978, 19.576564019713732, 20.790248193561737, 20.586961663139967, 19.459650025707866, 18.410401618080826, 17.987327111373446, 16.716160856143958, 15.367037402904382, 16.21021309533101, 16.60204797429612, 14.220287810869838, 14.488601567894722, 17.2595457351446, 17.993640401383665, 16.188417134324926, 16.017876940816457, 15.248460808309021, 13.789894310447949, 11.673358245605089, 8.013570104555589, 7.671465472522627, 11.959410609852172, 14.506961468669623, 15.698657272744507, 16.51114219387635, 16.401631194377167, 16.128642344761623, 14.355032044956955, 11.544246129937651, 8.461420735463216, 8.885264410198706, 8.957484164574199, 8.690356219579412, 9.16486585141549, 10.89966094431729, 12.14519359887357, 14.632327792848923, 17.23566475596696, 18.74393535994925, 18.06947318348594, 18.920703271718203, 20.327742509296545, 20.6938631631736, 19.311716386310692, 17.704503888303165, 18.59783300593708, 17.59682559832489, 16.099231969830097, 14.808409859703364, 13.888813190513831, 13.452917438555327, 11.68493061921686, 9.628406735515576, 6.0639819189239965, 5.850294764385582, 6.7171983742735195], [21.97390188161775, 21.638352210051693, 20.989685475642137, 21.074915872103396, 21.363049909397613, 20.597991532981204, 20.53509571748828, 20.25238432715341, 18.364920961337067, 15.569264044188246, 10.25484474502746, 5.569216267914987, 0.0, 1.6276429875111325, 1.681147222317857, 6.346440142805121, 8.7886182176346, 12.485057487677166, 15.198189797956173, 17.053659575907243, 18.244709915478687, 18.035676247290635, 19.34399715764013, 19.87640867127091, 20.687727054679502, 19.468139057176998, 17.408910133582474, 16.838477135196104, 13.85895817024359, 8.360367390773062, 2.552163446686596, 9.218913878953153, 13.620663069695363, 16.71444581381602, 19.65654016299373, 21.047782056473046, 22.081067106468225, 21.769987543651816, 20.775359809194228, 20.01256247602451, 19.60390586594862, 18.46038076074918, 17.3459810804415, 18.02872999465004, 18.3790690278222, 16.465797833943927, 16.74999690942276, 19.069952791166077, 19.710023410793138, 18.113859359569677, 17.865594858916037, 17.235600369478107, 16.001265236206237, 14.351915038099687, 11.427289786256821, 10.907292149805627, 14.623580652924232, 16.57360705107523, 17.374454289425454, 18.106022192379154, 18.0701117801327, 17.82790117925713, 16.514753201817616, 14.254319462177135, 11.834128206433988, 12.166843302141146, 12.20849007344479, 12.109139759307972, 12.477659062165465, 13.836613154633197, 14.815197779037966, 16.709627803615096, 18.763426450412855, 20.12797903414882, 19.530975143680823, 20.37634457178585, 21.480553923899482, 21.752469969581107, 20.517379425194573, 19.30401576105845, 20.09686317125635, 19.267547464471193, 17.928088123690525, 16.830226245217297, 16.09086899768305, 15.712350841920443, 14.306986804930458, 12.850107644080847, 9.872904221080027, 9.575617443539713, 10.361403784873717], [22.360470121898818, 22.017493358091127, 21.395899727222908, 21.329909710223266, 21.49345872925142, 21.015650087956416, 20.899024338692172, 20.65652041723421, 18.87763768732292, 16.02829415182735, 10.899063808521344, 6.602324128087332, 1.6302543226750483, 0.0, 1.1868200844334644, 7.1554839628850075, 9.417588345506484, 13.012248193440017, 15.646926508135524, 17.53719821160063, 18.578964687270755, 18.345523844870165, 19.627041263837057, 20.187193126856073, 21.012136820611232, 19.832775844567806, 17.8689650811776, 17.18110398819334, 14.244019307628385, 8.95357776665982, 2.802309497199255, 9.978489036003863, 14.171459390973942, 17.178583868999436, 20.119128653253785, 21.404973135391934, 22.336414135526045, 21.999829775933662, 21.18977744740371, 20.425620314244334, 20.11437173398157, 18.92295113872788, 17.875871043380506, 18.541444241343324, 18.834144786621437, 16.980637009508246, 17.2101848053989, 19.486674018898906, 20.138536576853884, 18.551469795870545, 18.198875881474986, 17.528613923890237, 16.37213369376248, 14.765045220327309, 11.976567459022807, 11.520491060899886, 15.052757438489005, 17.01310240346713, 17.6827384100099, 18.218192801035176, 18.170563755132836, 18.02498917965837, 16.94851650355274, 14.691917057591661, 12.418127449014396, 12.76940374857155, 12.798280876965382, 12.674097200761542, 12.979965599447354, 14.309038930840853, 15.295978895728078, 17.045254381856015, 19.079693202306945, 20.321905477389038, 19.764017885597607, 20.599771719762987, 21.692662579699558, 21.740512864656043, 20.841148374051656, 19.647789483171678, 20.42343850497716, 19.664767491854914, 18.344896417661527, 17.26878917369697, 16.55841374842323, 16.159441942997653, 14.81771780861928, 13.353642676175294, 10.557232091367782, 10.251926169334794, 10.99517738655666], [22.371889158544334, 22.057032079679097, 21.399303707691313, 21.5119582140475, 21.637645200778753, 21.02350717009906, 20.90266727390398, 20.629340741248008, 18.79984795982291, 15.807842927963327, 10.35122732464471, 6.001932964248553, 1.6829996446383675, 1.1866012492038494, 0.0, 6.914987161749107, 9.030374293902877, 12.749762620379274, 15.482242276733333, 17.50975717543895, 18.747250673109207, 18.421060981438416, 19.78181814568564, 20.303679949293503, 21.137319831049307, 19.866898108596263, 17.8046698399407, 17.127411542042285, 14.025691363268692, 8.567920425386909, 1.9155474076053909, 9.592903452730187, 13.940914442916004, 17.09273749022639, 20.115935977615194, 21.494842408371174, 22.5582221453422, 22.19129311231706, 21.22596923716514, 20.394016451418512, 19.990075617905436, 18.872875267264646, 17.758401868902627, 18.51004302578393, 18.783225584358174, 16.83348622403984, 17.040764243216397, 19.408547753946355, 20.095135686066904, 18.470204176405574, 18.159147449048273, 17.580852760475867, 16.166404509685997, 14.431209109469759, 11.397576108048694, 10.769644327679746, 14.667384540590252, 16.735299658948584, 17.505547345381316, 18.276483181707484, 18.135981468893963, 17.914498267729854, 16.705096134057243, 14.30070881811562, 11.768769636984366, 12.130159721542228, 12.199301292272668, 12.040941987495678, 12.395730774695762, 13.853232275782682, 14.915663505980488, 16.964494546938525, 19.15716322497745, 20.4655153343498, 19.91165183129703, 20.74145777362139, 21.82725556420847, 21.874811434315205, 20.981204474905827, 19.76010235796026, 20.552439815432376, 19.75119163077175, 18.517812596069643, 17.366019553838186, 16.574975531697074, 16.1853295068897, 14.568174856489632, 12.934011118366099, 9.936509033561581, 9.497284188405134, 10.27086242480526], [20.758513355593912, 20.348441751760554, 19.720345957466517, 19.891249706014825, 20.07160786150513, 19.304501038599813, 19.07767933174918, 18.821232750972026, 16.650504558140867, 13.219315295335186, 6.728476506188554, 3.000068676740147, 6.341906789205699, 7.142108720850524, 6.912753846687253, 0.0, 4.4656684295262625, 9.543948386360947, 12.906080487281525, 15.465407021480067, 16.807705325542035, 16.535238571312625, 17.89051431224347, 18.53082220060417, 19.43334933813963, 18.06611052622417, 15.591821328319503, 14.944373133762204, 11.250693205918502, 3.3736052458144967, 6.476208657550343, 4.755027406450892, 10.84933656487791, 14.672252374669133, 18.147342700419486, 19.85700867202507, 20.928787791963526, 20.63827047283262, 19.535487074327452, 18.540462551233276, 18.20806066759971, 16.86364156605542, 15.57796459778721, 16.491168602241423, 16.79319932815368, 14.506389443164071, 14.692649013131755, 17.4065072687853, 18.24910941837868, 16.354446967344078, 16.087869707356997, 15.348038957768614, 13.715006510913076, 11.55927016139583, 8.355406496861628, 8.11398658498893, 11.794253786904436, 14.410597112278285, 15.471056597695739, 16.32300247402942, 16.182915563369534, 15.860685318838003, 14.240720205765916, 11.350873649739757, 8.745448448670269, 9.135806080599746, 9.235468713775271, 8.789621608758326, 9.30739530891575, 10.92967786874805, 12.2123025747191, 14.738848332727532, 17.274402732978082, 18.755533323969374, 18.137273903718185, 19.038124854113164, 20.205931530474555, 20.452629684361277, 19.209773326735966, 17.87221117735403, 18.775965323888727, 17.86511366440026, 16.453070490300462, 15.284592506682591, 14.37290505390058, 13.996232148810329, 11.930427824867314, 9.877088173952691, 6.631371721935787, 6.294246591028037, 7.1888028655043925], [19.444912076051207, 18.96746309414445, 18.28934937005865, 18.497344046151152, 18.831866406296903, 17.97967850307693, 17.634260719438725, 17.363023268885975, 14.705581009485968, 10.70892805161501, 3.5805782141767244, 4.46463620841211, 8.789192119335983, 9.430950667680488, 9.03633105030593, 4.465547072211272, 0.0, 6.295872944382828, 10.371509262582764, 13.409472992243757, 15.09963403380536, 14.762938089018725, 16.325621171571832, 16.92824505523167, 17.9590750245866, 16.3597620449538, 13.635127303905652, 12.857541605115394, 8.310617089338791, 3.7425543282220475, 8.670916308855617, 4.099318009088784, 7.7785805587915355, 12.341442609408052, 16.442798347311403, 18.13615081611508, 19.427992302138193, 19.19861622256935, 18.05006751570631, 16.960914074194395, 16.52509897246072, 15.111417579314049, 13.643402816703478, 14.563927442334242, 15.000777965354292, 12.188923546496055, 12.565330250418096, 15.786968566536665, 16.571104288005753, 14.400429809383404, 14.11853344540547, 13.273070238887517, 11.378106146216075, 8.771467755637293, 5.8447045348982725, 5.985657814814219, 9.095058644603434, 12.450208337334296, 13.71604864418624, 14.627379375009921, 14.446571690991727, 14.348753819597077, 12.270112285938433, 8.469750895659606, 5.893743753328993, 6.226218186257116, 6.329382009432316, 5.917583978905192, 6.451174420956089, 8.207073148643614, 9.534085907068903, 12.553349457127156, 15.590132887028007, 17.185125981956986, 16.439720886457827, 17.49436056064271, 18.901120710603013, 19.107934657289917, 17.79890095138031, 16.2143430061507, 17.140217927262373, 16.09552100891635, 14.441896077282612, 13.271329398291925, 12.089702711104648, 11.62648123369669, 9.251500767097774, 7.135569292410215, 4.1909851562936264, 4.41937764509121, 5.046911654742959], [16.685105854119318, 16.134380887917285, 14.902466640677275, 15.159556657149068, 15.580435010692856, 14.506530944934577, 14.253752878674687, 13.90125294133941, 10.522260493880164, 6.232368639024203, 3.870662492268741, 9.389683573338255, 12.509459311854377, 13.022761336423269, 12.751177226541532, 9.544630298992669, 6.300741318969896, 0.0, 5.201416861920487, 9.038459696571673, 11.205798679419223, 10.740459276849505, 12.397550275093327, 13.199754608686435, 14.478925744832159, 12.482680677733741, 8.91422621493538, 8.20883732798194, 3.9711990447536585, 8.001604472683798, 12.433961005370767, 7.52278669117978, 3.478260242215622, 7.9950588398019775, 12.783006246556283, 14.789663606744906, 16.316635163637333, 15.87092377774557, 14.700062463880496, 13.327579884969955, 12.728453537196547, 10.906475302638066, 9.161969625812068, 10.261066317667021, 10.856879254733288, 7.389551462163193, 7.981411908733298, 12.17200064368791, 13.113864024352683, 10.202962181542842, 9.757649675481767, 8.70596513086324, 7.00041164426212, 5.1858110714644905, 4.7501513061849785, 5.746330384523661, 5.354009172106116, 7.705005177556744, 9.507275902463084, 10.41967402946366, 10.282076424713207, 10.137514991241845, 7.628375024493139, 4.475891019791641, 4.044465578210197, 3.7922789789816473, 3.6001498628161785, 3.8935987837661123, 3.671107196176423, 4.180683493849132, 4.774529364388568, 7.890086656709479, 11.38929580332536, 13.463181587782017, 12.565565293479063, 13.819278003055592, 15.544204208993227, 15.862503008552515, 14.273369744916788, 12.223458245705597, 13.427550157195686, 12.083980882117466, 10.274002127404161, 9.155552054272599, 7.363943755441081, 6.745650649213714, 4.437484647655762, 3.7549269135644234, 5.148614669041481, 5.760910073314225, 5.16462158473296], [13.771537798819612, 13.268139373193709, 11.456188860566742, 11.287596196530478, 11.78413589738879, 10.72151845958697, 10.688126831679357, 10.252829835767681, 7.014115935384903, 4.551151695449372, 7.756143540621945, 12.566836562912714, 15.10651847121844, 15.598057299715162, 15.477523262605471, 12.924167526638648, 10.373944843420814, 5.196665918883482, 0.0, 4.68480822120788, 6.861947682094537, 6.305006457578585, 8.314664325714581, 9.098245824949132, 10.585435115641449, 8.488746679197869, 5.457563486161436, 4.708344057334361, 5.734132511558601, 11.736561152657403, 15.266752665740704, 11.351970741606655, 5.435432215951211, 4.644222048698643, 9.2116419595351, 11.339446717484506, 13.212673984835664, 12.525058177008338, 11.055739795104937, 9.977420491893184, 8.914286119819366, 7.042063277092094, 5.216065192991227, 5.984313950814003, 6.734068940860594, 3.7766133611004276, 5.298968865732568, 9.143210332450266, 9.717187539159221, 7.225495590923029, 6.887493220169905, 5.924521489657259, 5.534163286895493, 5.532191354124451, 6.848346914001606, 7.754250661184351, 5.241388161759794, 5.894763946676537, 7.370806169351147, 7.74342722086683, 7.492120791138273, 7.745370664663557, 6.088999119661315, 4.81543067688043, 6.15994720103115, 5.696396016053453, 5.333669901503575, 5.731026675821756, 5.061073253057499, 4.031868123442431, 2.7746982062330954, 4.060814818912899, 7.114562881790295, 9.494113749345072, 8.529384777478803, 9.972809759637185, 11.977447454187196, 12.224816417010702, 10.352968103903764, 8.162287793938722, 9.504647623702224, 8.090735065189103, 6.315027433089279, 5.248232662903057, 2.938695081806598, 2.7676534320956274, 2.8167528437329237, 4.85432236222465, 8.341837102453836, 8.816074871491033, 7.952807716746185], [10.681863510049816, 10.363575878318308, 8.661631851650593, 8.044293028278558, 8.134814585459234, 7.190007178359771, 7.306902843095407, 6.896519800204549, 5.468735040683466, 6.734274336719683, 11.374725487754292, 15.077306260283109, 17.05365957590724, 17.536929898001226, 17.50967445483512, 15.402512336926046, 13.386516752421876, 9.07252161399011, 4.693576255795821, 0.0, 2.836608151038227, 2.7881496085359756, 5.64873697584355, 6.508511099542839, 7.631924301499482, 6.242324258716563, 4.353452835723527, 3.572937425319115, 8.925064200945148, 14.484796373809875, 17.485376484738044, 14.149387317276744, 8.97577923906003, 4.600055586514063, 6.878871024024273, 8.482798369108695, 10.153328950611055, 9.366927094098461, 8.156648613378145, 7.324931786908256, 6.2607455142205595, 4.761220786284334, 2.6242448977613577, 2.894013444627797, 3.4261871316177146, 3.1891851067012555, 5.210802918835687, 8.010840729580073, 8.388557469144297, 6.790755235357198, 6.296153069567208, 5.927477304044462, 6.878723749477995, 8.39309712920095, 9.84222667770839, 10.608162892481348, 7.9385563659425, 6.715324742773796, 7.250074582791457, 6.994262528778703, 6.703236330653519, 7.21947506745824, 7.196226933949226, 7.630361216084352, 9.162133873259169, 8.73572626918214, 8.599446152852337, 8.907645512849614, 8.407839565448453, 6.581889702700093, 5.089756231352682, 2.4429515980456755, 4.08923531600243, 5.7774497411131565, 5.054896141609394, 6.310177957326635, 8.249721954793596, 8.62773300491498, 6.709327021671309, 4.532508770755234, 5.993366895019209, 5.0652761480387, 3.600831986359017, 2.322189470362823, 2.3474313772109254, 2.648739889410719, 5.097013134191949, 7.7770132398408665, 11.835749056199086, 12.16567533194221, 11.252415008120066], [10.000318420737576, 10.150239226839542, 8.190847693978686, 6.4354821116631244, 6.000333564309655, 6.056404093029769, 6.675502554634985, 6.322646879154376, 6.3806497803226625, 8.69673679276207, 13.46244029543428, 16.678451324465644, 18.244709915478683, 18.57896468727075, 18.74440249838372, 16.80987567636905, 15.10317328056284, 11.218931646804721, 6.8612042517891405, 2.837460051451109, 0.0, 1.5828905673429408, 4.835759177326451, 5.761581390582376, 6.641033868265483, 6.160135494949076, 6.0204685383719, 5.599497175525912, 10.911510838245002, 15.965261141348797, 18.761586724590725, 15.613589160856598, 10.922319315157623, 6.141961511416169, 7.0215991446600325, 7.873065495182958, 9.27313525841142, 8.33439446849101, 7.531736758814041, 7.561007478025196, 6.29308077690737, 5.289902456046765, 4.156059471185507, 3.422557158735979, 3.924571768790227, 5.226060594758334, 6.810928248755267, 8.803325213507987, 8.704023378116364, 7.9407850175410974, 7.760844037830785, 7.659212773447242, 9.02675513970308, 10.47457625528041, 11.90047613468487, 12.595782847107216, 10.031782680704687, 8.818981727219521, 9.207283298149488, 8.440307091332706, 8.16615361690335, 9.053980402973417, 9.198882334666177, 9.817206380069244, 11.375445842828459, 10.966671598112619, 10.855516865828255, 11.087583685275956, 10.548903757879891, 8.811229151853578, 7.457656931644416, 4.7812487029828405, 3.4290081881007763, 4.29351827840047, 3.9371873351475, 5.196599942423079, 6.465833959832659, 6.616639121739989, 5.032770876409837, 3.9054442925825015, 5.197899241175051, 4.855075184571066, 3.8254854992276717, 3.2597485725209796, 4.382476514611268, 4.985843069378811, 7.529735833430555, 9.996913828397581, 13.790416967192613, 14.146804203937798, 13.25170275759653], [9.800796875122506, 10.001298127146969, 8.03042286946064, 6.455099383653705, 6.5017005513015125, 5.860734615986766, 6.541540297556724, 6.2136655598824735, 6.2402113711073675, 8.302157919388586, 13.221616758279573, 16.446813452071407, 18.003794170408668, 18.34552384487016, 18.418080612871666, 16.490907056698365, 14.750211727723325, 10.747604175632699, 6.2991954929241585, 2.7866330910707817, 1.5825877438800258, 0.0, 4.49468423415287, 5.695300623108925, 6.694529637281887, 5.859160123681225, 5.5367950262135, 5.078471318667629, 10.533678071525948, 15.704394256855814, 18.5146283363178, 15.275538452302754, 10.423938182495966, 6.095707722104726, 6.961916646302414, 7.914311335432916, 9.394742481175959, 8.346676569151901, 7.31430331983349, 7.441710455763914, 6.170909429665926, 5.074707523444928, 3.992316235666931, 3.342636651476074, 3.8840518938584316, 5.129313633530213, 6.753346046426316, 8.596505810060675, 8.46500052862672, 7.525975162947499, 7.224828744674024, 7.168188728218416, 8.731638299524635, 10.245503715584988, 11.77281346978375, 12.464385968986466, 9.80650037218471, 8.417684520987804, 8.720183066049236, 7.754196742531854, 7.466486648140992, 8.52820450642847, 8.8412656488997, 9.535697796947124, 11.218115075074055, 10.787006609178546, 10.603480654103812, 10.878265482395411, 10.304688864884772, 8.666521904298975, 7.302199516848954, 4.4284534905283754, 2.813909445256269, 4.965194244178206, 4.582499628899752, 5.663686016958516, 6.770219661714989, 7.236551897501452, 5.140193644970076, 4.215159845344572, 5.3861309078192905, 5.119999954550407, 4.223869991498386, 3.8291137987945434, 3.8578714424336047, 4.52863004926749, 7.252656269016072, 9.756309578304611, 13.629045151582929, 13.971211130962718, 13.038895864946868], [7.702143856586824, 8.054988109199122, 5.596069678196779, 3.9972091823009346, 5.336957240675174, 4.3443229678577095, 5.158250888593404, 4.980353381652011, 5.4026999942084775, 8.218116780340237, 15.027562269087413, 17.889904167611704, 19.314274847069637, 19.627041263837054, 19.70274705016568, 17.898288691659562, 16.30889537922649, 12.397993558926485, 8.30321244454013, 5.664251218421351, 4.829729942195334, 4.48354393625523, 0.0, 2.658965163908156, 4.1943281995114585, 3.5325283052356906, 4.882432917725075, 6.211434475382223, 11.311015561537564, 16.68699309274252, 19.786797833021815, 16.06677442963112, 11.099910063549537, 6.902895370286777, 4.044669215896042, 4.993268726300538, 6.911813122510341, 5.547974570716999, 4.639878554832045, 5.561667263870987, 3.995963533561893, 3.055322080656855, 4.705771110181498, 3.4044362195942353, 3.7265228369237056, 6.566696005569818, 6.427954164375099, 6.009667972920611, 5.720016374467654, 5.61608616604962, 6.486785114349019, 6.845771200471737, 8.48049234716635, 10.35987205728988, 14.25596427784788, 15.106181325626018, 9.979537970062074, 7.9958035912833445, 8.183466326798593, 7.155861817046502, 7.080975627018976, 7.985347337324139, 8.558840144958234, 10.06038531015724, 13.582203880416925, 13.193303392079256, 13.046385040786648, 13.101624097978979, 12.634219073469277, 10.648921934151343, 8.942364514274336, 6.0762274589627205, 2.247109460766891, 4.389334865643131, 4.232292866030547, 4.571381540105049, 5.422733527639042, 6.116710783321959, 3.778039271702858, 3.5266298145138935, 3.876877151697899, 4.039963582798751, 4.007590479836204, 6.8158398995268525, 6.600068249447101, 7.204848974948079, 9.61001996463313, 11.946006765289873, 15.563293178354686, 15.92836589776721, 15.184856811415067], [6.785265908405086, 6.981680908256871, 4.238480662899818, 3.5607567942511773, 4.865011637130596, 4.100820489920752, 4.632425963250199, 4.436073999421936, 4.976853653944683, 8.459854341085805, 15.634556435034334, 18.43964402219585, 19.890025019018843, 20.18719312685607, 20.306293966994232, 18.515512813050417, 16.93481918771515, 13.200594961451712, 9.10379116490644, 6.5187500142043335, 5.757534243378141, 5.70584427704778, 2.658965163908156, 0.0, 2.963772865350182, 2.2177522061032544, 5.338083318970117, 6.686020410698058, 11.688558397098236, 17.27203162756254, 20.371194689100605, 16.785148941131325, 11.76984138291284, 6.965558565272872, 3.659026345405434, 3.1591317787646047, 5.397049306631438, 4.333974516469083, 3.931725412210005, 4.7428623764392075, 2.945319594825163, 3.3719345481876677, 5.6458763883152345, 4.336491934974043, 4.193621114687938, 7.103296740119976, 7.066304455364688, 4.663874910344929, 4.236516180242054, 5.410281121177792, 6.2314777992601575, 6.620525849214262, 8.338663623140475, 10.947260046276526, 15.153426086573619, 16.034532133899443, 10.375024225869232, 7.853196007874223, 7.943755664806189, 7.132794689954623, 7.12648713093058, 7.712995495788751, 8.42923975994786, 10.746278628301349, 14.46482736010905, 13.948076788474602, 13.811424464472077, 13.9170386776747, 13.488609642481553, 11.533822125986028, 9.66339294349433, 6.680290536978241, 3.6212822564136213, 3.949188323421043, 3.8924000261692626, 3.993769069428104, 4.918904147049681, 5.551580506447318, 3.5033525202858806, 3.1088266514536764, 3.3650483527135964, 3.469191953639656, 4.965544830813042, 7.752899770758386, 7.7282881365519165, 8.308634883620252, 10.442841919403621, 13.015144104216379, 16.29943361393488, 16.71265633136969, 15.984357457587555], [6.246041824961343, 6.277801959093606, 3.461198043823191, 3.098581884571668, 4.3755806935770405, 3.4071637090453066, 4.262313060964434, 4.17054440080951, 5.699113933254392, 10.17696409258981, 16.782860803374003, 19.32855177784832, 20.687727054679502, 21.01213682061123, 21.128842721401252, 19.41789859345171, 17.99399231270405, 14.53264119414903, 10.583109163870384, 7.634809293744356, 6.640900704396476, 6.7061971774778995, 4.194070995048215, 2.962961309400783, 0.0, 3.2242318548105597, 6.5498947467710575, 7.735481506480739, 12.892520764872348, 18.208047410123825, 21.162274245482035, 17.779806097431592, 13.114060655239127, 7.755665583552428, 4.213407155300864, 3.215496895629479, 3.4911606430426123, 3.1672750561389758, 3.09817006137672, 4.496806619765894, 3.2127641987454463, 5.052228667209049, 6.940965435091576, 5.700745953935031, 5.308868767709591, 8.206336092069543, 8.304042829212795, 5.97563963566779, 4.317184336651406, 6.093822173567353, 6.86583982526734, 7.415147775650739, 9.814937131803461, 12.51114614537407, 16.474348502581922, 17.319062934490937, 11.868530524362564, 9.062484517630292, 8.801271187958298, 7.9950138382950175, 7.997693510450142, 8.520884212588777, 9.31773011914039, 12.283912462080995, 15.77611654058459, 15.255640034153563, 15.137770397734021, 15.261278314657828, 14.867850834133465, 12.90782629407197, 10.96435501993657, 7.901427506081865, 4.686205238808277, 3.352202818573705, 3.616883656045462, 3.3970336004959663, 3.889969596988681, 4.288418456358076, 2.822256043528387, 3.827296349520468, 2.8829712527175686, 3.561484554595922, 6.388238572820329, 8.774623379566814, 9.122529008535382, 9.63101945767607, 11.820366342462723, 14.448235816242523, 17.564913593393516, 17.92640430244931, 17.214132179356046], [6.3952973767385615, 6.590217940849781, 3.5474482475074676, 4.541835963727592, 6.060529689606432, 4.352080549218981, 3.9189857697119264, 3.7183844016558405, 3.9375097313539675, 7.837293124172651, 15.049934499406966, 17.854977298483576, 19.43493715225439, 19.838562948265977, 19.865434217840118, 17.983091505524975, 16.384763540710736, 12.487462718731322, 8.490164558974955, 6.255534982384291, 6.1578416934693365, 5.871571067235886, 3.5241457974688664, 2.2213913596897132, 3.222621214765524, 0.0, 4.272058578113565, 5.430434627781585, 10.859551206906264, 16.77677728332238, 19.852802868172102, 16.197756917135845, 11.088878135114376, 6.2679085399725665, 3.244971808591085, 3.652677725387836, 5.395918189659895, 4.640446595526663, 3.4941485436097945, 3.8022402788969845, 1.4554040153900325, 2.8719391662353972, 5.213795143502733, 4.141903010808288, 3.6262645324871428, 6.412504492484403, 6.481508872410402, 4.098392675094061, 3.1871652130111485, 4.099589174695285, 4.313758917931036, 4.997930800526742, 7.476003282403752, 10.424265327490067, 14.703551744267125, 15.62493656177929, 9.762370599962683, 6.656792267496152, 6.641141536392489, 5.2817208876542745, 5.362051161523224, 6.385548273155042, 7.063203989688458, 10.13746780191789, 13.852747498655178, 13.352412102603735, 13.187120616959604, 13.437364467824645, 12.924722474033821, 10.987968244986858, 9.044329798012308, 5.837036347294135, 3.7319186517332907, 4.488416826822499, 4.254116748792973, 4.310852793717994, 5.647926788441691, 6.5238912214836144, 4.254147039326579, 3.0060578150780253, 3.1802509667159473, 2.959990529122016, 5.311721788476324, 7.7703305884921035, 7.381137786635526, 7.812641839733781, 9.840867238443957, 12.435355475067443, 15.842214355455019, 16.267921233507774, 15.609284936464796], [9.371772341565006, 8.732021403196994, 7.0429563677139395, 7.748755425164954, 8.91153112783142, 7.017236740467609, 6.542544715032387, 6.146611356946177, 3.7399543900363805, 5.013196832526731, 11.955933740311526, 15.492347113629611, 17.420701919153082, 17.843363764878966, 17.780289141836604, 15.600542046030515, 13.645402434640223, 8.89786798969078, 5.482401401928041, 4.341706938787294, 6.03012676165304, 5.542215027320027, 4.882432917725075, 5.339708200910792, 6.55212400829325, 4.27235875247934, 0.0, 2.8253565338168696, 7.8826492591755715, 14.182546120943755, 17.711327234574664, 13.585251250747461, 7.742680235116296, 4.20003259810493, 4.652862357630727, 6.895010084327601, 8.74517415299955, 8.211284576498725, 6.565554083184179, 5.3704822811950494, 4.230224160778118, 2.669794895946858, 2.6728525195827277, 3.0606969528235886, 3.0519340600325404, 3.844337114924366, 3.60107229371851, 4.937027584273405, 5.442889358520211, 3.0146749588832438, 3.4331633622724462, 2.8888820966060784, 4.529019282719236, 7.139036378959156, 11.333460395882573, 12.33540412934466, 6.632828229766612, 3.9995605794606885, 4.227414890376734, 4.254644092691855, 4.143638429862073, 4.454907270035217, 4.811336304484006, 6.712210238889876, 10.356361453413538, 9.843636410866496, 9.699995405318218, 10.000354490745295, 9.506746848144628, 7.571976944036897, 5.662937199981757, 2.994697135558043, 4.385226077299765, 6.51677844543658, 5.731418019515803, 6.510133043775295, 8.604346869257265, 9.345890325804165, 6.956666183850638, 4.664731436469354, 5.624170612523732, 4.528092705607753, 4.237418744916209, 5.9670207371080375, 4.82359325403489, 4.9249026218546925, 6.496579344605203, 8.910339580330247, 12.717818570517236, 13.18172532579383, 12.515548538717304], [9.895454861093043, 9.88531969988543, 8.051913470244113, 8.750822151758607, 9.49582665279032, 7.637145538159776, 6.7739160897520945, 6.272214041306173, 4.958165266112157, 5.564569321015357, 11.162956335582527, 14.915829627662205, 16.8210804747781, 17.182202004340507, 17.126362188610962, 14.972580879879196, 12.884409777297696, 8.194793222753022, 4.710229812065838, 3.575597077566979, 5.605092838487859, 5.07706829600978, 6.206972029685462, 6.665938782855667, 7.735711682758749, 5.413583204803958, 2.8234135149404174, 0.0, 7.611650834080707, 13.894162655341704, 17.197390253686503, 13.33061714702021, 7.434918565745927, 4.375068651580629, 6.463455600261958, 8.407785233406573, 9.887572347504936, 9.326866878061944, 7.769685391994062, 6.7847054405669, 5.36382368280755, 4.089839428179436, 3.2567288589540166, 3.6035642315595795, 3.48235944231242, 3.630556530712914, 4.931434331720545, 6.8388905576510215, 7.114699569536464, 5.220893802880716, 4.0116413552980275, 3.0938747818400665, 5.5402510105490865, 7.649669895941506, 10.282601999075204, 11.123495434008937, 7.006341999727216, 5.019284740589447, 5.366214322706327, 4.039545339180256, 3.75669297460773, 5.472654814976329, 5.58292724581828, 6.981878358692152, 9.37409571555814, 8.831026146920838, 8.65553688780312, 9.079432311535683, 8.576867048637205, 6.920314893876794, 5.205753469498574, 1.5527370509448095, 5.043023119963009, 7.025220478095694, 6.272960767100421, 7.275063497473214, 9.214869268387815, 9.89971562460806, 7.673389268619086, 5.0397040158427995, 6.354295944059982, 5.371987489920422, 4.970261423399622, 5.233997791708205, 3.9335687689254897, 3.8024253131082446, 5.443560316668761, 7.948341166983252, 11.881335952897015, 12.366077995739628, 11.511969766916444], [14.93310012816648, 13.993894792849954, 13.159617572813083, 13.784208957677532, 14.49899283262242, 13.15651214490317, 12.791998234113661, 12.467502631324555, 8.678750652147956, 5.373566951760316, 7.033000860262519, 11.422815655726474, 13.844355166410846, 14.233739138128755, 14.023259704841598, 11.253396695409759, 8.306288580833526, 3.9675566579458605, 5.734108334671611, 8.923260729614157, 10.8851075934317, 10.495207845331942, 11.335751050409128, 11.675182588476254, 12.854398162648492, 10.87587094244264, 7.909593225415383, 7.621545483582349, 0.0, 9.85025667669773, 14.059136743373777, 8.978301691003395, 3.883834223312858, 7.567850598071263, 10.990244575320325, 12.987047636497321, 14.679217721785093, 14.322604851837871, 13.005892725968568, 11.514239379316827, 11.10002061470725, 9.730472740367887, 8.803740726975258, 9.544547762968541, 9.920121481390645, 6.877712463708696, 7.371975978064629, 10.221807221361328, 11.084133003981876, 8.565553207526376, 8.09079644204848, 7.254280001786948, 5.388822908823262, 5.351259367043771, 7.866174891813206, 8.880365098140668, 5.284276101910636, 5.553186449922005, 7.838443189217089, 8.848063275432045, 8.679151866987777, 8.375916365613566, 5.43434439279662, 4.647881613519923, 7.014498550174521, 6.665420991427635, 6.464726101374922, 6.748509675828129, 6.481196458941012, 5.752226786595463, 5.562743519136944, 7.637046488271583, 10.477927977480359, 12.315048574341155, 11.488202978505955, 12.339120960295821, 14.40308017387666, 14.961282866979053, 12.973031309653926, 10.96139225593703, 11.89544064883596, 10.645609765459044, 9.71317523122447, 9.397586542664936, 7.765675886928998, 7.444679895376004, 5.992043015901677, 6.509663800436427, 8.25852371300079, 8.957297501728778, 8.430876874557601], [19.6719342943896, 19.18291221809054, 18.611950355658674, 18.82151676920101, 19.30140237297238, 18.315102573918747, 18.01401855737964, 17.743719741270123, 15.247067329688788, 11.35897567917081, 5.665864479525241, 4.821356863057795, 8.365246943883765, 8.939930094058045, 8.55761376172106, 3.3881188973513376, 3.732330443367934, 8.017652563516506, 11.704295098016713, 14.424303776535577, 15.949359000082064, 15.729110343639428, 16.686993092742522, 17.28373895072603, 18.219865038515106, 16.786626833719936, 14.153496790639435, 13.88136902415139, 9.844923132944329, 0.0, 8.314140560239679, 2.0160049445183876, 8.942157101709805, 13.176978969124242, 16.835549269647647, 18.502819304963904, 19.788400273755922, 19.370138015427187, 18.347349857830565, 17.31886870004624, 16.89884782176862, 15.499416181918635, 14.297557759970834, 15.12565827065244, 15.535263948815231, 13.146570164968805, 13.07468057211461, 16.152144381942897, 16.903261303062052, 14.857342455075534, 14.669233790603277, 13.893293497027958, 11.940825353075647, 9.247600979590795, 7.401086842146739, 7.7015129960303605, 9.743443663981546, 13.014298578497073, 14.361729295644778, 15.254152026490639, 15.169325688057349, 14.840015721724114, 12.829951816812297, 9.23551976429651, 7.636674749016189, 8.018920360796685, 8.125896634395772, 7.621822087911752, 8.04855557042275, 9.567763930273998, 10.803743564601316, 13.615384191811861, 16.15031301621359, 17.705581632294127, 16.946269785994577, 17.900596810605634, 19.256514659203802, 19.64657022117249, 18.17749488150528, 16.6780346672704, 17.517987263928603, 16.55424926858172, 14.957026586552146, 14.350379594114091, 13.273766651445989, 12.869359030150957, 10.744825146678762, 8.476504635631063, 6.089560513717293, 6.059292322065744, 6.756329220904208], [22.3322584281485, 21.95344334602086, 21.504031647365007, 21.526144084883292, 21.682035947693794, 21.045337652186628, 20.880405746673382, 20.613958288159328, 18.555436072142445, 15.48515207168022, 9.609641963717234, 5.231016835481921, 2.547707383526279, 2.7979597808000567, 1.9200015968839583, 6.475490098361295, 8.638093428799007, 12.426337350639232, 15.307980451238489, 17.490025480064354, 18.761586724590728, 18.532906126152486, 19.804620597555836, 20.402573744645284, 21.233418615726766, 19.863953199464888, 17.779183482902596, 17.20069141325586, 14.033286449716874, 8.31091695167879, 0.0, 9.273553377330495, 13.513303001608127, 16.729234863312158, 20.08827969685575, 21.53192286500613, 22.60509173650271, 22.223371272925085, 21.203779545012466, 20.28070809957025, 19.94257073663762, 18.844891238808145, 17.685831502627895, 18.421756280103985, 18.753199872821302, 16.517993122782567, 16.741963084068104, 19.285389817846447, 20.142220062050153, 18.36097854999566, 18.20075864204366, 17.495374871294192, 15.992500295163758, 13.9243525506576, 10.370235780784098, 9.513327032028492, 14.145828983511956, 16.62337688063357, 17.593978967377815, 18.405414478521834, 18.283790796045068, 17.96445197036254, 16.411112839832597, 13.886409337155309, 11.088681375825116, 11.477763320913347, 11.625668126628709, 11.24037456764956, 11.724286041951029, 13.42122058699184, 14.736138365059311, 16.893333469448333, 19.271609335895526, 20.56465808336456, 20.027549493437917, 20.852743959398488, 21.933033203972965, 22.090975384471673, 21.000615414764603, 19.769140177311254, 20.550776994595214, 19.732372513576724, 18.472010853967614, 17.313961500416454, 16.46794838675515, 16.115012437890872, 14.251520455514818, 12.184491643325078, 8.745203423333555, 8.19798733634107, 9.00406162900606], [19.385567387551923, 18.855483912844573, 18.096058792500706, 18.272464266140567, 18.557769207641712, 17.846738974355695, 17.75051178617835, 17.412295171109548, 14.805769081791194, 10.796298923395398, 5.776224606024492, 6.122201989031513, 9.212462144338764, 9.977986005888457, 9.57840879716761, 4.762175523586787, 4.089068438390253, 7.516029787319546, 11.331615200973221, 14.1387828338154, 15.615897437912142, 15.300049122151124, 16.051021703106656, 16.73816029731025, 17.754754592442918, 16.180170228976838, 13.568944966651069, 13.318723466221337, 8.972677553759011, 2.0177354232173825, 9.261269296914808, 0.0, 8.256814519039798, 12.8298315067335, 16.34120622118172, 18.08981121411439, 19.299788542366993, 19.019980798326962, 17.807299894149416, 16.7409909071083, 16.324054357207956, 14.933824234045927, 13.82941432273412, 14.661305340526425, 15.093745515887042, 12.692470523116288, 12.492248248443252, 15.399805487063974, 16.347991123740176, 14.23166324681719, 14.114526154985695, 13.30339798277455, 11.290185831180963, 8.360939503732682, 7.560295023038747, 8.07200070888759, 8.865013842382528, 12.224207931115522, 13.474928338272623, 14.439948549290033, 14.402730110753676, 14.083586911543096, 12.101236263475638, 8.554697681682507, 7.604960656791265, 7.8541994271506566, 7.947529500957803, 7.595736891100808, 7.859181186704805, 9.196002547542726, 10.352500049702032, 13.112815597478143, 15.660104841805557, 17.207977809485644, 16.584680367556643, 17.47761989686265, 18.73314805941682, 18.917630581495136, 17.715304454877952, 16.26845532440293, 17.134792677330804, 16.154192729353415, 14.546161027102997, 14.166027033534702, 12.942883402400506, 12.584907421861468, 10.506356169497996, 8.407346882594904, 6.450395770731642, 6.606652770460366, 7.248932199846839], [15.916683582677724, 15.371494156653718, 13.776754528376987, 13.929904019889792, 14.474025577275487, 13.615881590641907, 13.484227334047537, 13.066460890860986, 9.754296105087118, 4.125885509133806, 6.192988372929322, 10.805087648291998, 13.633274195589356, 14.171265831888526, 13.936125088771947, 10.848534009132267, 7.763621975135418, 3.48064971906903, 5.4367900434376635, 8.962708689403783, 10.905840313427834, 10.403543623084023, 11.141264674028646, 11.753550302953766, 13.114625928593039, 11.137572820015173, 7.757267897919586, 7.440497732053234, 3.870476537201459, 8.942287116511444, 13.52568629374646, 8.260926198058357, 0.0, 7.4537914648752155, 11.621832226807346, 13.611005686223445, 15.210546947059061, 14.750864725761172, 13.545996786731543, 12.467228934961858, 11.483495037134904, 9.507621200560694, 8.563857209702535, 9.445109748718231, 10.001925241105955, 7.331274581265591, 7.272674295738016, 10.224121270196726, 11.454114551768784, 8.744692206328434, 8.689708117749827, 7.329364115763468, 5.348717244500106, 4.045432715432323, 7.0334154463159315, 8.031646962554028, 3.871408361822348, 6.512613934236544, 8.355631193328238, 9.15183888356672, 9.084059883897647, 9.149946821381981, 6.893786132084644, 3.7520687226143115, 6.169316473730288, 5.845615765269567, 5.671297575699639, 5.387827220224705, 5.509630899126327, 5.555216160676183, 5.248780769763232, 7.338797024976435, 10.546960941851822, 12.63611305175583, 11.70176661648532, 12.951505876538473, 14.61257010619854, 14.85394258029037, 13.30390551927158, 11.343145548962372, 12.531913607252733, 11.22963422730729, 9.364893561492037, 9.365522122143561, 7.512512968016851, 7.002434020227971, 5.300994718408272, 5.380966864160352, 7.554031217744373, 8.051222938647015, 7.484273725330712], [12.153028712615404, 11.389921535560394, 9.30682988235608, 9.46352172983896, 10.06729703985657, 9.033342392810816, 8.973392779569398, 8.46896479868441, 5.051668946841943, 4.390686947960096, 10.426535396376318, 14.496702479343, 16.698447606104814, 17.185362589144372, 17.073345083847222, 14.673005654336867, 12.378839529759473, 7.990922174468394, 4.6518552018055415, 4.617969041220502, 6.138460990580716, 6.10511905606017, 6.865081649726089, 6.965135088236039, 7.747678579345595, 6.269019273309752, 4.205985548342801, 4.38757608955093, 7.5679477757624065, 13.171991256701851, 16.725885232335106, 12.846808839198012, 7.435551356413367, 0.0, 7.054252612641072, 8.977602917590252, 10.443146873390146, 10.258284517382268, 9.07792532702507, 7.8622068316392095, 6.441243025794668, 5.296666869537216, 4.3760846799240545, 4.77905273184323, 5.210717446862426, 2.8521450846337046, 3.8329609103048266, 6.66029972887205, 6.735282625411229, 4.908123444435804, 5.39920357719992, 4.178857238076728, 4.592098427565878, 5.961447732292614, 9.3913983530055, 10.340231303983735, 5.0836306602128465, 5.145759313561015, 6.580316075724707, 7.357539079295515, 7.259644439977166, 7.192245498400731, 5.075418470620246, 5.595417997247955, 8.439252337871858, 7.8915284670599855, 7.819296171031683, 8.334721174766093, 7.568035471048002, 5.9002994047980595, 4.082248595808087, 3.7636777343171732, 6.001968015654963, 7.061947784541612, 5.639951592214085, 7.687780022774202, 10.10629569895312, 10.195238025039208, 8.295314572768003, 5.852695798220352, 7.265737552568836, 5.2712424915725276, 4.478546861822462, 4.925288543324634, 4.572728552482223, 4.688528706687442, 5.200660936001353, 7.479611421235436, 11.0940666132855, 11.549827750964166, 10.991034694810615], [6.943496147448046, 6.32333119115122, 4.151089605968448, 5.226271258940939, 6.749984786791378, 5.353856027080923, 4.909897177934789, 4.8923513340561655, 3.6295931436392097, 8.345179702838307, 15.239428158311066, 17.96170325876004, 19.656141700282017, 20.078233563441344, 20.1051510397545, 18.18848429094511, 16.49882330308536, 12.727448520152052, 9.212689762453037, 6.905940660733879, 7.015128117799131, 6.96084435228859, 4.050142344219039, 3.6590834964293393, 4.214483329300432, 3.2456968949582703, 4.652741762313364, 6.46345308677655, 10.974611395332568, 16.84403070178964, 20.03407087289973, 16.359798800023405, 11.608092368394459, 7.061362394024444, 0.0, 3.6189361437918763, 5.696900249870299, 4.914294270008889, 3.9262124722486327, 3.00296942265621, 2.8633234866629302, 3.334610105907455, 5.586983955541878, 4.847195483453931, 4.367016438346, 6.719635660348787, 6.364174428328792, 3.9348228428721077, 3.8640549513948788, 4.446760474582063, 5.211024161071463, 6.055831197154274, 7.468169548007921, 10.247538407396629, 14.855062667495037, 15.829005168635653, 9.915393360703842, 6.285986481974959, 6.532451659379734, 6.188939617909038, 6.209754433625011, 6.035373958189638, 6.860407838294991, 10.14388636786744, 14.230659815348229, 13.768391709153107, 13.70238262321972, 13.897293868165091, 13.47158672220744, 11.179554476784016, 9.183401981100147, 6.594290274711043, 4.435085663920601, 4.924429082139948, 4.995853787606412, 4.029678942717533, 6.082147340180821, 6.9848742319535715, 5.106217343493412, 4.129253336998293, 3.5660516433951397, 3.493664476969821, 5.426808674458445, 8.14291222145824, 7.981819866923111, 8.508737933276839, 10.34125932086544, 12.828940296416361, 15.864658922461459, 16.306354181714738, 15.723361609976136], [5.129225621932123, 4.4426117462283425, 2.8172513671790376, 3.8082451439725964, 5.189009356426706, 4.302799104844522, 4.350897334265826, 4.453558668164505, 5.89762554665738, 10.51380807065321, 17.179001872859498, 19.577901389377832, 21.034902534500915, 21.308779398147347, 21.48243351839143, 19.78624488792364, 18.160942227092484, 14.800496434901458, 11.322547758367374, 8.475983321363858, 7.867259935950732, 7.902300539835546, 4.994127768740658, 3.1576048573326685, 3.214626073253493, 3.6490273542266833, 6.920887218338726, 8.388674405152036, 13.0136875666825, 18.531980495186247, 21.517931483885558, 18.08174846310452, 13.621176506185321, 8.9756729952903, 3.6177282269709954, 0.0, 3.241617997964617, 2.660410827892135, 3.1581386534304827, 3.567068497568071, 3.481736980658671, 5.2754668521785995, 7.572765827793, 6.567959733236768, 5.91197027799751, 9.06370117832397, 8.965475458493934, 5.018591801226689, 4.509534561099546, 6.552054025864167, 7.160019086899087, 7.940609205292397, 9.690379711158732, 12.917965125418787, 17.110228805344686, 17.934102790899203, 12.40007781747318, 8.797982696464803, 8.173479903293659, 7.789788611612918, 7.808191233072702, 7.651380281155437, 9.414573796395759, 12.81901391925768, 16.51366193054205, 16.045708095342246, 15.913835495996768, 16.080721224550174, 15.646918567646756, 13.723556011292576, 11.657771080058723, 8.555365831240874, 5.667789262407643, 4.876491875120449, 5.474568483333306, 4.0626755109176385, 4.555583087970279, 5.5835502985089285, 4.142128527959631, 4.746234051289643, 3.85372202126511, 4.711923342029199, 7.323949520108938, 9.879681440671133, 9.979209004738555, 10.539472061967798, 12.588324347415986, 15.307407449136804, 17.943899972662926, 18.34666960323876, 17.841258485724627], [4.532692017417954, 4.250575393106212, 3.3222806219788685, 4.5476661187356155, 5.503601823433735, 4.790537921355969, 4.623860846507095, 4.765510675920923, 7.721919454411052, 12.730138457710012, 18.681622102877725, 20.771072763678774, 22.08616631003371, 22.33641413552604, 22.467150956503136, 20.850992109191868, 19.39469013702422, 16.312485425423912, 13.20637787737711, 10.15386071260656, 9.25883147739348, 9.395974533334757, 6.91289402021817, 5.397191029538123, 3.4902003242772044, 5.385313979570201, 8.760801743841128, 9.867133238748329, 14.677670331642956, 19.71110329594674, 22.589305181152323, 19.30421911296044, 15.19143261222001, 10.447448627793671, 5.695246828480722, 3.238673043162925, 0.0, 2.5388940198206797, 3.883594949028012, 4.830567035696649, 4.83465583637364, 7.332837195366343, 9.385314340609783, 8.347721011003738, 7.509329082557566, 10.819242699292703, 10.858328611172169, 7.302800629822987, 5.792974149775784, 8.19591000674638, 8.554028012159058, 9.30972487486134, 11.838954059825989, 14.815038329389097, 18.731658695005624, 19.46368559817609, 14.373261229144017, 10.870027115838823, 9.834848962214926, 9.096585039124735, 9.139876277268772, 9.365693451497053, 11.250744711230256, 14.898317355785279, 18.197671466390215, 17.74875388367898, 17.53990976799565, 17.740984692781012, 17.335557472377744, 15.552666953327044, 13.580490518547599, 10.225274220629961, 7.405490754693695, 5.56028864169018, 6.362498417777062, 5.027984775614799, 4.45773929324676, 5.16822463194138, 4.761901752253775, 6.141219667763239, 4.802395579991873, 6.003467983167989, 9.161946802750128, 11.442083582966731, 11.83570297087366, 12.318656871291953, 14.43163621543794, 17.039868457500887, 19.424417863982, 19.746000079997472, 19.35627382872065], [4.0832845518470275, 4.735418225570871, 2.3194145042851666, 2.8345868373680454, 4.301493270636385, 3.45824368860758, 3.6898168512937124, 4.146667130104083, 7.175896786633676, 12.25251520959264, 18.339888579836558, 20.48033757377725, 21.73705552265364, 21.99982977593366, 22.13255488728379, 20.507059128182846, 19.062011620253024, 15.885733693181333, 12.614575547886856, 9.34320640466645, 8.29256685172629, 8.333916753110758, 5.559708342686653, 4.338200706110912, 3.167170177951584, 4.638896760898389, 8.212835429131298, 9.322771626359684, 14.351147063751023, 19.381102101457174, 22.188306409427813, 18.928326321665946, 14.727169971623196, 10.25828638148865, 4.917553645486413, 2.660410827892135, 2.539325319954834, 0.0, 2.4388796489684057, 4.58962095027141, 4.367797251922425, 6.491020952615078, 8.631306367862267, 7.403456579689034, 6.749135187459679, 10.208706348635697, 10.225079737730491, 7.098431381300623, 5.876411964477316, 7.8665089537904835, 8.057360519250098, 9.193815087555766, 11.586788815428141, 14.480002149407216, 18.29391725208307, 19.146395214781588, 14.066718452121313, 10.505636875774961, 9.836435985531171, 8.557623247760194, 8.67027658168847, 9.217068161475925, 10.873809934870772, 14.3434415094831, 17.666366447309034, 17.237061844875203, 16.97756550186229, 17.2660325676981, 16.803047554749728, 14.983579854184596, 13.028160863206457, 9.652787647583247, 6.243382153025141, 4.997639275507078, 5.958985147895657, 4.24425753353763, 3.325768996803416, 4.50223258762031, 3.797243018227162, 5.369562855699563, 3.8372785240392364, 5.419825386682001, 8.320826782085556, 10.704556875724029, 10.971405763629148, 11.467188802072325, 13.814331863640213, 16.422304276813627, 19.196103114072454, 19.568817185104905, 18.97168724472022], [4.518695025009584, 5.04058860706698, 1.8820977995305155, 3.352641281185791, 5.1610424028955535, 2.8055228177544045, 3.014631867639602, 3.4746823947104044, 5.8263103925466, 10.782877282859442, 17.115126266967717, 19.464309663236346, 20.762898509382882, 21.181878651233795, 21.153853226688938, 19.514836463067773, 18.079240554058053, 14.695835042888984, 11.030642072674853, 8.130444291221712, 7.537346129742092, 7.3138785230068155, 4.639990143335318, 3.931725412210005, 3.0980812038762564, 3.4936389377817916, 6.565554083184179, 7.76869294436785, 13.008601015533491, 18.36760687526776, 21.217117477472982, 17.820417417719163, 13.498247201314369, 9.065802912716558, 3.922511406247902, 3.1581386534304827, 3.8825158536539246, 2.43522373861485, 0.0, 3.6029572307258624, 3.2800270937412517, 5.219416065714248, 7.197875150287789, 6.091322067641161, 5.461037222329172, 8.816883533706955, 8.737929692642275, 6.237093145955109, 5.097640730154678, 6.285594258858636, 6.447343475122049, 7.691414952679308, 10.188961741776945, 13.19963109530399, 17.04581481081718, 17.849038903178048, 12.689285195477199, 8.96720983022983, 8.465244984195824, 6.887968697053347, 6.976666328689588, 7.814715693731209, 9.334283565023982, 12.84853762375248, 16.312251575926965, 15.854399611947676, 15.564238797947382, 15.963555342707698, 15.469480240712908, 13.479238057328566, 11.601455954838768, 8.24151566581883, 5.097489711780275, 4.886469784909266, 5.588965042309377, 4.054683131416972, 4.153609985233972, 5.466966343028788, 3.873532942104142, 4.635286988777922, 3.091390949720444, 4.617895241560475, 7.406004152584054, 9.654871156388339, 9.593920358444025, 9.98035632508175, 12.321344236724967, 14.982286772998881, 18.051735441320517, 18.44161526154806, 17.810091156906378], [6.009535648005629, 4.307051166064917, 3.22755829303199, 5.457927981072485, 6.753719561885562, 5.109960672187302, 4.232051484299469, 4.420155784835605, 3.9751582614336884, 9.620597447092981, 16.002716745708003, 18.40041867977383, 20.00117158487339, 20.419292853406983, 20.392843880762605, 18.504570123244964, 16.97905991444331, 13.327075644967717, 9.952124497072358, 7.347328010718616, 7.575270460811421, 7.451121987415702, 5.569120459175143, 4.7428623764392075, 4.493184205590962, 3.8078893718757043, 5.385336383656198, 6.791687925981509, 11.51323578416403, 17.355204560728186, 20.253797250003604, 16.74578212048219, 12.471386015761805, 7.864484950211416, 3.001399715053271, 3.557429044764571, 4.836348081832112, 4.589482351723047, 3.6029572307258624, 0.0, 3.02608795310998, 4.872843638518303, 6.334594802618781, 5.873706811986961, 4.938200929843301, 7.416863976568092, 7.567079036112989, 5.194433188347666, 4.63536222868657, 5.29689502721104, 5.137479761751823, 6.401771384770248, 8.316571302156714, 11.75253229308748, 15.728294216367416, 16.68588191186757, 11.26879907681248, 6.920003013343554, 6.009162320016214, 5.899192383978862, 5.8993737351299265, 5.315529725903781, 7.332890782383543, 11.388893598726154, 14.998447313838351, 14.450678414759585, 14.364234628794494, 14.790178264145654, 14.260667315719937, 12.065145859142005, 10.107851509204224, 7.112158558332186, 5.3109214457253975, 5.1968459923299, 5.596331241832511, 4.125302170672707, 5.8154218005240566, 6.996346605125442, 5.124728741684588, 4.662102061257804, 3.5174988004311554, 4.007299346962783, 6.966450372002729, 8.8862163359103, 8.748544998456065, 9.151541070454613, 11.00561390878456, 13.746326417865696, 16.77919020429286, 17.2776210739614, 16.70673827197628], [5.939228786240943, 5.90779221491337, 3.272242839522857, 4.714816010654695, 6.0808919503972, 4.287899200433649, 3.309919797783359, 3.096178691060004, 4.0048376438228095, 8.284338888214124, 15.212765564559797, 17.987239445659302, 19.58800503166161, 20.024323387201417, 19.991728013666364, 18.130343241367573, 16.551252121408766, 12.733940589959758, 8.900042326036854, 6.27485764883695, 6.301221235360815, 6.176170078420295, 3.996556998935498, 2.9456574889705482, 3.208692127994693, 1.4554040153900325, 4.232723179349065, 5.356787859994583, 11.089588087085545, 16.909206792937916, 19.96173715011747, 16.41884729577629, 11.510178819911854, 6.4465061843496345, 2.8632865276695365, 3.481025299720144, 4.839838875723255, 4.369275287359862, 3.2800270937412517, 3.0284908373633224, 0.0, 2.9075855198952083, 5.1259089083239795, 4.207567338100193, 3.3504129709875086, 6.524341863253056, 6.5397068421128886, 4.294763764943453, 3.466491001409593, 4.256535655351374, 4.262682258977783, 5.023047417505106, 7.640775623532655, 10.655689153704275, 14.907773582019276, 15.756695387815999, 10.033670164644464, 6.722034735369765, 6.335747366996346, 5.086297822132926, 5.193592167233451, 6.043224506242701, 7.152278666872666, 10.370593613051586, 14.020065976197973, 13.472978264784322, 13.374618502139082, 13.694947615749967, 13.164693605105976, 11.131847318192623, 9.17072479816734, 5.801440074821874, 4.101018603365721, 4.207442118609558, 4.120244104033541, 3.9096770029422516, 5.402187211854704, 6.275616305064959, 4.229476410292658, 2.791179858770365, 2.7378458322413612, 2.6623608710876305, 5.369335836141959, 7.776836357774966, 7.64436269913083, 8.031708237467715, 9.99348481447254, 12.62485826381209, 15.981686286233948, 16.38803049187666, 15.765932368831974], [7.908462556704698, 8.001751409444367, 5.711904515081699, 5.94319574256106, 7.092390639147315, 5.545937671932057, 5.085603902124581, 4.697785632671349, 4.002878276653265, 6.286056759902399, 13.58488717591712, 16.713659476640686, 18.465841449779532, 18.911481562806138, 18.85712066478702, 16.879767058336686, 15.139353992450035, 10.9057055508576, 7.04035943739171, 4.761220786284334, 5.293035006411012, 5.071743609195275, 3.0548613353684644, 3.3720148284988243, 5.050846916857123, 2.877225767468705, 2.669794895946858, 4.079236390041904, 9.717883370736756, 15.497715602689084, 18.86225922444341, 14.953694456193942, 9.497761564999937, 5.3137741392128275, 3.3342425589407436, 5.279857688251002, 7.329829929107644, 6.481463676287179, 5.219383656255483, 4.875091159632013, 2.9046031296073975, 0.0, 3.2412877231868915, 2.3754828597225006, 2.2271454588324993, 4.9886746895891, 4.735682905340914, 4.2836946793169695, 4.761503278923983, 3.96670491410418, 4.4869141079010975, 4.472617830608126, 6.15236987922914, 8.545894610900696, 12.825093625214137, 13.831646315360791, 8.050112321687848, 5.6802294041316435, 6.087926707664328, 5.077021965899983, 5.047197857911046, 6.033872491275024, 6.463832581886378, 8.24494883853463, 12.013411703884323, 11.59229173101045, 11.418826310011527, 11.527664783602058, 11.133557235366572, 9.109068642383624, 7.240661506112328, 4.131867007836461, 3.2897975302793125, 4.988959057627966, 4.452743630727938, 5.019755084369942, 6.833020688558003, 7.50012406698204, 5.336271761524526, 2.982598687031221, 4.1225204164728435, 3.41047311032743, 3.2892475038386992, 6.159316069732971, 5.718846184626616, 6.0964950114669145, 8.026723641731033, 10.434286262695526, 14.236304175589837, 14.638709559472572, 13.87826417931316], [10.003134368840623, 9.602015769068208, 7.901139975414252, 7.53598596999381, 8.125168250243412, 6.994681699365822, 6.754005668749046, 6.37745430708821, 4.726149673216796, 5.984800527373238, 11.757640981035392, 15.380205192131225, 17.343241444134076, 17.80323604314989, 17.763635869986295, 15.579876020343457, 13.674873518692971, 9.172432850616927, 5.222788061835761, 2.6254639159866393, 4.15233768627013, 3.9930240383479085, 4.711306284521747, 5.651991043590567, 6.938627578421524, 5.212765460708698, 2.6717243962841124, 3.2491465911835125, 8.756484837933314, 14.300041826700012, 17.680470181097043, 13.84700723544669, 8.563588601381152, 4.358647015252102, 5.584637561296624, 7.567699463460046, 9.369262755406535, 8.648753020311311, 7.198344189161429, 6.330672321147332, 5.127677876298772, 3.2385066176439956, 0.0, 1.8136764537657013, 2.2095980275853333, 3.2521437530563535, 3.4576203328234763, 6.619620423729325, 7.129061323481827, 5.100905174857018, 5.207488532720172, 4.962323734841577, 5.865922099819053, 7.678250481993658, 10.421946444860712, 11.46641189777684, 7.2883427813991135, 5.771190233568692, 6.239310484876444, 5.9336766651908155, 5.78518966415166, 6.327854885026674, 6.371012400554081, 6.9890730287125855, 9.741448739629105, 9.30618965537714, 9.200824451228623, 9.396356385904701, 8.947701317538451, 6.864502304039301, 5.262112318079812, 2.4671759650785665, 3.8599087004341053, 5.7398912596187, 4.984359904440587, 6.053501253656036, 8.088829718547796, 8.602245369810337, 6.528384347006203, 4.1233600007833955, 5.54579702891, 4.455427960805238, 2.8708117052932844, 3.8723584449946533, 3.499813615387025, 3.695509163621123, 5.765404366270407, 8.194913991257662, 12.270474568434766, 12.641816815794137, 11.897389263343868], [8.93923558601345, 9.035368739744785, 6.774138506516488, 6.1995552601202935, 6.8016734563758545, 5.649081825898639, 5.650549360297182, 5.256362088674766, 4.444205656087294, 6.581971735383134, 12.843971798387889, 16.21724182401916, 17.986699394610717, 18.46513235032455, 18.430415181116153, 16.4260876833362, 14.527772935751761, 10.247363522738988, 5.984313950814003, 2.898568124314168, 3.425436277970464, 3.3380937581596344, 3.4039792789933045, 4.339192831962506, 5.7046684234456775, 4.14605705307683, 3.0650546502281966, 3.606034622184804, 9.519817483341644, 15.122978796685134, 18.422834862204795, 14.672486992411022, 9.45288867159195, 4.772537588139097, 4.848391450796371, 6.564860111206137, 8.340893791575555, 7.386590019351767, 6.064606548193688, 5.85524034000435, 4.208293882624496, 2.3766126066357334, 1.8136764537657013, 0.0, 1.4210989360124735, 3.9460743705579024, 4.330429435896481, 6.208873827143475, 6.3862648365914465, 5.078150419041414, 5.254761617570545, 5.154672357649023, 6.695749383313133, 8.537401747300391, 11.599762217821093, 12.547954196014478, 8.068378381802685, 6.371149079996458, 6.916912226963503, 5.984166413286371, 5.8293724206107305, 6.841405586413798, 6.953779270266069, 7.949050412893823, 10.918918596260436, 10.453098236201361, 10.344996503278221, 10.488800677802592, 10.01309475817026, 7.970761129577089, 6.35450114343591, 3.186478123052721, 2.778772381382123, 4.569603644486165, 3.916386268760307, 5.012570325744441, 6.83950633769881, 7.316105522096382, 5.267913386363758, 2.898899385456395, 4.31443605556282, 3.559185299174222, 2.333617462284795, 4.235268157542082, 4.1600534160787745, 4.47738598996763, 6.859852345507247, 9.306622681023203, 13.303432230321494, 13.68686804368259, 12.914065379808077], [7.9539589366114685, 8.024032759137535, 5.9784115148158525, 5.8748830694296785, 6.504523664963797, 5.236754253083338, 4.653272595004407, 4.245798056038385, 4.1862764858408115, 7.17532598787642, 13.430069653340615, 16.61719321096536, 18.35994181423629, 18.834210705497387, 18.775992002686227, 16.748352459199847, 15.048780491889612, 10.84275023891642, 6.7556614646081865, 3.4224340720834627, 3.901652746177615, 3.8801895930294523, 3.7395923063663847, 4.2011192822624315, 5.291035333843802, 3.625723254817275, 3.0501960381449993, 3.479629489875221, 9.901953278802484, 15.534169474211488, 18.73194553334973, 15.098157623840319, 10.014190935584294, 5.20762939305819, 4.370076396044435, 5.9103133432591575, 7.502475877108918, 6.746170980314558, 5.453702694332151, 4.933282120170034, 3.3552370149354473, 2.2267342936936956, 2.223343677578362, 1.4207709652683262, 0.0, 4.4321367752073755, 4.85998081094649, 5.924427270143957, 6.021840779628171, 4.9983133578876755, 4.802511786955169, 4.919448068023398, 6.887447028872901, 9.230137319191877, 12.317304872868663, 13.256474145970996, 8.711247712128962, 6.336177388251635, 6.439567511850368, 5.291213190447867, 5.13439843061422, 6.263630818220538, 6.951402089775878, 8.65767684769309, 11.583862308362786, 11.098828800184691, 11.01184398819411, 11.245029580573487, 10.792976588498483, 8.674778340043478, 6.985860722290301, 3.3523651159941346, 2.9922627922994405, 4.191864708441075, 3.7881307285583494, 4.428570892976772, 6.281020647772281, 6.912728029883794, 4.856470472300661, 2.2939113141871297, 3.6628820005065257, 3.0946888966298953, 3.2097024375532412, 4.918868132227911, 4.937979328354839, 5.24994956976202, 7.504227336009531, 10.036914926563263, 13.966515972115955, 14.384878080845068, 13.589736068329037], [11.850230988932088, 11.238599435976997, 9.108692407045716, 9.281003828364966, 9.760142575414745, 8.765702955598147, 8.518717261924992, 8.16371423339619, 4.260513605855498, 4.880207638762191, 10.032368484197505, 14.227460264456806, 16.46038774805194, 16.94703568031512, 16.832388692787013, 14.412338039708477, 12.204482963509893, 7.378562833083009, 3.770375306845177, 3.191681920200933, 5.2177894916524306, 5.135269522376174, 6.540844356268589, 7.090051321130398, 8.207613371911593, 6.408680414637775, 3.852215779939325, 3.629100973962805, 6.873808605624512, 13.15809721534166, 16.51858254779562, 12.70158166864649, 7.333785813449128, 2.8507740899076923, 6.717770646256177, 9.074060218744602, 10.822107687389403, 10.22201372377956, 8.853410949721358, 7.416863976568092, 6.524341863253056, 4.987700520705546, 3.2573752838526397, 3.9460743705579024, 4.4330511692007715, 0.0, 3.274959091884851, 7.176476156003653, 7.583734734078961, 5.519110626520965, 5.2281188741713835, 4.836842332002888, 4.827331407969001, 6.21216823201429, 8.75390754157981, 9.806447791618709, 5.761339987391727, 4.687381278668196, 6.5202463598351965, 6.8044698701355, 6.617070792920987, 6.738693538507266, 4.745237717532312, 5.335575396082313, 7.981245977416046, 7.505996377970498, 7.448830280548509, 7.822436104421122, 7.2067312262728205, 4.901545572807129, 3.3096258067580444, 2.717004790613538, 5.26670806618469, 6.864874696083508, 5.841648292129868, 7.202778680695937, 9.751845576056597, 10.087159294840346, 8.113526156341441, 5.530180052173543, 6.776142520356374, 5.157140733341768, 3.964815408324577, 3.5311943008520474, 2.925535873700447, 3.1076695898125757, 4.173546580941688, 6.741585410212822, 10.573517914564835, 11.094914095263535, 10.336016988418573], [12.087349056534213, 11.417385782761443, 9.28353603408855, 9.454017217120255, 10.340368162573894, 9.290520265109848, 9.020708745128998, 8.731529358414859, 4.93353714803425, 4.579695923582773, 10.63383925275666, 14.495535561575283, 16.74116497026017, 17.21053424873913, 17.046212234118194, 14.714909413616317, 12.57890399726952, 7.989945777202613, 5.296718844319658, 5.203312792571344, 6.8202936670649, 6.758361938221987, 6.426715606618498, 7.070132896119921, 8.307706968490775, 6.478392719135423, 3.60107229371851, 4.933999342723312, 7.3817226437690175, 13.063776591017701, 16.745163004826058, 12.515599893463264, 7.272674295738016, 3.8251758131204396, 6.359960048939249, 8.957516751155758, 10.867217646128868, 10.231229369374006, 8.755501236023784, 7.576410086352107, 6.534819222877187, 4.726939628577242, 3.459491807951974, 4.3304118412297035, 4.858927030519837, 3.274459500052803, 0.0, 6.440961331256783, 7.087216974613261, 4.335539407177503, 5.285287108023644, 5.122813514067937, 4.426899303171565, 5.495906712649433, 9.60999240538131, 10.8470917315008, 5.21536869907671, 4.736183923262532, 6.601665967725639, 7.02413145548818, 7.119635712735004, 7.02139387300267, 4.823311706403849, 4.834502476396832, 8.974690438526741, 8.576721548201215, 8.539881611484544, 8.635942193247933, 8.155837287639295, 5.8271903855019405, 4.4669539243268845, 4.4138027753768645, 6.141318264239516, 7.6709012724437775, 6.603326763754847, 7.880250396000047, 10.312668103507933, 10.605303323347682, 8.76070976388862, 6.254442843782141, 7.34612796396841, 5.675827763950302, 4.10287155875042, 5.532418503791815, 5.029028201771043, 5.00242656000449, 5.705369754435031, 7.56993248644007, 11.134013876386406, 11.529823300571682, 11.003128125999485], [8.761377982203365, 7.912712103314163, 6.032822527092726, 7.710623374486171, 9.154089589213903, 7.577484847410188, 7.169468342108365, 6.927784971694053, 4.589879618784938, 6.659414557531717, 14.585981684877087, 17.262460496140214, 19.08848323886092, 19.49884072184681, 19.39848560151222, 17.404016173004337, 15.773079739010406, 12.18813608231633, 9.13650725270308, 8.02773645383603, 8.752817983145595, 8.585235588317895, 6.017077873887856, 4.6631905681098935, 5.974209783379549, 4.090237684476098, 4.940955676851513, 6.834570353036491, 10.20046590909259, 16.151572584978844, 19.31292691387101, 15.430837194407173, 10.191228724973934, 6.659244775480534, 3.936666971059962, 5.026122172596343, 7.302079075439893, 7.0984831209065105, 6.233741320361816, 5.183677954378673, 4.2847472323055475, 4.274285605941827, 6.624102188406532, 6.210638148460885, 5.942152930343029, 7.180718250093405, 6.434132094913551, 0.0, 3.0037990037575573, 3.8539713078266957, 5.215159915931193, 5.2722312931009725, 5.676000048994815, 9.055971296106817, 14.549868038452733, 15.435612761615758, 8.473186705231836, 5.237984457518485, 5.868370155061539, 6.457243470556503, 6.585568109490193, 5.933170426299741, 6.051043531770716, 9.194184125499476, 13.779287622373358, 13.2235937498436, 13.192533227840048, 13.260213959080376, 12.932259845979287, 11.025968444960478, 9.000115179819922, 7.042539417010197, 6.533126353375936, 7.170061759503412, 6.683593596129526, 6.781939393318078, 8.71867651001881, 9.312129790297213, 7.490964883755675, 5.780682900337673, 6.193371092646475, 5.283399970673553, 6.496135565140413, 9.290524304563204, 8.721793797335632, 9.093555784343298, 10.185053140805518, 12.540854925768427, 15.225443786077248, 15.683583997378754, 15.207232325739058], [7.891686381659954, 7.3272278529864705, 4.7246221138579845, 6.58474935802855, 8.22582060968001, 6.67733341301838, 6.327295192142932, 6.132841319285851, 4.5153119542202775, 7.954870308607249, 15.429968725684523, 18.000019871006714, 19.716209040724568, 20.121582542912495, 20.096167634155044, 18.2276392238016, 16.546104007107452, 13.072357704066151, 9.713057951392237, 8.385638663379474, 8.669655033044263, 8.481789399305304, 5.732852307591354, 4.221030779920531, 4.320400227724458, 3.1851067007783675, 5.439518871847967, 7.122437866847195, 11.092314913348135, 16.880249125418967, 20.068127955990825, 16.359687510012964, 11.437396638388496, 6.730247440895374, 3.8789429919218095, 4.50813377824274, 5.790432978919597, 5.874977706620179, 5.097640730154678, 4.632837648153906, 3.466491001409593, 4.761503278923983, 7.136982044157004, 6.384536154212838, 6.03838548027862, 7.583977824348086, 7.087458753757516, 3.0032284818187254, 0.0, 3.598860556488636, 4.977199900330854, 5.27975283774621, 7.252481873416322, 10.290709128806672, 15.439525100951327, 16.287826266472145, 9.591836948058885, 6.465464343247215, 6.724758309123835, 6.551675624722528, 6.6664268652843095, 6.723676084939803, 6.720248164362642, 10.334839182581272, 14.737707645495242, 14.175311198466051, 14.02761525907713, 14.331230179399338, 13.809590185349176, 11.865585249465843, 9.86724064276483, 7.564437754859622, 6.23479583183189, 6.420481025991082, 5.974266848412526, 6.150673017329299, 7.745981575063685, 8.31900069405147, 6.533055470866148, 5.498904814564702, 5.303517657121388, 4.61827576615562, 6.943655239237946, 9.651538309898685, 9.23152036423124, 9.628138156292676, 11.066485925994169, 13.491993585501557, 16.234835316090273, 16.560426828316277, 16.08941283220379], [9.596813321204944, 8.71062079978202, 6.5971675037826385, 7.865108444005374, 9.46215150609376, 7.597103724781197, 7.2450394644207226, 6.998547349183564, 3.8664823950255953, 5.663496545293338, 13.053993002619576, 16.188417134324926, 18.125221886448895, 18.534060426896836, 18.472546485010614, 16.353567081598786, 14.459412903367248, 10.16744361003312, 7.230155095961699, 6.797597886398805, 7.949123626810817, 7.520339524958939, 5.613116430610552, 5.405540389017959, 6.094002563598672, 4.099706837687694, 3.011774663155857, 5.212533406721509, 8.574200744988419, 14.898108288584616, 18.366003802807537, 14.341750334154167, 8.744692206328434, 4.904032902859934, 4.442975332584897, 6.5598089428557245, 8.206664685176039, 7.896527712326254, 6.288098575680179, 5.299691829514956, 4.256535655351374, 3.974364107971909, 5.079331855628027, 5.068016823822834, 5.000690917020862, 5.5131142429570845, 4.322197397466922, 3.874266505422181, 3.598860556488636, 0.0, 3.1809404350947466, 3.437451332425523, 4.955657820365937, 7.707145967725681, 12.977770737962706, 13.818365059388832, 7.144629203393976, 4.303128298882362, 4.8843481503844375, 5.170982963456063, 5.400665543024082, 5.20097688510861, 4.463274377779088, 7.60684097652852, 12.012107159547988, 11.478393180938953, 11.338706826945923, 11.67326927787467, 11.085118583975111, 9.213682813920821, 7.297694364911246, 5.6125742832757926, 5.748631386846928, 7.19149870440023, 6.344263490971131, 7.03893216930775, 9.109080728044496, 9.755002547514472, 7.572118023656834, 5.759050366255419, 6.132767740134935, 4.824399555155948, 5.822852448307036, 8.1147368291645, 7.178827426191149, 7.315176697861301, 8.497415262249477, 10.731036634184878, 13.955522322469765, 14.388613711703332, 13.847916846596805], [9.057770880457317, 8.529139420006354, 6.346033703450538, 8.246326008474435, 9.65835618075035, 7.572631302817573, 6.439440367145357, 6.334595044363969, 3.7978776104098775, 6.403405367489715, 12.948128470516629, 16.011783036303626, 17.86794192981162, 18.194350682896093, 18.17760623795511, 16.086668650841634, 14.145372891620802, 9.750077996517955, 6.881946534905079, 6.301503429528961, 7.728980028525161, 7.232828345572962, 6.489504961869514, 6.2314777992601575, 6.8595722806770825, 4.313672519777372, 3.4380510727132205, 4.007598677815317, 8.0669486782815, 14.674615244320902, 18.123127686209447, 14.110155594356117, 8.684019132460339, 5.401400031772798, 5.216774467505551, 7.149825774454648, 8.55630562902677, 8.068010492919557, 6.419450489056841, 5.132025622263692, 4.267039366232862, 4.493044414061459, 5.201993209020645, 5.254761617570545, 4.794279811119247, 5.237863374395161, 5.294427571225913, 5.221544755171538, 4.990820201913383, 3.178266154199629, 0.0, 2.9642428576301194, 5.5552115520140415, 8.52703467172987, 12.59216353585499, 13.748239534408096, 7.995169794677073, 4.217252992441102, 4.532795200485151, 3.166633170818265, 3.6556419424922098, 4.466705548699079, 4.019078549959739, 8.165000740413248, 11.781638122106227, 11.213363661066174, 11.023941836511838, 11.55259505878744, 11.043756332581367, 9.08741094146646, 7.208985804810807, 4.925559770901301, 5.859315706516998, 7.384733975809443, 6.753084189347793, 7.096819866511337, 9.087843007118602, 9.969785610653508, 7.751156995610386, 5.571850841196717, 5.980466131964682, 4.835649641046809, 6.47834446871606, 7.881173847804109, 6.771152932041391, 6.818726001473866, 8.045977739888354, 10.500622583347834, 13.949867986705518, 14.390535206467222, 13.92149991234174], [9.959508177532241, 9.491460345928212, 7.697925555427328, 9.166300469757573, 10.340966294384074, 8.297031233278807, 7.4011487361225345, 6.89383640275715, 4.596037888932461, 4.930098306901881, 11.904677795621279, 15.282069147117554, 17.26444497646916, 17.5257720239411, 17.490286179650788, 15.341426830222579, 13.301970406133325, 8.700206559257538, 5.9313985532148745, 5.928452858399099, 7.655875205112877, 7.168279088590004, 6.835782071391765, 6.616172752327003, 7.4358548690457695, 5.0011907294810785, 2.887146812127047, 3.099558193403109, 7.253990938178196, 13.886701811031458, 17.5161607242876, 13.296355317222526, 7.314429267986871, 4.178030022469627, 6.0546529494181645, 7.93738437270607, 9.309944869888497, 9.201268442468368, 7.6829140275578105, 6.397592318087612, 5.0205727611128745, 4.4901056644954345, 4.955236173618256, 5.149307537024935, 4.905513802671101, 4.845847394068111, 5.120091600985451, 5.2684549675265995, 5.2834465935109165, 3.4245493241111817, 2.9631294838049813, 0.0, 4.423160810001033, 7.247783332580986, 11.496090535491296, 12.451086259333547, 6.410616749116793, 3.8488734918348277, 4.130717980382884, 3.8420674281786322, 3.7608609994510567, 4.61927664511783, 4.303797645882498, 7.010308634453741, 10.450506365386666, 9.843171449327478, 9.668227820951312, 10.174515084870023, 9.589880032101371, 8.069168458525668, 6.146260723479127, 3.954387842819045, 6.216799296608328, 7.79685589838096, 6.897108588738853, 7.898160852910646, 9.956534863725922, 10.639395052375535, 8.344422775903624, 5.957775884698723, 6.9096608857560815, 5.629233566456258, 6.156790221442531, 7.412178894603166, 6.168566399000241, 6.134372926242623, 6.998696083579635, 9.284700600757064, 12.885808439490491, 13.379158816267243, 12.733473189593893], [12.916239426978409, 11.690313605433102, 10.25875557005933, 11.376675958411267, 12.412233664790103, 10.860712298695205, 10.380517550165782, 9.975962469639203, 5.64076192376292, 2.6951597008598234, 9.829816748980537, 13.790503191300509, 16.005484175773283, 16.37282226342387, 16.16831396865239, 13.715833780198794, 11.378591482639843, 6.998707517442024, 5.536050602558911, 6.877286371627251, 9.017356240025704, 8.730391178502053, 8.489667733406847, 8.355110517868306, 9.82380529366895, 7.4741357757315106, 4.52698350026914, 5.548730994296845, 5.387249309505232, 11.941740872621425, 16.01653992959732, 11.347926897157787, 5.344184657487788, 4.584791854426735, 7.4649193161471965, 9.68377065439548, 11.842035925313887, 11.591151185592219, 10.184402594147574, 8.324847834896966, 7.63071008600433, 6.149021797816334, 5.871074874408992, 6.6929684637566895, 6.896871349729166, 4.825848101316112, 4.431752355099221, 5.670093642242374, 7.252793460909146, 4.968627989019289, 5.55500796320419, 4.4256525005685114, 0.0, 4.428762331136637, 9.734997359324131, 10.847202313248221, 3.8620946449210116, 2.4532790571389045, 4.80652223652342, 6.884228932967538, 6.849822239644581, 5.597700358742444, 3.399587844959451, 4.398875413913779, 8.68224081382933, 8.160521769546541, 8.118561736099043, 8.253504733559426, 8.00874374376132, 6.4463529957952135, 4.663905935085874, 5.275542891205013, 7.9780808622949735, 9.671121896550597, 8.651616964088058, 9.656839621434376, 12.212341074468142, 12.723466154202136, 10.564025817590958, 7.982007515910434, 9.1754999704803, 7.484826341627698, 6.673474630458307, 7.706427116381682, 6.409192699870176, 6.425717152750642, 5.9290830341467435, 7.797665440062969, 11.011272686887208, 11.568858508427468, 10.985925896517166], [15.892964601470497, 14.961948925991683, 13.48127757334619, 13.82440243458791, 14.777735184911897, 13.552139423989857, 13.294484864412523, 12.855901544091745, 8.659065304566976, 3.3923249884955307, 7.264273341139413, 11.700749213842236, 14.32808273099213, 14.806783133464602, 14.450831849086166, 11.563876012104615, 8.754249111784578, 5.186489025565446, 5.528167018466772, 8.379758789416073, 10.459514912091576, 10.241583254211289, 10.359625042125955, 10.961844967748862, 12.483408459270944, 10.445150786704392, 7.13073810079462, 7.6622564060242615, 5.363722946006449, 9.25634039545234, 13.93005206041075, 8.36501457459526, 4.045961440493924, 5.9567464321593935, 10.255163487775715, 12.890230151212089, 14.791576375831154, 14.501483030721914, 13.15992129803745, 11.697544946707845, 10.67448882523326, 8.561233400423605, 7.686576883698746, 8.548376019097159, 9.236334758516085, 6.214517884205433, 5.475802979658335, 9.080270404406082, 10.287014488834435, 7.699850479376437, 8.543187566987783, 7.278051504576965, 4.432740113379224, 0.0, 7.26865460456591, 8.445856722879123, 1.4658826966091965, 5.940006781090995, 8.30800405667039, 9.779902894173794, 9.766201572072795, 9.15360934700658, 6.1401888722350435, 1.8354182420239504, 6.462520292614769, 6.152099270569972, 6.154842367564283, 5.987401808202017, 5.79262373123267, 4.814722688140139, 4.142447420334548, 7.1210141215565015, 10.032034109746853, 12.030860566276479, 10.773184140752061, 12.317501405402668, 14.845463585356775, 15.106437178071397, 13.085953040534053, 10.489358446974196, 11.844245886136159, 10.020212502386206, 7.8433359833284895, 8.371486818906192, 7.088470529101643, 6.93551430699488, 5.455024347369766, 5.655431759145957, 8.345610925545865, 8.796426348556892, 8.387632215374769], [19.576182933095335, 18.943511891545782, 17.473504180255013, 17.335840042089526, 17.642205370644188, 16.810168530430985, 16.604803789734767, 16.15909552862431, 12.78319147586162, 8.7425847573605, 2.860924998138321, 8.007632695036325, 11.407122150459204, 11.967462900959543, 11.368608091231462, 8.36487771713472, 5.845401318151616, 4.738887992382913, 6.838757127196074, 9.822181953647588, 11.890745047919863, 11.751869442543788, 14.229622485858778, 15.14259664173665, 16.631274730934926, 14.682826232158321, 11.254316160089287, 10.249232956324937, 7.870027469504711, 7.410734507405758, 10.336821316941199, 7.567414762677461, 7.036337650772334, 9.390855903173614, 14.835998811100827, 17.092861004439456, 18.783151108080865, 18.361095172719054, 17.001996535370694, 15.728166938797532, 14.864376077772445, 12.801942431771776, 10.426261040557531, 11.579327221638748, 12.305689794690402, 8.758064747837365, 9.626214577925209, 14.507265827534264, 15.420646083490428, 12.911613573080505, 12.59605311975916, 11.49623684380293, 9.744455539991348, 7.2596218075337, 0.0, 1.579372890739904, 7.476915883211837, 10.875409487073938, 12.574131800795065, 13.414463913129357, 13.237917024779488, 13.201822306304368, 10.784243799473563, 6.432623425390671, 1.536105247199203, 2.1275818026500883, 2.288908270575309, 2.074723502385967, 2.2332592671477434, 4.087368200662426, 5.990304259694579, 9.430755604274456, 13.123897606806, 15.04208013650022, 13.87258401803886, 15.61043607929197, 17.850976340143287, 17.922318546399183, 16.244869981721294, 13.739874961864402, 15.336550946438326, 13.686886540352202, 11.127636122049525, 8.993446301282486, 8.17142857495031, 7.610141980377393, 5.105823464082054, 2.6005354501247595, 2.2742799069633977, 2.6958408540373395, 2.141762568523206], [20.325346221778126, 19.930317400768153, 18.307548943312838, 18.11587080428574, 18.364836525214262, 17.57079327845979, 17.423202526806982, 16.979811957773407, 13.807264977531478, 9.800520452537048, 3.261041093861368, 7.687362797467304, 10.901737526493866, 11.488166019699584, 10.755581216369311, 8.10878532838614, 5.985597743868131, 5.735966153419016, 7.761917158562729, 10.603970086280404, 12.595982804846955, 12.512989761470248, 15.065624893936125, 16.03877030525454, 17.32393644307332, 15.60606487573333, 12.297252864484129, 11.126149597026147, 8.886239395776922, 7.706895979815353, 9.512871563538106, 8.082280283514882, 8.050939163870831, 10.335895504461288, 15.820870458909418, 17.93230388963382, 19.460802832366582, 19.123537826322107, 17.84561119630108, 16.690338334524444, 15.72854912227295, 13.815210354080246, 11.449418546268708, 12.522791800192, 13.243142821621932, 9.765385023549365, 10.861841491215005, 15.406616921262742, 16.293982593750755, 13.800685748332468, 13.713827496675307, 12.450095714285423, 10.842333527488492, 8.454379149316175, 1.581291719262914, 0.0, 8.608797826968999, 11.979264150377295, 13.547767560328218, 14.38136290792781, 14.143614390606112, 14.179117327614383, 11.946894333565407, 7.771870131025863, 2.248983756245477, 2.840543695391044, 2.9679220743501147, 2.927961515596912, 3.1158249303997896, 5.252292117776486, 7.052525583195469, 10.288319948524117, 14.014767828933923, 15.84345875487421, 14.71326978467197, 16.473684078869415, 18.63693984146917, 18.660895816824056, 17.047537725677504, 14.64346946332512, 16.168151039282677, 14.683466722300707, 12.086444707343297, 9.712367124623013, 8.97838509804035, 8.435890021069497, 6.035373755532581, 3.6370837329608934, 2.2732328347640562, 2.1219394710006885, 1.8486834753513337], [15.553241107115147, 14.759737005121735, 12.922334074084414, 13.364485296483045, 14.243970511408811, 12.97257421910452, 12.725906202271373, 12.233129925613296, 8.21648892025181, 2.5281630403297806, 7.498654485317618, 11.969948065081216, 14.624749202327251, 15.05319605996314, 14.67771227749703, 11.834605871383248, 9.090671380498254, 5.363305059712756, 5.246753207512843, 7.942722849876239, 9.999322480968393, 9.773055366915637, 9.993225016589259, 10.365040187236552, 11.843534445124806, 9.773552608285915, 6.6258777713775165, 7.022058061128413, 5.286605100896956, 9.73616319288103, 14.198506596466524, 8.870571151644375, 3.8680321283051233, 5.083242881585359, 9.915202043820475, 12.37667869713668, 14.372701795491059, 13.99712884904249, 12.636954776336072, 11.279998156747123, 10.034370707023319, 8.049128080846787, 7.286917903209872, 8.068231577849927, 8.709290386797726, 5.7737346529540305, 5.21462587943338, 8.464690043334775, 9.588527465696073, 7.146730914786633, 7.990136435833893, 6.4162887896708884, 3.8494320209459647, 1.466581309464378, 7.458546864227132, 8.567070016182564, 0.0, 5.588794581108213, 7.940438354382276, 9.285267880203637, 9.268696040155785, 8.84266483284769, 5.791919677343426, 2.0537646760528894, 6.4958107287238445, 6.112029183926166, 6.096049366099641, 6.046711676228715, 5.743413862967045, 4.838717830318571, 3.955582972336308, 6.5379237549388405, 9.603828123375829, 11.455734411121922, 10.148558845881949, 11.850453913068268, 14.3365474546375, 14.55452113475941, 12.531668376269103, 9.887370967748168, 11.309282863172326, 9.457987818301177, 7.456780416631109, 8.01210464314007, 6.789388687151075, 6.585721586384549, 5.156110209276191, 5.728811007171502, 8.588660219972605, 9.02930213447477, 8.649556536936092], [11.641866364176977, 10.45332929766751, 8.931915343442943, 10.524844430835294, 11.703061830384485, 9.908391809413502, 9.230407102000738, 8.948243605816378, 4.220104221805217, 4.319285998557711, 11.008522612256519, 14.51712661983846, 16.58947888196245, 16.961157436822617, 16.73585704621657, 14.410645373370956, 12.468846953859805, 7.699412928762064, 5.914549080375138, 6.722127434528899, 8.80835510761992, 8.417450634292315, 8.035142675662241, 7.848911326903305, 9.056176821181298, 6.650163530281462, 3.99924759601908, 5.024339472143098, 5.580564900750135, 13.011461628417933, 16.639710643999496, 12.249543157257422, 6.511514354689055, 5.142391636706913, 6.281292155565328, 8.800146631130584, 10.879737925596594, 10.521859720313861, 8.992345826373855, 6.89889227557439, 6.717989189174419, 5.691122461217832, 5.751929162079574, 6.373767605173558, 6.329112775149606, 4.689719804034396, 4.7362256090420205, 5.238635401581445, 6.464314139965189, 4.303128298882362, 4.21383539439382, 3.834131808997951, 2.4532790571389045, 5.951950773332979, 10.870267584160075, 11.967300647340705, 5.588399463863325, 0.0, 3.893722957907651, 5.5308415680111525, 5.4800343705338666, 4.124910039034389, 1.9079401751709686, 5.777367002293197, 9.852919089060611, 9.319814026543906, 9.24203926938337, 9.554237090924357, 9.194509525708234, 7.329000484909397, 5.432095419860315, 5.153331721496703, 7.31450754208637, 9.038413739605481, 8.278292335935044, 8.700553929845745, 11.3084540543957, 12.07084812808996, 9.834427488330881, 7.404998527376837, 8.117059247444548, 6.715793740110281, 6.847147954871948, 7.874683162575588, 6.490679958212835, 6.602349297130009, 6.7126062590640485, 8.865974763450913, 12.110469525487838, 12.675601416110753, 12.094022183986867], [10.17801011333458, 8.363421279359956, 8.406706839154523, 10.136738808422942, 11.379641199736493, 9.319796664320146, 8.433730225032503, 8.110389679648396, 5.540043575902151, 6.56202150427545, 12.630247222860719, 15.71966657071089, 17.367371761336376, 17.622788224870618, 17.497748285854144, 15.531541752153052, 13.729216052926462, 9.502805882100533, 7.374997002972253, 7.243179511418063, 9.212657297193326, 8.706786990434559, 8.181375381751241, 7.954733940330658, 8.805425714591715, 6.647622636509114, 4.233518897552508, 5.36250620365876, 7.828996699439672, 14.337872304728034, 17.59227335333786, 13.480091920268784, 8.343649347758141, 6.583684123017282, 6.536448351028109, 8.197168455498344, 9.843992162786996, 9.838011978057558, 8.467419658117494, 6.001984037501749, 6.322838363143135, 6.0782924002227245, 6.222839940733094, 6.934919099785266, 6.432587205272365, 6.518199321776743, 6.593812721760398, 5.873774592909406, 6.724758309123835, 4.893593931360206, 4.53949780984268, 4.112936566773481, 4.8163296479027355, 8.30560027799839, 12.593296808181028, 13.550917787166258, 7.91759217298099, 3.8918235363162603, 0.0, 4.717425951496395, 4.638993092117283, 1.5931032424326266, 4.897526920216875, 8.236567587485975, 11.511279860469159, 10.898283380537373, 10.716704603365377, 11.292786316337082, 10.87493622769227, 9.34178146551977, 7.368502367879182, 5.73017658783583, 7.560025978029461, 9.175874287467904, 8.650783189975183, 8.798298053470337, 10.852810037724952, 11.84935559773521, 9.436383194568952, 7.615375649846057, 8.099794557907973, 7.180849945307684, 7.915890790459673, 8.975488033264458, 7.624116443300846, 7.672358229731725, 8.215594464763425, 10.529979948042369, 13.720462072840242, 14.278877226297546, 13.672550869684725], [8.14608787835552, 8.274914626470867, 6.847108466193193, 8.833781018039979, 10.22633919514263, 7.795300306055021, 6.096482600041684, 5.894419235227606, 5.662575530985811, 7.6042313028596125, 13.608530094929446, 16.513472146692735, 18.027679048851063, 18.223354258749755, 18.226072827598173, 16.301802386825294, 14.594998960046782, 10.408545504020223, 7.7225512829699605, 7.006595374034235, 8.441697463313453, 7.760426674618514, 7.138288122361458, 7.131572937169633, 8.015452418800107, 5.2850106696954375, 4.252976359897172, 4.041244547450965, 8.820659643061033, 15.279013323677074, 18.3604447459399, 14.455836949967445, 9.114567460133147, 7.35690091965988, 6.178132918110934, 7.77987719620113, 9.10297151807605, 8.566102587114942, 6.876286280389769, 5.899695738855282, 5.086559920678678, 5.083123012903497, 5.9288105976109655, 5.970190446618791, 5.279640362520312, 6.813061568753713, 7.021992492577275, 6.437570325858925, 6.53552823333917, 5.170689992851223, 3.166341281823932, 3.8398720329819924, 6.882981854952207, 9.78568761335794, 13.415460312444836, 14.392344788590908, 9.292310439442069, 5.532839849409041, 4.719228295727263, 0.0, 1.0832790699617436, 4.311618679723362, 6.079167830597829, 9.360079470637023, 12.54282401868745, 12.017158009093304, 11.795618358097048, 12.245667820292512, 11.799816995775052, 10.160255087747162, 8.394403665104486, 5.340905325777607, 6.567978161544056, 8.48133019179791, 8.205322452299905, 8.09192454478919, 9.545696027980057, 10.768799680277754, 8.404466600809307, 6.478238077139584, 6.910577835607861, 6.5701583358464966, 7.659103371154512, 8.895661044175535, 7.458563912469575, 7.437666765499688, 8.853019427140556, 11.180010580182433, 14.657334741578593, 15.109505203450968, 14.497954883890339], [8.124867659459687, 8.247633874953955, 6.954856125135498, 8.804638566724247, 10.106800987456369, 7.672259902789948, 6.06890151731687, 5.7663793130333065, 5.529503834062682, 7.518806394434897, 13.491694763892088, 16.399740096491172, 17.92662331661631, 18.140125875218573, 18.136056279553262, 16.183969094630513, 14.455615055538644, 10.351357149803881, 7.491218939595709, 6.7139120686336495, 8.164113485882002, 7.461663311757123, 7.079985217009808, 7.126953218721735, 8.012860750165014, 5.365325721534486, 4.149325392229918, 3.759146437793748, 8.67071949694064, 15.161472935385143, 18.260328629068887, 14.404605995623948, 9.074759032839227, 7.263838934584182, 6.198639806305031, 7.8065827694376875, 9.133999552075576, 8.675675568137859, 6.971250802819767, 5.9009757183775, 5.18946642192019, 5.0582283753548385, 5.782685449214332, 5.812025815091438, 5.131879503158827, 6.638333048370461, 7.101906078259446, 6.579496157315636, 6.6601819545958, 5.400778331943886, 3.661920027934849, 3.7495979337117107, 6.846111960697659, 9.786174136932134, 13.248892797864686, 14.153668119654373, 9.246702266398753, 5.472376561361577, 4.629240068176039, 1.082987560831959, 0.0, 4.1715705863921615, 6.195482108834479, 9.336542184784971, 12.318628044656826, 11.794381736177499, 11.574448736889874, 12.002141477250957, 11.622847982370894, 9.953799299518577, 8.215517200198338, 5.036473914856881, 6.370587196748812, 8.338996261859078, 8.081474010710409, 7.992698972150948, 9.453250463601607, 10.689018657394405, 8.273920220968801, 6.42567951169423, 6.823446862261904, 6.612552796128686, 7.584865067591598, 8.606537304780431, 7.155173417754165, 7.1564396221738855, 8.640596923907966, 11.002308232936315, 14.512050539250692, 14.984145032091606, 14.281036379053154], [9.501682845181648, 7.5787770319401595, 7.685476292090776, 9.601365714517913, 10.867321376928594, 8.739826025758378, 7.748625839913069, 7.549696159954227, 5.174172713788146, 7.358646728114155, 13.28059000385472, 16.15585657211238, 17.71971756825032, 18.005101846224576, 17.886818713739125, 15.859291850536602, 14.379352410398498, 10.134919157437908, 7.731518376503395, 7.2206422695654116, 9.032916284861065, 8.50869819449538, 7.991037800174839, 7.712086911933404, 8.528501152255933, 6.376553718491274, 4.466548695364664, 5.471910128867348, 8.376127620584512, 14.838769768933433, 17.949820329518577, 14.078745722467822, 9.13979033612566, 7.189057913652877, 6.027274436714998, 7.650595530547239, 9.357571253633754, 9.228085447127796, 7.799490405498146, 5.296805613736719, 6.031189211174386, 6.018799640262975, 6.306159122928865, 6.841298347996236, 6.251618486936446, 6.737250047915339, 7.011242082125579, 5.933144708558188, 6.724126224393117, 5.22415424701288, 4.458076339745293, 4.615936140972612, 5.599123778093806, 9.150292694656786, 13.215229010149093, 14.180850594913899, 8.842607156449372, 4.124681705617346, 1.5931032424326266, 4.3221786662252955, 4.181003099821152, 0.0, 5.1206861804495984, 9.04276713908169, 12.21182064188788, 11.613755195837102, 11.44381750332929, 12.012127924998092, 11.62535543586817, 9.918739461088448, 7.895289674449397, 5.939406068084393, 7.236442473527642, 8.845233033559255, 8.547251104361814, 8.231410643636796, 10.23499244632121, 11.427799182693601, 9.0146616117202, 7.3680014168760595, 7.6126249640063435, 6.9515456618978515, 8.06217406815959, 9.061943294277341, 7.747757679505233, 7.8695692686550975, 8.729386658781738, 11.204187787788214, 14.349628665340862, 14.928423955600142, 14.297010152056846], [12.277047044623364, 11.085477661854295, 9.253174469827524, 10.919996719691724, 12.097827455911299, 10.410890629784591, 9.712548006084589, 9.517915420308722, 4.400828395217373, 4.9172333940013, 10.942749975099971, 14.352449163463792, 16.51199762616941, 16.894558114280482, 16.60783327621877, 14.239250962239318, 12.2699018800949, 7.630493382221663, 6.087772941754308, 7.206275369578201, 9.191045954332347, 8.827346187340094, 8.567800849922433, 8.446866954203239, 9.318176815715416, 7.064815654504174, 4.821110017470891, 5.5783078258211924, 5.436919553437413, 12.82755917039379, 16.423267963888, 12.09545457496936, 6.888711531634732, 5.076823609227823, 6.84855980672232, 9.440283032923633, 11.237235951760516, 10.883666166945229, 9.350191773476821, 7.336156616444293, 7.156403507775293, 6.471196039003813, 6.35926705778753, 6.9645941934645474, 6.960900212484903, 4.744050659239554, 4.831353441233214, 6.039613058004912, 6.706427462916218, 4.476661011315258, 4.018559038087539, 4.30333808972145, 3.4047630722981777, 6.136498485090569, 10.820031351278613, 11.94664967270129, 5.7896646551729285, 1.9088202087364954, 4.90257850168166, 6.077189705672641, 6.1969514901096385, 5.122993466369499, 0.0, 5.912323332078794, 9.870918732305647, 9.34457438499841, 9.269359698349351, 9.715102640101838, 9.204501058649305, 7.327750070975814, 5.560235302193894, 5.776947028787518, 7.768510921685476, 9.336144717255072, 8.469349741029937, 9.016702156025117, 11.677754528772049, 12.362687947872706, 10.240722338532272, 7.856033244899635, 8.428867346365218, 6.81234669078912, 7.3427424250518465, 8.1325130409075, 6.88075278760235, 6.934469473312374, 6.933192016433506, 9.006267896606147, 12.050124859364663, 12.61366170775021, 12.113060461663059], [15.805365802812286, 15.043985530913256, 13.181781982384674, 13.532012367770978, 14.349519146328221, 13.137261003942793, 12.847755255251684, 12.447241817055136, 8.235350673136246, 3.330499561455111, 6.706085461069756, 11.575009351443, 14.259864691742592, 14.709208337315134, 14.30598753950972, 11.347926172111523, 8.453814340785787, 4.469127581304153, 4.828794034084721, 7.614384185503304, 9.787750197614482, 9.541026538300084, 10.07071516310013, 10.75322961949245, 12.277999029736163, 10.143574474741522, 6.710381452605373, 6.981050089808256, 4.644442819334184, 9.234804054557593, 13.908410709277616, 8.527300451227266, 3.7463495042874624, 5.595939643768845, 10.165633775835614, 12.820489230133349, 14.851775217612884, 14.32049259395767, 12.847640574405188, 11.39526724926302, 10.370991364918954, 8.246001488091494, 6.9939411332779065, 7.957831325716964, 8.654299026739949, 5.335575396082313, 4.842776638838268, 9.227813736779357, 10.343223168818461, 7.60684097652852, 8.146136827277866, 7.009802153972772, 4.39992731915938, 1.8354182420239504, 6.444412607913988, 7.70418293167856, 2.0552057545905495, 5.776729941830595, 8.235701264098589, 9.357736366810972, 9.30061535844198, 9.030267349155173, 5.92102687439619, 0.0, 5.665881397554994, 5.385170787054333, 5.420323596418693, 5.168139022668157, 4.972426642578361, 3.537484848720511, 3.389678590214709, 6.391190488900175, 9.575892373927037, 11.599336181778074, 10.377536203349038, 11.917108365867017, 14.413095006294533, 14.726057061750874, 12.681424163142259, 10.018334918760136, 11.370680373732482, 9.636322133840155, 7.356711720364069, 7.5104404343595315, 6.229275879872147, 5.918439812655779, 4.318520161257874, 4.622334812246386, 7.648998535565868, 8.208481569124878, 7.664728422488527], [18.848646727546072, 18.27012372541608, 16.75245091874909, 16.699392676050515, 17.05771803974412, 16.128524036871923, 15.840343938814044, 15.334636400491377, 11.91649496220105, 7.759867563967914, 2.8247334493662453, 8.457841078200598, 11.821007472523, 12.39405322933661, 11.771476388010585, 8.78060987826349, 5.889814690245183, 4.035861110993042, 6.150978671247125, 9.156310352266761, 11.385267020938697, 11.175598173547868, 13.580447054136142, 14.428274772095856, 15.74538618828319, 13.866003851456563, 10.357566959976234, 9.367594659079494, 7.011971854903913, 7.644833126537705, 11.05207606026703, 7.630150261164569, 6.156788033828824, 8.432826280975245, 14.225086625848538, 16.51401127603078, 18.19873559853478, 17.755050941575277, 16.291427675636825, 14.985222013086723, 14.003971045181878, 11.997604759256758, 9.750286553428976, 10.911713665968085, 11.553845017389941, 7.991120975551405, 8.996338961050744, 13.740238928713476, 14.687272157060415, 12.036956319154594, 11.759679142571308, 10.433234142368178, 8.697632401514593, 6.457665190882538, 1.536105247199203, 2.2474854473857464, 6.496806477183269, 9.857039691934219, 11.526127158596283, 12.538844674239169, 12.305946930127535, 12.21371702818572, 9.876011570467796, 5.657204621624209, 0.0, 0.7348658195286284, 1.1706380184217908, 1.5409594135887736, 1.4253567394132602, 3.461504032553386, 5.114264939405425, 8.568101469102261, 12.447651827062984, 14.321755126992672, 13.135710497906787, 14.868827505075576, 17.24370363146223, 17.420792233697313, 15.504287832901726, 12.953061478656801, 14.546965504380879, 12.900335466475466, 10.476175519904622, 8.463939924394811, 7.555152432255067, 6.9800671395526575, 4.267268756640289, 2.0695540584890253, 3.0065671267406233, 3.3172570981463863, 2.8495445238007755], [18.36141007059181, 17.82917994708655, 16.214512239942113, 16.28062092697621, 16.57949102700168, 15.580342388767187, 15.345765034869878, 14.834952320581886, 11.413946270335963, 7.311203305957662, 3.145376631756222, 8.892926738737863, 12.128074238154246, 12.702251061476234, 12.120495602102965, 9.146392138842891, 6.223927791211324, 3.794418280646432, 5.6989008861940675, 8.696546233620943, 10.954395681587465, 10.782787068057857, 13.162068977669383, 13.938022091622965, 15.227011906901911, 13.3392536108775, 9.860979371080129, 8.835977396375991, 6.66086233308679, 8.03537722753096, 11.484345174248952, 7.8641214038348695, 5.8342427607696195, 7.890479311483981, 13.74060313292125, 16.05146154520898, 17.806119069646915, 17.224399043037884, 15.823303867381776, 14.43570256466177, 13.46637757042449, 11.5329250360539, 9.304045567588455, 10.467528529373027, 11.093714816131094, 7.51657688793151, 8.594694078795506, 13.211403393621532, 14.130677657734962, 11.481813620424086, 11.204404776447257, 9.847544612207027, 8.165245229077753, 6.1523655424776935, 2.127080559931729, 2.8350228826175887, 6.118552485696554, 9.324881027168805, 10.89361114964778, 12.01365211793531, 11.786324731953696, 11.617953245651673, 9.354591790298025, 5.3705816932887025, 0.7348658195286284, 0.0, 0.7486014565251831, 1.7284136927441622, 1.3167087601629914, 3.2240880326087926, 4.632811817598535, 8.043577329873138, 11.998334921018936, 13.862449424044758, 12.63084461240297, 14.398682003251974, 16.76890925173979, 16.932715054992105, 15.02641944614992, 12.473564593802461, 14.059492047872888, 12.405900033456101, 10.074726905642358, 8.120504980173154, 7.1580569360616035, 6.580269629371796, 3.8115162256523676, 2.070902965717433, 3.5411859434096042, 3.8689073429611973, 3.425172074604906], [18.132778559244336, 17.603150620995844, 15.971187731163578, 15.9966289950752, 16.39360580897558, 15.38405473542236, 15.09230228543925, 14.702327150959205, 11.330417259716992, 7.194262209889486, 3.1610453157190235, 8.953868004876263, 12.193441130709529, 12.791647114005224, 12.19442034373134, 9.253132515216828, 6.325150979253205, 3.613007311716713, 5.333669901503575, 8.596278542935568, 10.840095867727047, 10.601887341815845, 13.004188541157093, 13.807704975737327, 15.1210702736337, 13.190406120009769, 9.706642015093436, 8.670524546821515, 6.453706281211451, 8.148632020771222, 11.601381108879801, 7.960012342615282, 5.653509407383019, 7.824026111242344, 13.663855174841427, 15.880336221152286, 17.54940104252925, 16.975417544878265, 15.54999017799233, 14.352077640861568, 13.353976471104486, 11.43745285942803, 9.221215196856193, 10.341014687001415, 10.977269904017273, 7.45868271658492, 8.606237056270764, 13.150577380714887, 14.014629636495924, 11.341885257268013, 11.021275858382356, 9.668900037854065, 8.145314543221954, 6.146023432167174, 2.288908270575309, 2.9668550213861877, 6.103837885315872, 9.248697115127932, 10.725646573867127, 11.767834081672833, 11.547930397545551, 11.45689980891457, 9.26671105126891, 5.3920615143210595, 1.1706380184217908, 0.7476721393735726, 0.0, 1.7400610309563644, 1.0443534913235735, 3.2703625969945063, 4.596693707840004, 7.906015502754355, 11.841629305839946, 13.799425837265087, 12.603486955727302, 14.430466794752896, 16.505494594629855, 16.72746855287355, 14.912291746317358, 12.4029408855299, 13.968659675568606, 12.334387818319886, 10.072681395373744, 8.11730410018447, 6.995511275077074, 6.437302630165129, 3.736467069345512, 2.0384705648019024, 3.588120327155347, 3.9133131868921316, 3.400794086780174], [18.52828007902823, 17.956417797409063, 16.34184928768726, 16.226587666384358, 16.62825061847512, 15.650495878118505, 15.53086707154894, 15.034955557497133, 11.698022391157362, 7.086782217430816, 3.061517837210902, 8.688370348587993, 12.106694675381348, 12.659519230312036, 12.043843467634456, 8.809778073283638, 5.912262232502228, 3.899027780001324, 5.720882197771246, 8.907047266215812, 11.089109138754397, 10.85832687563876, 13.086103631457624, 13.927809837181723, 15.23963970450693, 13.440066676671691, 9.998122016589834, 9.079065192336413, 6.7483234160491605, 7.641134895375014, 11.24770969451209, 7.602143543295873, 5.3870791340196735, 8.337353786889082, 13.918226391458026, 16.0763179072455, 17.77175545654776, 17.26504802654206, 15.929380000755677, 14.77759661828345, 13.68542476501966, 11.5297847281301, 9.393241963484218, 10.496624825746215, 11.226126544628329, 7.824555717693855, 8.661743601773429, 13.255406664609792, 14.185039977487506, 11.698719083251662, 11.501919498957388, 10.178295792073152, 8.28440070567207, 5.992898023275553, 2.074723502385967, 2.923977113913031, 6.035817975873394, 9.57591274979924, 11.292813256725688, 12.200794987311, 11.991400110142031, 11.989472404204239, 9.720544783418742, 5.168339986599991, 1.5409594135887736, 1.7286325924669794, 1.7401824549096614, 0.0, 1.431756777698865, 3.444510654143295, 4.982727349502663, 8.274088314480403, 12.08625985590572, 14.136289668558545, 12.975780023540526, 14.706675386209326, 16.815903137799523, 16.949200738855467, 15.184567802242048, 12.646288490074653, 14.29941892513336, 12.699293364933306, 10.077056229271056, 8.350683039363151, 7.245107535448884, 6.660876723701116, 4.033435033508791, 1.7369211615503433, 3.3715006623824806, 3.738325506815256, 3.0285040846245], [18.138724341139305, 17.52282009419182, 15.82753349995089, 15.729675079431399, 16.15026655127706, 15.182949813176165, 15.07697853789932, 14.546749527007828, 11.15312079806408, 6.841399630428114, 3.3785817870588066, 9.167405956318941, 12.451265698501246, 12.988527870460729, 12.37898106189481, 9.3144896533053, 6.445673335235699, 3.6736089384423596, 5.06497718366038, 8.416730758430681, 10.548650246549299, 10.309097492789832, 12.598774925327621, 13.473001537888212, 14.848257286283891, 12.903510138814195, 9.522489791896684, 8.592972104167785, 6.480325120765143, 8.053037905765223, 11.708023636148628, 7.8665685441799855, 5.498262760885325, 7.586435248606662, 13.449563582204924, 15.647495334867296, 17.351806334998614, 16.77889454563665, 15.431692987204043, 14.256062705803503, 13.152887873060871, 11.141065549603884, 8.959515939050084, 10.030569539576112, 10.770949020569793, 7.2327843467799955, 8.208062869589543, 12.955575477886905, 13.77449565844433, 11.122922436780831, 10.938057316801151, 9.59810864056875, 8.028610222576438, 5.795310930253826, 2.2343393627076003, 3.1075489836191834, 5.743485906980082, 9.218049903097866, 10.898232447744817, 11.78064935319254, 11.556665721198955, 11.578532241496795, 9.207269918340394, 4.972390870335349, 1.4253567394132602, 1.3167087601629914, 1.0453953978983868, 1.431756777698865, 0.0, 2.896045689815967, 4.409156354222303, 7.808743564206057, 11.536900731334715, 13.596437552568563, 12.313990808005505, 14.180166622601362, 16.303614355905502, 16.446770724457142, 14.652040475243194, 12.175883099120455, 13.747607547704321, 12.119121499484422, 9.673012124546712, 7.838102417243875, 6.710999773374609, 6.155649052637138, 3.589783124558995, 1.6130146390011049, 3.693239684055874, 4.0555944352042745, 3.4909897769267846], [16.35524944423204, 15.712235060686826, 13.883872773401457, 13.816298776919767, 14.179707480703508, 13.260024496424686, 13.053662796273185, 12.623329281918892, 8.861093683472724, 5.685892667349257, 5.535366787048192, 10.926316718175611, 13.826427386347575, 14.293772717015203, 13.842087301081298, 10.925566768438355, 8.20856375987167, 4.1814276787878315, 4.031868123442431, 6.593721885502512, 8.805249555733122, 8.670871285586124, 10.67699728729877, 11.531968771909726, 12.858647856820856, 10.996025394734286, 7.566246518597925, 6.923839366174165, 5.749489668117211, 9.584758981873371, 13.420802022894321, 9.197935173067894, 5.546890580141546, 5.898243746359044, 11.182200832517015, 13.707429305319023, 15.546985778692084, 14.956447093176882, 13.47907335895456, 12.035194590350077, 11.130037007073224, 9.110902001467121, 6.852953953844882, 7.983155671894837, 8.676414251542322, 4.901329857819714, 5.8137094711165105, 11.048110642423028, 11.874789299468638, 9.198465892061185, 9.095022445775339, 8.083319474852807, 6.441294619444147, 4.816641536858771, 4.092339788869584, 5.255570683679001, 4.836523437260545, 7.322766090105333, 9.35308127334646, 10.166818031795417, 9.944124895658248, 9.941085402986245, 7.360990195114589, 3.534515449260148, 3.45033132169966, 3.215509320465682, 3.2742342449549486, 3.437029518235293, 2.896045689815967, 0.0, 2.5307639488295375, 6.029315496552186, 9.597566171314245, 11.422499872855264, 10.280915214658812, 11.900527341526818, 14.408515877561065, 14.542551060902557, 12.677998027052812, 10.103185380743898, 11.539271698466072, 9.928276867032022, 7.530578140155841, 5.907558350096802, 5.036063785667573, 4.5606656271339965, 2.351411020080341, 2.3816800411404997, 5.911492534847925, 6.447956591479409, 5.742333830621269], [14.476764863091349, 13.670637814615873, 11.988801507253191, 12.036185482916702, 12.561233816089784, 11.501753220815608, 11.260139184123425, 10.811342519486935, 7.046546891353711, 4.209692932564408, 7.038142569743046, 12.156158455879483, 14.834331495817914, 15.273098403210106, 14.914373071999412, 12.219137757635972, 9.53534733086136, 4.774529364388568, 2.770240204126374, 5.100869654522938, 7.457874413261007, 7.307350563750401, 8.95744376331697, 9.674500510037719, 10.993044200161554, 9.070555221208444, 5.653578614438525, 5.198807550432531, 5.573179332546572, 10.829246247457204, 14.65871106558682, 10.362855215095056, 5.251355792732566, 4.083149936085437, 9.210022386543171, 11.668286047296274, 13.561783847047787, 13.016725213430714, 11.593424006706538, 10.13982369341739, 9.188190812651202, 7.2346687268576435, 5.25711469023984, 6.356810505934321, 7.001555983627089, 3.307358308856872, 4.466209234963286, 9.003901816899603, 9.8833767545679, 7.294211870885001, 7.20747294808432, 6.142165165872737, 4.671812230999791, 4.1481892179900335, 5.982858321003406, 7.0559656906043635, 3.9577377206897215, 5.4259426504182935, 7.368528737564512, 8.395800658377107, 8.2315915679345, 7.904872510873793, 5.562814427216835, 3.389369947668392, 5.12056222151653, 4.643504517873411, 4.605758498153349, 4.988387649632428, 4.4219185248492865, 2.5289434786313967, 0.0, 4.276421850827912, 7.8553962242643705, 9.75447942254337, 8.596646662246316, 10.120811198567568, 12.631537595606861, 12.965712847184493, 10.927670122095437, 8.345837440158734, 9.791249311453493, 8.084209104705451, 6.042722048796957, 4.969796688742959, 3.746532108048602, 3.519115815616506, 2.096535547961961, 4.054652013984134, 7.719098590206837, 8.204475252227827, 7.507408137821678], [10.577677347096452, 10.294453500040456, 8.610800188310536, 8.802128515120327, 9.311993185696515, 7.892040381332811, 7.340445161957846, 6.83181331269311, 5.011682472985564, 5.225866002105207, 10.605676506454238, 14.547868904575358, 16.601227733706494, 17.039199028911852, 16.952113249667757, 14.686169873230014, 12.550057868433496, 7.8849123037533015, 4.055700349881125, 2.4433099878743354, 4.775214219733464, 4.435548145309431, 6.057309545862159, 6.662573413427079, 7.905823935258502, 5.823080346884448, 2.9965099691408024, 1.5527010280650861, 7.627670822352275, 13.588921682540384, 16.89334433787037, 13.110139956435498, 7.345874704297317, 3.764623477788893, 6.594289546316154, 8.590526485968914, 10.2229374085826, 9.659278205312535, 8.250231192321142, 7.099149621604025, 5.793545067296903, 4.137056124761279, 2.467719887368268, 3.196946293665271, 3.351003003416224, 2.7175116820306466, 4.4134751356320825, 7.030249705678696, 7.555942078524257, 5.624084537186185, 4.90696446393221, 3.955269105425615, 5.271790980544803, 7.1132061894287215, 9.47650348403952, 10.289027493272071, 6.528120976169857, 5.139187195533831, 5.730386008032307, 5.340915464499277, 5.042882328602675, 5.935826360453686, 5.773255910100282, 6.390193357216997, 8.549857405402184, 8.046632984499851, 7.916740708560061, 8.274471331649984, 7.796374174786861, 6.0207226495239325, 4.272993622536866, 0.0, 4.779351554930088, 6.736011098987854, 5.893695810570298, 7.132813842214439, 9.193327005899397, 9.759044790093785, 7.57216856723085, 4.916060930155955, 6.47489225201986, 5.279583252411274, 4.095835955062063, 3.923358045564788, 2.778334916230851, 2.7920707279011188, 4.5206440723421375, 7.147237172455971, 11.19604423576997, 11.630266495525413, 10.768224066564722], [8.081631909127475, 8.133781824590232, 5.850606964954651, 4.6528558872893955, 5.545939463122341, 4.400423506664545, 5.004986031100514, 4.7870265941002215, 4.572288678657669, 7.87351246641755, 14.16682350465729, 17.184998100925544, 18.763652110139603, 19.073269082603684, 19.157160086133715, 17.266311439838557, 15.536621367669511, 11.37772249001843, 7.105128927846174, 4.090264478493005, 3.4298377246983174, 2.8167096159607556, 2.2491030143399224, 3.630124879298623, 4.692406336342462, 3.7340530441142277, 4.385315710277656, 5.046248628171134, 10.48889914195959, 16.1667173878101, 19.256215492639623, 15.610376941940812, 10.554304155357897, 6.012722714153415, 4.434088355747255, 5.667789262407643, 7.410354202971485, 6.2400359586793455, 5.0995629276111485, 5.304190088259365, 4.102626781482149, 3.2871396724127795, 3.860089839855284, 2.776893252261427, 2.993490679608125, 5.2704697588588525, 6.137583283693302, 6.522782566446533, 6.231682295051072, 5.738503367912421, 5.857319100027093, 6.229852386390928, 7.976283383164218, 10.045091234645287, 13.146061618233208, 14.010720882988021, 9.604221250023079, 7.306455629033143, 7.5511110107629955, 6.5641821947524175, 6.370715154885399, 7.2285309668431195, 7.765874568901742, 9.546190230289564, 12.467492530204902, 12.006668623729201, 11.846381887554369, 12.084826034274558, 11.547640195225583, 9.587291632529633, 7.855772274705015, 4.780445911751223, 0.0, 3.9173545849300506, 3.7086331083025907, 4.0932484996240746, 5.486670796376222, 6.290560254880172, 3.6676431043417557, 2.9696995054028896, 3.5596056297844405, 3.496141826424913, 3.8040496099731382, 5.428672030329897, 5.114043182777025, 5.846098794495822, 8.376474523464438, 10.938555308654568, 14.764068741363486, 15.15514654226056, 14.334566862266685], [7.4962834216009995, 7.545494128534224, 5.205992943076316, 3.9745430975818827, 3.605065115809965, 3.9903274019475017, 4.605668944027029, 4.413412055230081, 5.478697767599879, 10.03186740632622, 15.912721415515241, 18.784819337728948, 20.133851321566297, 20.321905477389034, 20.465515334349796, 18.75699356958374, 17.185251153394432, 13.482385186939192, 9.486915013377228, 5.75878682595768, 4.2797554759650485, 4.969588151682942, 4.3917335448073676, 3.951321382668083, 3.3518040594631855, 4.493614582305162, 6.500084986335919, 7.017913766242456, 12.328269536453572, 17.66661670716418, 20.564658083364556, 17.199301565620456, 12.619850711973255, 7.066828643669667, 4.9451808173894705, 4.883428656159379, 5.566432158100384, 5.006998292103704, 4.899227221205137, 5.204527413665161, 4.207442118609558, 4.994055022016972, 5.738252758343788, 4.569155571912845, 4.192675887683518, 6.870337283059017, 7.67056796398396, 7.167286582125636, 6.406848713193323, 7.195834798024667, 7.380046032178625, 7.799006968630033, 9.673875193740885, 12.045295343252512, 15.036794959385512, 15.840129382367277, 11.471955357938244, 9.043261765040999, 9.183418139827314, 8.486172508322577, 8.327280232038776, 8.848816264702569, 9.342195392783465, 11.610588303346418, 14.303421085423613, 13.82849813039082, 13.803192136266727, 14.129377931326049, 13.554381189046817, 11.436913054752077, 9.745113442994224, 6.727079042263361, 3.9167894523382145, 0.0, 1.6416555791876768, 1.7380783036597576, 3.4328651524871856, 3.3176390072216706, 2.4256277483485436, 2.4555748486699964, 2.2888313351561376, 2.7900411891266956, 4.9307419101614745, 6.41164680828958, 7.576159150308764, 8.13603801023209, 10.440839505395289, 13.014192863890125, 16.485626064633728, 16.862829023931578, 16.08863278112604], [8.51311847379154, 8.371264673539152, 5.918256973109912, 4.890263655097877, 4.848143529248015, 4.873142914983528, 5.409162497397675, 5.096953899166427, 5.059495816457916, 8.832389125175236, 15.034612738833383, 18.035506915275562, 19.547319457193975, 19.764017885597603, 19.911651831297025, 18.11064502257667, 16.45408091302276, 12.598069269596584, 8.521100927120358, 5.064307470096158, 3.921285943935998, 4.581398914083206, 4.227978085004369, 3.8924000261692626, 3.621601597081518, 4.257060390199398, 5.741192377503716, 6.280856041520492, 11.506701882495161, 16.929740238653306, 19.99274979437539, 16.521026021334034, 11.759610983754714, 5.649874795704294, 4.998477446599453, 5.478090719798619, 6.350793725127585, 5.943847310120011, 5.564522352035229, 5.603392599506122, 4.12126826085155, 4.455407444001616, 4.977990520667149, 3.915868740875176, 3.791190634310359, 5.838106869519884, 6.60594013092334, 6.68168409268788, 5.9501788355690195, 6.353786030485762, 6.75343136027769, 6.895388552759585, 8.65198497626412, 10.776461665182902, 13.894621677602622, 14.695158798950002, 10.137560708000422, 8.285963816878164, 8.639773291520884, 8.186406911779152, 8.085266696580645, 8.547865678850162, 8.486503201446276, 10.399710465995716, 13.141073763414935, 12.650194017808797, 12.605845337072036, 12.954227388390102, 12.353241809698426, 10.316942358400844, 8.59737520566746, 5.874766222324901, 3.7091140319221876, 1.6416555791876768, 0.0, 2.9535901250882173, 4.867572459207949, 4.587759994556742, 3.411478445467939, 2.2760183709411748, 3.0603731233777203, 2.2363471120121363, 3.932238058169866, 5.570554797649363, 6.721390127014752, 7.249885425592398, 9.314102354207138, 11.900856869266926, 15.483554002333795, 15.816099273292197, 15.090799597824304], [6.750841381056148, 6.549001966004687, 4.280276453254795, 3.7277253720115455, 3.847628264076905, 3.7869464380996094, 4.0853313731996685, 4.155324887199554, 4.993418133042801, 10.322983714123176, 16.253656225035005, 18.93972802666611, 20.373269532301038, 20.599771719762984, 20.741457773621388, 19.004195074588623, 17.46420400365171, 13.823237700962851, 9.959008790230964, 6.302958168259987, 5.210127906398244, 5.676514599588469, 4.570085767699456, 3.993769069428104, 3.4002944331837046, 4.314208234772495, 6.519146584220182, 7.276136601290861, 12.361996149532159, 17.86542532661626, 20.814883618848594, 17.454393525323436, 13.01299160022404, 7.694067083485304, 4.029940918993791, 4.058142995708333, 5.033156923456953, 4.242059407823335, 4.0480185773260455, 4.12463397915704, 3.907728607874288, 5.038697066338932, 6.0570710221571264, 5.016366482356311, 4.432033593225564, 7.191765125467003, 7.871616875244761, 6.757720881081507, 6.1551942690375085, 7.03793589893152, 7.083809895801164, 7.893876829907705, 9.652825496222471, 12.314814342636014, 15.597040987314148, 16.442623738278872, 11.844001618819592, 8.689992947653675, 8.796091589689164, 8.094036104836135, 7.9840963252971875, 8.223485462470657, 9.002526784687644, 11.934041845772352, 14.866040848691059, 14.409971651342332, 14.395466157775306, 14.692840577747035, 14.133506009640739, 11.927402533365608, 10.11492372526185, 7.113745806253199, 4.091985876889137, 1.7378109719903696, 2.951243095878209, 0.0, 3.1536092966965907, 3.7133523313081858, 2.6569229015548035, 2.911446253987771, 1.7996943959912994, 2.889016193456465, 5.613080290768889, 7.176353205507593, 8.049693897032334, 8.647854076038348, 10.90673301685274, 13.602774544082367, 16.878221519988404, 17.30149886393768, 16.59327999081455], [5.500215783908539, 6.372655691848299, 4.526003483165964, 2.4285152710595725, 1.85402580142933, 3.012499030230243, 3.9297111232447666, 4.222642378422258, 7.647597076924903, 12.638057809607291, 18.17720242561849, 20.327742509296545, 21.49188270114912, 21.692662579699554, 21.827255564208468, 20.212361648003274, 18.8776473350687, 15.5769264701917, 12.012485511668986, 8.237767640308073, 6.468951358146597, 6.7777624119483955, 5.414463304014664, 4.930334561125918, 3.889969596988681, 5.646406224734545, 8.604346869257265, 9.210987455626235, 14.415055351996665, 19.268227245439878, 21.897040780812414, 18.701860729896296, 14.64926748538956, 10.103895152485745, 6.087690531211985, 4.551660024452707, 4.452489708038317, 3.3246431115086663, 4.153609985233972, 5.801152634424159, 5.396993215495231, 6.8359046641816725, 8.095425887130498, 6.835195127219133, 6.290673311620095, 9.736830623898362, 10.310666842015136, 8.708232973373155, 7.746935916991259, 9.098887805837407, 9.071628019725654, 9.953362733357157, 12.227783614540584, 14.837568034452994, 17.81192816114126, 18.584724293985154, 14.339389148963752, 11.336542813257038, 10.872530937108444, 9.526862092521153, 9.44363547427582, 10.239715121253095, 11.723012406073305, 14.455228190053958, 17.244594973667493, 16.763299555152454, 16.49610937243475, 16.83087907848031, 16.311496960767915, 14.367695608220643, 12.65145846975742, 9.189550870658033, 5.48473181471188, 3.435887814509636, 4.887877687943163, 3.153160225220695, 0.0, 2.038329350516197, 2.145385384261578, 4.707200812895936, 3.5020495788049937, 5.344030520994994, 7.6391163998832505, 9.228658428539184, 10.032490608092788, 10.620181819521845, 13.166342107951985, 15.816468009206943, 19.027695321384027, 19.37951331723717, 18.67519424125963], [7.075631989847009, 7.815366212175045, 5.844541632969241, 3.6379522392773764, 2.238687038204839, 4.185471125503835, 5.351316030078545, 5.464858009979129, 8.377942475414075, 13.004214911505827, 18.44516278459891, 20.693146284864177, 21.732886853676476, 21.74051286465604, 21.874811434315202, 20.42076952715277, 19.122814607049655, 15.847798192110076, 12.25428118811072, 8.633011382280262, 6.602473865311485, 7.234902186863743, 6.090213736047243, 5.5666219680508195, 4.2903831753072526, 6.520234885460781, 9.345295310178221, 9.899962979385274, 14.952586528553237, 19.691267677281157, 22.09097538447167, 18.917395596370557, 14.850757644165558, 10.187382172365211, 6.974851946556093, 5.569351046905709, 5.169768244589277, 4.502195427588795, 5.459893024734205, 7.011019112043369, 6.269857659740503, 7.500050639545313, 8.584393653653152, 7.3159013832377, 6.91259630222108, 10.080525445939207, 10.59354183347041, 9.315690348451907, 8.335813673806236, 9.743641176321535, 9.967295767990356, 10.64280559944134, 12.753116381177543, 15.083342453662798, 17.92236628289412, 18.66247589924357, 14.559792345075476, 12.095176026031229, 11.87124559096972, 10.772606067915664, 10.6923005334268, 11.4447589821891, 12.364412994343907, 14.689597255279077, 17.368320041933508, 16.93511924062701, 16.719253812406247, 16.9435071080406, 16.454548725082873, 14.539811398361065, 12.992076771096949, 9.742530556778421, 6.284060345463093, 3.31964255258067, 4.593200172820805, 3.7120448538000717, 2.038329350516197, 0.0, 3.0337432490223244, 5.120916739361321, 4.299734649035471, 5.671925189022245, 7.653791452326304, 9.217072209205668, 10.484141717493616, 11.081383442020076, 13.468536694723971, 16.04065310158138, 19.219126093963695, 19.5399122957994, 18.764657331575503], [6.192813008424937, 6.5224847738131695, 4.443520136297205, 2.166343236017241, 2.490780298016932, 2.517147915005606, 3.815105291572495, 3.7899303989216038, 6.3242687322517295, 10.834306510545083, 16.7721541203429, 19.31382059396224, 20.522995211890674, 20.841148374051652, 20.967304414262667, 19.210590987961545, 17.817182436127286, 14.281244104049346, 10.354464085871744, 6.6833259765745066, 5.033414502218567, 5.141211230967269, 3.775168992811131, 3.499014336109483, 2.8237408478708983, 4.252787808510263, 6.957733634586941, 7.645851229043225, 12.991717295308378, 18.174434214017772, 20.993521340396647, 17.699009678032468, 13.331392035978396, 8.300403515113883, 5.107342099260726, 4.143189330472821, 4.764954269484202, 3.7972662131628825, 3.8690449608448234, 5.117467630220735, 4.232156259230757, 5.3365419967026195, 6.522000062258986, 5.2648203749217775, 4.870794626817697, 8.108318379345407, 8.76397687652096, 7.481807905947413, 6.530070627777435, 7.554184767274, 7.759841224263296, 8.350635197837846, 10.593032130857226, 13.073928062931133, 16.24687462545108, 17.0544860283157, 12.52242697811221, 9.819940782959849, 9.434537811263514, 8.41097994395931, 8.271159785666589, 9.000386231740215, 10.222094046049016, 12.700594672055242, 15.517371233826326, 15.024245075932113, 14.904470219032632, 15.153930425484859, 14.654879317543653, 12.687800936418085, 10.949137342306592, 7.561883176064508, 3.6678888736474424, 2.4301216264428462, 3.4076350066225483, 2.651230978705219, 2.150312539879868, 3.033727133279439, 0.0, 3.3557061485807984, 2.646733448810566, 3.9961087876277595, 6.072498676541761, 7.7722449655929715, 8.335714737789026, 8.959492850493074, 11.49006791509562, 14.103537651165153, 17.520541035547282, 17.9126906553549, 17.13851224488734], [7.199934367762201, 7.500794550573658, 4.925554641322104, 4.627748470175122, 5.004617749883571, 4.1407985550987005, 3.88596559814169, 3.557709700111361, 4.409221790080984, 8.247781393280729, 14.650200003126663, 17.67592861340504, 19.299890983118217, 19.647789483171675, 19.759866661478913, 17.87419559884193, 16.206746786523755, 12.24109181271832, 8.140386182036654, 4.531551749129714, 3.9046717226817904, 4.214784030430421, 3.530292209129715, 3.100254451499863, 3.8186494003072577, 3.0038453006726886, 4.6897762860942525, 5.045599028667781, 10.996726770424827, 16.66681465431291, 19.77517940465054, 16.269149472706633, 11.343845400044465, 5.856697327067069, 4.144411506089162, 4.755630659223639, 6.139180134972695, 5.369577794482431, 4.633710615759693, 4.665583256251831, 2.783631897721494, 2.985220119436232, 4.1270465646494685, 2.9024118620114803, 2.294815705801007, 5.531618286904968, 6.248807692096385, 5.774281900853056, 5.51417591545625, 5.764890155081727, 5.5784099999031485, 5.961226546978402, 7.974873003566221, 10.54412657801626, 13.720194557766787, 14.611691649622106, 9.87127300588433, 7.413469553845885, 7.6137728444889605, 6.471747094069533, 6.39048866462466, 7.366352467262803, 7.840426691223319, 10.004761659468242, 12.96028131767749, 12.508831669274763, 12.397412967631052, 12.659348100385579, 12.200871424817, 10.106134506568145, 8.34489100430701, 4.933214232395225, 2.9736442609441456, 2.453834239722064, 2.2742409209325385, 2.9113567744598923, 4.7203090672050365, 5.128616671427209, 3.361201249432718, 0.0, 2.277290937792946, 1.9680980764826186, 3.734504207873243, 5.6800072087957085, 6.246526517718552, 6.705026263727851, 8.92053283776063, 11.58848098378224, 15.267878355048852, 15.653380325725667, 14.935212991159077], [6.085541628361873, 6.293802635470004, 3.3615573913851082, 3.537116108657555, 4.245043797782581, 3.0822001348697747, 3.02730736272454, 3.110929816502695, 4.416639373711499, 9.67801959411476, 15.901365256159385, 18.595924371781937, 20.07778284237319, 20.42343850497716, 20.539876226456812, 18.735024722442265, 17.145256206822573, 13.42804318412023, 9.506145316499513, 5.995084465726307, 5.197318795384185, 5.410000103539373, 3.8778602519368075, 3.3643595619166446, 2.88681114883477, 3.1815263814071972, 5.636315912046808, 6.354516152963269, 11.909190277641358, 17.502027386569587, 20.557109376351598, 17.145997686258728, 12.547543894783749, 7.254919569727226, 3.5670700651655567, 3.8526203341516374, 4.813671517627183, 3.8372359077801916, 3.094747779146125, 3.515134795276114, 2.7374264468460137, 4.122201086912046, 5.536762142413929, 4.311189005037327, 3.6597240647177567, 6.77466476940329, 7.344383813858342, 6.186942902564938, 5.30435915595351, 6.123527450651562, 5.984472171066241, 6.897087959739593, 9.153321284445186, 11.88151314918368, 15.302663479761048, 16.168936569384496, 11.307282616224867, 8.108474141761821, 8.101031896479249, 6.883827340664482, 6.80935365312538, 7.601135979014646, 8.42482316267374, 11.380555636425614, 14.550343351396847, 14.06241854473327, 13.988048457964837, 14.332975338294455, 13.744060187870225, 11.544321906024585, 9.793428698137525, 6.472034390468268, 3.5585999684679197, 2.2863026696520046, 3.0597013476530264, 1.7989236811514655, 3.4982516160886976, 4.2999029164105105, 2.6530477743825407, 2.279284445701822, 0.0, 2.376809735948617, 5.29106339270152, 7.18101341521702, 7.69352385072358, 8.149589665451785, 10.463498266130845, 13.165369097352526, 16.569497005907465, 16.9515772837317, 16.29192162186308], [7.8355086076524225, 7.471234708904433, 4.736280501812043, 4.986913997588433, 5.72489425239197, 4.9349769201300075, 4.676852036693321, 4.537131651961044, 3.3648281648396736, 8.020535115078742, 14.544862188267862, 17.57632051388014, 19.26754746447119, 19.66476749185491, 19.75001469749173, 17.865834203238425, 16.040920068932753, 12.081520874399443, 8.080915132459115, 5.069819086313704, 4.844343670397928, 5.123573186887481, 4.03787589403499, 3.468611722745187, 3.5593138072423405, 2.9595258403528324, 4.524110362892947, 5.379412800202775, 10.647298631809083, 16.563810157485086, 19.765170700466868, 16.17570174741852, 11.233181635077582, 5.284074042927931, 3.495972341313316, 4.721698636968971, 6.0076298628904015, 5.419639751533253, 4.6233598379016705, 4.004951705803159, 2.6623608710876305, 3.4117791460845392, 4.453003177596224, 3.5593468437676234, 3.095151325324496, 5.170394937126126, 5.677564938914885, 5.28297227546847, 4.617567901067513, 4.829981875523988, 4.851076802571573, 5.62593239448758, 7.486593172857514, 10.017631457081471, 13.68588954469498, 14.680002995538104, 9.443610700300434, 6.721181995887014, 7.160734437560399, 6.554116328862908, 6.606440512094736, 6.962763036542058, 6.8136206743612755, 9.624370845826503, 12.90692609639196, 12.440177011770166, 12.341977596170912, 12.726003478409726, 12.134514158236641, 9.918829590021705, 8.08251546838785, 5.290429964941144, 3.495074566421451, 2.7921416627966917, 2.23693864653636, 2.888837565402473, 5.330023463030339, 5.662919709263134, 3.9962574921072997, 1.969087865411598, 2.372136232350588, 0.0, 4.046015537086322, 6.053419354570105, 6.556007179600351, 7.0189237348577125, 8.979997827817233, 11.636331204056697, 15.14669375194064, 15.567917844192666, 14.895755722304013], [10.3654264967995, 10.27514367511597, 7.997801311284768, 7.0737951596889035, 7.425382403451338, 6.981062342442306, 7.172128931810129, 6.7825665132003685, 5.178992245867273, 6.3192101037129165, 12.59869248427109, 16.125146383137416, 17.940205466955586, 18.36946943503139, 18.43732045806891, 16.40927897201621, 14.480717119430965, 10.266504840636637, 6.3276615304511274, 3.6018067381260384, 3.8244654870038066, 4.224059154953026, 4.007590479836204, 4.9646654369569925, 6.37777586047396, 5.311721788476324, 4.225913143484154, 4.9664243351509905, 9.714753332216548, 14.96921711792604, 18.428686105820773, 14.54715501215357, 9.365632554508531, 4.471085644362124, 5.425143570592473, 7.317270041547344, 9.1761113600193, 8.33301636437443, 7.391962072438385, 6.95783852337623, 5.3639577778447824, 3.2861286981146693, 2.8655777620858585, 2.335527300075873, 3.2082865702300185, 3.965117243850998, 4.1005880855285, 6.494365147406191, 6.92991235310017, 5.793281643774831, 6.477379993879103, 6.165086492409326, 6.690657188484759, 7.829021724607201, 11.136590308325133, 12.158249651091843, 7.446407334543015, 6.84289048473344, 7.890975176178706, 7.653268874130589, 7.545237155451776, 8.057576187247669, 7.342292758925752, 7.359473733964043, 10.463378055977216, 10.079588248687104, 10.052403294134955, 10.075455335923596, 9.65375852115243, 7.52555191808233, 6.059272350151703, 4.08132257262882, 3.80665911552852, 4.925656279086492, 3.930837584085391, 5.603094751076833, 7.63859830522935, 7.661261071788311, 6.06443170986276, 3.7348334006108352, 5.294693038444924, 4.045934724635997, 0.0, 3.8118177465266156, 4.465199331494049, 4.914448055621038, 6.779960618008364, 8.951677600054484, 12.941829668010152, 13.3017366337705, 12.524470459683366], [12.347050096556021, 12.115530146702456, 10.208408794740933, 9.211922328257932, 8.942794722455082, 8.725785607448353, 8.898574854875136, 8.476381908104068, 6.631767366132771, 7.334077656890281, 10.969713966189689, 14.828416298391911, 16.841602081508015, 17.268789173696966, 17.36705038323141, 15.287899242255854, 13.258850377892413, 9.168772785295968, 5.234395029634634, 2.3175540422088408, 3.260409662047159, 3.8334980410436144, 6.8088498412031475, 7.747169409326066, 8.798832508455439, 7.771885027743983, 5.962101988079391, 5.23173148701991, 9.414975424844462, 14.329256567075037, 17.31851230858969, 14.130017936952152, 9.353324577847099, 4.932205481388506, 8.143129097535363, 9.890685815820571, 11.436560655165456, 10.704842265180325, 9.668377775430521, 8.892464778903838, 7.791574375849892, 6.16165137660138, 3.888023059122446, 4.234303674381495, 4.9091895794950124, 3.5321299727633573, 5.529208197049057, 9.287907945112996, 9.690639555200123, 8.10262178717772, 7.877616826042889, 7.418461178190086, 7.698051947294294, 8.372268976767174, 8.996625296918772, 9.728976814404849, 8.011892787771133, 7.868243901147978, 8.99993040367852, 8.908225094636652, 8.637830292386177, 9.076573878355488, 8.136763386355943, 7.508530991379188, 8.474599965405677, 8.120187761137494, 8.130901714539416, 8.355219020241602, 7.8371281809042115, 5.914674647944332, 4.971285760991057, 3.9275269992214596, 5.430849779168111, 6.41821722309088, 5.5756867746021115, 7.1772778575807745, 9.272155915302035, 9.229397365016178, 7.765727506513986, 5.665224696494758, 7.181756113927261, 6.048884391352465, 3.8184593660330415, 0.0, 2.8733000474736663, 3.209036692926744, 4.973600313013348, 7.207023060070695, 11.099597516412029, 11.4362065872888, 10.593358829235436], [12.268556129802604, 11.990647488294787, 10.150579602659754, 9.528802568057726, 9.8595171623406, 8.888669548839141, 8.956082628543305, 8.546270782904225, 6.226405544645526, 5.733942158662447, 9.669895834483944, 13.875581254954902, 16.102537079722577, 16.546799068663514, 16.57497553169707, 14.269247511190438, 12.126778995700617, 7.366825420801142, 2.931930774743846, 2.3461764381970056, 4.380169267635344, 3.87607215142034, 6.586512768794609, 7.730341721569181, 9.127106628092841, 7.370047458896462, 4.82213518999974, 3.9392856670152923, 7.775582245560961, 13.216564081786798, 16.481454040883555, 12.931175916423083, 7.514055787706221, 4.575903749677483, 7.974132569046518, 9.974509960694734, 11.85285844879074, 10.963455179367987, 9.62188088531238, 8.776509769414883, 7.687536119510226, 5.706038499403833, 3.5069921829967443, 4.159787086217236, 4.937325049746975, 2.9267280761111025, 5.032023142457467, 8.716250314445583, 9.232740030069444, 7.174593659201276, 6.777442356390287, 6.15193792631022, 6.40942453847232, 7.08711707920075, 8.169519870178231, 8.986904590663917, 6.774249242517944, 6.484383553102023, 7.649564314718009, 7.452311360087003, 7.1383426108443455, 7.794231840089163, 6.874822860827868, 6.2206081567416245, 7.543651540547874, 7.140937143059576, 6.969377144357468, 7.211346803527456, 6.689943615714033, 5.0358170833402465, 3.747314719480395, 2.7766118088755465, 5.112904194004759, 7.595536814949266, 6.711339255991557, 8.059666251831858, 10.038971277192335, 10.484553226481387, 8.33361574200123, 6.257127733624039, 7.7159162987408605, 6.570431468266741, 4.467382324567655, 2.8716442676420435, 0.0, 1.2845225249676056, 3.598853812288611, 6.045244719799961, 9.993243345792504, 10.395553203818162, 9.445921582659196], [12.659359129523917, 12.405141797158237, 10.576529592958982, 10.157298064768042, 10.473808046165399, 9.301204389404075, 9.318541384041758, 8.904878852137312, 6.6375733942029616, 5.703801077531819, 9.088608685161136, 13.442819685376303, 15.689856025335557, 16.14596181620762, 16.168500537706052, 13.869956836639016, 11.648912873753384, 6.72425759200696, 2.7682054237945777, 2.648739889410719, 4.995632690260128, 4.522577627298084, 7.207674619309561, 8.318649260183896, 9.628480752124224, 7.828288874728019, 4.932522753094037, 3.804378273132024, 7.45401689959631, 12.807649390733648, 16.102165292421766, 12.570807827839786, 6.998728376676703, 4.693641114940488, 8.512158653102816, 10.550834917803046, 12.323935237783502, 11.466029289362464, 9.975716522608696, 9.16675838530671, 8.016153639525086, 6.08728694428353, 3.7035473440582103, 4.472342136629713, 5.239717063719644, 3.1076695898125757, 5.002864175365838, 9.129590867591029, 9.638679253784373, 7.315176697861301, 6.809106737827002, 6.115885294554427, 6.418526737673612, 6.935032992720604, 7.599142405194608, 8.435467863228954, 6.580279437217801, 6.585706291442263, 7.702937916685639, 7.425929026683819, 7.147649477233804, 7.877693930081104, 6.939349878017323, 5.918439812655779, 6.97934471586362, 6.588002985548663, 6.408460464196822, 6.6626087527967055, 6.148888913198171, 4.552442262341342, 3.519115815616506, 2.7952690765631973, 5.8451769475094535, 8.134929166642085, 7.257087805191103, 8.641838285740224, 10.625808395216252, 11.022564036078803, 8.968642280587545, 6.71972870374393, 8.175353714335518, 7.0370020214238584, 4.922298405293819, 3.2079445353445224, 1.2847208759091104, 0.0, 2.9371567226360353, 5.440210228547134, 9.444082248119958, 9.849093989298646, 8.907044199458628], [14.986980892467225, 14.397381256265962, 12.7293696816618, 12.704441424385791, 13.046392109700903, 11.866117071985444, 11.713004377333153, 11.265439684671472, 8.14334538462986, 5.172715352265789, 6.376632712098431, 11.648730581847342, 14.311683540675157, 14.784768276134077, 14.570067105816344, 11.930191114263241, 9.291493601226483, 4.460674994823326, 2.8167528437329237, 5.09931083046125, 7.531389556761266, 7.251608215129016, 9.600102475986594, 10.45848289035609, 11.816611866546225, 9.88553520999707, 6.466204509772043, 5.450327575962241, 5.9762769356373155, 10.77081155078016, 14.23653419641006, 10.522803274082557, 5.296653547109486, 5.191602906372734, 10.339212648422265, 12.555885376301966, 14.4179370276084, 13.804040357407146, 12.304659944632741, 11.02816450505839, 10.00387031943378, 8.118469401586788, 5.758291961489996, 6.852710739857969, 7.520582129418014, 4.1697008118534304, 5.697170334355467, 10.169747324771272, 11.084533374468869, 8.481876980062696, 8.04951075444148, 6.996271204436169, 5.929353247973103, 5.426558313778876, 5.086773705537875, 6.015095234446292, 5.158822442237981, 6.714194274723925, 8.227009114911104, 8.878789641798864, 8.657468116581738, 8.733693221078004, 6.929142692275738, 4.329477306856932, 4.270096955124372, 3.805895716283228, 3.739698238879248, 4.047454112223928, 3.5924773389220364, 2.351411020080341, 2.0931295449766494, 4.514396771828788, 8.387615769387795, 10.395266150129862, 9.319779076665117, 10.878866142472981, 13.169329591412502, 13.49302637878938, 11.46709336780497, 8.930780129048994, 10.464893984660199, 8.972173012333956, 6.7655282606504885, 4.979584534950983, 3.6215962438925136, 2.9361602801869298, 0.0, 3.0183692848056274, 6.839682302352761, 7.304916597363667, 6.4331266068730235], [17.676617143107546, 17.145108404582, 15.447441796768539, 15.2707607488997, 15.637760441776258, 14.558543779432325, 14.363343273213218, 13.874681988337201, 10.745026007354681, 6.643880394729049, 4.082790924402878, 9.664638313314807, 12.789628041111431, 13.329842014608266, 12.912716428253747, 9.882813390309018, 7.1263399242344425, 3.7601786404150697, 4.85432236222465, 7.795489828941667, 9.951214214790392, 9.716519239050028, 11.932832234022243, 12.986250745531757, 14.419334964455299, 12.438212347119714, 8.92613459482988, 7.952754063366514, 6.505966496853139, 8.476516732772213, 12.167587371218872, 8.396932457468578, 5.3490006335167, 7.49763428605147, 12.815194380442215, 15.229517735159654, 17.040043342321063, 16.394835414909775, 14.955586211622682, 13.725963147666478, 12.62155166801204, 10.434218082120926, 8.195889267878838, 9.30061466387219, 10.054571544374454, 6.7390657688470315, 7.561650032553719, 12.540817138890349, 13.486539245739932, 10.758679077766738, 10.504990084900259, 9.283817740695103, 7.828426701836122, 5.6517989738542385, 2.5937793284759976, 3.640345797315567, 5.72558056891364, 8.862936826379972, 10.5379779752065, 11.138002857433445, 10.929987991790203, 11.179900344155856, 9.004540782669798, 4.628853402301843, 2.0695540584890253, 2.0743150431528887, 2.0422096589461556, 1.7369211615503433, 1.6181045625157482, 2.3736526270594553, 4.049077167739202, 7.154051959839234, 10.911858372645412, 13.060148084459712, 11.870412991974627, 13.594261162472788, 15.819555765676409, 16.021116819124927, 14.096463932612574, 11.569415476356173, 13.140522744785121, 11.613215961364693, 8.947163150730724, 7.2035446028570185, 6.051860553884809, 5.435346645063472, 3.0192081802280257, 0.0, 4.330000598767744, 4.707715156650357, 3.871321643278637], [20.147814209623146, 19.571834349117914, 18.283792565860523, 18.518796698423646, 18.907021763280163, 17.946453145868983, 17.732822986710705, 17.315955934582448, 14.113539925768068, 9.975408776602261, 1.8690755556977399, 6.065911421135124, 9.894644747690325, 10.551747029717289, 9.921284210725428, 6.653392452934021, 4.1932331100220415, 5.14565178985454, 8.35010462696772, 11.867243615176358, 13.83692944402525, 13.652072600786516, 15.561913398328894, 16.292598325277883, 17.575094514013035, 15.842326756790664, 12.719758143312323, 11.889067135605801, 8.253783907537853, 6.088481726162133, 8.761323664454293, 6.447739236817913, 7.553495705806558, 11.08819346823017, 15.845334898807673, 17.934036147270394, 19.477231893822594, 19.219580717233388, 18.12507984489721, 16.768268082180054, 15.972254561862288, 14.201431713125924, 12.271091812866036, 13.299507317934202, 13.944356228555591, 10.53371785527245, 11.150578843620515, 15.223835390192933, 16.231021547894514, 13.92377128410346, 13.939779609797153, 12.882511367671983, 11.013030821574747, 8.34992285577432, 2.2740655752412837, 2.2754077510482578, 8.621485318871017, 12.113161466125792, 13.719699394604495, 14.646961070005752, 14.48841014500092, 14.344618161027588, 11.974196055956535, 7.648998535565868, 3.005876611300445, 3.540708742378635, 3.5770066575455437, 3.3728295391718746, 3.6953755323737028, 5.917661817315064, 7.724665357392683, 11.185061082716562, 14.760912942693215, 16.479514340143034, 15.52284267731951, 16.887011395429493, 19.02969065018864, 19.25730120971969, 17.505191030238663, 15.27641422058216, 16.57253047704975, 15.227984374520341, 12.914306041418984, 11.111563955124742, 9.991088638972185, 9.426871674066618, 6.838186520393371, 4.333227595122509, 0.0, 1.117738654222282, 1.3587309935736993], [20.53866141581842, 19.932734930954442, 18.734000925440853, 18.878663300149228, 19.272184634051776, 18.399482015411227, 18.206918018532892, 17.753500767039583, 14.617916271223416, 10.42355240603748, 2.329543954839459, 5.84906246380832, 9.552642601492046, 10.222297617731646, 9.483700813917203, 6.296428065838718, 4.414082824809528, 5.763022252231696, 8.805244669097814, 12.207053404909692, 14.13232793754405, 13.980654825005574, 15.902830945537445, 16.683056246409627, 17.948569548017815, 16.24106733223343, 13.17569728631903, 12.338068085997602, 8.95631298771879, 6.0607854697967465, 8.20729893268784, 6.602703085672884, 8.071169272625692, 11.52459239684503, 16.291997743290835, 18.39786044435824, 19.828336110487612, 19.627037528928938, 18.449654319910245, 17.313202800325836, 16.401621970938237, 14.603323612052662, 12.62280086419584, 13.683563238553068, 14.349887279405895, 11.088756217145626, 11.569866741210559, 15.687375992215816, 16.567033199979594, 14.373636306149999, 14.37536950415483, 13.342772304229896, 11.542742509336408, 8.799276050134658, 2.696021655146105, 2.123134950967479, 9.054880645575091, 12.671849577643357, 14.241957237619484, 15.096287554763256, 14.978940289643441, 14.911290768453053, 12.615627222017096, 8.213609668196641, 3.3116739715537213, 3.8646890210524982, 3.9012649264096044, 3.7211826917115465, 4.046633440389811, 6.446691525813504, 8.204601805645726, 11.621959099578214, 15.240610888065579, 16.85779633852665, 15.807012742770134, 17.309878772306238, 19.388707933783465, 19.61746316902145, 17.931840409676642, 15.674778401486954, 16.950311801598215, 15.56454066067902, 13.275906107888204, 11.48576351867458, 10.378742451279788, 9.858577724253896, 7.32602634272742, 4.704136868191249, 1.117738654222282, 0.0, 1.2984518352600247], [20.181191467538248, 19.628791572499395, 18.18262110100331, 18.143032831003282, 18.484895864368323, 17.590521282825605, 17.487891247313655, 17.04590911505323, 14.044639162538322, 9.830667926078636, 2.406224192401004, 6.722387051731193, 10.355661047527718, 10.98215268970238, 10.238352964283782, 7.200328514033821, 5.041734707805158, 5.163172447679454, 7.9533093051063775, 11.24232045174384, 13.342287264229215, 13.052019157572351, 15.162572189364312, 15.944356901501706, 17.221015805242757, 15.596967675954222, 12.482905365372952, 11.49040010687884, 8.44215706243598, 6.757497609370752, 9.010302386074239, 7.245266077167356, 7.482475653029293, 10.96845611041585, 15.72383632792377, 17.788269392197858, 19.386531554632054, 19.06903359346374, 17.818586864471037, 16.761100056052108, 15.771199609409996, 13.871448407691025, 11.871350594778631, 12.897810652639986, 13.578802269568127, 10.317616836981061, 11.03027293059818, 15.199293040994833, 16.079877095481898, 13.827498079317644, 13.871659015861132, 12.737022957277391, 10.97207468036105, 8.401417205422023, 2.1466232486425207, 1.8489481015044598, 8.650978248671693, 12.055545441342732, 13.634644476052618, 14.449341348491952, 14.247187126567871, 14.277492552414838, 12.074186397962809, 7.69347059340281, 2.853579023490815, 3.409072031054033, 3.3952295954023506, 3.028764911469988, 3.483317243150467, 5.753524400350761, 7.5181891269849475, 10.768868157782423, 14.323320936254035, 16.112540240051135, 15.11809391679304, 16.65306211633354, 18.670871165833113, 18.748227248012462, 17.140891877746466, 14.962294027143178, 16.30265680630154, 14.950007711652212, 12.504430066370395, 10.605202506783282, 9.427312083922699, 8.871260146981255, 6.4335422080632805, 3.8657631608410936, 1.3587309935736993, 1.297195706414506, 0.0]]}],                        {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('94dd314f-0e14-4595-a9e4-14c5b2cf8072');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


Notice that how dramatically things can change when the metrics are
modified.

New distances in the embedding space: kNN graphs and geodesic distances
-----------------------------------------------------------------------

We propose here a new way to compute distances between points in the
embedding space. Instead of considering the Euclidean distance in the
Takens space, we propose to build a :math:`k`-nearest neighbors graph
and then use the geodesic distance on such graph.

.. code:: ipython3

    n_neighbors = 2
    kNN = KNeighborsGraph(n_neighbors=n_neighbors)
    
    X_kNN = kNN.fit_transform(X_embedded)

Given the graph embedding, the natural notion of distance between
vertices corresponds to the lengths of the shortest path connecting two
vertices. This is also known as *graph geodesic distance*. We compute it
and plot it for our chosen window number.

.. code:: ipython3

    GGD = GraphGeodesicDistance()
    
    GGD.fit_transform_plot(X_kNN, sample=window_number);



.. raw:: html

    <div>                            <div id="7bb435b1-4eab-4319-8e85-a1a07cd04273" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("7bb435b1-4eab-4319-8e85-a1a07cd04273")) {                    Plotly.newPlot(                        "7bb435b1-4eab-4319-8e85-a1a07cd04273",                        [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 1.0, 2.0, 2.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 9.0], [1.0, 0.0, 1.0, 2.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 10.0], [2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 10.0, 10.0], [2.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 9.0], [1.0, 2.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 8.0], [2.0, 3.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 7.0], [3.0, 4.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 6.0], [4.0, 5.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 5.0], [5.0, 6.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 4.0, 4.0], [6.0, 7.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 3.0, 3.0], [7.0, 8.0, 8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 2.0, 2.0], [8.0, 9.0, 9.0, 8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0, 1.0], [9.0, 10.0, 10.0, 9.0, 8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 0.0, 1.0], [9.0, 10.0, 10.0, 9.0, 8.0, 7.0, 6.0, 5.0, 4.0, 3.0, 2.0, 1.0, 1.0, 0.0]]}],                        {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "title": {"text": "3-th geodesic distance matrix"}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('7bb435b1-4eab-4319-8e85-a1a07cd04273');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>




.. parsed-literal::

    array([[[ 0.,  1.,  2.,  2.,  1.,  2.,  3.,  4.,  5.,  6.,  7.,  8.,
              9.,  9.],
            [ 1.,  0.,  1.,  2.,  2.,  3.,  4.,  5.,  6.,  7.,  8.,  9.,
             10., 10.],
            [ 2.,  1.,  0.,  1.,  2.,  3.,  4.,  5.,  6.,  7.,  8.,  9.,
             10., 10.],
            [ 2.,  2.,  1.,  0.,  1.,  2.,  3.,  4.,  5.,  6.,  7.,  8.,
              9.,  9.],
            [ 1.,  2.,  2.,  1.,  0.,  1.,  2.,  3.,  4.,  5.,  6.,  7.,
              8.,  8.],
            [ 2.,  3.,  3.,  2.,  1.,  0.,  1.,  2.,  3.,  4.,  5.,  6.,
              7.,  7.],
            [ 3.,  4.,  4.,  3.,  2.,  1.,  0.,  1.,  2.,  3.,  4.,  5.,
              6.,  6.],
            [ 4.,  5.,  5.,  4.,  3.,  2.,  1.,  0.,  1.,  2.,  3.,  4.,
              5.,  5.],
            [ 5.,  6.,  6.,  5.,  4.,  3.,  2.,  1.,  0.,  1.,  2.,  3.,
              4.,  4.],
            [ 6.,  7.,  7.,  6.,  5.,  4.,  3.,  2.,  1.,  0.,  1.,  2.,
              3.,  3.],
            [ 7.,  8.,  8.,  7.,  6.,  5.,  4.,  3.,  2.,  1.,  0.,  1.,
              2.,  2.],
            [ 8.,  9.,  9.,  8.,  7.,  6.,  5.,  4.,  3.,  2.,  1.,  0.,
              1.,  1.],
            [ 9., 10., 10.,  9.,  8.,  7.,  6.,  5.,  4.,  3.,  2.,  1.,
              0.,  1.],
            [ 9., 10., 10.,  9.,  8.,  7.,  6.,  5.,  4.,  3.,  2.,  1.,
              1.,  0.]]])



For comparison, this is what the ordinary pairwise Euclidean distance
matrix looks like for the same window:

.. code:: ipython3

    plot_heatmap(pairwise_distances(X_embedded[window_number]), colorscale='blues')



.. raw:: html

    <div>                            <div id="75233edb-b155-4855-aa0f-57f20750e515" class="plotly-graph-div" style="height:525px; width:100%;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("75233edb-b155-4855-aa0f-57f20750e515")) {                    Plotly.newPlot(                        "75233edb-b155-4855-aa0f-57f20750e515",                        [{"colorscale": [[0.0, "rgb(247,251,255)"], [0.125, "rgb(222,235,247)"], [0.25, "rgb(198,219,239)"], [0.375, "rgb(158,202,225)"], [0.5, "rgb(107,174,214)"], [0.625, "rgb(66,146,198)"], [0.75, "rgb(33,113,181)"], [0.875, "rgb(8,81,156)"], [1.0, "rgb(8,48,107)"]], "type": "heatmap", "z": [[0.0, 13.35400104522705, 27.24783706665039, 27.679216384887695, 26.57337760925293, 29.99872589111328, 33.72920608520508, 36.93894958496094, 35.818817138671875, 34.97959899902344, 35.342838287353516, 31.2563419342041, 29.68316078186035, 33.07707595825195], [13.35400104522705, 0.0, 14.200610160827637, 15.515490531921387, 16.51246452331543, 23.069135665893555, 28.996803283691406, 33.779319763183594, 33.77479553222656, 33.788330078125, 34.96614456176758, 31.868635177612305, 30.158823013305664, 31.461484909057617], [27.24783706665039, 14.200610160827637, 0.0, 7.32454252243042, 14.557328224182129, 23.690141677856445, 31.01677894592285, 36.8125114440918, 38.03731918334961, 38.89018630981445, 40.475975036621094, 38.32909393310547, 36.737884521484375, 36.332618713378906], [27.679216384887695, 15.515490531921387, 7.32454252243042, 0.0, 9.037556648254395, 19.341419219970703, 27.16861915588379, 33.61528396606445, 35.26842498779297, 36.446929931640625, 38.4437141418457, 36.772335052490234, 35.589080810546875, 35.76811599731445], [26.57337760925293, 16.51246452331543, 14.557328224182129, 9.037556648254395, 0.0, 10.829265594482422, 19.431554794311523, 27.46920394897461, 29.952110290527344, 31.82552146911621, 34.610382080078125, 33.511688232421875, 32.791072845458984, 33.603240966796875], [29.99872589111328, 23.069135665893555, 23.690141677856445, 19.341419219970703, 10.829265594482422, 0.0, 10.516725540161133, 21.4647159576416, 25.885887145996094, 29.417715072631836, 33.53140640258789, 33.5377082824707, 33.596275329589844, 34.90442657470703], [33.72920608520508, 28.996803283691406, 31.01677894592285, 27.16861915588379, 19.431554794311523, 10.516725540161133, 0.0, 12.20455265045166, 19.329652786254883, 25.60667610168457, 31.701379776000977, 33.088470458984375, 34.1364860534668, 36.12800216674805], [36.93894958496094, 33.779319763183594, 36.8125114440918, 33.61528396606445, 27.46920394897461, 21.4647159576416, 12.20455265045166, 0.0, 10.96535873413086, 20.523401260375977, 29.084556579589844, 32.10300064086914, 34.336788177490234, 37.154396057128906], [35.818817138671875, 33.77479553222656, 38.03731918334961, 35.26842498779297, 29.952110290527344, 25.885887145996094, 19.329652786254883, 10.96535873413086, 0.0, 11.520899772644043, 22.800588607788086, 27.64656639099121, 31.428300857543945, 35.51258850097656], [34.97959899902344, 33.788330078125, 38.89018630981445, 36.446929931640625, 31.82552146911621, 29.417715072631836, 25.60667610168457, 20.523401260375977, 11.520899772644043, 0.0, 12.556045532226562, 19.9498233795166, 26.361040115356445, 32.43656539916992], [35.342838287353516, 34.96614456176758, 40.475975036621094, 38.4437141418457, 34.610382080078125, 33.53140640258789, 31.701379776000977, 29.084556579589844, 22.800588607788086, 12.556045532226562, 0.0, 11.142565727233887, 20.786701202392578, 29.343582153320312], [31.2563419342041, 31.868635177612305, 38.32909393310547, 36.772335052490234, 33.511688232421875, 33.5377082824707, 33.088470458984375, 32.10300064086914, 27.64656639099121, 19.9498233795166, 11.142565727233887, 0.0, 11.59591293334961, 22.87957191467285], [29.68316078186035, 30.158823013305664, 36.737884521484375, 35.589080810546875, 32.791072845458984, 33.596275329589844, 34.1364860534668, 34.336788177490234, 31.428300857543945, 26.361040115356445, 20.786701202392578, 11.59591293334961, 0.0, 12.568832397460938], [33.07707595825195, 31.461484909057617, 36.332618713378906, 35.76811599731445, 33.603240966796875, 34.90442657470703, 36.12800216674805, 37.154396057128906, 35.51258850097656, 32.43656539916992, 29.343582153320312, 22.87957191467285, 12.568832397460938, 0.0]]}],                        {"plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "xaxis": {"constrain": "domain", "scaleanchor": "y"}, "yaxis": {"autorange": "reversed", "constrain": "domain"}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('75233edb-b155-4855-aa0f-57f20750e515');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


This is what the first few steps (before scaling and filtering) of the
pipeline described above would be if you’d like persistence diagrams to
be obtained using this new distance instead.

*Note*: ``WeakAlphaPersistence`` cannot be used now as it needs point
cloud input. We can use instead an instance of
``VietorisRipsPersistence``, but we have to take care to pass
``metric='precomputed'`` to the constructor!

.. code:: ipython3

    # Steps of the Pipeline
    steps = [
        ('sampling', periodicSampler),
        ('window', SW),
        ('embedding', TE),
        ('kNN_graph', kNN),
        ('graph_geo_distance', GGD),
        ('diagrams', VietorisRipsPersistence(metric='precomputed',
                                             homology_dimensions=homology_dimensions))
        ]
    
    # Define the Pipeline
    pipeline = Pipeline(steps)
    
    # Run the pipeline
    X_diagrams = pipeline.fit_transform(X)

Let’s look at the persistence diagrams obtained with this new distance:

.. code:: ipython3

    pipeline[-1].plot(X_diagrams, sample=window_number)



.. raw:: html

    <div>                            <div id="e6f3ce70-1d58-497e-8168-356589bbb49e" class="plotly-graph-div" style="height:500px; width:500px;"></div>            <script type="text/javascript">                require(["plotly"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById("e6f3ce70-1d58-497e-8168-356589bbb49e")) {                    Plotly.newPlot(                        "e6f3ce70-1d58-497e-8168-356589bbb49e",                        [{"hoverinfo": "none", "line": {"color": "black", "dash": "dash", "width": 1}, "mode": "lines", "showlegend": false, "type": "scatter", "x": [-0.04, 2.04], "y": [-0.04, 2.04]}, {"hoverinfo": "text", "hovertext": ["(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13", "(0.0, 1.0), multiplicity: 13"], "mode": "markers", "name": "H0", "type": "scatter", "x": [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0], "y": [1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0, 1.0]}, {"hoverinfo": "text", "hovertext": ["(1.0, 2.0)"], "mode": "markers", "name": "H1", "type": "scatter", "x": [1.0], "y": [2.0]}, {"hoverinfo": "text", "hovertext": [], "mode": "markers", "name": "H2", "type": "scatter", "x": [], "y": []}],                        {"height": 500, "plot_bgcolor": "white", "template": {"data": {"bar": [{"error_x": {"color": "#2a3f5f"}, "error_y": {"color": "#2a3f5f"}, "marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "bar"}], "barpolar": [{"marker": {"line": {"color": "#E5ECF6", "width": 0.5}}, "type": "barpolar"}], "carpet": [{"aaxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "baxis": {"endlinecolor": "#2a3f5f", "gridcolor": "white", "linecolor": "white", "minorgridcolor": "white", "startlinecolor": "#2a3f5f"}, "type": "carpet"}], "choropleth": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}], "contour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "contour"}], "contourcarpet": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}], "heatmap": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmap"}], "heatmapgl": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "heatmapgl"}], "histogram": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "histogram"}], "histogram2d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2d"}], "histogram2dcontour": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "histogram2dcontour"}], "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}], "parcoords": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "parcoords"}], "pie": [{"automargin": true, "type": "pie"}], "scatter": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter"}], "scatter3d": [{"line": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatter3d"}], "scattercarpet": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattercarpet"}], "scattergeo": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergeo"}], "scattergl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattergl"}], "scattermapbox": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scattermapbox"}], "scatterpolar": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolar"}], "scatterpolargl": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterpolargl"}], "scatterternary": [{"marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "type": "scatterternary"}], "surface": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "colorscale": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "type": "surface"}], "table": [{"cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}}, "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}}, "type": "table"}]}, "layout": {"annotationdefaults": {"arrowcolor": "#2a3f5f", "arrowhead": 0, "arrowwidth": 1}, "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}}, "colorscale": {"diverging": [[0, "#8e0152"], [0.1, "#c51b7d"], [0.2, "#de77ae"], [0.3, "#f1b6da"], [0.4, "#fde0ef"], [0.5, "#f7f7f7"], [0.6, "#e6f5d0"], [0.7, "#b8e186"], [0.8, "#7fbc41"], [0.9, "#4d9221"], [1, "#276419"]], "sequential": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]], "sequentialminus": [[0.0, "#0d0887"], [0.1111111111111111, "#46039f"], [0.2222222222222222, "#7201a8"], [0.3333333333333333, "#9c179e"], [0.4444444444444444, "#bd3786"], [0.5555555555555556, "#d8576b"], [0.6666666666666666, "#ed7953"], [0.7777777777777778, "#fb9f3a"], [0.8888888888888888, "#fdca26"], [1.0, "#f0f921"]]}, "colorway": ["#636efa", "#EF553B", "#00cc96", "#ab63fa", "#FFA15A", "#19d3f3", "#FF6692", "#B6E880", "#FF97FF", "#FECB52"], "font": {"color": "#2a3f5f"}, "geo": {"bgcolor": "white", "lakecolor": "white", "landcolor": "#E5ECF6", "showlakes": true, "showland": true, "subunitcolor": "white"}, "hoverlabel": {"align": "left"}, "hovermode": "closest", "mapbox": {"style": "light"}, "paper_bgcolor": "white", "plot_bgcolor": "#E5ECF6", "polar": {"angularaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "radialaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "scene": {"xaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "yaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}, "zaxis": {"backgroundcolor": "#E5ECF6", "gridcolor": "white", "gridwidth": 2, "linecolor": "white", "showbackground": true, "ticks": "", "zerolinecolor": "white"}}, "shapedefaults": {"line": {"color": "#2a3f5f"}}, "ternary": {"aaxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "baxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}, "bgcolor": "#E5ECF6", "caxis": {"gridcolor": "white", "linecolor": "white", "ticks": ""}}, "title": {"x": 0.05}, "xaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}, "yaxis": {"automargin": true, "gridcolor": "white", "linecolor": "white", "ticks": "", "title": {"standoff": 15}, "zerolinecolor": "white", "zerolinewidth": 2}}}, "width": 500, "xaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.04, 2.04], "showexponent": "all", "showline": true, "side": "bottom", "ticks": "outside", "title": {"text": "Birth"}, "type": "linear", "zeroline": true}, "yaxis": {"autorange": false, "exponentformat": "e", "linecolor": "black", "linewidth": 1, "mirror": false, "range": [-0.04, 2.04], "scaleanchor": "x", "scaleratio": 1, "showexponent": "all", "showline": true, "side": "left", "ticks": "outside", "title": {"text": "Death"}, "type": "linear", "zeroline": true}},                        {"responsive": true}                    ).then(function(){
    
    var gd = document.getElementById('e6f3ce70-1d58-497e-8168-356589bbb49e');
    var x = new MutationObserver(function (mutations, observer) {{
            var display = window.getComputedStyle(gd).display;
            if (!display || display === 'none') {{
                console.log([gd, 'removed!']);
                Plotly.purge(gd);
                observer.disconnect();
            }}
    }});
    
    // Listen for the removal of the full notebook cells
    var notebookContainer = gd.closest('#notebook-container');
    if (notebookContainer) {{
        x.observe(notebookContainer, {childList: true});
    }}
    
    // Listen for the clearing of the current output cell
    var outputEl = gd.closest('.output');
    if (outputEl) {{
        x.observe(outputEl, {childList: true});
    }}
    
                            })                };                });            </script>        </div>


